# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/esports/notify.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/broadcast/message/esports/notify.proto\x12\"bilibili.broadcast.message.esports\"\x15\n\x06Notify\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x62\x06proto3')



_NOTIFY = DESCRIPTOR.message_types_by_name['Notify']
Notify = _reflection.GeneratedProtocolMessageType('Notify', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFY,
  '__module__' : 'bilibili.broadcast.message.esports.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.esports.Notify)
  })
_sym_db.RegisterMessage(Notify)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFY._serialized_start=87
  _NOTIFY._serialized_end=108
# @@protoc_insertion_point(module_scope)
