# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/nativeact/v1/nativeact.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/app/nativeact/v1/nativeact.proto\x12\x19\x62ilibili.app.nativeact.v1\x1a\x19google/protobuf/any.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"?\n\x05\x42\x61\x64ge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x62g_color\x18\x02 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x03 \x01(\t\"d\n\x0f\x43\x61rouselImgCard\x12\x15\n\rcontent_style\x18\x01 \x01(\x03\x12:\n\x06images\x18\x02 \x03(\x0b\x32*.bilibili.app.nativeact.v1.CarouselImgItem\"\x90\x01\n\x0f\x43\x61rouselImgItem\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06length\x18\x03 \x01(\x03\x12\r\n\x05width\x18\x04 \x01(\x03\x12\x32\n\x07top_tab\x18\x05 \x01(\x0b\x32!.bilibili.app.nativeact.v1.TopTab\x12\x0e\n\x06height\x18\x06 \x01(\x03\"z\n\x10\x43\x61rouselWordCard\x12\x15\n\rcontent_style\x18\x01 \x01(\x03\x12\x13\n\x0bscroll_type\x18\x02 \x01(\x03\x12:\n\x05words\x18\x03 \x03(\x0b\x32+.bilibili.app.nativeact.v1.CarouselWordItem\"#\n\x10\x43\x61rouselWordItem\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\x98\x05\n\x05\x43olor\x12\x10\n\x08\x62g_color\x18\x01 \x01(\t\x12\x13\n\x0btitle_color\x18\x02 \x01(\t\x12\x16\n\x0etop_font_color\x18\x03 \x01(\t\x12\x19\n\x11\x62ottom_font_color\x18\x04 \x01(\t\x12\x12\n\nfont_color\x18\x05 \x01(\t\x12\x1d\n\x15text_title_font_color\x18\x06 \x01(\t\x12\x17\n\x0findicator_color\x18\x07 \x01(\t\x12\x15\n\rcard_bg_color\x18\x08 \x01(\t\x12\x1d\n\x15\x63\x61rd_title_font_color\x18\t \x01(\t\x12\x1b\n\x13\x63\x61rd_title_bg_color\x18\n \x01(\t\x12\x1c\n\x14view_more_font_color\x18\x0b \x01(\t\x12\x1a\n\x12view_more_bg_color\x18\x0c \x01(\t\x12\x16\n\x0etimeline_color\x18\r \x01(\t\x12\x17\n\x0frcmd_font_color\x18\x0e \x01(\t\x12\x1b\n\x13subtitle_font_color\x18\x0f \x01(\t\x12\x1b\n\x13selected_font_color\x18\x10 \x01(\t\x12\x19\n\x11selected_bg_color\x18\x11 \x01(\t\x12\x1d\n\x15unselected_font_color\x18\x12 \x01(\t\x12\x1b\n\x13unselected_bg_color\x18\x13 \x01(\t\x12\x1e\n\x16nt_selected_font_color\x18\x14 \x01(\t\x12\x1c\n\x14nt_selected_bg_color\x18\x15 \x01(\t\x12 \n\x18nt_unselected_font_color\x18\x16 \x01(\t\x12\x1e\n\x16nt_unselected_bg_color\x18\x17 \x01(\t\x12\x1a\n\x12progress_bar_color\x18\x18 \x01(\t\"m\n\x12\x44ynamicActMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"D\n\x0b\x44ynamicCard\x12\x35\n\x07\x64ynamic\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"j\n\x0f\x44ynamicMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"\x84\x01\n\rDynamicParams\x12)\n\x0b\x66\x65\x65\x64_offset\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x12\n\nlast_group\x18\x03 \x01(\x03\x12\x11\n\tmodule_id\x18\x04 \x01(\x03\x12\x11\n\tsort_type\x18\x05 \x01(\x03\"\xf7\x01\n\nDynamicReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.bilibili.app.nativeact.v1.DynamicParams\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x15\n\ris_cold_start\x18\x06 \x01(\x08\x12\x17\n\x0fprimary_page_id\x18\x07 \x01(\x03\"@\n\x0b\x44ynamicResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"1\n\x0c\x45\x64itorParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x11\n\tmodule_id\x18\x02 \x01(\x03\"\xfa\x03\n\x13\x45\x64itorRecommendCard\x12\x10\n\x08top_icon\x18\x01 \x01(\t\x12\x13\n\x0btop_content\x18\x02 \x01(\t\x12\x13\n\x0b\x62ottom_icon\x18\x03 \x01(\t\x12\x16\n\x0e\x62ottom_content\x18\x04 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x11\n\tposition1\x18\x08 \x01(\t\x12\x11\n\tposition2\x18\t \x01(\t\x12\x11\n\tposition3\x18\n \x01(\t\x12\x11\n\tposition4\x18\x0b \x01(\t\x12\x11\n\tposition5\x18\x0c \x01(\t\x12/\n\x05share\x18\r \x01(\x0b\x32 .bilibili.app.nativeact.v1.Share\x12/\n\x05\x62\x61\x64ge\x18\x0e \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\x0f \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x33\n\x07setting\x18\x10 \x01(\x0b\x32\".bilibili.app.nativeact.v1.Setting\x12\x13\n\x0bmiddle_icon\x18\x11 \x01(\t\x12\x15\n\rresource_type\x18\x12 \x01(\t\"q\n\tEditorReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.EditorParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"?\n\nEditorResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"X\n\x08GameCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\"\xca\x01\n\nHeaderCard\x12\x12\n\nuser_image\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\x17\n\x0fsponsor_content\x18\x03 \x01(\t\x12\x18\n\x10high_light_image\x18\x04 \x01(\t\x12\x17\n\x0flow_light_image\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08view_num\x18\x07 \x01(\t\x12\x13\n\x0b\x64iscuss_num\x18\x08 \x01(\t\x12\x15\n\ris_subscribed\x18\t \x01(\x08\"\x1f\n\x0eImageTitleCard\x12\r\n\x05image\x18\x01 \x01(\t\"\xde\x02\n\x08IndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_from\x18\x02 \x01(\t\x12\x12\n\ndynamic_id\x18\x03 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x04 \x01(\t\x12\x0e\n\x06tab_id\x18\x05 \x01(\x03\x12\x15\n\rtab_module_id\x18\x06 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x07 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x08 \x01(\t\x12\x13\n\x0b\x63urrent_tab\x18\t \x01(\t\x12\x43\n\x0bplayer_args\x18\n \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x0b \x01(\x05\x12\x15\n\ris_cold_start\x18\x0c \x01(\x08\x12\x17\n\x0fprimary_page_id\x18\r \x01(\x03\x12\x10\n\x08tab_from\x18\x0e \x01(\t\"\xbc\x01\n\x0eInlineIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x02 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x15\n\ris_cold_start\x18\x06 \x01(\x08\"T\n\x0cLayerDynamic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x35\n\x07\x64ynamic\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"R\n\x08LiveCard\x12\x10\n\x08has_live\x18\x01 \x01(\x05\x12\x34\n\x07\x63ontent\x18\x02 \x01(\x0b\x32#.bilibili.app.nativeact.v1.LiveItem\"\xb7\x02\n\x08LiveItem\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12\x13\n\x0blive_status\x18\x03 \x01(\x03\x12\x11\n\troom_type\x18\x04 \x01(\x03\x12\x11\n\tplay_type\x18\x05 \x01(\x03\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x63over\x18\x07 \x01(\t\x12\x0e\n\x06online\x18\x08 \x01(\x03\x12\x0f\n\x07\x61rea_id\x18\t \x01(\x03\x12\x11\n\tarea_name\x18\n \x01(\t\x12\x16\n\x0eparent_area_id\x18\x0b \x01(\x03\x12\x18\n\x10parent_area_name\x18\x0c \x01(\t\x12\x18\n\x10live_screen_type\x18\r \x01(\x03\x12\x15\n\rlast_end_time\x18\x0e \x01(\x03\x12\x0c\n\x04link\x18\x0f \x01(\t\x12\x0f\n\x07live_id\x18\x10 \x01(\x03\"\xb1\x02\n\x06Module\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\x03\x12\x36\n\x0cmodule_color\x18\x03 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Color\x12:\n\x0emodule_setting\x18\x04 \x01(\x0b\x32\".bilibili.app.nativeact.v1.Setting\x12;\n\x0cmodule_items\x18\x05 \x03(\x0b\x32%.bilibili.app.nativeact.v1.ModuleItem\x12\x16\n\x0esubpage_params\x18\x06 \x01(\t\x12\x13\n\x0bmodule_ukey\x18\x07 \x01(\t\x12\x10\n\x08has_more\x18\x08 \x01(\x08\x12\x0f\n\x07is_feed\x18\t \x01(\x08\"\xcf\t\n\nModuleItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61rd_id\x18\x02 \x01(\t\x12O\n\x15\x65\x64itor_recommend_card\x18\n \x01(\x0b\x32..bilibili.app.nativeact.v1.EditorRecommendCardH\x00\x12J\n\x12participation_card\x18\x0b \x01(\x0b\x32,.bilibili.app.nativeact.v1.ParticipationCardH\x00\x12<\n\x0bheader_card\x18\x0c \x01(\x0b\x32%.bilibili.app.nativeact.v1.HeaderCardH\x00\x12>\n\x0c\x64ynamic_card\x18\r \x01(\x0b\x32&.bilibili.app.nativeact.v1.DynamicCardH\x00\x12\x38\n\ttext_card\x18\x0e \x01(\x0b\x32#.bilibili.app.nativeact.v1.TextCardH\x00\x12\x43\n\x0ftext_title_card\x18\x0f \x01(\x0b\x32(.bilibili.app.nativeact.v1.TextTitleCardH\x00\x12\x45\n\x10image_title_card\x18\x10 \x01(\x0b\x32).bilibili.app.nativeact.v1.ImageTitleCardH\x00\x12G\n\x11\x64ynamic_more_card\x18\x11 \x01(\x0b\x32*.bilibili.app.nativeact.v1.DynamicMoreCardH\x00\x12N\n\x15\x64ynamic_act_more_card\x18\x12 \x01(\x0b\x32-.bilibili.app.nativeact.v1.DynamicActMoreCardH\x00\x12\x38\n\tlive_card\x18\x13 \x01(\x0b\x32#.bilibili.app.nativeact.v1.LiveCardH\x00\x12G\n\x11\x63\x61rousel_img_card\x18\x14 \x01(\x0b\x32*.bilibili.app.nativeact.v1.CarouselImgCardH\x00\x12I\n\x12\x63\x61rousel_word_card\x18\x15 \x01(\x0b\x32+.bilibili.app.nativeact.v1.CarouselWordCardH\x00\x12@\n\rresource_card\x18\x16 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.ResourceCardH\x00\x12I\n\x12resource_more_card\x18\x17 \x01(\x0b\x32+.bilibili.app.nativeact.v1.ResourceMoreCardH\x00\x12\x38\n\tgame_card\x18\x18 \x01(\x0b\x32#.bilibili.app.nativeact.v1.GameCardH\x00\x12:\n\nvideo_card\x18\x19 \x01(\x0b\x32$.bilibili.app.nativeact.v1.VideoCardH\x00\x12\x43\n\x0fvideo_more_card\x18\x1a \x01(\x0b\x32(.bilibili.app.nativeact.v1.VideoMoreCardH\x00\x42\r\n\x0b\x63\x61rd_detail\"\x91\x04\n\x08PageResp\x12\x11\n\tis_online\x18\x01 \x01(\x08\x12\x1d\n\x15ignore_app_dark_theme\x18\x02 \x01(\x08\x12\x34\n\npage_color\x18\x03 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Color\x12\x38\n\npage_share\x18\x04 \x01(\x0b\x32$.bilibili.app.nativeact.v1.PageShare\x12\x36\n\x0bpage_header\x18\x05 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x38\n\rparticipation\x18\x06 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x36\n\x0bmodule_list\x18\x07 \x03(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x17\n\x0fis_dynamic_feed\x18\x08 \x01(\x08\x12>\n\rlayer_dynamic\x18\t \x01(\x0b\x32\'.bilibili.app.nativeact.v1.LayerDynamic\x12\x16\n\x0eis_editor_feed\x18\n \x01(\x08\x12\x14\n\x0csponsor_type\x18\x0b \x01(\x03\x12\x32\n\x07top_tab\x18\x0c \x01(\x0b\x32!.bilibili.app.nativeact.v1.TopTab\"n\n\tPageShare\x12\x0c\n\x04type\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x12\n\ninside_uri\x18\x05 \x01(\t\x12\x13\n\x0boutside_uri\x18\x06 \x01(\t\"{\n\x11ParticipationCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\x16\n\x0eselected_image\x18\x02 \x01(\t\x12?\n\x05items\x18\x03 \x03(\x0b\x32\x30.bilibili.app.nativeact.v1.ParticipationCardItem\"P\n\x15ParticipationCardItem\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\"@\n\x0fPlayerDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x08\"\xa9\x01\n\tReportDic\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\t\x12\x13\n\x0bseason_type\x18\x02 \x01(\t\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\x10\n\x08sub_type\x18\x05 \x01(\x05\x12\r\n\x05\x65p_id\x18\x06 \x01(\x03\x12\x12\n\nis_preview\x18\x07 \x01(\x05\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x13\n\x0b\x61uthor_name\x18\t \x01(\t\"\xc7\x02\n\x0cResourceCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x06 \x01(\x03\x12\x18\n\x10\x63over_left_text2\x18\x07 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x08 \x01(\x03\x12/\n\x05\x62\x61\x64ge\x18\t \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\n \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x0b \x01(\t\"k\n\x10ResourceMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"\\\n\x0eResourceParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x14\n\x0ctopic_offset\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\x12\x11\n\tsort_type\x18\x04 \x01(\x03\"u\n\x0bResourceReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x39\n\x06params\x18\x02 \x01(\x0b\x32).bilibili.app.nativeact.v1.ResourceParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"A\n\x0cResourceResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"\xf3\x02\n\x07Setting\x12\x1b\n\x13\x64isplay_more_button\x18\x01 \x01(\x08\x12\x15\n\rdisplay_title\x18\x02 \x01(\x08\x12\x15\n\rauto_carousel\x18\x03 \x01(\x08\x12\x1a\n\x12top_tab_follow_img\x18\x04 \x01(\x08\x12\x19\n\x11top_tab_fade_away\x18\x05 \x01(\x08\x12\x11\n\tauto_play\x18\x06 \x01(\x08\x12\x1d\n\x15\x64isplay_unfold_button\x18\x07 \x01(\x08\x12\x13\n\x0b\x64isplay_num\x18\x08 \x01(\x08\x12\x18\n\x10\x64isplay_view_num\x18\t \x01(\x08\x12\x1d\n\x15\x64isplay_subscribe_btn\x18\n \x01(\x08\x12\x13\n\x0bunfold_rest\x18\x0b \x01(\x08\x12\x1c\n\x14\x64isplay_progress_num\x18\x0c \x01(\x08\x12\x18\n\x10\x64isplay_node_num\x18\r \x01(\x08\x12\x19\n\x11\x64isplay_node_desc\x18\x0e \x01(\x08\"U\n\x05Share\x12\x15\n\rdisplay_later\x18\x01 \x01(\x08\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x12\n\nshare_type\x18\x04 \x01(\x03\"a\n\x0bSubpageData\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\x12\x33\n\x04tabs\x18\x03 \x03(\x0b\x32%.bilibili.app.nativeact.v1.SubpageTab\"*\n\nSubpageTab\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\"\xd2\x01\n\x0bTabIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x02 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x17\n\x0fprimary_page_id\x18\x05 \x01(\x03\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x15\n\ris_cold_start\x18\x07 \x01(\x08\"\x18\n\x08TextCard\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x1e\n\rTextTitleCard\x12\r\n\x05title\x18\x01 \x01(\t\"\x9f\x01\n\x06TopTab\x12\x11\n\tbg_image1\x18\x01 \x01(\t\x12\x11\n\tbg_image2\x18\x02 \x01(\t\x12\x15\n\rtab_top_color\x18\x03 \x01(\t\x12\x18\n\x10tab_middle_color\x18\x04 \x01(\t\x12\x18\n\x10tab_bottom_color\x18\x05 \x01(\t\x12\x12\n\nfont_color\x18\x06 \x01(\t\x12\x10\n\x08\x62\x61r_type\x18\x07 \x01(\x03\"\xb8\x02\n\rTopicIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_from\x18\x02 \x01(\t\x12\x12\n\ndynamic_id\x18\x03 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x04 \x01(\t\x12\x0e\n\x06tab_id\x18\x05 \x01(\x03\x12\x15\n\rtab_module_id\x18\x06 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x07 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x08 \x01(\t\x12\x13\n\x0b\x63urrent_tab\x18\t \x01(\t\x12\x43\n\x0bplayer_args\x18\n \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x0b \x01(\x05\x12\x15\n\ris_cold_start\x18\x0c \x01(\x08\"\x87\x03\n\tVideoCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x03 \x01(\t\x12\x18\n\x10\x63over_left_text2\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text3\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x36\n\x06rights\x18\x08 \x01(\x0b\x32&.bilibili.app.nativeact.v1.VideoRights\x12=\n\tdimension\x18\t \x01(\x0b\x32*.bilibili.app.nativeact.v1.PlayerDimension\x12\x38\n\nreport_dic\x18\n \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x0b \x01(\t\"h\n\rVideoMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"Y\n\x0bVideoParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x14\n\x0ctopic_offset\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\x12\x11\n\tsort_type\x18\x04 \x01(\x03\"o\n\x08VideoReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32&.bilibili.app.nativeact.v1.VideoParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\">\n\tVideoResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"F\n\x0bVideoRights\x12\x0f\n\x07ugc_pay\x18\x01 \x01(\x08\x12\x16\n\x0eis_cooperation\x18\x02 \x01(\x08\x12\x0e\n\x06is_pgc\x18\x03 \x01(\x08\x62\x06proto3')



_BADGE = DESCRIPTOR.message_types_by_name['Badge']
_CAROUSELIMGCARD = DESCRIPTOR.message_types_by_name['CarouselImgCard']
_CAROUSELIMGITEM = DESCRIPTOR.message_types_by_name['CarouselImgItem']
_CAROUSELWORDCARD = DESCRIPTOR.message_types_by_name['CarouselWordCard']
_CAROUSELWORDITEM = DESCRIPTOR.message_types_by_name['CarouselWordItem']
_COLOR = DESCRIPTOR.message_types_by_name['Color']
_DYNAMICACTMORECARD = DESCRIPTOR.message_types_by_name['DynamicActMoreCard']
_DYNAMICCARD = DESCRIPTOR.message_types_by_name['DynamicCard']
_DYNAMICMORECARD = DESCRIPTOR.message_types_by_name['DynamicMoreCard']
_DYNAMICPARAMS = DESCRIPTOR.message_types_by_name['DynamicParams']
_DYNAMICREQ = DESCRIPTOR.message_types_by_name['DynamicReq']
_DYNAMICRESP = DESCRIPTOR.message_types_by_name['DynamicResp']
_EDITORPARAMS = DESCRIPTOR.message_types_by_name['EditorParams']
_EDITORRECOMMENDCARD = DESCRIPTOR.message_types_by_name['EditorRecommendCard']
_EDITORREQ = DESCRIPTOR.message_types_by_name['EditorReq']
_EDITORRESP = DESCRIPTOR.message_types_by_name['EditorResp']
_GAMECARD = DESCRIPTOR.message_types_by_name['GameCard']
_HEADERCARD = DESCRIPTOR.message_types_by_name['HeaderCard']
_IMAGETITLECARD = DESCRIPTOR.message_types_by_name['ImageTitleCard']
_INDEXREQ = DESCRIPTOR.message_types_by_name['IndexReq']
_INLINEINDEXREQ = DESCRIPTOR.message_types_by_name['InlineIndexReq']
_LAYERDYNAMIC = DESCRIPTOR.message_types_by_name['LayerDynamic']
_LIVECARD = DESCRIPTOR.message_types_by_name['LiveCard']
_LIVEITEM = DESCRIPTOR.message_types_by_name['LiveItem']
_MODULE = DESCRIPTOR.message_types_by_name['Module']
_MODULEITEM = DESCRIPTOR.message_types_by_name['ModuleItem']
_PAGERESP = DESCRIPTOR.message_types_by_name['PageResp']
_PAGESHARE = DESCRIPTOR.message_types_by_name['PageShare']
_PARTICIPATIONCARD = DESCRIPTOR.message_types_by_name['ParticipationCard']
_PARTICIPATIONCARDITEM = DESCRIPTOR.message_types_by_name['ParticipationCardItem']
_PLAYERDIMENSION = DESCRIPTOR.message_types_by_name['PlayerDimension']
_REPORTDIC = DESCRIPTOR.message_types_by_name['ReportDic']
_RESOURCECARD = DESCRIPTOR.message_types_by_name['ResourceCard']
_RESOURCEMORECARD = DESCRIPTOR.message_types_by_name['ResourceMoreCard']
_RESOURCEPARAMS = DESCRIPTOR.message_types_by_name['ResourceParams']
_RESOURCEREQ = DESCRIPTOR.message_types_by_name['ResourceReq']
_RESOURCERESP = DESCRIPTOR.message_types_by_name['ResourceResp']
_SETTING = DESCRIPTOR.message_types_by_name['Setting']
_SHARE = DESCRIPTOR.message_types_by_name['Share']
_SUBPAGEDATA = DESCRIPTOR.message_types_by_name['SubpageData']
_SUBPAGETAB = DESCRIPTOR.message_types_by_name['SubpageTab']
_TABINDEXREQ = DESCRIPTOR.message_types_by_name['TabIndexReq']
_TEXTCARD = DESCRIPTOR.message_types_by_name['TextCard']
_TEXTTITLECARD = DESCRIPTOR.message_types_by_name['TextTitleCard']
_TOPTAB = DESCRIPTOR.message_types_by_name['TopTab']
_TOPICINDEXREQ = DESCRIPTOR.message_types_by_name['TopicIndexReq']
_VIDEOCARD = DESCRIPTOR.message_types_by_name['VideoCard']
_VIDEOMORECARD = DESCRIPTOR.message_types_by_name['VideoMoreCard']
_VIDEOPARAMS = DESCRIPTOR.message_types_by_name['VideoParams']
_VIDEOREQ = DESCRIPTOR.message_types_by_name['VideoReq']
_VIDEORESP = DESCRIPTOR.message_types_by_name['VideoResp']
_VIDEORIGHTS = DESCRIPTOR.message_types_by_name['VideoRights']
Badge = _reflection.GeneratedProtocolMessageType('Badge', (_message.Message,), {
  'DESCRIPTOR' : _BADGE,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Badge)
  })
_sym_db.RegisterMessage(Badge)

CarouselImgCard = _reflection.GeneratedProtocolMessageType('CarouselImgCard', (_message.Message,), {
  'DESCRIPTOR' : _CAROUSELIMGCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.CarouselImgCard)
  })
_sym_db.RegisterMessage(CarouselImgCard)

CarouselImgItem = _reflection.GeneratedProtocolMessageType('CarouselImgItem', (_message.Message,), {
  'DESCRIPTOR' : _CAROUSELIMGITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.CarouselImgItem)
  })
_sym_db.RegisterMessage(CarouselImgItem)

CarouselWordCard = _reflection.GeneratedProtocolMessageType('CarouselWordCard', (_message.Message,), {
  'DESCRIPTOR' : _CAROUSELWORDCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.CarouselWordCard)
  })
_sym_db.RegisterMessage(CarouselWordCard)

CarouselWordItem = _reflection.GeneratedProtocolMessageType('CarouselWordItem', (_message.Message,), {
  'DESCRIPTOR' : _CAROUSELWORDITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.CarouselWordItem)
  })
_sym_db.RegisterMessage(CarouselWordItem)

Color = _reflection.GeneratedProtocolMessageType('Color', (_message.Message,), {
  'DESCRIPTOR' : _COLOR,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Color)
  })
_sym_db.RegisterMessage(Color)

DynamicActMoreCard = _reflection.GeneratedProtocolMessageType('DynamicActMoreCard', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICACTMORECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicActMoreCard)
  })
_sym_db.RegisterMessage(DynamicActMoreCard)

DynamicCard = _reflection.GeneratedProtocolMessageType('DynamicCard', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicCard)
  })
_sym_db.RegisterMessage(DynamicCard)

DynamicMoreCard = _reflection.GeneratedProtocolMessageType('DynamicMoreCard', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICMORECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicMoreCard)
  })
_sym_db.RegisterMessage(DynamicMoreCard)

DynamicParams = _reflection.GeneratedProtocolMessageType('DynamicParams', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICPARAMS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicParams)
  })
_sym_db.RegisterMessage(DynamicParams)

DynamicReq = _reflection.GeneratedProtocolMessageType('DynamicReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicReq)
  })
_sym_db.RegisterMessage(DynamicReq)

DynamicResp = _reflection.GeneratedProtocolMessageType('DynamicResp', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICRESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicResp)
  })
_sym_db.RegisterMessage(DynamicResp)

EditorParams = _reflection.GeneratedProtocolMessageType('EditorParams', (_message.Message,), {
  'DESCRIPTOR' : _EDITORPARAMS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.EditorParams)
  })
_sym_db.RegisterMessage(EditorParams)

EditorRecommendCard = _reflection.GeneratedProtocolMessageType('EditorRecommendCard', (_message.Message,), {
  'DESCRIPTOR' : _EDITORRECOMMENDCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.EditorRecommendCard)
  })
_sym_db.RegisterMessage(EditorRecommendCard)

EditorReq = _reflection.GeneratedProtocolMessageType('EditorReq', (_message.Message,), {
  'DESCRIPTOR' : _EDITORREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.EditorReq)
  })
_sym_db.RegisterMessage(EditorReq)

EditorResp = _reflection.GeneratedProtocolMessageType('EditorResp', (_message.Message,), {
  'DESCRIPTOR' : _EDITORRESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.EditorResp)
  })
_sym_db.RegisterMessage(EditorResp)

GameCard = _reflection.GeneratedProtocolMessageType('GameCard', (_message.Message,), {
  'DESCRIPTOR' : _GAMECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.GameCard)
  })
_sym_db.RegisterMessage(GameCard)

HeaderCard = _reflection.GeneratedProtocolMessageType('HeaderCard', (_message.Message,), {
  'DESCRIPTOR' : _HEADERCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.HeaderCard)
  })
_sym_db.RegisterMessage(HeaderCard)

ImageTitleCard = _reflection.GeneratedProtocolMessageType('ImageTitleCard', (_message.Message,), {
  'DESCRIPTOR' : _IMAGETITLECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ImageTitleCard)
  })
_sym_db.RegisterMessage(ImageTitleCard)

IndexReq = _reflection.GeneratedProtocolMessageType('IndexReq', (_message.Message,), {
  'DESCRIPTOR' : _INDEXREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.IndexReq)
  })
_sym_db.RegisterMessage(IndexReq)

InlineIndexReq = _reflection.GeneratedProtocolMessageType('InlineIndexReq', (_message.Message,), {
  'DESCRIPTOR' : _INLINEINDEXREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.InlineIndexReq)
  })
_sym_db.RegisterMessage(InlineIndexReq)

LayerDynamic = _reflection.GeneratedProtocolMessageType('LayerDynamic', (_message.Message,), {
  'DESCRIPTOR' : _LAYERDYNAMIC,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.LayerDynamic)
  })
_sym_db.RegisterMessage(LayerDynamic)

LiveCard = _reflection.GeneratedProtocolMessageType('LiveCard', (_message.Message,), {
  'DESCRIPTOR' : _LIVECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.LiveCard)
  })
_sym_db.RegisterMessage(LiveCard)

LiveItem = _reflection.GeneratedProtocolMessageType('LiveItem', (_message.Message,), {
  'DESCRIPTOR' : _LIVEITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.LiveItem)
  })
_sym_db.RegisterMessage(LiveItem)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Module)
  })
_sym_db.RegisterMessage(Module)

ModuleItem = _reflection.GeneratedProtocolMessageType('ModuleItem', (_message.Message,), {
  'DESCRIPTOR' : _MODULEITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ModuleItem)
  })
_sym_db.RegisterMessage(ModuleItem)

PageResp = _reflection.GeneratedProtocolMessageType('PageResp', (_message.Message,), {
  'DESCRIPTOR' : _PAGERESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.PageResp)
  })
_sym_db.RegisterMessage(PageResp)

PageShare = _reflection.GeneratedProtocolMessageType('PageShare', (_message.Message,), {
  'DESCRIPTOR' : _PAGESHARE,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.PageShare)
  })
_sym_db.RegisterMessage(PageShare)

ParticipationCard = _reflection.GeneratedProtocolMessageType('ParticipationCard', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPATIONCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ParticipationCard)
  })
_sym_db.RegisterMessage(ParticipationCard)

ParticipationCardItem = _reflection.GeneratedProtocolMessageType('ParticipationCardItem', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPATIONCARDITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ParticipationCardItem)
  })
_sym_db.RegisterMessage(ParticipationCardItem)

PlayerDimension = _reflection.GeneratedProtocolMessageType('PlayerDimension', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDIMENSION,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.PlayerDimension)
  })
_sym_db.RegisterMessage(PlayerDimension)

ReportDic = _reflection.GeneratedProtocolMessageType('ReportDic', (_message.Message,), {
  'DESCRIPTOR' : _REPORTDIC,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ReportDic)
  })
_sym_db.RegisterMessage(ReportDic)

ResourceCard = _reflection.GeneratedProtocolMessageType('ResourceCard', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceCard)
  })
_sym_db.RegisterMessage(ResourceCard)

ResourceMoreCard = _reflection.GeneratedProtocolMessageType('ResourceMoreCard', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEMORECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceMoreCard)
  })
_sym_db.RegisterMessage(ResourceMoreCard)

ResourceParams = _reflection.GeneratedProtocolMessageType('ResourceParams', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEPARAMS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceParams)
  })
_sym_db.RegisterMessage(ResourceParams)

ResourceReq = _reflection.GeneratedProtocolMessageType('ResourceReq', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceReq)
  })
_sym_db.RegisterMessage(ResourceReq)

ResourceResp = _reflection.GeneratedProtocolMessageType('ResourceResp', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCERESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceResp)
  })
_sym_db.RegisterMessage(ResourceResp)

Setting = _reflection.GeneratedProtocolMessageType('Setting', (_message.Message,), {
  'DESCRIPTOR' : _SETTING,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Setting)
  })
_sym_db.RegisterMessage(Setting)

Share = _reflection.GeneratedProtocolMessageType('Share', (_message.Message,), {
  'DESCRIPTOR' : _SHARE,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Share)
  })
_sym_db.RegisterMessage(Share)

SubpageData = _reflection.GeneratedProtocolMessageType('SubpageData', (_message.Message,), {
  'DESCRIPTOR' : _SUBPAGEDATA,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.SubpageData)
  })
_sym_db.RegisterMessage(SubpageData)

SubpageTab = _reflection.GeneratedProtocolMessageType('SubpageTab', (_message.Message,), {
  'DESCRIPTOR' : _SUBPAGETAB,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.SubpageTab)
  })
_sym_db.RegisterMessage(SubpageTab)

TabIndexReq = _reflection.GeneratedProtocolMessageType('TabIndexReq', (_message.Message,), {
  'DESCRIPTOR' : _TABINDEXREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TabIndexReq)
  })
_sym_db.RegisterMessage(TabIndexReq)

TextCard = _reflection.GeneratedProtocolMessageType('TextCard', (_message.Message,), {
  'DESCRIPTOR' : _TEXTCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TextCard)
  })
_sym_db.RegisterMessage(TextCard)

TextTitleCard = _reflection.GeneratedProtocolMessageType('TextTitleCard', (_message.Message,), {
  'DESCRIPTOR' : _TEXTTITLECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TextTitleCard)
  })
_sym_db.RegisterMessage(TextTitleCard)

TopTab = _reflection.GeneratedProtocolMessageType('TopTab', (_message.Message,), {
  'DESCRIPTOR' : _TOPTAB,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TopTab)
  })
_sym_db.RegisterMessage(TopTab)

TopicIndexReq = _reflection.GeneratedProtocolMessageType('TopicIndexReq', (_message.Message,), {
  'DESCRIPTOR' : _TOPICINDEXREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TopicIndexReq)
  })
_sym_db.RegisterMessage(TopicIndexReq)

VideoCard = _reflection.GeneratedProtocolMessageType('VideoCard', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoCard)
  })
_sym_db.RegisterMessage(VideoCard)

VideoMoreCard = _reflection.GeneratedProtocolMessageType('VideoMoreCard', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOMORECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoMoreCard)
  })
_sym_db.RegisterMessage(VideoMoreCard)

VideoParams = _reflection.GeneratedProtocolMessageType('VideoParams', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOPARAMS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoParams)
  })
_sym_db.RegisterMessage(VideoParams)

VideoReq = _reflection.GeneratedProtocolMessageType('VideoReq', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoReq)
  })
_sym_db.RegisterMessage(VideoReq)

VideoResp = _reflection.GeneratedProtocolMessageType('VideoResp', (_message.Message,), {
  'DESCRIPTOR' : _VIDEORESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoResp)
  })
_sym_db.RegisterMessage(VideoResp)

VideoRights = _reflection.GeneratedProtocolMessageType('VideoRights', (_message.Message,), {
  'DESCRIPTOR' : _VIDEORIGHTS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoRights)
  })
_sym_db.RegisterMessage(VideoRights)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BADGE._serialized_start=188
  _BADGE._serialized_end=251
  _CAROUSELIMGCARD._serialized_start=253
  _CAROUSELIMGCARD._serialized_end=353
  _CAROUSELIMGITEM._serialized_start=356
  _CAROUSELIMGITEM._serialized_end=500
  _CAROUSELWORDCARD._serialized_start=502
  _CAROUSELWORDCARD._serialized_end=624
  _CAROUSELWORDITEM._serialized_start=626
  _CAROUSELWORDITEM._serialized_end=661
  _COLOR._serialized_start=664
  _COLOR._serialized_end=1328
  _DYNAMICACTMORECARD._serialized_start=1330
  _DYNAMICACTMORECARD._serialized_end=1439
  _DYNAMICCARD._serialized_start=1441
  _DYNAMICCARD._serialized_end=1509
  _DYNAMICMORECARD._serialized_start=1511
  _DYNAMICMORECARD._serialized_end=1617
  _DYNAMICPARAMS._serialized_start=1620
  _DYNAMICPARAMS._serialized_end=1752
  _DYNAMICREQ._serialized_start=1755
  _DYNAMICREQ._serialized_end=2002
  _DYNAMICRESP._serialized_start=2004
  _DYNAMICRESP._serialized_end=2068
  _EDITORPARAMS._serialized_start=2070
  _EDITORPARAMS._serialized_end=2119
  _EDITORRECOMMENDCARD._serialized_start=2122
  _EDITORRECOMMENDCARD._serialized_end=2628
  _EDITORREQ._serialized_start=2630
  _EDITORREQ._serialized_end=2743
  _EDITORRESP._serialized_start=2745
  _EDITORRESP._serialized_end=2808
  _GAMECARD._serialized_start=2810
  _GAMECARD._serialized_end=2898
  _HEADERCARD._serialized_start=2901
  _HEADERCARD._serialized_end=3103
  _IMAGETITLECARD._serialized_start=3105
  _IMAGETITLECARD._serialized_end=3136
  _INDEXREQ._serialized_start=3139
  _INDEXREQ._serialized_end=3489
  _INLINEINDEXREQ._serialized_start=3492
  _INLINEINDEXREQ._serialized_end=3680
  _LAYERDYNAMIC._serialized_start=3682
  _LAYERDYNAMIC._serialized_end=3766
  _LIVECARD._serialized_start=3768
  _LIVECARD._serialized_end=3850
  _LIVEITEM._serialized_start=3853
  _LIVEITEM._serialized_end=4164
  _MODULE._serialized_start=4167
  _MODULE._serialized_end=4472
  _MODULEITEM._serialized_start=4475
  _MODULEITEM._serialized_end=5706
  _PAGERESP._serialized_start=5709
  _PAGERESP._serialized_end=6238
  _PAGESHARE._serialized_start=6240
  _PAGESHARE._serialized_end=6350
  _PARTICIPATIONCARD._serialized_start=6352
  _PARTICIPATIONCARD._serialized_end=6475
  _PARTICIPATIONCARDITEM._serialized_start=6477
  _PARTICIPATIONCARDITEM._serialized_end=6557
  _PLAYERDIMENSION._serialized_start=6559
  _PLAYERDIMENSION._serialized_end=6623
  _REPORTDIC._serialized_start=6626
  _REPORTDIC._serialized_end=6795
  _RESOURCECARD._serialized_start=6798
  _RESOURCECARD._serialized_end=7125
  _RESOURCEMORECARD._serialized_start=7127
  _RESOURCEMORECARD._serialized_end=7234
  _RESOURCEPARAMS._serialized_start=7236
  _RESOURCEPARAMS._serialized_end=7328
  _RESOURCEREQ._serialized_start=7330
  _RESOURCEREQ._serialized_end=7447
  _RESOURCERESP._serialized_start=7449
  _RESOURCERESP._serialized_end=7514
  _SETTING._serialized_start=7517
  _SETTING._serialized_end=7888
  _SHARE._serialized_start=7890
  _SHARE._serialized_end=7975
  _SUBPAGEDATA._serialized_start=7977
  _SUBPAGEDATA._serialized_end=8074
  _SUBPAGETAB._serialized_start=8076
  _SUBPAGETAB._serialized_end=8118
  _TABINDEXREQ._serialized_start=8121
  _TABINDEXREQ._serialized_end=8331
  _TEXTCARD._serialized_start=8333
  _TEXTCARD._serialized_end=8357
  _TEXTTITLECARD._serialized_start=8359
  _TEXTTITLECARD._serialized_end=8389
  _TOPTAB._serialized_start=8392
  _TOPTAB._serialized_end=8551
  _TOPICINDEXREQ._serialized_start=8554
  _TOPICINDEXREQ._serialized_end=8866
  _VIDEOCARD._serialized_start=8869
  _VIDEOCARD._serialized_end=9260
  _VIDEOMORECARD._serialized_start=9262
  _VIDEOMORECARD._serialized_end=9366
  _VIDEOPARAMS._serialized_start=9368
  _VIDEOPARAMS._serialized_end=9457
  _VIDEOREQ._serialized_start=9459
  _VIDEOREQ._serialized_end=9570
  _VIDEORESP._serialized_start=9572
  _VIDEORESP._serialized_end=9634
  _VIDEORIGHTS._serialized_start=9636
  _VIDEORIGHTS._serialized_end=9706
# @@protoc_insertion_point(module_scope)
