"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FawkesReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONFIG_FIELD_NUMBER: builtins.int
    FF_FIELD_NUMBER: builtins.int
    config: typing.Text
    """客户端在fawkes系统中对应的已发布最新的config版本号"""

    ff: typing.Text
    """客户端在fawkes系统中对应的已发布最新的ff版本号"""

    def __init__(self,
        *,
        config: typing.Text = ...,
        ff: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config",b"config","ff",b"ff"]) -> None: ...
global___FawkesReply = FawkesReply

class FawkesReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    APPKEY_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    appkey: typing.Text
    """客户端在fawkes系统的唯一名"""

    env: typing.Text
    """客户端在fawkes系统中的环境参数"""

    session_id: typing.Text
    """启动id"""

    def __init__(self,
        *,
        appkey: typing.Text = ...,
        env: typing.Text = ...,
        session_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["appkey",b"appkey","env",b"env","session_id",b"session_id"]) -> None: ...
global___FawkesReq = FawkesReq
