"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _GT14Status:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _GT14StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GT14Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LT14: _GT14Status.ValueType  # 0
    """"""

    GE14: _GT14Status.ValueType  # 1
    """"""

    UNKNOWN_GT14: _GT14Status.ValueType  # 2
    """"""

class GT14Status(_GT14Status, metaclass=_GT14StatusEnumTypeWrapper):
    """"""
    pass

LT14: GT14Status.ValueType  # 0
""""""

GE14: GT14Status.ValueType  # 1
""""""

UNKNOWN_GT14: GT14Status.ValueType  # 2
""""""

global___GT14Status = GT14Status


class _NFTStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _NFTStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NFTStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED: _NFTStatus.ValueType  # 0
    """"""

    NORMAL: _NFTStatus.ValueType  # 1
    """"""

    DOING: _NFTStatus.ValueType  # 2
    """"""

class NFTStatus(_NFTStatus, metaclass=_NFTStatusEnumTypeWrapper):
    """"""
    pass

UNDEFINED: NFTStatus.ValueType  # 0
""""""

NORMAL: NFTStatus.ValueType  # 1
""""""

DOING: NFTStatus.ValueType  # 2
""""""

global___NFTStatus = NFTStatus


class _PolicyAgreeStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PolicyAgreeStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PolicyAgreeStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSIGNED: _PolicyAgreeStatus.ValueType  # 0
    """"""

    ACCEPTED: _PolicyAgreeStatus.ValueType  # 1
    """"""

    EXPIRED: _PolicyAgreeStatus.ValueType  # 2
    """"""

class PolicyAgreeStatus(_PolicyAgreeStatus, metaclass=_PolicyAgreeStatusEnumTypeWrapper):
    """"""
    pass

UNSIGNED: PolicyAgreeStatus.ValueType  # 0
""""""

ACCEPTED: PolicyAgreeStatus.ValueType  # 1
""""""

EXPIRED: PolicyAgreeStatus.ValueType  # 2
""""""

global___PolicyAgreeStatus = PolicyAgreeStatus


class _PolicyType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PolicyTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PolicyType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_POLICY: _PolicyType.ValueType  # 0
    """"""

    WALLET: _PolicyType.ValueType  # 1
    """"""

    SALE: _PolicyType.ValueType  # 2
    """"""

class PolicyType(_PolicyType, metaclass=_PolicyTypeEnumTypeWrapper):
    """"""
    pass

UNKNOWN_POLICY: PolicyType.ValueType  # 0
""""""

WALLET: PolicyType.ValueType  # 1
""""""

SALE: PolicyType.ValueType  # 2
""""""

global___PolicyType = PolicyType


class AgreePolicyReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___AgreePolicyReply = AgreePolicyReply

class AgreePolicyReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    policy_type: global___PolicyType.ValueType
    """"""

    version: typing.Text
    """"""

    def __init__(self,
        *,
        policy_type: global___PolicyType.ValueType = ...,
        version: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_type",b"policy_type","version",b"version"]) -> None: ...
global___AgreePolicyReq = AgreePolicyReq

class BasicInfoReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CUSTOMER_SERVICE_URL_FIELD_NUMBER: builtins.int
    AGREEMENT_URL_FIELD_NUMBER: builtins.int
    PRIVACY_URL_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    customer_service_url: typing.Text
    """"""

    agreement_url: typing.Text
    """"""

    privacy_url: typing.Text
    """"""

    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Link]:
        """"""
        pass
    def __init__(self,
        *,
        customer_service_url: typing.Text = ...,
        agreement_url: typing.Text = ...,
        privacy_url: typing.Text = ...,
        links: typing.Optional[typing.Iterable[global___Link]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["agreement_url",b"agreement_url","customer_service_url",b"customer_service_url","links",b"links","privacy_url",b"privacy_url"]) -> None: ...
global___BasicInfoReply = BasicInfoReply

class BasicInfoReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid"]) -> None: ...
global___BasicInfoReq = BasicInfoReq

class Display(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BG_THEME_LIGHT_FIELD_NUMBER: builtins.int
    BG_THEME_NIGHT_FIELD_NUMBER: builtins.int
    NFT_POSTER_FIELD_NUMBER: builtins.int
    NFT_RAW_FIELD_NUMBER: builtins.int
    bg_theme_light: typing.Text
    """"""

    bg_theme_night: typing.Text
    """"""

    nft_poster: typing.Text
    """"""

    nft_raw: typing.Text
    """"""

    def __init__(self,
        *,
        bg_theme_light: typing.Text = ...,
        bg_theme_night: typing.Text = ...,
        nft_poster: typing.Text = ...,
        nft_raw: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_theme_light",b"bg_theme_light","bg_theme_night",b"bg_theme_night","nft_poster",b"nft_poster","nft_raw",b"nft_raw"]) -> None: ...
global___Display = Display

class GetLastPolicyReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHORT_DESC_FIELD_NUMBER: builtins.int
    DETAIL_JUMP_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    short_desc: typing.Text
    """"""

    detail_jump: typing.Text
    """"""

    version: typing.Text
    """"""

    def __init__(self,
        *,
        short_desc: typing.Text = ...,
        detail_jump: typing.Text = ...,
        version: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail_jump",b"detail_jump","short_desc",b"short_desc","version",b"version"]) -> None: ...
global___GetLastPolicyReply = GetLastPolicyReply

class GetLastPolicyReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    policy_type: global___PolicyType.ValueType
    """"""

    def __init__(self,
        *,
        policy_type: global___PolicyType.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_type",b"policy_type"]) -> None: ...
global___GetLastPolicyReq = GetLastPolicyReq

class GetUserInfoReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    AVATAR_URL_FIELD_NUMBER: builtins.int
    HELP_URL_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    name: typing.Text
    """"""

    address: typing.Text
    """"""

    avatar_url: typing.Text
    """"""

    help_url: typing.Text
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        address: typing.Text = ...,
        avatar_url: typing.Text = ...,
        help_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","avatar_url",b"avatar_url","help_url",b"help_url","mid",b"mid","name",b"name"]) -> None: ...
global___GetUserInfoReply = GetUserInfoReply

class GetUserInfoReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid"]) -> None: ...
global___GetUserInfoReq = GetUserInfoReq

class Link(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    TRACK_EVENT_ID_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    link_url: typing.Text
    """"""

    track_event_id: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        link_url: typing.Text = ...,
        track_event_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["link_url",b"link_url","name",b"name","track_event_id",b"track_event_id"]) -> None: ...
global___Link = Link

class ListNFTByMidReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NFTS_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def nfts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NFT]:
        """"""
        pass
    anchor_id: builtins.int
    """"""

    end: builtins.bool
    """"""

    def __init__(self,
        *,
        nfts: typing.Optional[typing.Iterable[global___NFT]] = ...,
        anchor_id: builtins.int = ...,
        end: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id",b"anchor_id","end",b"end","nfts",b"nfts"]) -> None: ...
global___ListNFTByMidReply = ListNFTByMidReply

class ListNFTByMidReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    category: typing.Text
    """"""

    biz_type: typing.Text
    """"""

    anchor_id: builtins.int
    """"""

    page_size: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        category: typing.Text = ...,
        biz_type: typing.Text = ...,
        anchor_id: builtins.int = ...,
        page_size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id",b"anchor_id","biz_type",b"biz_type","category",b"category","mid",b"mid","page_size",b"page_size"]) -> None: ...
global___ListNFTByMidReq = ListNFTByMidReq

class ListOrderByMidReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ORDERS_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def orders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Order]:
        """"""
        pass
    anchor_id: builtins.int
    """"""

    end: builtins.bool
    """"""

    def __init__(self,
        *,
        orders: typing.Optional[typing.Iterable[global___Order]] = ...,
        anchor_id: builtins.int = ...,
        end: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id",b"anchor_id","end",b"end","orders",b"orders"]) -> None: ...
global___ListOrderByMidReply = ListOrderByMidReply

class ListOrderByMidReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    anchor_id: builtins.int
    """"""

    page_size: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        anchor_id: builtins.int = ...,
        page_size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id",b"anchor_id","mid",b"mid","page_size",b"page_size"]) -> None: ...
global___ListOrderByMidReq = ListOrderByMidReq

class NFT(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NFT_ID_FIELD_NUMBER: builtins.int
    ITEM_NAME_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    DETAIL_URL_FIELD_NUMBER: builtins.int
    NFT_STATUS_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    nft_id: typing.Text
    """"""

    item_name: typing.Text
    """"""

    serial_number: typing.Text
    """"""

    issuer: typing.Text
    """"""

    @property
    def display(self) -> global___Display:
        """"""
        pass
    detail_url: typing.Text
    """"""

    nft_status: global___NFTStatus.ValueType
    """"""

    item_id: builtins.int
    """"""

    def __init__(self,
        *,
        nft_id: typing.Text = ...,
        item_name: typing.Text = ...,
        serial_number: typing.Text = ...,
        issuer: typing.Text = ...,
        display: typing.Optional[global___Display] = ...,
        detail_url: typing.Text = ...,
        nft_status: global___NFTStatus.ValueType = ...,
        item_id: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display",b"display"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail_url",b"detail_url","display",b"display","issuer",b"issuer","item_id",b"item_id","item_name",b"item_name","nft_id",b"nft_id","nft_status",b"nft_status","serial_number",b"serial_number"]) -> None: ...
global___NFT = NFT

class Order(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEM_NAME_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    TX_HASH_FIELD_NUMBER: builtins.int
    TX_TIME_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    ISSUE_TIME_FIELD_NUMBER: builtins.int
    TOKEN_ID_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    CONTRACT_ADDRESS_FIELD_NUMBER: builtins.int
    HASH_JUMP_FIELD_NUMBER: builtins.int
    CONTRACT_JUMP_FIELD_NUMBER: builtins.int
    DISABLE_BROWSER_JUMP_FIELD_NUMBER: builtins.int
    item_name: typing.Text
    """"""

    serial_number: typing.Text
    """"""

    tx_hash: typing.Text
    """"""

    tx_time: typing.Text
    """"""

    issuer: typing.Text
    """"""

    issue_time: typing.Text
    """"""

    token_id: typing.Text
    """"""

    @property
    def display(self) -> global___Display:
        """"""
        pass
    contract_address: typing.Text
    """"""

    hash_jump: typing.Text
    """"""

    contract_jump: typing.Text
    """"""

    disable_browser_jump: builtins.bool
    """"""

    def __init__(self,
        *,
        item_name: typing.Text = ...,
        serial_number: typing.Text = ...,
        tx_hash: typing.Text = ...,
        tx_time: typing.Text = ...,
        issuer: typing.Text = ...,
        issue_time: typing.Text = ...,
        token_id: typing.Text = ...,
        display: typing.Optional[global___Display] = ...,
        contract_address: typing.Text = ...,
        hash_jump: typing.Text = ...,
        contract_jump: typing.Text = ...,
        disable_browser_jump: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display",b"display"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contract_address",b"contract_address","contract_jump",b"contract_jump","disable_browser_jump",b"disable_browser_jump","display",b"display","hash_jump",b"hash_jump","issue_time",b"issue_time","issuer",b"issuer","item_name",b"item_name","serial_number",b"serial_number","token_id",b"token_id","tx_hash",b"tx_hash","tx_time",b"tx_time"]) -> None: ...
global___Order = Order

class UserCheckReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POLICY_STATUS_FIELD_NUMBER: builtins.int
    GT14_FIELD_NUMBER: builtins.int
    policy_status: builtins.int
    """"""

    gt14: builtins.int
    """"""

    def __init__(self,
        *,
        policy_status: builtins.int = ...,
        gt14: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gt14",b"gt14","policy_status",b"policy_status"]) -> None: ...
global___UserCheckReply = UserCheckReply

class UserCheckReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    policy_type: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        policy_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid","policy_type",b"policy_type"]) -> None: ...
global___UserCheckReq = UserCheckReq
