# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.view.v1 import view_pb2 as bilibili_dot_app_dot_view_dot_v1_dot_view__pb2


class ViewStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.View = channel.unary_unary(
                '/bilibili.app.view.v1.View/View',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReply.FromString,
                )
        self.ViewProgress = channel.unary_unary(
                '/bilibili.app.view.v1.View/ViewProgress',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReply.FromString,
                )
        self.ShortFormVideoDownload = channel.unary_unary(
                '/bilibili.app.view.v1.View/ShortFormVideoDownload',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReply.FromString,
                )
        self.ClickPlayerCard = channel.unary_unary(
                '/bilibili.app.view.v1.View/ClickPlayerCard',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickPlayerCardReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
                )
        self.ClickActivitySeason = channel.unary_unary(
                '/bilibili.app.view.v1.View/ClickActivitySeason',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickActivitySeasonReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
                )
        self.Season = channel.unary_unary(
                '/bilibili.app.view.v1.View/Season',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReply.FromString,
                )
        self.ExposePlayerCard = channel.unary_unary(
                '/bilibili.app.view.v1.View/ExposePlayerCard',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ExposePlayerCardReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
                )
        self.AddContract = channel.unary_unary(
                '/bilibili.app.view.v1.View/AddContract',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.AddContractReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
                )
        self.FeedView = channel.unary_unary(
                '/bilibili.app.view.v1.View/FeedView',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReply.FromString,
                )
        self.ChronosPkg = channel.unary_unary(
                '/bilibili.app.view.v1.View/ChronosPkg',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ChronosPkgReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.Chronos.FromString,
                )
        self.CacheView = channel.unary_unary(
                '/bilibili.app.view.v1.View/CacheView',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReply.FromString,
                )


class ViewServicer(object):
    """Missing associated documentation comment in .proto file."""

    def View(self, request, context):
        """视频页详情页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ViewProgress(self, request, context):
        """视频播放过程中的数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShortFormVideoDownload(self, request, context):
        """短视频下载
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClickPlayerCard(self, request, context):
        """点击播放器卡片事件
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClickActivitySeason(self, request, context):
        """点击大型活动页预约
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Season(self, request, context):
        """合集详情页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExposePlayerCard(self, request, context):
        """播放器卡片曝光
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddContract(self, request, context):
        """点击签订契约
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeedView(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChronosPkg(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CacheView(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ViewServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'View': grpc.unary_unary_rpc_method_handler(
                    servicer.View,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReply.SerializeToString,
            ),
            'ViewProgress': grpc.unary_unary_rpc_method_handler(
                    servicer.ViewProgress,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReply.SerializeToString,
            ),
            'ShortFormVideoDownload': grpc.unary_unary_rpc_method_handler(
                    servicer.ShortFormVideoDownload,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReply.SerializeToString,
            ),
            'ClickPlayerCard': grpc.unary_unary_rpc_method_handler(
                    servicer.ClickPlayerCard,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickPlayerCardReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.SerializeToString,
            ),
            'ClickActivitySeason': grpc.unary_unary_rpc_method_handler(
                    servicer.ClickActivitySeason,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickActivitySeasonReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.SerializeToString,
            ),
            'Season': grpc.unary_unary_rpc_method_handler(
                    servicer.Season,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReply.SerializeToString,
            ),
            'ExposePlayerCard': grpc.unary_unary_rpc_method_handler(
                    servicer.ExposePlayerCard,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ExposePlayerCardReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.SerializeToString,
            ),
            'AddContract': grpc.unary_unary_rpc_method_handler(
                    servicer.AddContract,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.AddContractReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.SerializeToString,
            ),
            'FeedView': grpc.unary_unary_rpc_method_handler(
                    servicer.FeedView,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReply.SerializeToString,
            ),
            'ChronosPkg': grpc.unary_unary_rpc_method_handler(
                    servicer.ChronosPkg,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ChronosPkgReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.Chronos.SerializeToString,
            ),
            'CacheView': grpc.unary_unary_rpc_method_handler(
                    servicer.CacheView,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.view.v1.View', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class View(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def View(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/View',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ViewProgress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ViewProgress',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShortFormVideoDownload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ShortFormVideoDownload',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClickPlayerCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ClickPlayerCard',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickPlayerCardReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClickActivitySeason(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ClickActivitySeason',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickActivitySeasonReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Season(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/Season',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExposePlayerCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ExposePlayerCard',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ExposePlayerCardReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/AddContract',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.AddContractReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeedView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/FeedView',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChronosPkg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ChronosPkg',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ChronosPkgReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.Chronos.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CacheView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/CacheView',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
