"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AddContractReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMMON_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    @property
    def common(self) -> global___CommonReq:
        """"""
        pass
    mid: builtins.int
    """"""

    up_mid: builtins.int
    """"""

    aid: builtins.int
    """"""

    def __init__(self,
        *,
        common: typing.Optional[global___CommonReq] = ...,
        mid: builtins.int = ...,
        up_mid: builtins.int = ...,
        aid: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["common",b"common"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","common",b"common","mid",b"mid","up_mid",b"up_mid"]) -> None: ...
global___AddContractReq = AddContractReq

class CommonReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLATFORM_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    platform: typing.Text
    """"""

    build: builtins.int
    """"""

    buvid: typing.Text
    """"""

    mobi_app: typing.Text
    """"""

    device: typing.Text
    """"""

    ip: typing.Text
    """"""

    spmid: typing.Text
    """"""

    def __init__(self,
        *,
        platform: typing.Text = ...,
        build: builtins.int = ...,
        buvid: typing.Text = ...,
        mobi_app: typing.Text = ...,
        device: typing.Text = ...,
        ip: typing.Text = ...,
        spmid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build",b"build","buvid",b"buvid","device",b"device","ip",b"ip","mobi_app",b"mobi_app","platform",b"platform","spmid",b"spmid"]) -> None: ...
global___CommonReq = CommonReq
