# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/note/sync.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/broadcast/message/note/sync.proto\x12\x1f\x62ilibili.broadcast.message.note\"%\n\x04Sync\x12\x0f\n\x07note_id\x18\x01 \x01(\x03\x12\x0c\n\x04hash\x18\x02 \x01(\tb\x06proto3')



_SYNC = DESCRIPTOR.message_types_by_name['Sync']
Sync = _reflection.GeneratedProtocolMessageType('Sync', (_message.Message,), {
  'DESCRIPTOR' : _SYNC,
  '__module__' : 'bilibili.broadcast.message.note.sync_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.note.Sync)
  })
_sym_db.RegisterMessage(Sync)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SYNC._serialized_start=79
  _SYNC._serialized_end=116
# @@protoc_insertion_point(module_scope)
