# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/api/probe/v1/probe.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/api/probe/v1/probe.proto\x12\x15\x62ilibili.api.probe.v1\"\x17\n\x07\x43odeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"\x0b\n\tCodeReply\"&\n\x08ProbeReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05\x62uvid\x18\x02 \x01(\t\"0\n\nProbeReply\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\"/\n\x0eProbeStreamReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"H\n\x10ProbeStreamReply\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\"\x1c\n\x0bProbeSubReq\x12\r\n\x05\x62uvid\x18\x01 \x01(\x03\"#\n\rProbeSubReply\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\x32\xd7\x02\n\x05Probe\x12L\n\x08TestCode\x12\x1e.bilibili.api.probe.v1.CodeReq\x1a .bilibili.api.probe.v1.CodeReply\x12M\n\x07TestReq\x12\x1f.bilibili.api.probe.v1.ProbeReq\x1a!.bilibili.api.probe.v1.ProbeReply\x12\\\n\nTestStream\x12%.bilibili.api.probe.v1.ProbeStreamReq\x1a\'.bilibili.api.probe.v1.ProbeStreamReply\x12S\n\x07TestSub\x12\".bilibili.api.probe.v1.ProbeSubReq\x1a$.bilibili.api.probe.v1.ProbeSubReplyb\x06proto3')



_CODEREQ = DESCRIPTOR.message_types_by_name['CodeReq']
_CODEREPLY = DESCRIPTOR.message_types_by_name['CodeReply']
_PROBEREQ = DESCRIPTOR.message_types_by_name['ProbeReq']
_PROBEREPLY = DESCRIPTOR.message_types_by_name['ProbeReply']
_PROBESTREAMREQ = DESCRIPTOR.message_types_by_name['ProbeStreamReq']
_PROBESTREAMREPLY = DESCRIPTOR.message_types_by_name['ProbeStreamReply']
_PROBESUBREQ = DESCRIPTOR.message_types_by_name['ProbeSubReq']
_PROBESUBREPLY = DESCRIPTOR.message_types_by_name['ProbeSubReply']
CodeReq = _reflection.GeneratedProtocolMessageType('CodeReq', (_message.Message,), {
  'DESCRIPTOR' : _CODEREQ,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.CodeReq)
  })
_sym_db.RegisterMessage(CodeReq)

CodeReply = _reflection.GeneratedProtocolMessageType('CodeReply', (_message.Message,), {
  'DESCRIPTOR' : _CODEREPLY,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.CodeReply)
  })
_sym_db.RegisterMessage(CodeReply)

ProbeReq = _reflection.GeneratedProtocolMessageType('ProbeReq', (_message.Message,), {
  'DESCRIPTOR' : _PROBEREQ,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeReq)
  })
_sym_db.RegisterMessage(ProbeReq)

ProbeReply = _reflection.GeneratedProtocolMessageType('ProbeReply', (_message.Message,), {
  'DESCRIPTOR' : _PROBEREPLY,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeReply)
  })
_sym_db.RegisterMessage(ProbeReply)

ProbeStreamReq = _reflection.GeneratedProtocolMessageType('ProbeStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _PROBESTREAMREQ,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeStreamReq)
  })
_sym_db.RegisterMessage(ProbeStreamReq)

ProbeStreamReply = _reflection.GeneratedProtocolMessageType('ProbeStreamReply', (_message.Message,), {
  'DESCRIPTOR' : _PROBESTREAMREPLY,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeStreamReply)
  })
_sym_db.RegisterMessage(ProbeStreamReply)

ProbeSubReq = _reflection.GeneratedProtocolMessageType('ProbeSubReq', (_message.Message,), {
  'DESCRIPTOR' : _PROBESUBREQ,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeSubReq)
  })
_sym_db.RegisterMessage(ProbeSubReq)

ProbeSubReply = _reflection.GeneratedProtocolMessageType('ProbeSubReply', (_message.Message,), {
  'DESCRIPTOR' : _PROBESUBREPLY,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeSubReply)
  })
_sym_db.RegisterMessage(ProbeSubReply)

_PROBE = DESCRIPTOR.services_by_name['Probe']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CODEREQ._serialized_start=60
  _CODEREQ._serialized_end=83
  _CODEREPLY._serialized_start=85
  _CODEREPLY._serialized_end=96
  _PROBEREQ._serialized_start=98
  _PROBEREQ._serialized_end=136
  _PROBEREPLY._serialized_start=138
  _PROBEREPLY._serialized_end=186
  _PROBESTREAMREQ._serialized_start=188
  _PROBESTREAMREQ._serialized_end=235
  _PROBESTREAMREPLY._serialized_start=237
  _PROBESTREAMREPLY._serialized_end=309
  _PROBESUBREQ._serialized_start=311
  _PROBESUBREQ._serialized_end=339
  _PROBESUBREPLY._serialized_start=341
  _PROBESUBREPLY._serialized_end=376
  _PROBE._serialized_start=379
  _PROBE._serialized_end=722
# @@protoc_insertion_point(module_scope)
