"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RuleRequest(google.protobuf.message.Message):
    """获取免流规则信息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RuleRequest = RuleRequest

class RulesReply(google.protobuf.message.Message):
    """获取免流规则信息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class RulesInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___RulesInfo: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___RulesInfo] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    RULESINFO_FIELD_NUMBER: builtins.int
    @property
    def rulesInfo(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___RulesInfo]:
        """各ISP的免流规则信息组
        ISP如: cu ct cm
        """
        pass
    def __init__(self,
        *,
        rulesInfo: typing.Optional[typing.Mapping[typing.Text, global___RulesInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rulesInfo",b"rulesInfo"]) -> None: ...
global___RulesReply = RulesReply

class RuleInfo(google.protobuf.message.Message):
    """免流规则信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TF_FIELD_NUMBER: builtins.int
    M_FIELD_NUMBER: builtins.int
    A_FIELD_NUMBER: builtins.int
    P_FIELD_NUMBER: builtins.int
    tf: builtins.bool
    """是否支持免流"""

    m: typing.Text
    """操作模式
    break:无 replace:替换 proxy:代理
    """

    a: typing.Text
    """操作参数"""

    p: typing.Text
    """匹配目标正则"""

    def __init__(self,
        *,
        tf: builtins.bool = ...,
        m: typing.Text = ...,
        a: typing.Text = ...,
        p: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["a",b"a","m",b"m","p",b"p","tf",b"tf"]) -> None: ...
global___RuleInfo = RuleInfo

class RulesInfo(google.protobuf.message.Message):
    """免流规则信息组"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RULESINFO_FIELD_NUMBER: builtins.int
    @property
    def rulesInfo(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleInfo]:
        """免流规则信息"""
        pass
    def __init__(self,
        *,
        rulesInfo: typing.Optional[typing.Iterable[global___RuleInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rulesInfo",b"rulesInfo"]) -> None: ...
global___RulesInfo = RulesInfo
