# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/live/general/interfaces/v1/interfaces.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4bilibili/live/general/interfaces/v1/interfaces.proto\x12#bilibili.live.general.interfaces.v1\"d\n\x10GetOnlineRankReq\x12\x0c\n\x04ruid\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\x12\x11\n\tpage_size\x18\x04 \x01(\x03\x12\x10\n\x08platform\x18\x05 \x01(\t\"\xaa\x02\n\x11GetOnlineRankResp\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.bilibili.live.general.interfaces.v1.GetOnlineRankResp.OnlineRankItem\x12\x12\n\nonline_num\x18\x02 \x01(\x03\x1a\xab\x01\n\x0eOnlineRankItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x16\n\x0e\x63ontinue_watch\x18\x04 \x01(\x03\x12\x42\n\nmedal_info\x18\x05 \x01(\x0b\x32..bilibili.live.general.interfaces.v1.MedalInfo\x12\x13\n\x0bguard_level\x18\x06 \x01(\x03\"\xb8\x01\n\tMedalInfo\x12\x13\n\x0bguard_level\x18\x01 \x01(\x03\x12\x19\n\x11medal_color_start\x18\x02 \x01(\x03\x12\x17\n\x0fmedal_color_end\x18\x03 \x01(\x03\x12\x1a\n\x12medal_color_border\x18\x04 \x01(\x03\x12\x12\n\nmedal_name\x18\x05 \x01(\t\x12\r\n\x05level\x18\x06 \x01(\x03\x12\x11\n\ttarget_id\x18\x07 \x01(\x03\x12\x10\n\x08is_light\x18\x08 \x01(\x03\x62\x06proto3')



_GETONLINERANKREQ = DESCRIPTOR.message_types_by_name['GetOnlineRankReq']
_GETONLINERANKRESP = DESCRIPTOR.message_types_by_name['GetOnlineRankResp']
_GETONLINERANKRESP_ONLINERANKITEM = _GETONLINERANKRESP.nested_types_by_name['OnlineRankItem']
_MEDALINFO = DESCRIPTOR.message_types_by_name['MedalInfo']
GetOnlineRankReq = _reflection.GeneratedProtocolMessageType('GetOnlineRankReq', (_message.Message,), {
  'DESCRIPTOR' : _GETONLINERANKREQ,
  '__module__' : 'bilibili.live.general.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.live.general.interfaces.v1.GetOnlineRankReq)
  })
_sym_db.RegisterMessage(GetOnlineRankReq)

GetOnlineRankResp = _reflection.GeneratedProtocolMessageType('GetOnlineRankResp', (_message.Message,), {

  'OnlineRankItem' : _reflection.GeneratedProtocolMessageType('OnlineRankItem', (_message.Message,), {
    'DESCRIPTOR' : _GETONLINERANKRESP_ONLINERANKITEM,
    '__module__' : 'bilibili.live.general.interfaces.v1.interfaces_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.live.general.interfaces.v1.GetOnlineRankResp.OnlineRankItem)
    })
  ,
  'DESCRIPTOR' : _GETONLINERANKRESP,
  '__module__' : 'bilibili.live.general.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.live.general.interfaces.v1.GetOnlineRankResp)
  })
_sym_db.RegisterMessage(GetOnlineRankResp)
_sym_db.RegisterMessage(GetOnlineRankResp.OnlineRankItem)

MedalInfo = _reflection.GeneratedProtocolMessageType('MedalInfo', (_message.Message,), {
  'DESCRIPTOR' : _MEDALINFO,
  '__module__' : 'bilibili.live.general.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.live.general.interfaces.v1.MedalInfo)
  })
_sym_db.RegisterMessage(MedalInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETONLINERANKREQ._serialized_start=93
  _GETONLINERANKREQ._serialized_end=193
  _GETONLINERANKRESP._serialized_start=196
  _GETONLINERANKRESP._serialized_end=494
  _GETONLINERANKRESP_ONLINERANKITEM._serialized_start=323
  _GETONLINERANKRESP_ONLINERANKITEM._serialized_end=494
  _MEDALINFO._serialized_start=497
  _MEDALINFO._serialized_end=681
# @@protoc_insertion_point(module_scope)
