"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.broadcast.message.main.native_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetActProgressReq(google.protobuf.message.Message):
    """获取Native页进度数据-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGEID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    pageID: builtins.int
    """Native页id"""

    mid: builtins.int
    """用户mid"""

    def __init__(self,
        *,
        pageID: builtins.int = ...,
        mid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid","pageID",b"pageID"]) -> None: ...
global___GetActProgressReq = GetActProgressReq

class GetActProgressReply(google.protobuf.message.Message):
    """获取Native页进度数据-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVENT_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> bilibili.broadcast.message.main.native_pb2.NativePageEvent:
        """进度数据"""
        pass
    def __init__(self,
        *,
        event: typing.Optional[bilibili.broadcast.message.main.native_pb2.NativePageEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event",b"event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event",b"event"]) -> None: ...
global___GetActProgressReply = GetActProgressReply
