# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/interfaces/v1/space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.app.archive.v1 import archive_pb2 as bilibili_dot_app_dot_archive_dot_v1_dot_archive__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&bilibili/app/interfaces/v1/space.proto\x12\x1a\x62ilibili.app.interfaces.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a%bilibili/app/archive/v1/archive.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\"A\n\x03\x41rc\x12-\n\x07\x61rchive\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12\x0b\n\x03uri\x18\x02 \x01(\t\"@\n\x07\x44ynamic\x12\x35\n\x07\x64ynamic\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"N\n\x0eSearchTabReply\x12\r\n\x05\x66ocus\x18\x01 \x01(\x03\x12-\n\x04tabs\x18\x02 \x03(\x0b\x32\x1f.bilibili.app.interfaces.v1.Tab\":\n\x0cSearchTabReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x03 \x01(\x05\"V\n\x12SearchArchiveReply\x12\x31\n\x08\x61rchives\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.interfaces.v1.Arc\x12\r\n\x05total\x18\x02 \x01(\x03\"\x8d\x01\n\x10SearchArchiveReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\n\n\x02pn\x18\x03 \x01(\x03\x12\n\n\x02ps\x18\x04 \x01(\x03\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"Z\n\x12SearchDynamicReply\x12\x35\n\x08\x64ynamics\x18\x01 \x03(\x0b\x32#.bilibili.app.interfaces.v1.Dynamic\x12\r\n\x05total\x18\x02 \x01(\x03\"\x8d\x01\n\x10SearchDynamicReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\n\n\x02pn\x18\x03 \x01(\x03\x12\n\n\x02ps\x18\x04 \x01(\x03\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"!\n\x03Tab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t*&\n\x04\x46rom\x12\x0e\n\nArchiveTab\x10\x00\x12\x0e\n\nDynamicTab\x10\x01\x32\xc8\x02\n\x05Space\x12\x61\n\tSearchTab\x12(.bilibili.app.interfaces.v1.SearchTabReq\x1a*.bilibili.app.interfaces.v1.SearchTabReply\x12m\n\rSearchArchive\x12,.bilibili.app.interfaces.v1.SearchArchiveReq\x1a..bilibili.app.interfaces.v1.SearchArchiveReply\x12m\n\rSearchDynamic\x12,.bilibili.app.interfaces.v1.SearchDynamicReq\x1a..bilibili.app.interfaces.v1.SearchDynamicReplyb\x06proto3')

_FROM = DESCRIPTOR.enum_types_by_name['From']
From = enum_type_wrapper.EnumTypeWrapper(_FROM)
ArchiveTab = 0
DynamicTab = 1


_ARC = DESCRIPTOR.message_types_by_name['Arc']
_DYNAMIC = DESCRIPTOR.message_types_by_name['Dynamic']
_SEARCHTABREPLY = DESCRIPTOR.message_types_by_name['SearchTabReply']
_SEARCHTABREQ = DESCRIPTOR.message_types_by_name['SearchTabReq']
_SEARCHARCHIVEREPLY = DESCRIPTOR.message_types_by_name['SearchArchiveReply']
_SEARCHARCHIVEREQ = DESCRIPTOR.message_types_by_name['SearchArchiveReq']
_SEARCHDYNAMICREPLY = DESCRIPTOR.message_types_by_name['SearchDynamicReply']
_SEARCHDYNAMICREQ = DESCRIPTOR.message_types_by_name['SearchDynamicReq']
_TAB = DESCRIPTOR.message_types_by_name['Tab']
Arc = _reflection.GeneratedProtocolMessageType('Arc', (_message.Message,), {
  'DESCRIPTOR' : _ARC,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Arc)
  })
_sym_db.RegisterMessage(Arc)

Dynamic = _reflection.GeneratedProtocolMessageType('Dynamic', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMIC,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Dynamic)
  })
_sym_db.RegisterMessage(Dynamic)

SearchTabReply = _reflection.GeneratedProtocolMessageType('SearchTabReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHTABREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchTabReply)
  })
_sym_db.RegisterMessage(SearchTabReply)

SearchTabReq = _reflection.GeneratedProtocolMessageType('SearchTabReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHTABREQ,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchTabReq)
  })
_sym_db.RegisterMessage(SearchTabReq)

SearchArchiveReply = _reflection.GeneratedProtocolMessageType('SearchArchiveReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHARCHIVEREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchArchiveReply)
  })
_sym_db.RegisterMessage(SearchArchiveReply)

SearchArchiveReq = _reflection.GeneratedProtocolMessageType('SearchArchiveReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHARCHIVEREQ,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchArchiveReq)
  })
_sym_db.RegisterMessage(SearchArchiveReq)

SearchDynamicReply = _reflection.GeneratedProtocolMessageType('SearchDynamicReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHDYNAMICREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchDynamicReply)
  })
_sym_db.RegisterMessage(SearchDynamicReply)

SearchDynamicReq = _reflection.GeneratedProtocolMessageType('SearchDynamicReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHDYNAMICREQ,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchDynamicReq)
  })
_sym_db.RegisterMessage(SearchDynamicReq)

Tab = _reflection.GeneratedProtocolMessageType('Tab', (_message.Message,), {
  'DESCRIPTOR' : _TAB,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Tab)
  })
_sym_db.RegisterMessage(Tab)

_SPACE = DESCRIPTOR.services_by_name['Space']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FROM._serialized_start=974
  _FROM._serialized_end=1012
  _ARC._serialized_start=198
  _ARC._serialized_end=263
  _DYNAMIC._serialized_start=265
  _DYNAMIC._serialized_end=329
  _SEARCHTABREPLY._serialized_start=331
  _SEARCHTABREPLY._serialized_end=409
  _SEARCHTABREQ._serialized_start=411
  _SEARCHTABREQ._serialized_end=469
  _SEARCHARCHIVEREPLY._serialized_start=471
  _SEARCHARCHIVEREPLY._serialized_end=557
  _SEARCHARCHIVEREQ._serialized_start=560
  _SEARCHARCHIVEREQ._serialized_end=701
  _SEARCHDYNAMICREPLY._serialized_start=703
  _SEARCHDYNAMICREPLY._serialized_end=793
  _SEARCHDYNAMICREQ._serialized_start=796
  _SEARCHDYNAMICREQ._serialized_end=937
  _TAB._serialized_start=939
  _TAB._serialized_end=972
  _SPACE._serialized_start=1015
  _SPACE._serialized_end=1343
# @@protoc_insertion_point(module_scope)
