# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/im/interfaces/v1/im.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.im.type import im_pb2 as bilibili_dot_im_dot_type_dot_im__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"bilibili/im/interfaces/v1/im.proto\x12\x19\x62ilibili.im.interfaces.v1\x1a\x19\x62ilibili/im/type/im.proto\"\x17\n\x08\x44ummyReq\x12\x0b\n\x03idl\x18\x01 \x01(\r\"\x10\n\x08\x44ummyRspJ\x04\x08\x01\x10\x02\"G\n\x0b\x45motionInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12\x0f\n\x07gif_url\x18\x04 \x01(\t\"+\n\tMsgDetail\x12\x0f\n\x07msg_key\x18\x01 \x01(\x03\x12\r\n\x05seqno\x18\x02 \x01(\x03\"\x8a\x01\n\x10MsgFeedUnreadRsp\x12G\n\x06unread\x18\x01 \x03(\x0b\x32\x37.bilibili.im.interfaces.v1.MsgFeedUnreadRsp.UnreadEntry\x1a-\n\x0bUnreadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"#\n\x0eReqAckAssisMsg\x12\x11\n\tack_seqno\x18\x01 \x01(\x04\"@\n\x0eReqAckSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x02 \x01(\r\x12\x0c\n\x04size\x18\x03 \x01(\r\"\x0e\n\x0cReqBatRmSess\"\x17\n\x15ReqCloseClearUnreadUI\"n\n\tReqGetMsg\x12\x11\n\ttalker_id\x18\x01 \x01(\x03\x12\x14\n\x0csession_type\x18\x02 \x01(\x05\x12\x38\n\nmsg_detail\x18\x03 \x03(\x0b\x32$.bilibili.im.interfaces.v1.MsgDetail\"\xc1\x01\n\x0eReqGetSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\r\x12\x14\n\x0csession_type\x18\x04 \x01(\r\x12\x15\n\runfollow_fold\x18\x05 \x01(\r\x12\x12\n\ngroup_fold\x18\x06 \x01(\r\x12\x11\n\tsort_rule\x18\x07 \x01(\r\x12\x15\n\rteenager_mode\x18\x08 \x01(\r\x12\x14\n\x0clessons_mode\x18\t \x01(\r\"[\n\x16ReqGetSpecificSessions\x12\x41\n\x0ftalker_sessions\x18\x01 \x03(\x0b\x32(.bilibili.im.interfaces.v1.SimpleSession\"6\n\x10ReqGroupAssisMsg\x12\x14\n\x0c\x63lient_seqno\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\r\"-\n\x0bReqLiveInfo\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\ttalker_id\x18\x02 \x01(\x03\"]\n\x0eReqNewSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x15\n\rteenager_mode\x18\x03 \x01(\r\x12\x14\n\x0clessons_mode\x18\x04 \x01(\r\"6\n\x0fReqRelationSync\x12#\n\x1b\x63lient_relation_oplog_seqno\x18\x01 \x01(\x04\";\n\x10ReqRemoveSession\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\"u\n\nReqSendMsg\x12\"\n\x03msg\x18\x01 \x01(\x0b\x32\x15.bilibili.im.type.Msg\x12\x0e\n\x06\x63ookie\x18\x02 \x01(\t\x12\x0f\n\x07\x63ookie2\x18\x03 \x01(\t\x12\x12\n\nerror_code\x18\x04 \x01(\x05\x12\x0e\n\x06\x64\x65v_id\x18\x05 \x01(\t\"H\n\x10ReqSessionDetail\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x0b\n\x03uid\x18\x03 \x01(\x04\"R\n\x11ReqSessionDetails\x12=\n\x08sess_ids\x18\x01 \x03(\x0b\x32+.bilibili.im.interfaces.v1.ReqSessionDetail\"\x8d\x01\n\rReqSessionMsg\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\x05\x12\x11\n\tend_seqno\x18\x03 \x01(\x04\x12\x13\n\x0b\x62\x65gin_seqno\x18\x04 \x01(\x04\x12\x0c\n\x04size\x18\x05 \x01(\x05\x12\r\n\x05order\x18\x06 \x01(\x05\x12\x0e\n\x06\x64\x65v_id\x18\x07 \x01(\t\"E\n\tReqSetTop\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x0f\n\x07op_type\x18\x03 \x01(\r\"\x1c\n\x0cReqShareList\x12\x0c\n\x04size\x18\x01 \x01(\x05\"]\n\x14ReqShowClearUnreadUI\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\"e\n\x0fReqSingleUnread\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\"\\\n\x17ReqSpecificSingleUnread\x12\x41\n\x0ftalker_sessions\x18\x01 \x03(\x0b\x32(.bilibili.im.interfaces.v1.SimpleSession\"\"\n\nReqSyncAck\x12\x14\n\x0c\x63lient_seqno\x18\x01 \x01(\x04\"\xa3\x01\n\x0eReqTotalUnread\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\x12\x17\n\x0fsingleunread_on\x18\x05 \x01(\x05\x12\x12\n\nmsgfeed_on\x18\x06 \x01(\x05\x12\x10\n\x08sysup_on\x18\x07 \x01(\x05\"J\n\x0cReqUpdateAck\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x11\n\tack_seqno\x18\x03 \x01(\x04\"D\n\x12ReqUpdateIntercept\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\ttalker_id\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\x05\"\x16\n\x14ReqUpdateTotalUnread\"\x17\n\x15RspCloseClearUnreadUI\"/\n\tRspGetMsg\x12\"\n\x03msg\x18\x01 \x03(\x0b\x32\x15.bilibili.im.type.Msg\"4\n\x0bRspLiveInfo\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"(\n\x10RspMyGroupUnread\x12\x14\n\x0cunread_count\x18\x01 \x01(\r\"\xe6\x01\n\x0fRspRelationSync\x12\x0c\n\x04\x66ull\x18\x01 \x01(\x05\x12\x34\n\rrelation_logs\x18\x02 \x03(\x0b\x32\x1d.bilibili.im.type.RelationLog\x12\x35\n\x0b\x66riend_list\x18\x03 \x03(\x0b\x32 .bilibili.im.type.FriendRelation\x12#\n\x1bserver_relation_oplog_seqno\x18\x04 \x01(\x04\x12\x33\n\ngroup_list\x18\x05 \x03(\x0b\x32\x1f.bilibili.im.type.GroupRelation\"\xa1\x01\n\nRspSendMsg\x12\x0f\n\x07msg_key\x18\x01 \x01(\x04\x12\x37\n\x07\x65_infos\x18\x02 \x03(\x0b\x32&.bilibili.im.interfaces.v1.EmotionInfo\x12\x13\n\x0bmsg_content\x18\x03 \x01(\t\x12\x34\n\rkey_hit_infos\x18\x04 \x01(\x0b\x32\x1d.bilibili.im.type.KeyHitInfos\"F\n\x11RspSessionDetails\x12\x31\n\nsess_infos\x18\x01 \x03(\x0b\x32\x1d.bilibili.im.type.SessionInfo\"\xa9\x01\n\rRspSessionMsg\x12\'\n\x08messages\x18\x01 \x03(\x0b\x32\x15.bilibili.im.type.Msg\x12\x10\n\x08has_more\x18\x02 \x01(\x05\x12\x11\n\tmin_seqno\x18\x03 \x01(\x04\x12\x11\n\tmax_seqno\x18\x04 \x01(\x04\x12\x37\n\x07\x65_infos\x18\x05 \x03(\x0b\x32&.bilibili.im.interfaces.v1.EmotionInfo\"\xa3\x02\n\x0bRspSessions\x12\x33\n\x0csession_list\x18\x01 \x03(\x0b\x32\x1d.bilibili.im.type.SessionInfo\x12\x10\n\x08has_more\x18\x02 \x01(\r\x12\x1d\n\x15\x61nti_disturb_cleaning\x18\x03 \x01(\x08\x12\x1d\n\x15is_address_list_empty\x18\x04 \x01(\x05\x12I\n\nsystem_msg\x18\x05 \x03(\x0b\x32\x35.bilibili.im.interfaces.v1.RspSessions.SystemMsgEntry\x12\x12\n\nshow_level\x18\x06 \x01(\x08\x1a\x30\n\x0eSystemMsgEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"m\n\x0cRspShareList\x12\x41\n\x0csession_list\x18\x01 \x03(\x0b\x32+.bilibili.im.interfaces.v1.ShareSessionInfo\x12\x1a\n\x12IsAddressListEmpty\x18\x02 \x01(\x05\"5\n\x14RspShowClearUnreadUI\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x8e\x01\n\x0fRspSingleUnread\x12\x17\n\x0funfollow_unread\x18\x01 \x01(\x04\x12\x15\n\rfollow_unread\x18\x02 \x01(\x04\x12\x19\n\x11unfollow_push_msg\x18\x03 \x01(\r\x12\x18\n\x10\x64ustbin_push_msg\x18\x04 \x01(\x05\x12\x16\n\x0e\x64ustbin_unread\x18\x05 \x01(\x03\"\xc9\x01\n\x17RspSpecificSingleUnread\x12`\n\x0ftalkerUnreadCnt\x18\x01 \x03(\x0b\x32G.bilibili.im.interfaces.v1.RspSpecificSingleUnread.TalkerUnreadCntEntry\x12\x14\n\x0c\x61llUnreadCnt\x18\x02 \x01(\x04\x1a\x36\n\x14TalkerUnreadCntEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"\x0c\n\nRspSyncAck\"\x98\x02\n\x0eRspTotalUnread\x12P\n\x15session_single_unread\x18\x01 \x01(\x0b\x32\x31.bilibili.im.interfaces.v1.SessionSingleUnreadRsp\x12\x44\n\x0fmsg_feed_unread\x18\x02 \x01(\x0b\x32+.bilibili.im.interfaces.v1.MsgFeedUnreadRsp\x12X\n\x1asys_msg_interface_last_msg\x18\x03 \x01(\x0b\x32\x34.bilibili.im.interfaces.v1.SysMsgInterfaceLastMsgRsp\x12\x14\n\x0ctotal_unread\x18\x04 \x01(\x05\"\x16\n\x14RspUpdateTotalUnread\"\x95\x01\n\x16SessionSingleUnreadRsp\x12\x17\n\x0funfollow_unread\x18\x01 \x01(\x03\x12\x15\n\rfollow_unread\x18\x02 \x01(\x03\x12\x19\n\x11unfollow_push_msg\x18\x03 \x01(\x05\x12\x18\n\x10\x64ustbin_push_msg\x18\x04 \x01(\x05\x12\x16\n\x0e\x64ustbin_unread\x18\x05 \x01(\x03\"g\n\x10ShareSessionInfo\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0ctalker_uname\x18\x02 \x01(\t\x12\x13\n\x0btalker_icon\x18\x03 \x01(\t\x12\x15\n\rofficial_type\x18\x04 \x01(\x05\"8\n\rSimpleSession\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\"T\n\x19SysMsgInterfaceLastMsgRsp\x12\x0e\n\x06unread\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\x03*8\n\tENUM_FOLD\x12\x0b\n\x07\x46OLD_NO\x10\x00\x12\x0c\n\x08\x46OLD_YES\x10\x01\x12\x10\n\x0c\x46OLD_UNKNOWN\x10\x02*r\n\x10\x45NUM_UNREAD_TYPE\x12\x13\n\x0fUNREAD_TYPE_ALL\x10\x00\x12\x16\n\x12UNREAD_TYPE_FOLLOW\x10\x01\x12\x18\n\x14UNREAD_TYPE_UNFOLLOW\x10\x02\x12\x17\n\x13UNREAD_TYPE_DUSTBIN\x10\x03*\x8a\x01\n\x0cSESSION_TYPE\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fUN_FOLD_SESSION\x10\x01\x12\x1c\n\x18UN_FOLLOW_SINGLE_SESSION\x10\x02\x12\x14\n\x10MY_GROUP_SESSION\x10\x03\x12\x0f\n\x0b\x41LL_SESSION\x10\x04\x12\x13\n\x0f\x44USTBIN_SESSION\x10\x05\x32\xe8\x14\n\x0bImInterface\x12W\n\x07SendMsg\x12%.bilibili.im.interfaces.v1.ReqSendMsg\x1a%.bilibili.im.interfaces.v1.RspSendMsg\x12\x66\n\x0cSyncRelation\x12*.bilibili.im.interfaces.v1.ReqRelationSync\x1a*.bilibili.im.interfaces.v1.RspRelationSync\x12W\n\x07SyncAck\x12%.bilibili.im.interfaces.v1.ReqSyncAck\x1a%.bilibili.im.interfaces.v1.RspSyncAck\x12j\n\x14SyncFetchSessionMsgs\x12(.bilibili.im.interfaces.v1.ReqSessionMsg\x1a(.bilibili.im.interfaces.v1.RspSessionMsg\x12`\n\x0bGetSessions\x12).bilibili.im.interfaces.v1.ReqGetSessions\x1a&.bilibili.im.interfaces.v1.RspSessions\x12`\n\x0bNewSessions\x12).bilibili.im.interfaces.v1.ReqNewSessions\x1a&.bilibili.im.interfaces.v1.RspSessions\x12`\n\x0b\x41\x63kSessions\x12).bilibili.im.interfaces.v1.ReqAckSessions\x1a&.bilibili.im.interfaces.v1.RspSessions\x12Y\n\tUpdateAck\x12\'.bilibili.im.interfaces.v1.ReqUpdateAck\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12S\n\x06SetTop\x12$.bilibili.im.interfaces.v1.ReqSetTop\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12\x61\n\rRemoveSession\x12+.bilibili.im.interfaces.v1.ReqRemoveSession\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12\x66\n\x0cSingleUnread\x12*.bilibili.im.interfaces.v1.ReqSingleUnread\x1a*.bilibili.im.interfaces.v1.RspSingleUnread\x12\x61\n\rMyGroupUnread\x12#.bilibili.im.interfaces.v1.DummyReq\x1a+.bilibili.im.interfaces.v1.RspMyGroupUnread\x12[\n\x0fUpdateUnflwRead\x12#.bilibili.im.interfaces.v1.DummyReq\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12\x66\n\rGroupAssisMsg\x12+.bilibili.im.interfaces.v1.ReqGroupAssisMsg\x1a(.bilibili.im.interfaces.v1.RspSessionMsg\x12]\n\x0b\x41\x63kAssisMsg\x12).bilibili.im.interfaces.v1.ReqAckAssisMsg\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12[\n\rSessionDetail\x12+.bilibili.im.interfaces.v1.ReqSessionDetail\x1a\x1d.bilibili.im.type.SessionInfo\x12m\n\x0f\x42\x61tchSessDetail\x12,.bilibili.im.interfaces.v1.ReqSessionDetails\x1a,.bilibili.im.interfaces.v1.RspSessionDetails\x12_\n\x0f\x42\x61tchRmSessions\x12\'.bilibili.im.interfaces.v1.ReqBatRmSess\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12]\n\tShareList\x12\'.bilibili.im.interfaces.v1.ReqShareList\x1a\'.bilibili.im.interfaces.v1.RspShareList\x12~\n\x14SpecificSingleUnread\x12\x32.bilibili.im.interfaces.v1.ReqSpecificSingleUnread\x1a\x32.bilibili.im.interfaces.v1.RspSpecificSingleUnread\x12p\n\x13GetSpecificSessions\x12\x31.bilibili.im.interfaces.v1.ReqGetSpecificSessions\x1a&.bilibili.im.interfaces.v1.RspSessions\x12]\n\x0bGetLiveInfo\x12&.bilibili.im.interfaces.v1.ReqLiveInfo\x1a&.bilibili.im.interfaces.v1.RspLiveInfo\x12\x66\n\x0eGetTotalUnread\x12).bilibili.im.interfaces.v1.ReqTotalUnread\x1a).bilibili.im.interfaces.v1.RspTotalUnread\x12u\n\x11ShowClearUnreadUI\x12/.bilibili.im.interfaces.v1.ReqShowClearUnreadUI\x1a/.bilibili.im.interfaces.v1.RspShowClearUnreadUI\x12x\n\x12\x43loseClearUnreadUI\x12\x30.bilibili.im.interfaces.v1.ReqCloseClearUnreadUI\x1a\x30.bilibili.im.interfaces.v1.RspCloseClearUnreadUI\x12u\n\x11UpdateTotalUnread\x12/.bilibili.im.interfaces.v1.ReqUpdateTotalUnread\x1a/.bilibili.im.interfaces.v1.RspUpdateTotalUnreadb\x06proto3')

_ENUM_FOLD = DESCRIPTOR.enum_types_by_name['ENUM_FOLD']
ENUM_FOLD = enum_type_wrapper.EnumTypeWrapper(_ENUM_FOLD)
_ENUM_UNREAD_TYPE = DESCRIPTOR.enum_types_by_name['ENUM_UNREAD_TYPE']
ENUM_UNREAD_TYPE = enum_type_wrapper.EnumTypeWrapper(_ENUM_UNREAD_TYPE)
_SESSION_TYPE = DESCRIPTOR.enum_types_by_name['SESSION_TYPE']
SESSION_TYPE = enum_type_wrapper.EnumTypeWrapper(_SESSION_TYPE)
FOLD_NO = 0
FOLD_YES = 1
FOLD_UNKNOWN = 2
UNREAD_TYPE_ALL = 0
UNREAD_TYPE_FOLLOW = 1
UNREAD_TYPE_UNFOLLOW = 2
UNREAD_TYPE_DUSTBIN = 3
UNKNOWN = 0
UN_FOLD_SESSION = 1
UN_FOLLOW_SINGLE_SESSION = 2
MY_GROUP_SESSION = 3
ALL_SESSION = 4
DUSTBIN_SESSION = 5


_DUMMYREQ = DESCRIPTOR.message_types_by_name['DummyReq']
_DUMMYRSP = DESCRIPTOR.message_types_by_name['DummyRsp']
_EMOTIONINFO = DESCRIPTOR.message_types_by_name['EmotionInfo']
_MSGDETAIL = DESCRIPTOR.message_types_by_name['MsgDetail']
_MSGFEEDUNREADRSP = DESCRIPTOR.message_types_by_name['MsgFeedUnreadRsp']
_MSGFEEDUNREADRSP_UNREADENTRY = _MSGFEEDUNREADRSP.nested_types_by_name['UnreadEntry']
_REQACKASSISMSG = DESCRIPTOR.message_types_by_name['ReqAckAssisMsg']
_REQACKSESSIONS = DESCRIPTOR.message_types_by_name['ReqAckSessions']
_REQBATRMSESS = DESCRIPTOR.message_types_by_name['ReqBatRmSess']
_REQCLOSECLEARUNREADUI = DESCRIPTOR.message_types_by_name['ReqCloseClearUnreadUI']
_REQGETMSG = DESCRIPTOR.message_types_by_name['ReqGetMsg']
_REQGETSESSIONS = DESCRIPTOR.message_types_by_name['ReqGetSessions']
_REQGETSPECIFICSESSIONS = DESCRIPTOR.message_types_by_name['ReqGetSpecificSessions']
_REQGROUPASSISMSG = DESCRIPTOR.message_types_by_name['ReqGroupAssisMsg']
_REQLIVEINFO = DESCRIPTOR.message_types_by_name['ReqLiveInfo']
_REQNEWSESSIONS = DESCRIPTOR.message_types_by_name['ReqNewSessions']
_REQRELATIONSYNC = DESCRIPTOR.message_types_by_name['ReqRelationSync']
_REQREMOVESESSION = DESCRIPTOR.message_types_by_name['ReqRemoveSession']
_REQSENDMSG = DESCRIPTOR.message_types_by_name['ReqSendMsg']
_REQSESSIONDETAIL = DESCRIPTOR.message_types_by_name['ReqSessionDetail']
_REQSESSIONDETAILS = DESCRIPTOR.message_types_by_name['ReqSessionDetails']
_REQSESSIONMSG = DESCRIPTOR.message_types_by_name['ReqSessionMsg']
_REQSETTOP = DESCRIPTOR.message_types_by_name['ReqSetTop']
_REQSHARELIST = DESCRIPTOR.message_types_by_name['ReqShareList']
_REQSHOWCLEARUNREADUI = DESCRIPTOR.message_types_by_name['ReqShowClearUnreadUI']
_REQSINGLEUNREAD = DESCRIPTOR.message_types_by_name['ReqSingleUnread']
_REQSPECIFICSINGLEUNREAD = DESCRIPTOR.message_types_by_name['ReqSpecificSingleUnread']
_REQSYNCACK = DESCRIPTOR.message_types_by_name['ReqSyncAck']
_REQTOTALUNREAD = DESCRIPTOR.message_types_by_name['ReqTotalUnread']
_REQUPDATEACK = DESCRIPTOR.message_types_by_name['ReqUpdateAck']
_REQUPDATEINTERCEPT = DESCRIPTOR.message_types_by_name['ReqUpdateIntercept']
_REQUPDATETOTALUNREAD = DESCRIPTOR.message_types_by_name['ReqUpdateTotalUnread']
_RSPCLOSECLEARUNREADUI = DESCRIPTOR.message_types_by_name['RspCloseClearUnreadUI']
_RSPGETMSG = DESCRIPTOR.message_types_by_name['RspGetMsg']
_RSPLIVEINFO = DESCRIPTOR.message_types_by_name['RspLiveInfo']
_RSPMYGROUPUNREAD = DESCRIPTOR.message_types_by_name['RspMyGroupUnread']
_RSPRELATIONSYNC = DESCRIPTOR.message_types_by_name['RspRelationSync']
_RSPSENDMSG = DESCRIPTOR.message_types_by_name['RspSendMsg']
_RSPSESSIONDETAILS = DESCRIPTOR.message_types_by_name['RspSessionDetails']
_RSPSESSIONMSG = DESCRIPTOR.message_types_by_name['RspSessionMsg']
_RSPSESSIONS = DESCRIPTOR.message_types_by_name['RspSessions']
_RSPSESSIONS_SYSTEMMSGENTRY = _RSPSESSIONS.nested_types_by_name['SystemMsgEntry']
_RSPSHARELIST = DESCRIPTOR.message_types_by_name['RspShareList']
_RSPSHOWCLEARUNREADUI = DESCRIPTOR.message_types_by_name['RspShowClearUnreadUI']
_RSPSINGLEUNREAD = DESCRIPTOR.message_types_by_name['RspSingleUnread']
_RSPSPECIFICSINGLEUNREAD = DESCRIPTOR.message_types_by_name['RspSpecificSingleUnread']
_RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY = _RSPSPECIFICSINGLEUNREAD.nested_types_by_name['TalkerUnreadCntEntry']
_RSPSYNCACK = DESCRIPTOR.message_types_by_name['RspSyncAck']
_RSPTOTALUNREAD = DESCRIPTOR.message_types_by_name['RspTotalUnread']
_RSPUPDATETOTALUNREAD = DESCRIPTOR.message_types_by_name['RspUpdateTotalUnread']
_SESSIONSINGLEUNREADRSP = DESCRIPTOR.message_types_by_name['SessionSingleUnreadRsp']
_SHARESESSIONINFO = DESCRIPTOR.message_types_by_name['ShareSessionInfo']
_SIMPLESESSION = DESCRIPTOR.message_types_by_name['SimpleSession']
_SYSMSGINTERFACELASTMSGRSP = DESCRIPTOR.message_types_by_name['SysMsgInterfaceLastMsgRsp']
DummyReq = _reflection.GeneratedProtocolMessageType('DummyReq', (_message.Message,), {
  'DESCRIPTOR' : _DUMMYREQ,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.DummyReq)
  })
_sym_db.RegisterMessage(DummyReq)

DummyRsp = _reflection.GeneratedProtocolMessageType('DummyRsp', (_message.Message,), {
  'DESCRIPTOR' : _DUMMYRSP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.DummyRsp)
  })
_sym_db.RegisterMessage(DummyRsp)

EmotionInfo = _reflection.GeneratedProtocolMessageType('EmotionInfo', (_message.Message,), {
  'DESCRIPTOR' : _EMOTIONINFO,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.EmotionInfo)
  })
_sym_db.RegisterMessage(EmotionInfo)

MsgDetail = _reflection.GeneratedProtocolMessageType('MsgDetail', (_message.Message,), {
  'DESCRIPTOR' : _MSGDETAIL,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.MsgDetail)
  })
_sym_db.RegisterMessage(MsgDetail)

MsgFeedUnreadRsp = _reflection.GeneratedProtocolMessageType('MsgFeedUnreadRsp', (_message.Message,), {

  'UnreadEntry' : _reflection.GeneratedProtocolMessageType('UnreadEntry', (_message.Message,), {
    'DESCRIPTOR' : _MSGFEEDUNREADRSP_UNREADENTRY,
    '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.MsgFeedUnreadRsp.UnreadEntry)
    })
  ,
  'DESCRIPTOR' : _MSGFEEDUNREADRSP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.MsgFeedUnreadRsp)
  })
_sym_db.RegisterMessage(MsgFeedUnreadRsp)
_sym_db.RegisterMessage(MsgFeedUnreadRsp.UnreadEntry)

ReqAckAssisMsg = _reflection.GeneratedProtocolMessageType('ReqAckAssisMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQACKASSISMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqAckAssisMsg)
  })
_sym_db.RegisterMessage(ReqAckAssisMsg)

ReqAckSessions = _reflection.GeneratedProtocolMessageType('ReqAckSessions', (_message.Message,), {
  'DESCRIPTOR' : _REQACKSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqAckSessions)
  })
_sym_db.RegisterMessage(ReqAckSessions)

ReqBatRmSess = _reflection.GeneratedProtocolMessageType('ReqBatRmSess', (_message.Message,), {
  'DESCRIPTOR' : _REQBATRMSESS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqBatRmSess)
  })
_sym_db.RegisterMessage(ReqBatRmSess)

ReqCloseClearUnreadUI = _reflection.GeneratedProtocolMessageType('ReqCloseClearUnreadUI', (_message.Message,), {
  'DESCRIPTOR' : _REQCLOSECLEARUNREADUI,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqCloseClearUnreadUI)
  })
_sym_db.RegisterMessage(ReqCloseClearUnreadUI)

ReqGetMsg = _reflection.GeneratedProtocolMessageType('ReqGetMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQGETMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqGetMsg)
  })
_sym_db.RegisterMessage(ReqGetMsg)

ReqGetSessions = _reflection.GeneratedProtocolMessageType('ReqGetSessions', (_message.Message,), {
  'DESCRIPTOR' : _REQGETSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqGetSessions)
  })
_sym_db.RegisterMessage(ReqGetSessions)

ReqGetSpecificSessions = _reflection.GeneratedProtocolMessageType('ReqGetSpecificSessions', (_message.Message,), {
  'DESCRIPTOR' : _REQGETSPECIFICSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqGetSpecificSessions)
  })
_sym_db.RegisterMessage(ReqGetSpecificSessions)

ReqGroupAssisMsg = _reflection.GeneratedProtocolMessageType('ReqGroupAssisMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQGROUPASSISMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqGroupAssisMsg)
  })
_sym_db.RegisterMessage(ReqGroupAssisMsg)

ReqLiveInfo = _reflection.GeneratedProtocolMessageType('ReqLiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _REQLIVEINFO,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqLiveInfo)
  })
_sym_db.RegisterMessage(ReqLiveInfo)

ReqNewSessions = _reflection.GeneratedProtocolMessageType('ReqNewSessions', (_message.Message,), {
  'DESCRIPTOR' : _REQNEWSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqNewSessions)
  })
_sym_db.RegisterMessage(ReqNewSessions)

ReqRelationSync = _reflection.GeneratedProtocolMessageType('ReqRelationSync', (_message.Message,), {
  'DESCRIPTOR' : _REQRELATIONSYNC,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqRelationSync)
  })
_sym_db.RegisterMessage(ReqRelationSync)

ReqRemoveSession = _reflection.GeneratedProtocolMessageType('ReqRemoveSession', (_message.Message,), {
  'DESCRIPTOR' : _REQREMOVESESSION,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqRemoveSession)
  })
_sym_db.RegisterMessage(ReqRemoveSession)

ReqSendMsg = _reflection.GeneratedProtocolMessageType('ReqSendMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQSENDMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSendMsg)
  })
_sym_db.RegisterMessage(ReqSendMsg)

ReqSessionDetail = _reflection.GeneratedProtocolMessageType('ReqSessionDetail', (_message.Message,), {
  'DESCRIPTOR' : _REQSESSIONDETAIL,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSessionDetail)
  })
_sym_db.RegisterMessage(ReqSessionDetail)

ReqSessionDetails = _reflection.GeneratedProtocolMessageType('ReqSessionDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQSESSIONDETAILS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSessionDetails)
  })
_sym_db.RegisterMessage(ReqSessionDetails)

ReqSessionMsg = _reflection.GeneratedProtocolMessageType('ReqSessionMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQSESSIONMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSessionMsg)
  })
_sym_db.RegisterMessage(ReqSessionMsg)

ReqSetTop = _reflection.GeneratedProtocolMessageType('ReqSetTop', (_message.Message,), {
  'DESCRIPTOR' : _REQSETTOP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSetTop)
  })
_sym_db.RegisterMessage(ReqSetTop)

ReqShareList = _reflection.GeneratedProtocolMessageType('ReqShareList', (_message.Message,), {
  'DESCRIPTOR' : _REQSHARELIST,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqShareList)
  })
_sym_db.RegisterMessage(ReqShareList)

ReqShowClearUnreadUI = _reflection.GeneratedProtocolMessageType('ReqShowClearUnreadUI', (_message.Message,), {
  'DESCRIPTOR' : _REQSHOWCLEARUNREADUI,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqShowClearUnreadUI)
  })
_sym_db.RegisterMessage(ReqShowClearUnreadUI)

ReqSingleUnread = _reflection.GeneratedProtocolMessageType('ReqSingleUnread', (_message.Message,), {
  'DESCRIPTOR' : _REQSINGLEUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSingleUnread)
  })
_sym_db.RegisterMessage(ReqSingleUnread)

ReqSpecificSingleUnread = _reflection.GeneratedProtocolMessageType('ReqSpecificSingleUnread', (_message.Message,), {
  'DESCRIPTOR' : _REQSPECIFICSINGLEUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSpecificSingleUnread)
  })
_sym_db.RegisterMessage(ReqSpecificSingleUnread)

ReqSyncAck = _reflection.GeneratedProtocolMessageType('ReqSyncAck', (_message.Message,), {
  'DESCRIPTOR' : _REQSYNCACK,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSyncAck)
  })
_sym_db.RegisterMessage(ReqSyncAck)

ReqTotalUnread = _reflection.GeneratedProtocolMessageType('ReqTotalUnread', (_message.Message,), {
  'DESCRIPTOR' : _REQTOTALUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqTotalUnread)
  })
_sym_db.RegisterMessage(ReqTotalUnread)

ReqUpdateAck = _reflection.GeneratedProtocolMessageType('ReqUpdateAck', (_message.Message,), {
  'DESCRIPTOR' : _REQUPDATEACK,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqUpdateAck)
  })
_sym_db.RegisterMessage(ReqUpdateAck)

ReqUpdateIntercept = _reflection.GeneratedProtocolMessageType('ReqUpdateIntercept', (_message.Message,), {
  'DESCRIPTOR' : _REQUPDATEINTERCEPT,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqUpdateIntercept)
  })
_sym_db.RegisterMessage(ReqUpdateIntercept)

ReqUpdateTotalUnread = _reflection.GeneratedProtocolMessageType('ReqUpdateTotalUnread', (_message.Message,), {
  'DESCRIPTOR' : _REQUPDATETOTALUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqUpdateTotalUnread)
  })
_sym_db.RegisterMessage(ReqUpdateTotalUnread)

RspCloseClearUnreadUI = _reflection.GeneratedProtocolMessageType('RspCloseClearUnreadUI', (_message.Message,), {
  'DESCRIPTOR' : _RSPCLOSECLEARUNREADUI,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspCloseClearUnreadUI)
  })
_sym_db.RegisterMessage(RspCloseClearUnreadUI)

RspGetMsg = _reflection.GeneratedProtocolMessageType('RspGetMsg', (_message.Message,), {
  'DESCRIPTOR' : _RSPGETMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspGetMsg)
  })
_sym_db.RegisterMessage(RspGetMsg)

RspLiveInfo = _reflection.GeneratedProtocolMessageType('RspLiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _RSPLIVEINFO,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspLiveInfo)
  })
_sym_db.RegisterMessage(RspLiveInfo)

RspMyGroupUnread = _reflection.GeneratedProtocolMessageType('RspMyGroupUnread', (_message.Message,), {
  'DESCRIPTOR' : _RSPMYGROUPUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspMyGroupUnread)
  })
_sym_db.RegisterMessage(RspMyGroupUnread)

RspRelationSync = _reflection.GeneratedProtocolMessageType('RspRelationSync', (_message.Message,), {
  'DESCRIPTOR' : _RSPRELATIONSYNC,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspRelationSync)
  })
_sym_db.RegisterMessage(RspRelationSync)

RspSendMsg = _reflection.GeneratedProtocolMessageType('RspSendMsg', (_message.Message,), {
  'DESCRIPTOR' : _RSPSENDMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSendMsg)
  })
_sym_db.RegisterMessage(RspSendMsg)

RspSessionDetails = _reflection.GeneratedProtocolMessageType('RspSessionDetails', (_message.Message,), {
  'DESCRIPTOR' : _RSPSESSIONDETAILS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSessionDetails)
  })
_sym_db.RegisterMessage(RspSessionDetails)

RspSessionMsg = _reflection.GeneratedProtocolMessageType('RspSessionMsg', (_message.Message,), {
  'DESCRIPTOR' : _RSPSESSIONMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSessionMsg)
  })
_sym_db.RegisterMessage(RspSessionMsg)

RspSessions = _reflection.GeneratedProtocolMessageType('RspSessions', (_message.Message,), {

  'SystemMsgEntry' : _reflection.GeneratedProtocolMessageType('SystemMsgEntry', (_message.Message,), {
    'DESCRIPTOR' : _RSPSESSIONS_SYSTEMMSGENTRY,
    '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSessions.SystemMsgEntry)
    })
  ,
  'DESCRIPTOR' : _RSPSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSessions)
  })
_sym_db.RegisterMessage(RspSessions)
_sym_db.RegisterMessage(RspSessions.SystemMsgEntry)

RspShareList = _reflection.GeneratedProtocolMessageType('RspShareList', (_message.Message,), {
  'DESCRIPTOR' : _RSPSHARELIST,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspShareList)
  })
_sym_db.RegisterMessage(RspShareList)

RspShowClearUnreadUI = _reflection.GeneratedProtocolMessageType('RspShowClearUnreadUI', (_message.Message,), {
  'DESCRIPTOR' : _RSPSHOWCLEARUNREADUI,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspShowClearUnreadUI)
  })
_sym_db.RegisterMessage(RspShowClearUnreadUI)

RspSingleUnread = _reflection.GeneratedProtocolMessageType('RspSingleUnread', (_message.Message,), {
  'DESCRIPTOR' : _RSPSINGLEUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSingleUnread)
  })
_sym_db.RegisterMessage(RspSingleUnread)

RspSpecificSingleUnread = _reflection.GeneratedProtocolMessageType('RspSpecificSingleUnread', (_message.Message,), {

  'TalkerUnreadCntEntry' : _reflection.GeneratedProtocolMessageType('TalkerUnreadCntEntry', (_message.Message,), {
    'DESCRIPTOR' : _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY,
    '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSpecificSingleUnread.TalkerUnreadCntEntry)
    })
  ,
  'DESCRIPTOR' : _RSPSPECIFICSINGLEUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSpecificSingleUnread)
  })
_sym_db.RegisterMessage(RspSpecificSingleUnread)
_sym_db.RegisterMessage(RspSpecificSingleUnread.TalkerUnreadCntEntry)

RspSyncAck = _reflection.GeneratedProtocolMessageType('RspSyncAck', (_message.Message,), {
  'DESCRIPTOR' : _RSPSYNCACK,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSyncAck)
  })
_sym_db.RegisterMessage(RspSyncAck)

RspTotalUnread = _reflection.GeneratedProtocolMessageType('RspTotalUnread', (_message.Message,), {
  'DESCRIPTOR' : _RSPTOTALUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspTotalUnread)
  })
_sym_db.RegisterMessage(RspTotalUnread)

RspUpdateTotalUnread = _reflection.GeneratedProtocolMessageType('RspUpdateTotalUnread', (_message.Message,), {
  'DESCRIPTOR' : _RSPUPDATETOTALUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspUpdateTotalUnread)
  })
_sym_db.RegisterMessage(RspUpdateTotalUnread)

SessionSingleUnreadRsp = _reflection.GeneratedProtocolMessageType('SessionSingleUnreadRsp', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONSINGLEUNREADRSP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.SessionSingleUnreadRsp)
  })
_sym_db.RegisterMessage(SessionSingleUnreadRsp)

ShareSessionInfo = _reflection.GeneratedProtocolMessageType('ShareSessionInfo', (_message.Message,), {
  'DESCRIPTOR' : _SHARESESSIONINFO,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ShareSessionInfo)
  })
_sym_db.RegisterMessage(ShareSessionInfo)

SimpleSession = _reflection.GeneratedProtocolMessageType('SimpleSession', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLESESSION,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.SimpleSession)
  })
_sym_db.RegisterMessage(SimpleSession)

SysMsgInterfaceLastMsgRsp = _reflection.GeneratedProtocolMessageType('SysMsgInterfaceLastMsgRsp', (_message.Message,), {
  'DESCRIPTOR' : _SYSMSGINTERFACELASTMSGRSP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.SysMsgInterfaceLastMsgRsp)
  })
_sym_db.RegisterMessage(SysMsgInterfaceLastMsgRsp)

_IMINTERFACE = DESCRIPTOR.services_by_name['ImInterface']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MSGFEEDUNREADRSP_UNREADENTRY._options = None
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_options = b'8\001'
  _RSPSESSIONS_SYSTEMMSGENTRY._options = None
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_options = b'8\001'
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._options = None
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_options = b'8\001'
  _ENUM_FOLD._serialized_start=4782
  _ENUM_FOLD._serialized_end=4838
  _ENUM_UNREAD_TYPE._serialized_start=4840
  _ENUM_UNREAD_TYPE._serialized_end=4954
  _SESSION_TYPE._serialized_start=4957
  _SESSION_TYPE._serialized_end=5095
  _DUMMYREQ._serialized_start=92
  _DUMMYREQ._serialized_end=115
  _DUMMYRSP._serialized_start=117
  _DUMMYRSP._serialized_end=133
  _EMOTIONINFO._serialized_start=135
  _EMOTIONINFO._serialized_end=206
  _MSGDETAIL._serialized_start=208
  _MSGDETAIL._serialized_end=251
  _MSGFEEDUNREADRSP._serialized_start=254
  _MSGFEEDUNREADRSP._serialized_end=392
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_start=347
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_end=392
  _REQACKASSISMSG._serialized_start=394
  _REQACKASSISMSG._serialized_end=429
  _REQACKSESSIONS._serialized_start=431
  _REQACKSESSIONS._serialized_end=495
  _REQBATRMSESS._serialized_start=497
  _REQBATRMSESS._serialized_end=511
  _REQCLOSECLEARUNREADUI._serialized_start=513
  _REQCLOSECLEARUNREADUI._serialized_end=536
  _REQGETMSG._serialized_start=538
  _REQGETMSG._serialized_end=648
  _REQGETSESSIONS._serialized_start=651
  _REQGETSESSIONS._serialized_end=844
  _REQGETSPECIFICSESSIONS._serialized_start=846
  _REQGETSPECIFICSESSIONS._serialized_end=937
  _REQGROUPASSISMSG._serialized_start=939
  _REQGROUPASSISMSG._serialized_end=993
  _REQLIVEINFO._serialized_start=995
  _REQLIVEINFO._serialized_end=1040
  _REQNEWSESSIONS._serialized_start=1042
  _REQNEWSESSIONS._serialized_end=1135
  _REQRELATIONSYNC._serialized_start=1137
  _REQRELATIONSYNC._serialized_end=1191
  _REQREMOVESESSION._serialized_start=1193
  _REQREMOVESESSION._serialized_end=1252
  _REQSENDMSG._serialized_start=1254
  _REQSENDMSG._serialized_end=1371
  _REQSESSIONDETAIL._serialized_start=1373
  _REQSESSIONDETAIL._serialized_end=1445
  _REQSESSIONDETAILS._serialized_start=1447
  _REQSESSIONDETAILS._serialized_end=1529
  _REQSESSIONMSG._serialized_start=1532
  _REQSESSIONMSG._serialized_end=1673
  _REQSETTOP._serialized_start=1675
  _REQSETTOP._serialized_end=1744
  _REQSHARELIST._serialized_start=1746
  _REQSHARELIST._serialized_end=1774
  _REQSHOWCLEARUNREADUI._serialized_start=1776
  _REQSHOWCLEARUNREADUI._serialized_end=1869
  _REQSINGLEUNREAD._serialized_start=1871
  _REQSINGLEUNREAD._serialized_end=1972
  _REQSPECIFICSINGLEUNREAD._serialized_start=1974
  _REQSPECIFICSINGLEUNREAD._serialized_end=2066
  _REQSYNCACK._serialized_start=2068
  _REQSYNCACK._serialized_end=2102
  _REQTOTALUNREAD._serialized_start=2105
  _REQTOTALUNREAD._serialized_end=2268
  _REQUPDATEACK._serialized_start=2270
  _REQUPDATEACK._serialized_end=2344
  _REQUPDATEINTERCEPT._serialized_start=2346
  _REQUPDATEINTERCEPT._serialized_end=2414
  _REQUPDATETOTALUNREAD._serialized_start=2416
  _REQUPDATETOTALUNREAD._serialized_end=2438
  _RSPCLOSECLEARUNREADUI._serialized_start=2440
  _RSPCLOSECLEARUNREADUI._serialized_end=2463
  _RSPGETMSG._serialized_start=2465
  _RSPGETMSG._serialized_end=2512
  _RSPLIVEINFO._serialized_start=2514
  _RSPLIVEINFO._serialized_end=2566
  _RSPMYGROUPUNREAD._serialized_start=2568
  _RSPMYGROUPUNREAD._serialized_end=2608
  _RSPRELATIONSYNC._serialized_start=2611
  _RSPRELATIONSYNC._serialized_end=2841
  _RSPSENDMSG._serialized_start=2844
  _RSPSENDMSG._serialized_end=3005
  _RSPSESSIONDETAILS._serialized_start=3007
  _RSPSESSIONDETAILS._serialized_end=3077
  _RSPSESSIONMSG._serialized_start=3080
  _RSPSESSIONMSG._serialized_end=3249
  _RSPSESSIONS._serialized_start=3252
  _RSPSESSIONS._serialized_end=3543
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_start=3495
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_end=3543
  _RSPSHARELIST._serialized_start=3545
  _RSPSHARELIST._serialized_end=3654
  _RSPSHOWCLEARUNREADUI._serialized_start=3656
  _RSPSHOWCLEARUNREADUI._serialized_end=3709
  _RSPSINGLEUNREAD._serialized_start=3712
  _RSPSINGLEUNREAD._serialized_end=3854
  _RSPSPECIFICSINGLEUNREAD._serialized_start=3857
  _RSPSPECIFICSINGLEUNREAD._serialized_end=4058
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_start=4004
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_end=4058
  _RSPSYNCACK._serialized_start=4060
  _RSPSYNCACK._serialized_end=4072
  _RSPTOTALUNREAD._serialized_start=4075
  _RSPTOTALUNREAD._serialized_end=4355
  _RSPUPDATETOTALUNREAD._serialized_start=4357
  _RSPUPDATETOTALUNREAD._serialized_end=4379
  _SESSIONSINGLEUNREADRSP._serialized_start=4382
  _SESSIONSINGLEUNREADRSP._serialized_end=4531
  _SHARESESSIONINFO._serialized_start=4533
  _SHARESESSIONINFO._serialized_end=4636
  _SIMPLESESSION._serialized_start=4638
  _SIMPLESESSION._serialized_end=4694
  _SYSMSGINTERFACELASTMSGRSP._serialized_start=4696
  _SYSMSGINTERFACELASTMSGRSP._serialized_end=4780
  _IMINTERFACE._serialized_start=5098
  _IMINTERFACE._serialized_end=7762
# @@protoc_insertion_point(module_scope)
