# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/push.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/broadcast/v1/push.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x1bgoogle/protobuf/empty.proto\"\x1b\n\rPageBlackList\x12\n\n\x02id\x18\x01 \x01(\t\"\x16\n\x08PageView\x12\n\n\x02id\x18\x01 \x01(\t\"\x9d\x06\n\x0fPushMessageResp\x12\x12\n\nold_taskid\x18\x01 \x01(\x03\x12\x37\n\x03\x62iz\x18\x02 \x01(\x0e\x32*.bilibili.broadcast.v1.PushMessageResp.Biz\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.bilibili.broadcast.v1.PushMessageResp.Type\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0f\n\x07summary\x18\x05 \x01(\t\x12\x0b\n\x03img\x18\x06 \x01(\t\x12\x0c\n\x04link\x18\x07 \x01(\t\x12\x41\n\x08position\x18\x08 \x01(\x0e\x32/.bilibili.broadcast.v1.PushMessageResp.Position\x12\x10\n\x08\x64uration\x18\t \x01(\x05\x12\x0e\n\x06\x65xpire\x18\n \x01(\x03\x12\x0e\n\x06taskid\x18\x0b \x01(\t\x12<\n\x0epage_blackList\x18\x0c \x03(\x0b\x32$.bilibili.broadcast.v1.PageBlackList\x12\x32\n\tpage_view\x18\r \x03(\x0b\x32\x1f.bilibili.broadcast.v1.PageView\x12>\n\x0ftarget_resource\x18\x0e \x01(\x0b\x32%.bilibili.broadcast.v1.TargetResource\x12\x13\n\x0bimage_frame\x18\x0f \x01(\x05\x12\x14\n\x0cimage_marker\x18\x10 \x01(\x05\x12\x16\n\x0eimage_position\x18\x11 \x01(\x05\x12\x0b\n\x03job\x18\x12 \x01(\x03\"E\n\x03\x42iz\x12\x0f\n\x0b\x42IZ_UNKNOWN\x10\x00\x12\r\n\tBIZ_VIDEO\x10\x01\x12\x0c\n\x08\x42IZ_LIVE\x10\x02\x12\x10\n\x0c\x42IZ_ACTIVITY\x10\x03\"_\n\x04Type\x12\x10\n\x0cTYPE_UNKNOWN\x10\x00\x12\x10\n\x0cTYPE_DEFAULT\x10\x01\x12\x0c\n\x08TYPE_HOT\x10\x02\x12\x11\n\rTYPE_REALTIME\x10\x03\x12\x12\n\x0eTYPE_RECOMMEND\x10\x04\"(\n\x08Position\x12\x0f\n\x0bPOS_UNKNOWN\x10\x00\x12\x0b\n\x07POS_TOP\x10\x01\"\xb7\x01\n\x0eTargetResource\x12-\n\x04Type\x18\x01 \x01(\x0e\x32\x1f.bilibili.broadcast.v1.LinkType\x12\x45\n\x08Resource\x18\x02 \x03(\x0b\x32\x33.bilibili.broadcast.v1.TargetResource.ResourceEntry\x1a/\n\rResourceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*a\n\x08LinkType\x12\x15\n\x11LINK_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11LINK_TYPE_BANGUMI\x10\x01\x12\x13\n\x0fLINK_TYPE_VIDEO\x10\x02\x12\x12\n\x0eLINK_TYPE_LIVE\x10\x03\x32X\n\x04Push\x12P\n\x0cWatchMessage\x12\x16.google.protobuf.Empty\x1a&.bilibili.broadcast.v1.PushMessageResp0\x01\x62\x06proto3')

_LINKTYPE = DESCRIPTOR.enum_types_by_name['LinkType']
LinkType = enum_type_wrapper.EnumTypeWrapper(_LINKTYPE)
LINK_TYPE_UNKNOWN = 0
LINK_TYPE_BANGUMI = 1
LINK_TYPE_VIDEO = 2
LINK_TYPE_LIVE = 3


_PAGEBLACKLIST = DESCRIPTOR.message_types_by_name['PageBlackList']
_PAGEVIEW = DESCRIPTOR.message_types_by_name['PageView']
_PUSHMESSAGERESP = DESCRIPTOR.message_types_by_name['PushMessageResp']
_TARGETRESOURCE = DESCRIPTOR.message_types_by_name['TargetResource']
_TARGETRESOURCE_RESOURCEENTRY = _TARGETRESOURCE.nested_types_by_name['ResourceEntry']
_PUSHMESSAGERESP_BIZ = _PUSHMESSAGERESP.enum_types_by_name['Biz']
_PUSHMESSAGERESP_TYPE = _PUSHMESSAGERESP.enum_types_by_name['Type']
_PUSHMESSAGERESP_POSITION = _PUSHMESSAGERESP.enum_types_by_name['Position']
PageBlackList = _reflection.GeneratedProtocolMessageType('PageBlackList', (_message.Message,), {
  'DESCRIPTOR' : _PAGEBLACKLIST,
  '__module__' : 'bilibili.broadcast.v1.push_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.PageBlackList)
  })
_sym_db.RegisterMessage(PageBlackList)

PageView = _reflection.GeneratedProtocolMessageType('PageView', (_message.Message,), {
  'DESCRIPTOR' : _PAGEVIEW,
  '__module__' : 'bilibili.broadcast.v1.push_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.PageView)
  })
_sym_db.RegisterMessage(PageView)

PushMessageResp = _reflection.GeneratedProtocolMessageType('PushMessageResp', (_message.Message,), {
  'DESCRIPTOR' : _PUSHMESSAGERESP,
  '__module__' : 'bilibili.broadcast.v1.push_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.PushMessageResp)
  })
_sym_db.RegisterMessage(PushMessageResp)

TargetResource = _reflection.GeneratedProtocolMessageType('TargetResource', (_message.Message,), {

  'ResourceEntry' : _reflection.GeneratedProtocolMessageType('ResourceEntry', (_message.Message,), {
    'DESCRIPTOR' : _TARGETRESOURCE_RESOURCEENTRY,
    '__module__' : 'bilibili.broadcast.v1.push_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.TargetResource.ResourceEntry)
    })
  ,
  'DESCRIPTOR' : _TARGETRESOURCE,
  '__module__' : 'bilibili.broadcast.v1.push_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.TargetResource)
  })
_sym_db.RegisterMessage(TargetResource)
_sym_db.RegisterMessage(TargetResource.ResourceEntry)

_PUSH = DESCRIPTOR.services_by_name['Push']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TARGETRESOURCE_RESOURCEENTRY._options = None
  _TARGETRESOURCE_RESOURCEENTRY._serialized_options = b'8\001'
  _LINKTYPE._serialized_start=1127
  _LINKTYPE._serialized_end=1224
  _PAGEBLACKLIST._serialized_start=88
  _PAGEBLACKLIST._serialized_end=115
  _PAGEVIEW._serialized_start=117
  _PAGEVIEW._serialized_end=139
  _PUSHMESSAGERESP._serialized_start=142
  _PUSHMESSAGERESP._serialized_end=939
  _PUSHMESSAGERESP_BIZ._serialized_start=731
  _PUSHMESSAGERESP_BIZ._serialized_end=800
  _PUSHMESSAGERESP_TYPE._serialized_start=802
  _PUSHMESSAGERESP_TYPE._serialized_end=897
  _PUSHMESSAGERESP_POSITION._serialized_start=899
  _PUSHMESSAGERESP_POSITION._serialized_end=939
  _TARGETRESOURCE._serialized_start=942
  _TARGETRESOURCE._serialized_end=1125
  _TARGETRESOURCE_RESOURCEENTRY._serialized_start=1078
  _TARGETRESOURCE_RESOURCEENTRY._serialized_end=1125
  _PUSH._serialized_start=1226
  _PUSH._serialized_end=1314
# @@protoc_insertion_point(module_scope)
