# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/im/interfaces/inner-interface/v1/api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3bilibili/im/interfaces/inner-interface/v1/api.proto\x12(bilibili.im.interface.inner.interface.v1\"A\n\x07\x42\x61nUser\x12\x0b\n\x03uid\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x03 \x01(\x05\x12\x0c\n\x04mode\x18\x04 \x01(\x05\"V\n\x0eReqOpBlacklist\x12\x44\n\tban_users\x18\x01 \x03(\x0b\x32\x31.bilibili.im.interface.inner.interface.v1.BanUser\"&\n\x0eRspOpBlacklist\x12\x14\n\x0c\x66\x61iled_users\x18\x01 \x03(\x04\x32\x96\x01\n\x0eInnerInterface\x12\x83\x01\n\rUpdateListInn\x12\x38.bilibili.im.interface.inner.interface.v1.ReqOpBlacklist\x1a\x38.bilibili.im.interface.inner.interface.v1.RspOpBlacklistb\x06proto3')



_BANUSER = DESCRIPTOR.message_types_by_name['BanUser']
_REQOPBLACKLIST = DESCRIPTOR.message_types_by_name['ReqOpBlacklist']
_RSPOPBLACKLIST = DESCRIPTOR.message_types_by_name['RspOpBlacklist']
BanUser = _reflection.GeneratedProtocolMessageType('BanUser', (_message.Message,), {
  'DESCRIPTOR' : _BANUSER,
  '__module__' : 'bilibili.im.interfaces.inner_interface.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interface.inner.interface.v1.BanUser)
  })
_sym_db.RegisterMessage(BanUser)

ReqOpBlacklist = _reflection.GeneratedProtocolMessageType('ReqOpBlacklist', (_message.Message,), {
  'DESCRIPTOR' : _REQOPBLACKLIST,
  '__module__' : 'bilibili.im.interfaces.inner_interface.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interface.inner.interface.v1.ReqOpBlacklist)
  })
_sym_db.RegisterMessage(ReqOpBlacklist)

RspOpBlacklist = _reflection.GeneratedProtocolMessageType('RspOpBlacklist', (_message.Message,), {
  'DESCRIPTOR' : _RSPOPBLACKLIST,
  '__module__' : 'bilibili.im.interfaces.inner_interface.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interface.inner.interface.v1.RspOpBlacklist)
  })
_sym_db.RegisterMessage(RspOpBlacklist)

_INNERINTERFACE = DESCRIPTOR.services_by_name['InnerInterface']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BANUSER._serialized_start=97
  _BANUSER._serialized_end=162
  _REQOPBLACKLIST._serialized_start=164
  _REQOPBLACKLIST._serialized_end=250
  _RSPOPBLACKLIST._serialized_start=252
  _RSPOPBLACKLIST._serialized_end=290
  _INNERINTERFACE._serialized_start=293
  _INNERINTERFACE._serialized_end=443
# @@protoc_insertion_point(module_scope)
