"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PlayerOnlineReq(google.protobuf.message.Message):
    """获取在线人数-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    PLAY_OPEN_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件 avid"""

    cid: builtins.int
    """视频 cid"""

    play_open: builtins.bool
    """是否在播放中"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        play_open: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","play_open",b"play_open"]) -> None: ...
global___PlayerOnlineReq = PlayerOnlineReq

class PlayerOnlineReply(google.protobuf.message.Message):
    """获取在线人数-回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOTAL_TEXT_FIELD_NUMBER: builtins.int
    SEC_NEXT_FIELD_NUMBER: builtins.int
    BOTTOM_SHOW_FIELD_NUMBER: builtins.int
    SDM_SHOW_FIELD_NUMBER: builtins.int
    SDM_TEXT_FIELD_NUMBER: builtins.int
    total_text: typing.Text
    """"""

    sec_next: builtins.int
    """下次轮询间隔时间"""

    bottom_show: builtins.bool
    """是否底部显示"""

    sdm_show: builtins.bool
    """"""

    sdm_text: typing.Text
    """"""

    def __init__(self,
        *,
        total_text: typing.Text = ...,
        sec_next: builtins.int = ...,
        bottom_show: builtins.bool = ...,
        sdm_show: builtins.bool = ...,
        sdm_text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_show",b"bottom_show","sdm_show",b"sdm_show","sdm_text",b"sdm_text","sec_next",b"sec_next","total_text",b"total_text"]) -> None: ...
global___PlayerOnlineReply = PlayerOnlineReply
