"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.rpc.status_pb2
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AuthReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___AuthReq = AuthReq

class AuthResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___AuthResp = AuthResp

class FrameOption(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VEGA_ID_FIELD_NUMBER: builtins.int
    REQ_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    IS_ACK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ACK_ORIGIN_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    vega_id: builtins.int
    """"""

    req_id: typing.Text
    """"""

    sequence: builtins.int
    """"""

    is_ack: builtins.bool
    """"""

    @property
    def status(self) -> bilibili.rpc.status_pb2.Status:
        """"""
        pass
    ack_origin: typing.Text
    """"""

    mid: builtins.int
    """"""

    def __init__(self,
        *,
        vega_id: builtins.int = ...,
        req_id: typing.Text = ...,
        sequence: builtins.int = ...,
        is_ack: builtins.bool = ...,
        status: typing.Optional[bilibili.rpc.status_pb2.Status] = ...,
        ack_origin: typing.Text = ...,
        mid: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_origin",b"ack_origin","is_ack",b"is_ack","mid",b"mid","req_id",b"req_id","sequence",b"sequence","status",b"status","vega_id",b"vega_id"]) -> None: ...
global___FrameOption = FrameOption

class HeartbeatReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___HeartbeatReq = HeartbeatReq

class HeartbeatResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___HeartbeatResp = HeartbeatResp

class MessageAckReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VEGA_ID_FIELD_NUMBER: builtins.int
    REQ_ID_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    vega_id: typing.Text
    """"""

    req_id: typing.Text
    """"""

    origin: typing.Text
    """"""

    target_path: typing.Text
    """"""

    def __init__(self,
        *,
        vega_id: typing.Text = ...,
        req_id: typing.Text = ...,
        origin: typing.Text = ...,
        target_path: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["origin",b"origin","req_id",b"req_id","target_path",b"target_path","vega_id",b"vega_id"]) -> None: ...
global___MessageAckReq = MessageAckReq

class SubscribeReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TARGET_PATHS_FIELD_NUMBER: builtins.int
    @property
    def target_paths(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TargetPath]:
        """"""
        pass
    def __init__(self,
        *,
        target_paths: typing.Optional[typing.Iterable[global___TargetPath]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_paths",b"target_paths"]) -> None: ...
global___SubscribeReq = SubscribeReq

class TargetPath(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    KEY_FIELD_NUMBER: builtins.int
    SUBS_FIELD_NUMBER: builtins.int
    key: typing.Text
    """"""

    @property
    def subs(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    def __init__(self,
        *,
        key: typing.Text = ...,
        subs: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subs",b"subs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key",b"key","subs",b"subs"]) -> None: ...
global___TargetPath = TargetPath

class VegaFrame(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OPTIONS_FIELD_NUMBER: builtins.int
    ROUTE_PATH_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    SUB_BIZ_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___FrameOption:
        """"""
        pass
    route_path: typing.Text
    """"""

    @property
    def body(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    @property
    def sub_biz(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    def __init__(self,
        *,
        options: typing.Optional[global___FrameOption] = ...,
        route_path: typing.Text = ...,
        body: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        sub_biz: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body",b"body","options",b"options","sub_biz",b"sub_biz"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body",b"body","options",b"options","route_path",b"route_path","sub_biz",b"sub_biz"]) -> None: ...
global___VegaFrame = VegaFrame
