# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/im/notify.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/broadcast/message/im/notify.proto\x12\x1d\x62ilibili.broadcast.message.im\x1a\x1bgoogle/protobuf/empty.proto\"s\n\tNotifyRsp\x12\x0b\n\x03uid\x18\x01 \x01(\x04\x12\x0b\n\x03\x63md\x18\x02 \x01(\x04\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12;\n\x0cpayload_type\x18\x04 \x01(\x0e\x32%.bilibili.broadcast.message.im.PLType\"\xd8\x02\n\x03Msg\x12\x12\n\nsender_uid\x18\x01 \x01(\x04\x12\x15\n\rreceiver_type\x18\x02 \x01(\x05\x12\x13\n\x0breceiver_id\x18\x03 \x01(\x04\x12\x12\n\ncli_msg_id\x18\x04 \x01(\x04\x12\x10\n\x08msg_type\x18\x05 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\x11\n\tmsg_seqno\x18\x07 \x01(\x04\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\x12\x0f\n\x07\x61t_uids\x18\t \x03(\x04\x12\x12\n\nrecver_ids\x18\n \x03(\x04\x12\x0f\n\x07msg_key\x18\x0b \x01(\x04\x12\x12\n\nmsg_status\x18\x0c \x01(\r\x12\x12\n\nsys_cancel\x18\r \x01(\x08\x12\x15\n\ris_multi_chat\x18\x0e \x01(\r\x12\x16\n\x0ewithdraw_seqno\x18\x0f \x01(\x04\x12\x13\n\x0bnotify_code\x18\x10 \x01(\t\x12\x12\n\nmsg_source\x18\x11 \x01(\r\"G\n\nNotifyInfo\x12\x10\n\x08msg_type\x18\x01 \x01(\r\x12\x11\n\ttalker_id\x18\x02 \x01(\x04\x12\x14\n\x0csession_type\x18\x03 \x01(\r\"\xa1\x01\n\x0fReqServerNotify\x12\x15\n\rlastest_seqno\x18\x01 \x01(\x04\x12\x37\n\x0binstant_msg\x18\x02 \x01(\x0b\x32\".bilibili.broadcast.message.im.Msg\x12>\n\x0bnotify_info\x18\x03 \x01(\x0b\x32).bilibili.broadcast.message.im.NotifyInfo*6\n\x06PLType\x12\x15\n\x11\x45N_PAYLOAD_NORMAL\x10\x00\x12\x15\n\x11\x45N_PAYLOAD_BASE64\x10\x01*P\n\x05\x43mdId\x12\x15\n\x11\x45N_CMD_ID_INVALID\x10\x00\x12\x18\n\x14\x45N_CMD_ID_MSG_NOTIFY\x10\x01\x12\x16\n\x12\x45N_CMD_ID_KICK_OUT\x10\x02\x32[\n\x06Notify\x12Q\n\x0bWatchNotify\x12\x16.google.protobuf.Empty\x1a(.bilibili.broadcast.message.im.NotifyRsp0\x01\x62\x06proto3')

_PLTYPE = DESCRIPTOR.enum_types_by_name['PLType']
PLType = enum_type_wrapper.EnumTypeWrapper(_PLTYPE)
_CMDID = DESCRIPTOR.enum_types_by_name['CmdId']
CmdId = enum_type_wrapper.EnumTypeWrapper(_CMDID)
EN_PAYLOAD_NORMAL = 0
EN_PAYLOAD_BASE64 = 1
EN_CMD_ID_INVALID = 0
EN_CMD_ID_MSG_NOTIFY = 1
EN_CMD_ID_KICK_OUT = 2


_NOTIFYRSP = DESCRIPTOR.message_types_by_name['NotifyRsp']
_MSG = DESCRIPTOR.message_types_by_name['Msg']
_NOTIFYINFO = DESCRIPTOR.message_types_by_name['NotifyInfo']
_REQSERVERNOTIFY = DESCRIPTOR.message_types_by_name['ReqServerNotify']
NotifyRsp = _reflection.GeneratedProtocolMessageType('NotifyRsp', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYRSP,
  '__module__' : 'bilibili.broadcast.message.im.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.im.NotifyRsp)
  })
_sym_db.RegisterMessage(NotifyRsp)

Msg = _reflection.GeneratedProtocolMessageType('Msg', (_message.Message,), {
  'DESCRIPTOR' : _MSG,
  '__module__' : 'bilibili.broadcast.message.im.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.im.Msg)
  })
_sym_db.RegisterMessage(Msg)

NotifyInfo = _reflection.GeneratedProtocolMessageType('NotifyInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYINFO,
  '__module__' : 'bilibili.broadcast.message.im.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.im.NotifyInfo)
  })
_sym_db.RegisterMessage(NotifyInfo)

ReqServerNotify = _reflection.GeneratedProtocolMessageType('ReqServerNotify', (_message.Message,), {
  'DESCRIPTOR' : _REQSERVERNOTIFY,
  '__module__' : 'bilibili.broadcast.message.im.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.im.ReqServerNotify)
  })
_sym_db.RegisterMessage(ReqServerNotify)

_NOTIFY = DESCRIPTOR.services_by_name['Notify']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLTYPE._serialized_start=807
  _PLTYPE._serialized_end=861
  _CMDID._serialized_start=863
  _CMDID._serialized_end=943
  _NOTIFYRSP._serialized_start=106
  _NOTIFYRSP._serialized_end=221
  _MSG._serialized_start=224
  _MSG._serialized_end=568
  _NOTIFYINFO._serialized_start=570
  _NOTIFYINFO._serialized_end=641
  _REQSERVERNOTIFY._serialized_start=644
  _REQSERVERNOTIFY._serialized_end=805
  _NOTIFY._serialized_start=945
  _NOTIFY._serialized_end=1036
# @@protoc_insertion_point(module_scope)
