# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/main/community/reply/v1/reply.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/main/community/reply/v1/reply.proto\x12 bilibili.main.community.reply.v1\x1a\x19google/protobuf/any.proto\"U\n\x08\x41\x63tivity\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x16\n\x0e\x61\x63tivity_state\x18\x02 \x01(\x03\x12\x1c\n\x14\x61\x63tivity_placeholder\x18\x03 \x01(\t\"G\n\x11\x41rticleSearchItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bup_nickname\x18\x02 \x01(\t\x12\x0e\n\x06\x63overs\x18\x03 \x03(\t\"j\n\x07\x41tGroup\x12\x12\n\ngroup_type\x18\x01 \x01(\x05\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x37\n\x05items\x18\x03 \x03(\x0b\x32(.bilibili.main.community.reply.v1.AtItem\"]\n\x06\x41tItem\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x04 \x01(\x05\x12\x1c\n\x14official_verify_type\x18\x05 \x01(\x05\"J\n\rAtSearchReply\x12\x39\n\x06groups\x18\x01 \x03(\x0b\x32).bilibili.main.community.reply.v1.AtGroup\"+\n\x0b\x41tSearchReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"2\n\x02\x43M\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"\xbc\x05\n\x07\x43ontent\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x45\n\x06menber\x18\x02 \x03(\x0b\x32\x35.bilibili.main.community.reply.v1.Content.MenberEntry\x12\x43\n\x05\x65mote\x18\x03 \x03(\x0b\x32\x34.bilibili.main.community.reply.v1.Content.EmoteEntry\x12\x43\n\x05topic\x18\x04 \x03(\x0b\x32\x34.bilibili.main.community.reply.v1.Content.TopicEntry\x12?\n\x03url\x18\x05 \x03(\x0b\x32\x32.bilibili.main.community.reply.v1.Content.UrlEntry\x12\x34\n\x04vote\x18\x06 \x01(\x0b\x32&.bilibili.main.community.reply.v1.Vote\x1aW\n\x0bMenberEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member:\x02\x38\x01\x1aU\n\nEmoteEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.bilibili.main.community.reply.v1.Emote:\x02\x38\x01\x1aU\n\nTopicEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.bilibili.main.community.reply.v1.Topic:\x02\x38\x01\x1aQ\n\x08UrlEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.bilibili.main.community.reply.v1.Url:\x02\x38\x01\"\x92\x01\n\x0b\x43ursorReply\x12\x0c\n\x04next\x18\x01 \x01(\x03\x12\x0c\n\x04prev\x18\x02 \x01(\x03\x12\x0f\n\x07isBegin\x18\x03 \x01(\x08\x12\r\n\x05isEnd\x18\x04 \x01(\x08\x12\x34\n\x04mode\x18\x05 \x01(\x0e\x32&.bilibili.main.community.reply.v1.Mode\x12\x11\n\tmode_text\x18\x06 \x01(\t\"]\n\tCursorReq\x12\x0c\n\x04next\x18\x01 \x01(\x03\x12\x0c\n\x04prev\x18\x02 \x01(\x03\x12\x34\n\x04mode\x18\x04 \x01(\x0e\x32&.bilibili.main.community.reply.v1.Mode\"\xcf\x02\n\x0f\x44\x65tailListReply\x12=\n\x06\x63ursor\x18\x01 \x01(\x0b\x32-.bilibili.main.community.reply.v1.CursorReply\x12I\n\x0fsubject_control\x18\x02 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.SubjectControl\x12\x39\n\x04root\x18\x03 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12<\n\x08\x61\x63tivity\x18\x04 \x01(\x0b\x32*.bilibili.main.community.reply.v1.Activity\x12\x39\n\x05likes\x18\x05 \x01(\x0b\x32*.bilibili.main.community.reply.v1.LikeInfo\"\xc5\x01\n\rDetailListReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\x0c\n\x04root\x18\x03 \x01(\x03\x12\x0c\n\x04rpid\x18\x04 \x01(\x03\x12;\n\x06\x63ursor\x18\x05 \x01(\x0b\x32+.bilibili.main.community.reply.v1.CursorReq\x12@\n\x05scene\x18\x06 \x01(\x0e\x32\x31.bilibili.main.community.reply.v1.DetailListScene\"\x97\x02\n\x0f\x44ialogListReply\x12=\n\x06\x63ursor\x18\x01 \x01(\x0b\x32-.bilibili.main.community.reply.v1.CursorReply\x12I\n\x0fsubject_control\x18\x02 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.SubjectControl\x12<\n\x07replies\x18\x03 \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12<\n\x08\x61\x63tivity\x18\x04 \x01(\x0b\x32*.bilibili.main.community.reply.v1.Activity\"\x83\x01\n\rDialogListReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\x0c\n\x04root\x18\x03 \x01(\x03\x12\x0c\n\x04rpid\x18\x04 \x01(\x03\x12;\n\x06\x63ursor\x18\x05 \x01(\x0b\x32+.bilibili.main.community.reply.v1.CursorReq\"\x1d\n\x07\x45\x66\x66\x65\x63ts\x12\x12\n\npreloading\x18\x01 \x01(\t\"y\n\x05\x45mote\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x12\n\njump_title\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\x12\x12\n\npackage_id\x18\x06 \x01(\x03\x12\x0f\n\x07gif_url\x18\x07 \x01(\t\"f\n\x0fGoodsSearchItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\t\x12\x0e\n\x06income\x18\x04 \x01(\t\x12\x0b\n\x03img\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\"\x9b\x01\n\x08LikeInfo\x12>\n\x05items\x18\x01 \x03(\x0b\x32/.bilibili.main.community.reply.v1.LikeInfo.Item\x12\r\n\x05title\x18\x02 \x01(\t\x1a@\n\x04Item\x12\x38\n\x06member\x18\x01 \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member\"\xc7\x02\n\x07Lottery\x12\x12\n\nlottery_id\x18\x01 \x01(\x03\x12\x16\n\x0elottery_status\x18\x02 \x01(\x03\x12\x13\n\x0blottery_mid\x18\x03 \x01(\x03\x12\x14\n\x0clottery_time\x18\x04 \x01(\x03\x12\x0b\n\x03oid\x18\x05 \x01(\x03\x12\x0c\n\x04type\x18\x06 \x01(\x03\x12\r\n\x05\x63time\x18\x07 \x01(\x03\x12:\n\x07\x63ontent\x18\x08 \x01(\x0b\x32).bilibili.main.community.reply.v1.Content\x12\x38\n\x06member\x18\t \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member\x12\x45\n\rreply_control\x18\n \x01(\x0b\x32..bilibili.main.community.reply.v1.ReplyControl\"\xb9\x08\n\rMainListReply\x12=\n\x06\x63ursor\x18\x01 \x01(\x0b\x32-.bilibili.main.community.reply.v1.CursorReply\x12<\n\x07replies\x18\x02 \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12I\n\x0fsubject_control\x18\x03 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.SubjectControl\x12;\n\x06up_top\x18\x04 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12>\n\tadmin_top\x18\x05 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12=\n\x08vote_top\x18\x06 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12\x38\n\x06notice\x18\x07 \x01(\x0b\x32(.bilibili.main.community.reply.v1.Notice\x12:\n\x07lottery\x18\x08 \x01(\x0b\x32).bilibili.main.community.reply.v1.Lottery\x12<\n\x08\x61\x63tivity\x18\t \x01(\x0b\x32*.bilibili.main.community.reply.v1.Activity\x12\x43\n\x0cup_selection\x18\n \x01(\x0b\x32-.bilibili.main.community.reply.v1.UpSelection\x12\x30\n\x02\x63m\x18\x0b \x01(\x0b\x32$.bilibili.main.community.reply.v1.CM\x12:\n\x07\x65\x66\x66\x65\x63ts\x18\x0c \x01(\x0b\x32).bilibili.main.community.reply.v1.Effects\x12>\n\toperation\x18\r \x01(\x0b\x32+.bilibili.main.community.reply.v1.Operation\x12@\n\x0btop_replies\x18\x0e \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12\x36\n\x03qoe\x18\x0f \x01(\x0b\x32).bilibili.main.community.reply.v1.QoeInfo\x12Q\n\tcallbacks\x18\x10 \x03(\x0b\x32>.bilibili.main.community.reply.v1.MainListReply.CallbacksEntry\x1a\x30\n\x0e\x43\x61llbacksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x94\x01\n\x0bMainListReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12;\n\x06\x63ursor\x18\x03 \x01(\x0b\x32+.bilibili.main.community.reply.v1.CursorReq\x12\r\n\x05\x65xtra\x18\x04 \x01(\t\x12\x10\n\x08\x61\x64_extra\x18\x05 \x01(\t\x12\x0c\n\x04rpid\x18\x06 \x01(\x03\"\x99\x06\n\x06Member\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\x03\x12\x1c\n\x14official_verify_type\x18\x06 \x01(\x03\x12\x10\n\x08vip_type\x18\x07 \x01(\x03\x12\x12\n\nvip_status\x18\x08 \x01(\x03\x12\x16\n\x0evip_theme_type\x18\t \x01(\x03\x12\x16\n\x0evip_label_path\x18\n \x01(\t\x12\x1a\n\x12garb_pendant_image\x18\x0b \x01(\t\x12\x17\n\x0fgarb_card_image\x18\x0c \x01(\t\x12\"\n\x1agarb_card_image_with_focus\x18\r \x01(\t\x12\x1a\n\x12garb_card_jump_url\x18\x0e \x01(\t\x12\x18\n\x10garb_card_number\x18\x0f \x01(\t\x12\x1b\n\x13garb_card_fan_color\x18\x10 \x01(\t\x12\x18\n\x10garb_card_is_fan\x18\x11 \x01(\x08\x12\x17\n\x0f\x66\x61ns_medal_name\x18\x12 \x01(\t\x12\x18\n\x10\x66\x61ns_medal_level\x18\x13 \x01(\x03\x12\x18\n\x10\x66\x61ns_medal_color\x18\x14 \x01(\x03\x12\x1a\n\x12vip_nickname_color\x18\x15 \x01(\t\x12\x1c\n\x14vip_avatar_subscript\x18\x16 \x01(\x05\x12\x16\n\x0evip_label_text\x18\x17 \x01(\t\x12\x17\n\x0fvip_label_theme\x18\x18 \x01(\t\x12\x1c\n\x14\x66\x61ns_medal_color_end\x18\x19 \x01(\x03\x12\x1f\n\x17\x66\x61ns_medal_color_border\x18\x1a \x01(\x03\x12\x1d\n\x15\x66\x61ns_medal_color_name\x18\x1b \x01(\x03\x12\x1e\n\x16\x66\x61ns_medal_color_level\x18\x1c \x01(\x03\x12\x18\n\x10\x66\x61ns_guard_level\x18\x1d \x01(\x03\x12\x10\n\x08\x66\x61\x63\x65_nft\x18\x1e \x01(\x05\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\x1f \x01(\x05\x12\x18\n\x10is_senior_member\x18  \x01(\x05\"3\n\x06Notice\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xce\x01\n\tOperation\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12?\n\x05title\x18\x03 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.OperationTitle\x12\x42\n\x08subtitle\x18\x04 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.OperationTitle\x12\x0c\n\x04link\x18\x05 \x01(\t\x12\x14\n\x0creport_extra\x18\x06 \x01(\t\"7\n\x0eOperationTitle\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x14\n\x0cis_highlight\x18\x02 \x01(\x08\"D\n\x12PGCVideoSearchItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\x95\x03\n\x10PreviewListReply\x12=\n\x06\x63ursor\x18\x01 \x01(\x0b\x32-.bilibili.main.community.reply.v1.CursorReply\x12<\n\x07replies\x18\x02 \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12I\n\x0fsubject_control\x18\x03 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.SubjectControl\x12:\n\x05upTop\x18\x04 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12>\n\tadmin_top\x18\x05 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12=\n\x08vote_top\x18\x06 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\"h\n\x0ePreviewListReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12;\n\x06\x63ursor\x18\x03 \x01(\x0b\x32+.bilibili.main.community.reply.v1.CursorReq\"\xb4\x01\n\x07QoeInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\r\n\x05style\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\x12\x16\n\x0e\x66\x65\x65\x64\x62\x61\x63k_title\x18\x05 \x01(\t\x12\x43\n\x0bscore_items\x18\x06 \x03(\x0b\x32..bilibili.main.community.reply.v1.QoeScoreItem\x12\x14\n\x0c\x64isplay_rank\x18\x07 \x01(\x03\"9\n\x0cQoeScoreItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x02\"\x84\x02\n\x0eReplyCardLabel\x12\x14\n\x0ctext_content\x18\x01 \x01(\t\x12\x16\n\x0etext_color_day\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x17\n\x0flabel_color_day\x18\x04 \x01(\t\x12\x19\n\x11label_color_night\x18\x05 \x01(\t\x12\r\n\x05image\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\x05\x12\x12\n\nbackground\x18\x08 \x01(\t\x12\x18\n\x10\x62\x61\x63kground_width\x18\t \x01(\x01\x12\x19\n\x11\x62\x61\x63kground_height\x18\n \x01(\x01\x12\x10\n\x08jump_url\x18\x0b \x01(\t\"\xb5\x04\n\x0cReplyControl\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x03\x12\x0f\n\x07up_like\x18\x02 \x01(\x08\x12\x10\n\x08up_reply\x18\x03 \x01(\x08\x12\x17\n\x0fshow_follow_btn\x18\x04 \x01(\x08\x12\x11\n\tis_assist\x18\x05 \x01(\x08\x12\x12\n\nlabel_text\x18\x06 \x01(\t\x12\x11\n\tfollowing\x18\x07 \x01(\x08\x12\x10\n\x08\x66ollowed\x18\x08 \x01(\x08\x12\x0f\n\x07\x62locked\x18\t \x01(\x08\x12\x18\n\x10has_folded_reply\x18\n \x01(\x08\x12\x17\n\x0fis_folded_reply\x18\x0b \x01(\x08\x12\x11\n\tis_up_top\x18\x0c \x01(\x08\x12\x14\n\x0cis_admin_top\x18\r \x01(\x08\x12\x13\n\x0bis_vote_top\x18\x0e \x01(\x08\x12\x10\n\x08max_line\x18\x0f \x01(\x03\x12\x11\n\tinvisible\x18\x10 \x01(\x08\x12\x15\n\ris_contractor\x18\x11 \x01(\x08\x12\x0f\n\x07is_note\x18\x12 \x01(\x08\x12\x45\n\x0b\x63\x61rd_labels\x18\x13 \x03(\x0b\x32\x30.bilibili.main.community.reply.v1.ReplyCardLabel\x12\x1c\n\x14sub_reply_entry_text\x18\x14 \x01(\t\x12\x1c\n\x14sub_reply_title_text\x18\x15 \x01(\t\x12\x15\n\rcontract_desc\x18\x16 \x01(\t\x12\x11\n\ttime_desc\x18\x17 \x01(\t\x12\x11\n\tbiz_scene\x18\x18 \x01(\t\"U\n\nReplyExtra\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x13\n\x0bseason_type\x18\x02 \x01(\x03\x12\r\n\x05\x65p_id\x18\x03 \x01(\x03\x12\x10\n\x08is_story\x18\x04 \x01(\x08\"\x94\x03\n\tReplyInfo\x12<\n\x07replies\x18\x01 \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x03\x12\x0b\n\x03mid\x18\x05 \x01(\x03\x12\x0c\n\x04root\x18\x06 \x01(\x03\x12\x0e\n\x06parent\x18\x07 \x01(\x03\x12\x0e\n\x06\x64ialog\x18\x08 \x01(\x03\x12\x0c\n\x04like\x18\t \x01(\x03\x12\r\n\x05\x63time\x18\n \x01(\x03\x12\r\n\x05\x63ount\x18\x0b \x01(\x03\x12:\n\x07\x63ontent\x18\x0c \x01(\x0b\x32).bilibili.main.community.reply.v1.Content\x12\x38\n\x06member\x18\r \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member\x12\x45\n\rreply_control\x18\x0e \x01(\x0b\x32..bilibili.main.community.reply.v1.ReplyControl\"L\n\x0eReplyInfoReply\x12:\n\x05reply\x18\x01 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\"+\n\x0cReplyInfoReq\x12\x0c\n\x04rpid\x18\x01 \x01(\x03\x12\r\n\x05scene\x18\x02 \x01(\x05\"\xf1\x01\n\nSearchItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x42\n\x05goods\x18\x02 \x01(\x0b\x32\x31.bilibili.main.community.reply.v1.GoodsSearchItemH\x00\x12\x42\n\x05video\x18\x03 \x01(\x0b\x32\x31.bilibili.main.community.reply.v1.VideoSearchItemH\x00\x12\x46\n\x07\x61rticle\x18\x04 \x01(\x0b\x32\x33.bilibili.main.community.reply.v1.ArticleSearchItemH\x00\x42\x06\n\x04item\"7\n\x15SearchItemCursorReply\x12\x10\n\x08has_next\x18\x01 \x01(\x08\x12\x0c\n\x04next\x18\x02 \x01(\x03\"h\n\x13SearchItemCursorReq\x12\x0c\n\x04next\x18\x01 \x01(\x03\x12\x43\n\titem_type\x18\x02 \x01(\x0e\x32\x30.bilibili.main.community.reply.v1.SearchItemType\"\x93\x01\n\x16SearchItemPreHookReply\x12\x18\n\x10placeholder_text\x18\x01 \x01(\t\x12\x17\n\x0f\x62\x61\x63kground_text\x18\x02 \x01(\t\x12\x46\n\x0cordered_type\x18\x03 \x03(\x0e\x32\x30.bilibili.main.community.reply.v1.SearchItemType\"1\n\x14SearchItemPreHookReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\"\xe2\x01\n\x0fSearchItemReply\x12G\n\x06\x63ursor\x18\x01 \x01(\x0b\x32\x37.bilibili.main.community.reply.v1.SearchItemCursorReply\x12;\n\x05items\x18\x02 \x03(\x0b\x32,.bilibili.main.community.reply.v1.SearchItem\x12I\n\x05\x65xtra\x18\x03 \x01(\x0b\x32:.bilibili.main.community.reply.v1.SearchItemReplyExtraInfo\",\n\x18SearchItemReplyExtraInfo\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\"\x82\x01\n\rSearchItemReq\x12\x45\n\x06\x63ursor\x18\x01 \x01(\x0b\x32\x35.bilibili.main.community.reply.v1.SearchItemCursorReq\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x03\x12\x0f\n\x07keyword\x18\x04 \x01(\t\"0\n\x13ShareRepliesInfoReq\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x03\"\xf6\x02\n\x14ShareRepliesInfoResp\x12?\n\x05infos\x18\x01 \x03(\x0b\x32\x30.bilibili.main.community.reply.v1.ShareReplyInfo\x12\x12\n\nfrom_title\x18\x02 \x01(\t\x12\x0f\n\x07\x66rom_up\x18\x03 \x01(\t\x12\x10\n\x08\x66rom_pic\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x12\n\nslogan_pic\x18\x06 \x01(\t\x12\x13\n\x0bslogan_text\x18\x07 \x01(\t\x12@\n\x05topic\x18\x08 \x01(\x0b\x32\x31.bilibili.main.community.reply.v1.ShareReplyTopic\x12P\n\x05\x65xtra\x18\t \x01(\x0b\x32\x41.bilibili.main.community.reply.v1.ShareRepliesInfoResp.ShareExtra\x1a\x1c\n\nShareExtra\x12\x0e\n\x06is_pgc\x18\x01 \x01(\x08\"\xd5\x01\n\x0eShareReplyInfo\x12\x38\n\x06member\x18\x01 \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member\x12:\n\x07\x63ontent\x18\x02 \x01(\x0b\x32).bilibili.main.community.reply.v1.Content\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\x18\n\x10\x61\x63hievement_text\x18\x05 \x01(\t\x12\x11\n\tlabel_url\x18\x06 \x01(\t\"^\n\x0fShareReplyTopic\x12\x36\n\x05topic\x18\x01 \x01(\x0b\x32\'.bilibili.main.community.reply.v1.Topic\x12\x13\n\x0borigin_text\x18\x02 \x01(\t\"\xc0\x03\n\x0eSubjectControl\x12\x0e\n\x06up_mid\x18\x01 \x01(\x03\x12\x11\n\tis_assist\x18\x02 \x01(\x08\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x17\n\x0fhas_vote_access\x18\x04 \x01(\x08\x12\x1a\n\x12has_lottery_access\x18\x05 \x01(\x08\x12\x18\n\x10has_folded_reply\x18\x06 \x01(\x08\x12\x0f\n\x07\x62g_text\x18\x07 \x01(\t\x12\x12\n\nup_blocked\x18\x08 \x01(\x08\x12\x1b\n\x13has_activity_access\x18\t \x01(\x08\x12\x12\n\nshow_title\x18\n \x01(\x08\x12\x16\n\x0eshow_up_action\x18\x0b \x01(\x08\x12\x15\n\rswitcher_type\x18\x0c \x01(\x03\x12\x15\n\rinput_disable\x18\r \x01(\x08\x12\x11\n\troot_text\x18\x0e \x01(\t\x12\x12\n\nchild_text\x18\x0f \x01(\t\x12\r\n\x05\x63ount\x18\x10 \x01(\x03\x12\r\n\x05title\x18\x11 \x01(\t\x12\x13\n\x0bgiveup_text\x18\x12 \x01(\t\x12\x17\n\x0fhas_note_access\x18\x13 \x01(\x08\x12\x1a\n\x12\x64isable_jump_emote\x18\x14 \x01(\x08\"!\n\x05Topic\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"Y\n\x12UGCVideoSearchItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bup_nickname\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\r\n\x05\x63over\x18\x04 \x01(\t\":\n\x0bUpSelection\x12\x15\n\rpending_count\x18\x01 \x01(\x03\x12\x14\n\x0cignore_count\x18\x02 \x01(\x03\"\xc3\x01\n\x03Url\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\x03\x12\x13\n\x0bprefix_icon\x18\x03 \x01(\t\x12\x16\n\x0e\x61pp_url_schema\x18\x04 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x05 \x01(\t\x12\x18\n\x10\x61pp_package_name\x18\x06 \x01(\t\x12\x14\n\x0c\x63lick_report\x18\x07 \x01(\t\x12\x16\n\x0eis_half_screen\x18\x08 \x01(\x08\x12\x17\n\x0f\x65xposure_report\x18\t \x01(\t\"\x13\n\x11UserCallbackReply\"\xc3\x01\n\x0fUserCallbackReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x42\n\x05scene\x18\x02 \x01(\x0e\x32\x33.bilibili.main.community.reply.v1.UserCallbackScene\x12\x44\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x34.bilibili.main.community.reply.v1.UserCallbackAction\x12\x0b\n\x03oid\x18\x04 \x01(\x03\x12\x0c\n\x04type\x18\x05 \x01(\x03\"\xf1\x01\n\x0fVideoSearchItem\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x38.bilibili.main.community.reply.v1.SearchItemVideoSubType\x12\x43\n\x03ugc\x18\x02 \x01(\x0b\x32\x34.bilibili.main.community.reply.v1.UGCVideoSearchItemH\x00\x12\x43\n\x03pgc\x18\x03 \x01(\x0b\x32\x34.bilibili.main.community.reply.v1.PGCVideoSearchItemH\x00\x42\x0c\n\nvideo_item\"0\n\x04Vote\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x03*6\n\x0f\x44\x65tailListScene\x12\t\n\x05REPLY\x10\x00\x12\x0c\n\x08MSG_FEED\x10\x01\x12\n\n\x06NOTIFY\x10\x02*K\n\x04Mode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0f\n\x0bUNSPECIFIED\x10\x01\x12\x12\n\x0eMAIN_LIST_TIME\x10\x02\x12\x11\n\rMAIN_LIST_HOT\x10\x03*J\n\x0eSearchItemType\x12\x15\n\x11\x44\x45\x46\x41ULT_ITEM_TYPE\x10\x00\x12\t\n\x05GOODS\x10\x01\x12\t\n\x05VIDEO\x10\x02\x12\x0b\n\x07\x41RTICLE\x10\x03**\n\x16SearchItemVideoSubType\x12\x07\n\x03UGC\x10\x00\x12\x07\n\x03PGC\x10\x01*!\n\x12UserCallbackAction\x12\x0b\n\x07\x44ismiss\x10\x00*\x1f\n\x11UserCallbackScene\x12\n\n\x06Insert\x10\x00\x32\x9d\t\n\x05Reply\x12j\n\x08MainList\x12-.bilibili.main.community.reply.v1.MainListReq\x1a/.bilibili.main.community.reply.v1.MainListReply\x12p\n\nDetailList\x12/.bilibili.main.community.reply.v1.DetailListReq\x1a\x31.bilibili.main.community.reply.v1.DetailListReply\x12p\n\nDialogList\x12/.bilibili.main.community.reply.v1.DialogListReq\x1a\x31.bilibili.main.community.reply.v1.DialogListReply\x12s\n\x0bPreviewList\x12\x30.bilibili.main.community.reply.v1.PreviewListReq\x1a\x32.bilibili.main.community.reply.v1.PreviewListReply\x12\x85\x01\n\x11SearchItemPreHook\x12\x36.bilibili.main.community.reply.v1.SearchItemPreHookReq\x1a\x38.bilibili.main.community.reply.v1.SearchItemPreHookReply\x12p\n\nSearchItem\x12/.bilibili.main.community.reply.v1.SearchItemReq\x1a\x31.bilibili.main.community.reply.v1.SearchItemReply\x12j\n\x08\x41tSearch\x12-.bilibili.main.community.reply.v1.AtSearchReq\x1a/.bilibili.main.community.reply.v1.AtSearchReply\x12m\n\tReplyInfo\x12..bilibili.main.community.reply.v1.ReplyInfoReq\x1a\x30.bilibili.main.community.reply.v1.ReplyInfoReply\x12v\n\x0cUserCallback\x12\x31.bilibili.main.community.reply.v1.UserCallbackReq\x1a\x33.bilibili.main.community.reply.v1.UserCallbackReply\x12\x81\x01\n\x10ShareRepliesInfo\x12\x35.bilibili.main.community.reply.v1.ShareRepliesInfoReq\x1a\x36.bilibili.main.community.reply.v1.ShareRepliesInfoRespb\x06proto3')

_DETAILLISTSCENE = DESCRIPTOR.enum_types_by_name['DetailListScene']
DetailListScene = enum_type_wrapper.EnumTypeWrapper(_DETAILLISTSCENE)
_MODE = DESCRIPTOR.enum_types_by_name['Mode']
Mode = enum_type_wrapper.EnumTypeWrapper(_MODE)
_SEARCHITEMTYPE = DESCRIPTOR.enum_types_by_name['SearchItemType']
SearchItemType = enum_type_wrapper.EnumTypeWrapper(_SEARCHITEMTYPE)
_SEARCHITEMVIDEOSUBTYPE = DESCRIPTOR.enum_types_by_name['SearchItemVideoSubType']
SearchItemVideoSubType = enum_type_wrapper.EnumTypeWrapper(_SEARCHITEMVIDEOSUBTYPE)
_USERCALLBACKACTION = DESCRIPTOR.enum_types_by_name['UserCallbackAction']
UserCallbackAction = enum_type_wrapper.EnumTypeWrapper(_USERCALLBACKACTION)
_USERCALLBACKSCENE = DESCRIPTOR.enum_types_by_name['UserCallbackScene']
UserCallbackScene = enum_type_wrapper.EnumTypeWrapper(_USERCALLBACKSCENE)
REPLY = 0
MSG_FEED = 1
NOTIFY = 2
DEFAULT = 0
UNSPECIFIED = 1
MAIN_LIST_TIME = 2
MAIN_LIST_HOT = 3
DEFAULT_ITEM_TYPE = 0
GOODS = 1
VIDEO = 2
ARTICLE = 3
UGC = 0
PGC = 1
Dismiss = 0
Insert = 0


_ACTIVITY = DESCRIPTOR.message_types_by_name['Activity']
_ARTICLESEARCHITEM = DESCRIPTOR.message_types_by_name['ArticleSearchItem']
_ATGROUP = DESCRIPTOR.message_types_by_name['AtGroup']
_ATITEM = DESCRIPTOR.message_types_by_name['AtItem']
_ATSEARCHREPLY = DESCRIPTOR.message_types_by_name['AtSearchReply']
_ATSEARCHREQ = DESCRIPTOR.message_types_by_name['AtSearchReq']
_CM = DESCRIPTOR.message_types_by_name['CM']
_CONTENT = DESCRIPTOR.message_types_by_name['Content']
_CONTENT_MENBERENTRY = _CONTENT.nested_types_by_name['MenberEntry']
_CONTENT_EMOTEENTRY = _CONTENT.nested_types_by_name['EmoteEntry']
_CONTENT_TOPICENTRY = _CONTENT.nested_types_by_name['TopicEntry']
_CONTENT_URLENTRY = _CONTENT.nested_types_by_name['UrlEntry']
_CURSORREPLY = DESCRIPTOR.message_types_by_name['CursorReply']
_CURSORREQ = DESCRIPTOR.message_types_by_name['CursorReq']
_DETAILLISTREPLY = DESCRIPTOR.message_types_by_name['DetailListReply']
_DETAILLISTREQ = DESCRIPTOR.message_types_by_name['DetailListReq']
_DIALOGLISTREPLY = DESCRIPTOR.message_types_by_name['DialogListReply']
_DIALOGLISTREQ = DESCRIPTOR.message_types_by_name['DialogListReq']
_EFFECTS = DESCRIPTOR.message_types_by_name['Effects']
_EMOTE = DESCRIPTOR.message_types_by_name['Emote']
_GOODSSEARCHITEM = DESCRIPTOR.message_types_by_name['GoodsSearchItem']
_LIKEINFO = DESCRIPTOR.message_types_by_name['LikeInfo']
_LIKEINFO_ITEM = _LIKEINFO.nested_types_by_name['Item']
_LOTTERY = DESCRIPTOR.message_types_by_name['Lottery']
_MAINLISTREPLY = DESCRIPTOR.message_types_by_name['MainListReply']
_MAINLISTREPLY_CALLBACKSENTRY = _MAINLISTREPLY.nested_types_by_name['CallbacksEntry']
_MAINLISTREQ = DESCRIPTOR.message_types_by_name['MainListReq']
_MEMBER = DESCRIPTOR.message_types_by_name['Member']
_NOTICE = DESCRIPTOR.message_types_by_name['Notice']
_OPERATION = DESCRIPTOR.message_types_by_name['Operation']
_OPERATIONTITLE = DESCRIPTOR.message_types_by_name['OperationTitle']
_PGCVIDEOSEARCHITEM = DESCRIPTOR.message_types_by_name['PGCVideoSearchItem']
_PREVIEWLISTREPLY = DESCRIPTOR.message_types_by_name['PreviewListReply']
_PREVIEWLISTREQ = DESCRIPTOR.message_types_by_name['PreviewListReq']
_QOEINFO = DESCRIPTOR.message_types_by_name['QoeInfo']
_QOESCOREITEM = DESCRIPTOR.message_types_by_name['QoeScoreItem']
_REPLYCARDLABEL = DESCRIPTOR.message_types_by_name['ReplyCardLabel']
_REPLYCONTROL = DESCRIPTOR.message_types_by_name['ReplyControl']
_REPLYEXTRA = DESCRIPTOR.message_types_by_name['ReplyExtra']
_REPLYINFO = DESCRIPTOR.message_types_by_name['ReplyInfo']
_REPLYINFOREPLY = DESCRIPTOR.message_types_by_name['ReplyInfoReply']
_REPLYINFOREQ = DESCRIPTOR.message_types_by_name['ReplyInfoReq']
_SEARCHITEM = DESCRIPTOR.message_types_by_name['SearchItem']
_SEARCHITEMCURSORREPLY = DESCRIPTOR.message_types_by_name['SearchItemCursorReply']
_SEARCHITEMCURSORREQ = DESCRIPTOR.message_types_by_name['SearchItemCursorReq']
_SEARCHITEMPREHOOKREPLY = DESCRIPTOR.message_types_by_name['SearchItemPreHookReply']
_SEARCHITEMPREHOOKREQ = DESCRIPTOR.message_types_by_name['SearchItemPreHookReq']
_SEARCHITEMREPLY = DESCRIPTOR.message_types_by_name['SearchItemReply']
_SEARCHITEMREPLYEXTRAINFO = DESCRIPTOR.message_types_by_name['SearchItemReplyExtraInfo']
_SEARCHITEMREQ = DESCRIPTOR.message_types_by_name['SearchItemReq']
_SHAREREPLIESINFOREQ = DESCRIPTOR.message_types_by_name['ShareRepliesInfoReq']
_SHAREREPLIESINFORESP = DESCRIPTOR.message_types_by_name['ShareRepliesInfoResp']
_SHAREREPLIESINFORESP_SHAREEXTRA = _SHAREREPLIESINFORESP.nested_types_by_name['ShareExtra']
_SHAREREPLYINFO = DESCRIPTOR.message_types_by_name['ShareReplyInfo']
_SHAREREPLYTOPIC = DESCRIPTOR.message_types_by_name['ShareReplyTopic']
_SUBJECTCONTROL = DESCRIPTOR.message_types_by_name['SubjectControl']
_TOPIC = DESCRIPTOR.message_types_by_name['Topic']
_UGCVIDEOSEARCHITEM = DESCRIPTOR.message_types_by_name['UGCVideoSearchItem']
_UPSELECTION = DESCRIPTOR.message_types_by_name['UpSelection']
_URL = DESCRIPTOR.message_types_by_name['Url']
_USERCALLBACKREPLY = DESCRIPTOR.message_types_by_name['UserCallbackReply']
_USERCALLBACKREQ = DESCRIPTOR.message_types_by_name['UserCallbackReq']
_VIDEOSEARCHITEM = DESCRIPTOR.message_types_by_name['VideoSearchItem']
_VOTE = DESCRIPTOR.message_types_by_name['Vote']
Activity = _reflection.GeneratedProtocolMessageType('Activity', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Activity)
  })
_sym_db.RegisterMessage(Activity)

ArticleSearchItem = _reflection.GeneratedProtocolMessageType('ArticleSearchItem', (_message.Message,), {
  'DESCRIPTOR' : _ARTICLESEARCHITEM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ArticleSearchItem)
  })
_sym_db.RegisterMessage(ArticleSearchItem)

AtGroup = _reflection.GeneratedProtocolMessageType('AtGroup', (_message.Message,), {
  'DESCRIPTOR' : _ATGROUP,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.AtGroup)
  })
_sym_db.RegisterMessage(AtGroup)

AtItem = _reflection.GeneratedProtocolMessageType('AtItem', (_message.Message,), {
  'DESCRIPTOR' : _ATITEM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.AtItem)
  })
_sym_db.RegisterMessage(AtItem)

AtSearchReply = _reflection.GeneratedProtocolMessageType('AtSearchReply', (_message.Message,), {
  'DESCRIPTOR' : _ATSEARCHREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.AtSearchReply)
  })
_sym_db.RegisterMessage(AtSearchReply)

AtSearchReq = _reflection.GeneratedProtocolMessageType('AtSearchReq', (_message.Message,), {
  'DESCRIPTOR' : _ATSEARCHREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.AtSearchReq)
  })
_sym_db.RegisterMessage(AtSearchReq)

CM = _reflection.GeneratedProtocolMessageType('CM', (_message.Message,), {
  'DESCRIPTOR' : _CM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.CM)
  })
_sym_db.RegisterMessage(CM)

Content = _reflection.GeneratedProtocolMessageType('Content', (_message.Message,), {

  'MenberEntry' : _reflection.GeneratedProtocolMessageType('MenberEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTENT_MENBERENTRY,
    '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Content.MenberEntry)
    })
  ,

  'EmoteEntry' : _reflection.GeneratedProtocolMessageType('EmoteEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTENT_EMOTEENTRY,
    '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Content.EmoteEntry)
    })
  ,

  'TopicEntry' : _reflection.GeneratedProtocolMessageType('TopicEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTENT_TOPICENTRY,
    '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Content.TopicEntry)
    })
  ,

  'UrlEntry' : _reflection.GeneratedProtocolMessageType('UrlEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTENT_URLENTRY,
    '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Content.UrlEntry)
    })
  ,
  'DESCRIPTOR' : _CONTENT,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Content)
  })
_sym_db.RegisterMessage(Content)
_sym_db.RegisterMessage(Content.MenberEntry)
_sym_db.RegisterMessage(Content.EmoteEntry)
_sym_db.RegisterMessage(Content.TopicEntry)
_sym_db.RegisterMessage(Content.UrlEntry)

CursorReply = _reflection.GeneratedProtocolMessageType('CursorReply', (_message.Message,), {
  'DESCRIPTOR' : _CURSORREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.CursorReply)
  })
_sym_db.RegisterMessage(CursorReply)

CursorReq = _reflection.GeneratedProtocolMessageType('CursorReq', (_message.Message,), {
  'DESCRIPTOR' : _CURSORREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.CursorReq)
  })
_sym_db.RegisterMessage(CursorReq)

DetailListReply = _reflection.GeneratedProtocolMessageType('DetailListReply', (_message.Message,), {
  'DESCRIPTOR' : _DETAILLISTREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.DetailListReply)
  })
_sym_db.RegisterMessage(DetailListReply)

DetailListReq = _reflection.GeneratedProtocolMessageType('DetailListReq', (_message.Message,), {
  'DESCRIPTOR' : _DETAILLISTREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.DetailListReq)
  })
_sym_db.RegisterMessage(DetailListReq)

DialogListReply = _reflection.GeneratedProtocolMessageType('DialogListReply', (_message.Message,), {
  'DESCRIPTOR' : _DIALOGLISTREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.DialogListReply)
  })
_sym_db.RegisterMessage(DialogListReply)

DialogListReq = _reflection.GeneratedProtocolMessageType('DialogListReq', (_message.Message,), {
  'DESCRIPTOR' : _DIALOGLISTREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.DialogListReq)
  })
_sym_db.RegisterMessage(DialogListReq)

Effects = _reflection.GeneratedProtocolMessageType('Effects', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTS,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Effects)
  })
_sym_db.RegisterMessage(Effects)

Emote = _reflection.GeneratedProtocolMessageType('Emote', (_message.Message,), {
  'DESCRIPTOR' : _EMOTE,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Emote)
  })
_sym_db.RegisterMessage(Emote)

GoodsSearchItem = _reflection.GeneratedProtocolMessageType('GoodsSearchItem', (_message.Message,), {
  'DESCRIPTOR' : _GOODSSEARCHITEM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.GoodsSearchItem)
  })
_sym_db.RegisterMessage(GoodsSearchItem)

LikeInfo = _reflection.GeneratedProtocolMessageType('LikeInfo', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _LIKEINFO_ITEM,
    '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.LikeInfo.Item)
    })
  ,
  'DESCRIPTOR' : _LIKEINFO,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.LikeInfo)
  })
_sym_db.RegisterMessage(LikeInfo)
_sym_db.RegisterMessage(LikeInfo.Item)

Lottery = _reflection.GeneratedProtocolMessageType('Lottery', (_message.Message,), {
  'DESCRIPTOR' : _LOTTERY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Lottery)
  })
_sym_db.RegisterMessage(Lottery)

MainListReply = _reflection.GeneratedProtocolMessageType('MainListReply', (_message.Message,), {

  'CallbacksEntry' : _reflection.GeneratedProtocolMessageType('CallbacksEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAINLISTREPLY_CALLBACKSENTRY,
    '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.MainListReply.CallbacksEntry)
    })
  ,
  'DESCRIPTOR' : _MAINLISTREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.MainListReply)
  })
_sym_db.RegisterMessage(MainListReply)
_sym_db.RegisterMessage(MainListReply.CallbacksEntry)

MainListReq = _reflection.GeneratedProtocolMessageType('MainListReq', (_message.Message,), {
  'DESCRIPTOR' : _MAINLISTREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.MainListReq)
  })
_sym_db.RegisterMessage(MainListReq)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), {
  'DESCRIPTOR' : _MEMBER,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Member)
  })
_sym_db.RegisterMessage(Member)

Notice = _reflection.GeneratedProtocolMessageType('Notice', (_message.Message,), {
  'DESCRIPTOR' : _NOTICE,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Notice)
  })
_sym_db.RegisterMessage(Notice)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), {
  'DESCRIPTOR' : _OPERATION,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Operation)
  })
_sym_db.RegisterMessage(Operation)

OperationTitle = _reflection.GeneratedProtocolMessageType('OperationTitle', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONTITLE,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.OperationTitle)
  })
_sym_db.RegisterMessage(OperationTitle)

PGCVideoSearchItem = _reflection.GeneratedProtocolMessageType('PGCVideoSearchItem', (_message.Message,), {
  'DESCRIPTOR' : _PGCVIDEOSEARCHITEM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.PGCVideoSearchItem)
  })
_sym_db.RegisterMessage(PGCVideoSearchItem)

PreviewListReply = _reflection.GeneratedProtocolMessageType('PreviewListReply', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWLISTREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.PreviewListReply)
  })
_sym_db.RegisterMessage(PreviewListReply)

PreviewListReq = _reflection.GeneratedProtocolMessageType('PreviewListReq', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWLISTREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.PreviewListReq)
  })
_sym_db.RegisterMessage(PreviewListReq)

QoeInfo = _reflection.GeneratedProtocolMessageType('QoeInfo', (_message.Message,), {
  'DESCRIPTOR' : _QOEINFO,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.QoeInfo)
  })
_sym_db.RegisterMessage(QoeInfo)

QoeScoreItem = _reflection.GeneratedProtocolMessageType('QoeScoreItem', (_message.Message,), {
  'DESCRIPTOR' : _QOESCOREITEM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.QoeScoreItem)
  })
_sym_db.RegisterMessage(QoeScoreItem)

ReplyCardLabel = _reflection.GeneratedProtocolMessageType('ReplyCardLabel', (_message.Message,), {
  'DESCRIPTOR' : _REPLYCARDLABEL,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ReplyCardLabel)
  })
_sym_db.RegisterMessage(ReplyCardLabel)

ReplyControl = _reflection.GeneratedProtocolMessageType('ReplyControl', (_message.Message,), {
  'DESCRIPTOR' : _REPLYCONTROL,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ReplyControl)
  })
_sym_db.RegisterMessage(ReplyControl)

ReplyExtra = _reflection.GeneratedProtocolMessageType('ReplyExtra', (_message.Message,), {
  'DESCRIPTOR' : _REPLYEXTRA,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ReplyExtra)
  })
_sym_db.RegisterMessage(ReplyExtra)

ReplyInfo = _reflection.GeneratedProtocolMessageType('ReplyInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPLYINFO,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ReplyInfo)
  })
_sym_db.RegisterMessage(ReplyInfo)

ReplyInfoReply = _reflection.GeneratedProtocolMessageType('ReplyInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _REPLYINFOREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ReplyInfoReply)
  })
_sym_db.RegisterMessage(ReplyInfoReply)

ReplyInfoReq = _reflection.GeneratedProtocolMessageType('ReplyInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _REPLYINFOREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ReplyInfoReq)
  })
_sym_db.RegisterMessage(ReplyInfoReq)

SearchItem = _reflection.GeneratedProtocolMessageType('SearchItem', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHITEM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SearchItem)
  })
_sym_db.RegisterMessage(SearchItem)

SearchItemCursorReply = _reflection.GeneratedProtocolMessageType('SearchItemCursorReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHITEMCURSORREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SearchItemCursorReply)
  })
_sym_db.RegisterMessage(SearchItemCursorReply)

SearchItemCursorReq = _reflection.GeneratedProtocolMessageType('SearchItemCursorReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHITEMCURSORREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SearchItemCursorReq)
  })
_sym_db.RegisterMessage(SearchItemCursorReq)

SearchItemPreHookReply = _reflection.GeneratedProtocolMessageType('SearchItemPreHookReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHITEMPREHOOKREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SearchItemPreHookReply)
  })
_sym_db.RegisterMessage(SearchItemPreHookReply)

SearchItemPreHookReq = _reflection.GeneratedProtocolMessageType('SearchItemPreHookReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHITEMPREHOOKREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SearchItemPreHookReq)
  })
_sym_db.RegisterMessage(SearchItemPreHookReq)

SearchItemReply = _reflection.GeneratedProtocolMessageType('SearchItemReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHITEMREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SearchItemReply)
  })
_sym_db.RegisterMessage(SearchItemReply)

SearchItemReplyExtraInfo = _reflection.GeneratedProtocolMessageType('SearchItemReplyExtraInfo', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHITEMREPLYEXTRAINFO,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SearchItemReplyExtraInfo)
  })
_sym_db.RegisterMessage(SearchItemReplyExtraInfo)

SearchItemReq = _reflection.GeneratedProtocolMessageType('SearchItemReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHITEMREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SearchItemReq)
  })
_sym_db.RegisterMessage(SearchItemReq)

ShareRepliesInfoReq = _reflection.GeneratedProtocolMessageType('ShareRepliesInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _SHAREREPLIESINFOREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ShareRepliesInfoReq)
  })
_sym_db.RegisterMessage(ShareRepliesInfoReq)

ShareRepliesInfoResp = _reflection.GeneratedProtocolMessageType('ShareRepliesInfoResp', (_message.Message,), {

  'ShareExtra' : _reflection.GeneratedProtocolMessageType('ShareExtra', (_message.Message,), {
    'DESCRIPTOR' : _SHAREREPLIESINFORESP_SHAREEXTRA,
    '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ShareRepliesInfoResp.ShareExtra)
    })
  ,
  'DESCRIPTOR' : _SHAREREPLIESINFORESP,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ShareRepliesInfoResp)
  })
_sym_db.RegisterMessage(ShareRepliesInfoResp)
_sym_db.RegisterMessage(ShareRepliesInfoResp.ShareExtra)

ShareReplyInfo = _reflection.GeneratedProtocolMessageType('ShareReplyInfo', (_message.Message,), {
  'DESCRIPTOR' : _SHAREREPLYINFO,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ShareReplyInfo)
  })
_sym_db.RegisterMessage(ShareReplyInfo)

ShareReplyTopic = _reflection.GeneratedProtocolMessageType('ShareReplyTopic', (_message.Message,), {
  'DESCRIPTOR' : _SHAREREPLYTOPIC,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.ShareReplyTopic)
  })
_sym_db.RegisterMessage(ShareReplyTopic)

SubjectControl = _reflection.GeneratedProtocolMessageType('SubjectControl', (_message.Message,), {
  'DESCRIPTOR' : _SUBJECTCONTROL,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.SubjectControl)
  })
_sym_db.RegisterMessage(SubjectControl)

Topic = _reflection.GeneratedProtocolMessageType('Topic', (_message.Message,), {
  'DESCRIPTOR' : _TOPIC,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Topic)
  })
_sym_db.RegisterMessage(Topic)

UGCVideoSearchItem = _reflection.GeneratedProtocolMessageType('UGCVideoSearchItem', (_message.Message,), {
  'DESCRIPTOR' : _UGCVIDEOSEARCHITEM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.UGCVideoSearchItem)
  })
_sym_db.RegisterMessage(UGCVideoSearchItem)

UpSelection = _reflection.GeneratedProtocolMessageType('UpSelection', (_message.Message,), {
  'DESCRIPTOR' : _UPSELECTION,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.UpSelection)
  })
_sym_db.RegisterMessage(UpSelection)

Url = _reflection.GeneratedProtocolMessageType('Url', (_message.Message,), {
  'DESCRIPTOR' : _URL,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Url)
  })
_sym_db.RegisterMessage(Url)

UserCallbackReply = _reflection.GeneratedProtocolMessageType('UserCallbackReply', (_message.Message,), {
  'DESCRIPTOR' : _USERCALLBACKREPLY,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.UserCallbackReply)
  })
_sym_db.RegisterMessage(UserCallbackReply)

UserCallbackReq = _reflection.GeneratedProtocolMessageType('UserCallbackReq', (_message.Message,), {
  'DESCRIPTOR' : _USERCALLBACKREQ,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.UserCallbackReq)
  })
_sym_db.RegisterMessage(UserCallbackReq)

VideoSearchItem = _reflection.GeneratedProtocolMessageType('VideoSearchItem', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOSEARCHITEM,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.VideoSearchItem)
  })
_sym_db.RegisterMessage(VideoSearchItem)

Vote = _reflection.GeneratedProtocolMessageType('Vote', (_message.Message,), {
  'DESCRIPTOR' : _VOTE,
  '__module__' : 'bilibili.main.community.reply.v1.reply_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.community.reply.v1.Vote)
  })
_sym_db.RegisterMessage(Vote)

_REPLY = DESCRIPTOR.services_by_name['Reply']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTENT_MENBERENTRY._options = None
  _CONTENT_MENBERENTRY._serialized_options = b'8\001'
  _CONTENT_EMOTEENTRY._options = None
  _CONTENT_EMOTEENTRY._serialized_options = b'8\001'
  _CONTENT_TOPICENTRY._options = None
  _CONTENT_TOPICENTRY._serialized_options = b'8\001'
  _CONTENT_URLENTRY._options = None
  _CONTENT_URLENTRY._serialized_options = b'8\001'
  _MAINLISTREPLY_CALLBACKSENTRY._options = None
  _MAINLISTREPLY_CALLBACKSENTRY._serialized_options = b'8\001'
  _DETAILLISTSCENE._serialized_start=11019
  _DETAILLISTSCENE._serialized_end=11073
  _MODE._serialized_start=11075
  _MODE._serialized_end=11150
  _SEARCHITEMTYPE._serialized_start=11152
  _SEARCHITEMTYPE._serialized_end=11226
  _SEARCHITEMVIDEOSUBTYPE._serialized_start=11228
  _SEARCHITEMVIDEOSUBTYPE._serialized_end=11270
  _USERCALLBACKACTION._serialized_start=11272
  _USERCALLBACKACTION._serialized_end=11305
  _USERCALLBACKSCENE._serialized_start=11307
  _USERCALLBACKSCENE._serialized_end=11338
  _ACTIVITY._serialized_start=109
  _ACTIVITY._serialized_end=194
  _ARTICLESEARCHITEM._serialized_start=196
  _ARTICLESEARCHITEM._serialized_end=267
  _ATGROUP._serialized_start=269
  _ATGROUP._serialized_end=375
  _ATITEM._serialized_start=377
  _ATITEM._serialized_end=470
  _ATSEARCHREPLY._serialized_start=472
  _ATSEARCHREPLY._serialized_end=546
  _ATSEARCHREQ._serialized_start=548
  _ATSEARCHREQ._serialized_end=591
  _CM._serialized_start=593
  _CM._serialized_end=643
  _CONTENT._serialized_start=646
  _CONTENT._serialized_end=1346
  _CONTENT_MENBERENTRY._serialized_start=1002
  _CONTENT_MENBERENTRY._serialized_end=1089
  _CONTENT_EMOTEENTRY._serialized_start=1091
  _CONTENT_EMOTEENTRY._serialized_end=1176
  _CONTENT_TOPICENTRY._serialized_start=1178
  _CONTENT_TOPICENTRY._serialized_end=1263
  _CONTENT_URLENTRY._serialized_start=1265
  _CONTENT_URLENTRY._serialized_end=1346
  _CURSORREPLY._serialized_start=1349
  _CURSORREPLY._serialized_end=1495
  _CURSORREQ._serialized_start=1497
  _CURSORREQ._serialized_end=1590
  _DETAILLISTREPLY._serialized_start=1593
  _DETAILLISTREPLY._serialized_end=1928
  _DETAILLISTREQ._serialized_start=1931
  _DETAILLISTREQ._serialized_end=2128
  _DIALOGLISTREPLY._serialized_start=2131
  _DIALOGLISTREPLY._serialized_end=2410
  _DIALOGLISTREQ._serialized_start=2413
  _DIALOGLISTREQ._serialized_end=2544
  _EFFECTS._serialized_start=2546
  _EFFECTS._serialized_end=2575
  _EMOTE._serialized_start=2577
  _EMOTE._serialized_end=2698
  _GOODSSEARCHITEM._serialized_start=2700
  _GOODSSEARCHITEM._serialized_end=2802
  _LIKEINFO._serialized_start=2805
  _LIKEINFO._serialized_end=2960
  _LIKEINFO_ITEM._serialized_start=2896
  _LIKEINFO_ITEM._serialized_end=2960
  _LOTTERY._serialized_start=2963
  _LOTTERY._serialized_end=3290
  _MAINLISTREPLY._serialized_start=3293
  _MAINLISTREPLY._serialized_end=4374
  _MAINLISTREPLY_CALLBACKSENTRY._serialized_start=4326
  _MAINLISTREPLY_CALLBACKSENTRY._serialized_end=4374
  _MAINLISTREQ._serialized_start=4377
  _MAINLISTREQ._serialized_end=4525
  _MEMBER._serialized_start=4528
  _MEMBER._serialized_end=5321
  _NOTICE._serialized_start=5323
  _NOTICE._serialized_end=5374
  _OPERATION._serialized_start=5377
  _OPERATION._serialized_end=5583
  _OPERATIONTITLE._serialized_start=5585
  _OPERATIONTITLE._serialized_end=5640
  _PGCVIDEOSEARCHITEM._serialized_start=5642
  _PGCVIDEOSEARCHITEM._serialized_end=5710
  _PREVIEWLISTREPLY._serialized_start=5713
  _PREVIEWLISTREPLY._serialized_end=6118
  _PREVIEWLISTREQ._serialized_start=6120
  _PREVIEWLISTREQ._serialized_end=6224
  _QOEINFO._serialized_start=6227
  _QOEINFO._serialized_end=6407
  _QOESCOREITEM._serialized_start=6409
  _QOESCOREITEM._serialized_end=6466
  _REPLYCARDLABEL._serialized_start=6469
  _REPLYCARDLABEL._serialized_end=6729
  _REPLYCONTROL._serialized_start=6732
  _REPLYCONTROL._serialized_end=7297
  _REPLYEXTRA._serialized_start=7299
  _REPLYEXTRA._serialized_end=7384
  _REPLYINFO._serialized_start=7387
  _REPLYINFO._serialized_end=7791
  _REPLYINFOREPLY._serialized_start=7793
  _REPLYINFOREPLY._serialized_end=7869
  _REPLYINFOREQ._serialized_start=7871
  _REPLYINFOREQ._serialized_end=7914
  _SEARCHITEM._serialized_start=7917
  _SEARCHITEM._serialized_end=8158
  _SEARCHITEMCURSORREPLY._serialized_start=8160
  _SEARCHITEMCURSORREPLY._serialized_end=8215
  _SEARCHITEMCURSORREQ._serialized_start=8217
  _SEARCHITEMCURSORREQ._serialized_end=8321
  _SEARCHITEMPREHOOKREPLY._serialized_start=8324
  _SEARCHITEMPREHOOKREPLY._serialized_end=8471
  _SEARCHITEMPREHOOKREQ._serialized_start=8473
  _SEARCHITEMPREHOOKREQ._serialized_end=8522
  _SEARCHITEMREPLY._serialized_start=8525
  _SEARCHITEMREPLY._serialized_end=8751
  _SEARCHITEMREPLYEXTRAINFO._serialized_start=8753
  _SEARCHITEMREPLYEXTRAINFO._serialized_end=8797
  _SEARCHITEMREQ._serialized_start=8800
  _SEARCHITEMREQ._serialized_end=8930
  _SHAREREPLIESINFOREQ._serialized_start=8932
  _SHAREREPLIESINFOREQ._serialized_end=8980
  _SHAREREPLIESINFORESP._serialized_start=8983
  _SHAREREPLIESINFORESP._serialized_end=9357
  _SHAREREPLIESINFORESP_SHAREEXTRA._serialized_start=9329
  _SHAREREPLIESINFORESP_SHAREEXTRA._serialized_end=9357
  _SHAREREPLYINFO._serialized_start=9360
  _SHAREREPLYINFO._serialized_end=9573
  _SHAREREPLYTOPIC._serialized_start=9575
  _SHAREREPLYTOPIC._serialized_end=9669
  _SUBJECTCONTROL._serialized_start=9672
  _SUBJECTCONTROL._serialized_end=10120
  _TOPIC._serialized_start=10122
  _TOPIC._serialized_end=10155
  _UGCVIDEOSEARCHITEM._serialized_start=10157
  _UGCVIDEOSEARCHITEM._serialized_end=10246
  _UPSELECTION._serialized_start=10248
  _UPSELECTION._serialized_end=10306
  _URL._serialized_start=10309
  _URL._serialized_end=10504
  _USERCALLBACKREPLY._serialized_start=10506
  _USERCALLBACKREPLY._serialized_end=10525
  _USERCALLBACKREQ._serialized_start=10528
  _USERCALLBACKREQ._serialized_end=10723
  _VIDEOSEARCHITEM._serialized_start=10726
  _VIDEOSEARCHITEM._serialized_end=10967
  _VOTE._serialized_start=10969
  _VOTE._serialized_end=11017
  _REPLY._serialized_start=11341
  _REPLY._serialized_end=12522
# @@protoc_insertion_point(module_scope)
