"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AtGroupType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _AtGroupTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AtGroupType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AT_GROUP_TYPE_DEFAULT: _AtGroupType.ValueType  # 0
    """默认"""

    AT_GROUP_TYPE_RECENT: _AtGroupType.ValueType  # 1
    """最近联系"""

    AT_GROUP_TYPE_FOLLOW: _AtGroupType.ValueType  # 2
    """我的关注（互相关注 > 单向关注）"""

    AT_GROUP_TYPE_FANS: _AtGroupType.ValueType  # 3
    """我的粉丝"""

    AT_GROUP_TYPE_OTHERS: _AtGroupType.ValueType  # 4
    """其他"""

class AtGroupType(_AtGroupType, metaclass=_AtGroupTypeEnumTypeWrapper):
    """at分组类型"""
    pass

AT_GROUP_TYPE_DEFAULT: AtGroupType.ValueType  # 0
"""默认"""

AT_GROUP_TYPE_RECENT: AtGroupType.ValueType  # 1
"""最近联系"""

AT_GROUP_TYPE_FOLLOW: AtGroupType.ValueType  # 2
"""我的关注（互相关注 > 单向关注）"""

AT_GROUP_TYPE_FANS: AtGroupType.ValueType  # 3
"""我的粉丝"""

AT_GROUP_TYPE_OTHERS: AtGroupType.ValueType  # 4
"""其他"""

global___AtGroupType = AtGroupType


class _AttachCardType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _AttachCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AttachCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ATTACH_CARD_NONE: _AttachCardType.ValueType  # 0
    """无"""

    ATTACH_CARD_GOODS: _AttachCardType.ValueType  # 1
    """商品卡"""

    ATTACH_CARD_VOTE: _AttachCardType.ValueType  # 2
    """投票卡"""

    ATTACH_CARD_UGC: _AttachCardType.ValueType  # 3
    """ugc视频卡"""

    ATTACH_CARD_ACTIVITY: _AttachCardType.ValueType  # 4
    """帮推"""

    ATTACH_CARD_OFFICIAL_ACTIVITY: _AttachCardType.ValueType  # 5
    """官方活动"""

    ATTACH_CARD_TOPIC: _AttachCardType.ValueType  # 6
    """话题活动"""

    ATTACH_CARD_OGV: _AttachCardType.ValueType  # 7
    """OGV"""

    ATTACH_CARD_AUTO_OGV: _AttachCardType.ValueType  # 8
    """OGV自动出卡"""

    ATTACH_CARD_GAME: _AttachCardType.ValueType  # 9
    """游戏"""

    ATTACH_CARD_MANGA: _AttachCardType.ValueType  # 10
    """漫画"""

    ATTACH_CARD_DECORATION: _AttachCardType.ValueType  # 11
    """装扮"""

    ATTACH_CARD_MATCH: _AttachCardType.ValueType  # 12
    """赛事"""

    ATTACH_CARD_PUGV: _AttachCardType.ValueType  # 13
    """课程"""

    ATTACH_CARD_RESERVE: _AttachCardType.ValueType  # 14
    """预约"""

    ATTACH_CARD_UP_TOPIC: _AttachCardType.ValueType  # 15
    """up主话题活动"""

class AttachCardType(_AttachCardType, metaclass=_AttachCardTypeEnumTypeWrapper):
    """"""
    pass

ATTACH_CARD_NONE: AttachCardType.ValueType  # 0
"""无"""

ATTACH_CARD_GOODS: AttachCardType.ValueType  # 1
"""商品卡"""

ATTACH_CARD_VOTE: AttachCardType.ValueType  # 2
"""投票卡"""

ATTACH_CARD_UGC: AttachCardType.ValueType  # 3
"""ugc视频卡"""

ATTACH_CARD_ACTIVITY: AttachCardType.ValueType  # 4
"""帮推"""

ATTACH_CARD_OFFICIAL_ACTIVITY: AttachCardType.ValueType  # 5
"""官方活动"""

ATTACH_CARD_TOPIC: AttachCardType.ValueType  # 6
"""话题活动"""

ATTACH_CARD_OGV: AttachCardType.ValueType  # 7
"""OGV"""

ATTACH_CARD_AUTO_OGV: AttachCardType.ValueType  # 8
"""OGV自动出卡"""

ATTACH_CARD_GAME: AttachCardType.ValueType  # 9
"""游戏"""

ATTACH_CARD_MANGA: AttachCardType.ValueType  # 10
"""漫画"""

ATTACH_CARD_DECORATION: AttachCardType.ValueType  # 11
"""装扮"""

ATTACH_CARD_MATCH: AttachCardType.ValueType  # 12
"""赛事"""

ATTACH_CARD_PUGV: AttachCardType.ValueType  # 13
"""课程"""

ATTACH_CARD_RESERVE: AttachCardType.ValueType  # 14
"""预约"""

ATTACH_CARD_UP_TOPIC: AttachCardType.ValueType  # 15
"""up主话题活动"""

global___AttachCardType = AttachCardType


class _ContentType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ContentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ContentType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONTENT_TYPE_NONE: _ContentType.ValueType  # 0
    """占位"""

    TEXT: _ContentType.ValueType  # 1
    """文本，简单内容，biz_id就是文本"""

    AT: _ContentType.ValueType  # 2
    """@用户，简单内容，biz_id是用户uid"""

    LOTTERY: _ContentType.ValueType  # 3
    """抽奖，简单内容，biz_id是抽奖id"""

    VOTE: _ContentType.ValueType  # 4
    """投票，简单内容，biz_id是投票id"""

    TOPIC: _ContentType.ValueType  # 5
    """话题，简单内容，biz_id是话题id"""

    GOODS: _ContentType.ValueType  # 6
    """商品文字链，复杂内容，定义在GoodsContent结构，biz_id为空"""

    BV: _ContentType.ValueType  # 7
    """bv，简单内容，biz_id是bvid，包括"BV1"等内容"""

    AV: _ContentType.ValueType  # 8
    """av，简单内容，biz_id是avid"""

    EMOJI: _ContentType.ValueType  # 9
    """表情，简单内容，biz_id为空"""

    USER: _ContentType.ValueType  # 10
    """外露用户，暂未使用"""

    CV: _ContentType.ValueType  # 11
    """专栏，简单内容，biz_id是cvid"""

    VC: _ContentType.ValueType  # 12
    """废弃业务，无用"""

    WEB: _ContentType.ValueType  # 13
    """网址，简单内容，biz_id是网页链接"""

    TAOBAO: _ContentType.ValueType  # 14
    """淘宝内容，暂时不用"""

    MAIL: _ContentType.ValueType  # 15
    """邮箱，简单内容，biz_id是邮箱地址"""

    OGV_SEASON: _ContentType.ValueType  # 16
    """番剧season，简单内容，biz_id是番剧的season_id"""

    OGV_EP: _ContentType.ValueType  # 17
    """番剧ep，简单内容，biz_id是番剧的epid"""

class ContentType(_ContentType, metaclass=_ContentTypeEnumTypeWrapper):
    """"""
    pass

CONTENT_TYPE_NONE: ContentType.ValueType  # 0
"""占位"""

TEXT: ContentType.ValueType  # 1
"""文本，简单内容，biz_id就是文本"""

AT: ContentType.ValueType  # 2
"""@用户，简单内容，biz_id是用户uid"""

LOTTERY: ContentType.ValueType  # 3
"""抽奖，简单内容，biz_id是抽奖id"""

VOTE: ContentType.ValueType  # 4
"""投票，简单内容，biz_id是投票id"""

TOPIC: ContentType.ValueType  # 5
"""话题，简单内容，biz_id是话题id"""

GOODS: ContentType.ValueType  # 6
"""商品文字链，复杂内容，定义在GoodsContent结构，biz_id为空"""

BV: ContentType.ValueType  # 7
"""bv，简单内容，biz_id是bvid，包括"BV1"等内容"""

AV: ContentType.ValueType  # 8
"""av，简单内容，biz_id是avid"""

EMOJI: ContentType.ValueType  # 9
"""表情，简单内容，biz_id为空"""

USER: ContentType.ValueType  # 10
"""外露用户，暂未使用"""

CV: ContentType.ValueType  # 11
"""专栏，简单内容，biz_id是cvid"""

VC: ContentType.ValueType  # 12
"""废弃业务，无用"""

WEB: ContentType.ValueType  # 13
"""网址，简单内容，biz_id是网页链接"""

TAOBAO: ContentType.ValueType  # 14
"""淘宝内容，暂时不用"""

MAIL: ContentType.ValueType  # 15
"""邮箱，简单内容，biz_id是邮箱地址"""

OGV_SEASON: ContentType.ValueType  # 16
"""番剧season，简单内容，biz_id是番剧的season_id"""

OGV_EP: ContentType.ValueType  # 17
"""番剧ep，简单内容，biz_id是番剧的epid"""

global___ContentType = ContentType


class _CreateInitCheckScene:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _CreateInitCheckSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CreateInitCheckScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CREATE_INIT_CHECK_SCENE_INVALID: _CreateInitCheckScene.ValueType  # 0
    """"""

    CREATE_INIT_CHECK_SCENE_NORMAL: _CreateInitCheckScene.ValueType  # 1
    """动态页面右上角点击进入发布页"""

    CREATE_INIT_CHECK_SCENE_REPOST: _CreateInitCheckScene.ValueType  # 2
    """动态feed流转发、三点分享，动态详情页转发"""

    CREATE_INIT_CHECK_SCENE_SHARE: _CreateInitCheckScene.ValueType  # 3
    """其他页面分享到动态"""

    CREATE_INIT_CHECK_SCENE_RESERVE_SHARE: _CreateInitCheckScene.ValueType  # 4
    """"""

class CreateInitCheckScene(_CreateInitCheckScene, metaclass=_CreateInitCheckSceneEnumTypeWrapper):
    """发布页预校验场景"""
    pass

CREATE_INIT_CHECK_SCENE_INVALID: CreateInitCheckScene.ValueType  # 0
""""""

CREATE_INIT_CHECK_SCENE_NORMAL: CreateInitCheckScene.ValueType  # 1
"""动态页面右上角点击进入发布页"""

CREATE_INIT_CHECK_SCENE_REPOST: CreateInitCheckScene.ValueType  # 2
"""动态feed流转发、三点分享，动态详情页转发"""

CREATE_INIT_CHECK_SCENE_SHARE: CreateInitCheckScene.ValueType  # 3
"""其他页面分享到动态"""

CREATE_INIT_CHECK_SCENE_RESERVE_SHARE: CreateInitCheckScene.ValueType  # 4
""""""

global___CreateInitCheckScene = CreateInitCheckScene


class _CreateScene:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _CreateSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CreateScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CREATE_SCENE_INVALID: _CreateScene.ValueType  # 0
    """"""

    CREATE_SCENE_CREATE_WORD: _CreateScene.ValueType  # 1
    """发布纯文字动态"""

    CREATE_SCENE_CREATE_DRAW: _CreateScene.ValueType  # 2
    """发布图文动态"""

    CREATE_SCENE_CREATE_DYN_VIDEO: _CreateScene.ValueType  # 3
    """发布动态视频"""

    CREATE_SCENE_REPOST: _CreateScene.ValueType  # 4
    """转发动态"""

    CREATE_SCENE_SHARE_BIZ: _CreateScene.ValueType  # 5
    """分享业务方资源"""

    CREATE_SCENE_SHARE_PAGE: _CreateScene.ValueType  # 6
    """分享网页（通用模板）"""

    CREATE_SCENE_SHARE_PROGRAM: _CreateScene.ValueType  # 7
    """分享小程序"""

    CREATE_SCENE_REPLY_SYNC: _CreateScene.ValueType  # 8
    """评论同步到动态"""

    CREATE_SCENE_REPLY_CREATE_ACTIVITY: _CreateScene.ValueType  # 9
    """评论同步到动态并且发起活动"""

class CreateScene(_CreateScene, metaclass=_CreateSceneEnumTypeWrapper):
    """发布类型（场景）"""
    pass

CREATE_SCENE_INVALID: CreateScene.ValueType  # 0
""""""

CREATE_SCENE_CREATE_WORD: CreateScene.ValueType  # 1
"""发布纯文字动态"""

CREATE_SCENE_CREATE_DRAW: CreateScene.ValueType  # 2
"""发布图文动态"""

CREATE_SCENE_CREATE_DYN_VIDEO: CreateScene.ValueType  # 3
"""发布动态视频"""

CREATE_SCENE_REPOST: CreateScene.ValueType  # 4
"""转发动态"""

CREATE_SCENE_SHARE_BIZ: CreateScene.ValueType  # 5
"""分享业务方资源"""

CREATE_SCENE_SHARE_PAGE: CreateScene.ValueType  # 6
"""分享网页（通用模板）"""

CREATE_SCENE_SHARE_PROGRAM: CreateScene.ValueType  # 7
"""分享小程序"""

CREATE_SCENE_REPLY_SYNC: CreateScene.ValueType  # 8
"""评论同步到动态"""

CREATE_SCENE_REPLY_CREATE_ACTIVITY: CreateScene.ValueType  # 9
"""评论同步到动态并且发起活动"""

global___CreateScene = CreateScene


class _ReserveSource:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ReserveSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESERVE_SOURCE_NEW: _ReserveSource.ValueType  # 0
    """"""

    RESERVE_SOURCE_ASSOCIATED: _ReserveSource.ValueType  # 1
    """"""

class ReserveSource(_ReserveSource, metaclass=_ReserveSourceEnumTypeWrapper):
    """"""
    pass

RESERVE_SOURCE_NEW: ReserveSource.ValueType  # 0
""""""

RESERVE_SOURCE_ASSOCIATED: ReserveSource.ValueType  # 1
""""""

global___ReserveSource = ReserveSource


class _UpPermissionType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _UpPermissionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UpPermissionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UP_PERMISSION_TYPE_NONE: _UpPermissionType.ValueType  # 0
    """占位"""

    UP_PERMISSION_TYPE_LOTTERY: _UpPermissionType.ValueType  # 1
    """是否是抽奖的灰度用户，默认不是"""

    UP_PERMISSION_TYPE_CLIP_PUBLISHED: _UpPermissionType.ValueType  # 2
    """之前是否发过小视频，默认没发过"""

    UP_PERMISSION_TYPE_UGC_ATTACH_CARD: _UpPermissionType.ValueType  # 3
    """是否可以添加ugc附加卡，默认不可以"""

    UP_PERMISSION_TYPE_GOODS_ATTACH_CARD: _UpPermissionType.ValueType  # 4
    """是否有权限添加商品附加卡"""

    UP_PERMISSION_TYPE_CHOOSE_COMMENT: _UpPermissionType.ValueType  # 5
    """是否有权限自主精选评论白名单，默认没有"""

    UP_PERMISSION_TYPE_CONTROL_COMMENT: _UpPermissionType.ValueType  # 6
    """是否有权限关闭评论区，默认有"""

    UP_PERMISSION_TYPE_CONTROL_DANMU: _UpPermissionType.ValueType  # 7
    """是否有权限关闭弹幕（仅对动态视频生效），默认有"""

    UP_PERMISSION_TYPE_VIDEO_RESERVE: _UpPermissionType.ValueType  # 8
    """是否可以发起稿件预约"""

    UP_PERMISSION_TYPE_LIVE_RESERVE: _UpPermissionType.ValueType  # 9
    """是否可以发起直播预约"""

class UpPermissionType(_UpPermissionType, metaclass=_UpPermissionTypeEnumTypeWrapper):
    """"""
    pass

UP_PERMISSION_TYPE_NONE: UpPermissionType.ValueType  # 0
"""占位"""

UP_PERMISSION_TYPE_LOTTERY: UpPermissionType.ValueType  # 1
"""是否是抽奖的灰度用户，默认不是"""

UP_PERMISSION_TYPE_CLIP_PUBLISHED: UpPermissionType.ValueType  # 2
"""之前是否发过小视频，默认没发过"""

UP_PERMISSION_TYPE_UGC_ATTACH_CARD: UpPermissionType.ValueType  # 3
"""是否可以添加ugc附加卡，默认不可以"""

UP_PERMISSION_TYPE_GOODS_ATTACH_CARD: UpPermissionType.ValueType  # 4
"""是否有权限添加商品附加卡"""

UP_PERMISSION_TYPE_CHOOSE_COMMENT: UpPermissionType.ValueType  # 5
"""是否有权限自主精选评论白名单，默认没有"""

UP_PERMISSION_TYPE_CONTROL_COMMENT: UpPermissionType.ValueType  # 6
"""是否有权限关闭评论区，默认有"""

UP_PERMISSION_TYPE_CONTROL_DANMU: UpPermissionType.ValueType  # 7
"""是否有权限关闭弹幕（仅对动态视频生效），默认有"""

UP_PERMISSION_TYPE_VIDEO_RESERVE: UpPermissionType.ValueType  # 8
"""是否可以发起稿件预约"""

UP_PERMISSION_TYPE_LIVE_RESERVE: UpPermissionType.ValueType  # 9
"""是否可以发起直播预约"""

global___UpPermissionType = UpPermissionType


class AtGroup(google.protobuf.message.Message):
    """at分组信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GROUP_TYPE_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    group_type: global___AtGroupType.ValueType
    """分组类型"""

    group_name: typing.Text
    """分组名称"""

    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtItem]:
        """items"""
        pass
    def __init__(self,
        *,
        group_type: global___AtGroupType.ValueType = ...,
        group_name: typing.Text = ...,
        items: typing.Optional[typing.Iterable[global___AtItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_name",b"group_name","group_type",b"group_type","items",b"items"]) -> None: ...
global___AtGroup = AtGroup

class AtItem(google.protobuf.message.Message):
    """at返回单条信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_TYPE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """mid"""

    name: typing.Text
    """昵称"""

    face: typing.Text
    """头像"""

    fans: builtins.int
    """粉丝数"""

    official_verify_type: builtins.int
    """认证信息"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        fans: builtins.int = ...,
        official_verify_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","fans",b"fans","name",b"name","official_verify_type",b"official_verify_type","uid",b"uid"]) -> None: ...
global___AtItem = AtItem

class AtListReq(google.protobuf.message.Message):
    """at列表-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """mid"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uid",b"uid"]) -> None: ...
global___AtListReq = AtListReq

class AtListRsp(google.protobuf.message.Message):
    """at列表-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GROUPS_FIELD_NUMBER: builtins.int
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtGroup]:
        """分组信息"""
        pass
    def __init__(self,
        *,
        groups: typing.Optional[typing.Iterable[global___AtGroup]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["groups",b"groups"]) -> None: ...
global___AtListRsp = AtListRsp

class AtSearchReq(google.protobuf.message.Message):
    """at搜索-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """mid"""

    keyword: typing.Text
    """关键字"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        keyword: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword",b"keyword","uid",b"uid"]) -> None: ...
global___AtSearchReq = AtSearchReq

class BottomBusiness(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    rid: builtins.int
    """业务方资源id"""

    type: builtins.int
    """业务方类型，定义在BottomBizType中"""

    def __init__(self,
        *,
        rid: builtins.int = ...,
        type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rid",b"rid","type",b"type"]) -> None: ...
global___BottomBusiness = BottomBusiness

class CreateActivity(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_STATE_FIELD_NUMBER: builtins.int
    IS_NEW_ACTIVITY_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """"""

    activity_state: builtins.int
    """"""

    is_new_activity: builtins.int
    """"""

    action: builtins.int
    """"""

    def __init__(self,
        *,
        activity_id: builtins.int = ...,
        activity_state: builtins.int = ...,
        is_new_activity: builtins.int = ...,
        action: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","activity_id",b"activity_id","activity_state",b"activity_state","is_new_activity",b"is_new_activity"]) -> None: ...
global___CreateActivity = CreateActivity

class CreateAttachCard(google.protobuf.message.Message):
    """动态附带的附加大卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GOODS_FIELD_NUMBER: builtins.int
    COMMON_CARD_FIELD_NUMBER: builtins.int
    @property
    def goods(self) -> global___CreateGoodsCard:
        """商品大卡"""
        pass
    @property
    def common_card(self) -> global___CreateCommonAttachCard:
        """通用附加大卡，目前仅限定Match,Game,Ugc,Pugv,Reserve，且同时只能有一个"""
        pass
    def __init__(self,
        *,
        goods: typing.Optional[global___CreateGoodsCard] = ...,
        common_card: typing.Optional[global___CreateCommonAttachCard] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["common_card",b"common_card","goods",b"goods"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_card",b"common_card","goods",b"goods"]) -> None: ...
global___CreateAttachCard = CreateAttachCard

class CreateCheckResp(google.protobuf.message.Message):
    """发布页预校验-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SETTING_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    SHARE_INFO_FIELD_NUMBER: builtins.int
    YELLOW_BAR_FIELD_NUMBER: builtins.int
    PLUS_RED_DOT_FIELD_NUMBER: builtins.int
    @property
    def setting(self) -> global___PublishSetting:
        """发布相关的配置项"""
        pass
    @property
    def permission(self) -> global___UpPermission:
        """用户具有的发布权限"""
        pass
    @property
    def share_info(self) -> global___ShareChannel:
        """分享渠道信息"""
        pass
    @property
    def yellow_bar(self) -> global___PublishYellowBar:
        """小黄条"""
        pass
    @property
    def plus_red_dot(self) -> global___PlusRedDot:
        """"""
        pass
    def __init__(self,
        *,
        setting: typing.Optional[global___PublishSetting] = ...,
        permission: typing.Optional[global___UpPermission] = ...,
        share_info: typing.Optional[global___ShareChannel] = ...,
        yellow_bar: typing.Optional[global___PublishYellowBar] = ...,
        plus_red_dot: typing.Optional[global___PlusRedDot] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["permission",b"permission","plus_red_dot",b"plus_red_dot","setting",b"setting","share_info",b"share_info","yellow_bar",b"yellow_bar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["permission",b"permission","plus_red_dot",b"plus_red_dot","setting",b"setting","share_info",b"share_info","yellow_bar",b"yellow_bar"]) -> None: ...
global___CreateCheckResp = CreateCheckResp

class CreateCommonAttachCard(google.protobuf.message.Message):
    """创建动态时附带的通用附加卡详情"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    RESERVE_SOURCE_FIELD_NUMBER: builtins.int
    RESERVE_LOTTERY_FIELD_NUMBER: builtins.int
    type: global___AttachCardType.ValueType
    """通用附加卡的类型"""

    biz_id: builtins.int
    """通用附加卡的业务id"""

    reserve_source: builtins.int
    """"""

    reserve_lottery: builtins.int
    """"""

    def __init__(self,
        *,
        type: global___AttachCardType.ValueType = ...,
        biz_id: builtins.int = ...,
        reserve_source: builtins.int = ...,
        reserve_lottery: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id",b"biz_id","reserve_lottery",b"reserve_lottery","reserve_source",b"reserve_source","type",b"type"]) -> None: ...
global___CreateCommonAttachCard = CreateCommonAttachCard

class CreateContent(google.protobuf.message.Message):
    """动态-描述文字模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENTS_FIELD_NUMBER: builtins.int
    @property
    def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreateContentItem]:
        """描述信息（已按高亮拆分）"""
        pass
    def __init__(self,
        *,
        contents: typing.Optional[typing.Iterable[global___CreateContentItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["contents",b"contents"]) -> None: ...
global___CreateContent = CreateContent

class CreateContentItem(google.protobuf.message.Message):
    """文本描述"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RAW_TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    GOODS_FIELD_NUMBER: builtins.int
    raw_text: typing.Text
    """原始文案"""

    type: global___ContentType.ValueType
    """类型"""

    biz_id: typing.Text
    """简单内容，可能为文字，BVID，AVID，uid等；复杂内容需要单独定义结构体"""

    @property
    def goods(self) -> global___GoodsContent:
        """商品内容"""
        pass
    def __init__(self,
        *,
        raw_text: typing.Text = ...,
        type: global___ContentType.ValueType = ...,
        biz_id: typing.Text = ...,
        goods: typing.Optional[global___GoodsContent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["goods",b"goods"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id",b"biz_id","goods",b"goods","raw_text",b"raw_text","type",b"type"]) -> None: ...
global___CreateContentItem = CreateContentItem

class CreateDynVideo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RELATION_FROM_FIELD_NUMBER: builtins.int
    BIZ_FROM_FIELD_NUMBER: builtins.int
    COPYRIGHT_FIELD_NUMBER: builtins.int
    NO_PUBLIC_FIELD_NUMBER: builtins.int
    NO_REPRINT_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DESC_FORMAT_ID_FIELD_NUMBER: builtins.int
    OPEN_ELEC_FIELD_NUMBER: builtins.int
    DTIME_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    WATERMARK_FIELD_NUMBER: builtins.int
    MISSION_ID_FIELD_NUMBER: builtins.int
    DYNAMIC_FIELD_NUMBER: builtins.int
    DYNAMIC_EXTENSION_FIELD_NUMBER: builtins.int
    DYNAMIC_CTRL_FIELD_NUMBER: builtins.int
    DYNAMIC_FROM_FIELD_NUMBER: builtins.int
    LOTTERY_ID_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    UP_SELECTION_REPLY_FIELD_NUMBER: builtins.int
    UP_CLOSE_REPLY_FIELD_NUMBER: builtins.int
    UP_CLOSE_DANMU_FIELD_NUMBER: builtins.int
    UP_FROM_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    relation_from: typing.Text
    """投稿平台来源，具体写什么@产品"""

    biz_from: builtins.int
    """1 — 投稿入口 + 相册选择视频 2 — 投稿入口 + 拍摄 3 — 小视频入口 + 相册选择视频 4 — 小视频入口 + 拍摄"""

    copyright: builtins.int
    """投稿类型:  2-转载、1-自制"""

    no_public: builtins.int
    """是否公开投稿 0允许公开，1不允许公开 默认 0公开"""

    no_reprint: builtins.int
    """是否允许转载字段 0允许，1不允许，默认为0    copyright = 1 自制的时候默认勾选上no_reprint=1"""

    source: typing.Text
    """转载的时候必须填写，非空字符串"""

    cover: typing.Text
    """稿件封面必须填写,不能为空 封面不支持其他源站链接 请确保 cover 是 先经过上传接口"""

    title: typing.Text
    """稿件标题"""

    tid: builtins.int
    """稿件分区ID 必须是有效的二级分区ID"""

    tag: typing.Text
    """标签 多个标签请使用英文逗号连接"""

    desc: typing.Text
    """稿件描述"""

    desc_format_id: builtins.int
    """当前输入环境下有，就输入http://domain/x/app/archive/desc/format返回的desc_format值
    如果返回null就输入默认为0， 表示当前环境（分区+投稿类型）不参与简介格式化
    """

    open_elec: builtins.int
    """稿件是否开启充电面板，1为是, 0为否"""

    dtime: builtins.int
    """定时发布的时间"""

    @property
    def videos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynVideoMultiP]:
        """分P聚合字段"""
        pass
    @property
    def watermark(self) -> global___DynVideoWatermark:
        """水印信息"""
        pass
    mission_id: builtins.int
    """新增加通过tag来参加活动"""

    dynamic: typing.Text
    """新增加可以添加动态内容"""

    dynamic_extension: typing.Text
    """序列化后的extend_info扩展信息"""

    dynamic_ctrl: typing.Text
    """客户端控制字段"""

    dynamic_from: typing.Text
    """动态来源"""

    lottery_id: builtins.int
    """抽奖服务生成的ID"""

    @property
    def vote(self) -> global___DynVideoVote:
        """"""
        pass
    up_selection_reply: builtins.bool
    """精选评论开关, true为开"""

    up_close_reply: builtins.bool
    """up主关闭评论"""

    up_close_danmu: builtins.bool
    """up主关闭弹幕"""

    up_from: builtins.int
    """稿件投稿来源"""

    duration: builtins.int
    """"""

    def __init__(self,
        *,
        relation_from: typing.Text = ...,
        biz_from: builtins.int = ...,
        copyright: builtins.int = ...,
        no_public: builtins.int = ...,
        no_reprint: builtins.int = ...,
        source: typing.Text = ...,
        cover: typing.Text = ...,
        title: typing.Text = ...,
        tid: builtins.int = ...,
        tag: typing.Text = ...,
        desc: typing.Text = ...,
        desc_format_id: builtins.int = ...,
        open_elec: builtins.int = ...,
        dtime: builtins.int = ...,
        videos: typing.Optional[typing.Iterable[global___DynVideoMultiP]] = ...,
        watermark: typing.Optional[global___DynVideoWatermark] = ...,
        mission_id: builtins.int = ...,
        dynamic: typing.Text = ...,
        dynamic_extension: typing.Text = ...,
        dynamic_ctrl: typing.Text = ...,
        dynamic_from: typing.Text = ...,
        lottery_id: builtins.int = ...,
        vote: typing.Optional[global___DynVideoVote] = ...,
        up_selection_reply: builtins.bool = ...,
        up_close_reply: builtins.bool = ...,
        up_close_danmu: builtins.bool = ...,
        up_from: builtins.int = ...,
        duration: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vote",b"vote","watermark",b"watermark"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_from",b"biz_from","copyright",b"copyright","cover",b"cover","desc",b"desc","desc_format_id",b"desc_format_id","dtime",b"dtime","duration",b"duration","dynamic",b"dynamic","dynamic_ctrl",b"dynamic_ctrl","dynamic_extension",b"dynamic_extension","dynamic_from",b"dynamic_from","lottery_id",b"lottery_id","mission_id",b"mission_id","no_public",b"no_public","no_reprint",b"no_reprint","open_elec",b"open_elec","relation_from",b"relation_from","source",b"source","tag",b"tag","tid",b"tid","title",b"title","up_close_danmu",b"up_close_danmu","up_close_reply",b"up_close_reply","up_from",b"up_from","up_selection_reply",b"up_selection_reply","videos",b"videos","vote",b"vote","watermark",b"watermark"]) -> None: ...
global___CreateDynVideo = CreateDynVideo

class CreateDynVideoResult(google.protobuf.message.Message):
    """创建动态视频的应答包（透传给客户端）"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    SUBMITACT_BANNER_FIELD_NUMBER: builtins.int
    PUSH_INTRO_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件id"""

    message: typing.Text
    """说明信息"""

    @property
    def submitact_banner(self) -> global___DynVideoSubmitActBanner:
        """推荐的活动信息"""
        pass
    @property
    def push_intro(self) -> global___DynVideoPushIntro:
        """"""
        pass
    def __init__(self,
        *,
        aid: builtins.int = ...,
        message: typing.Text = ...,
        submitact_banner: typing.Optional[global___DynVideoSubmitActBanner] = ...,
        push_intro: typing.Optional[global___DynVideoPushIntro] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["push_intro",b"push_intro","submitact_banner",b"submitact_banner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","message",b"message","push_intro",b"push_intro","submitact_banner",b"submitact_banner"]) -> None: ...
global___CreateDynVideoResult = CreateDynVideoResult

class CreateGoodsCard(google.protobuf.message.Message):
    """创建动态时附带的商品大卡详情"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEM_ID_FIELD_NUMBER: builtins.int
    @property
    def item_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """商品大卡中的商品id"""
        pass
    def __init__(self,
        *,
        item_id: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_id",b"item_id"]) -> None: ...
global___CreateGoodsCard = CreateGoodsCard

class CreateOption(google.protobuf.message.Message):
    """动态创建时的特殊选项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UP_CHOOSE_COMMENT_FIELD_NUMBER: builtins.int
    CLOSE_COMMENT_FIELD_NUMBER: builtins.int
    FOLD_EXCLUDE_FIELD_NUMBER: builtins.int
    AUDIT_LEVEL_FIELD_NUMBER: builtins.int
    SYNC_TO_COMMENT_FIELD_NUMBER: builtins.int
    VIDEO_SHARE_INFO_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    up_choose_comment: builtins.int
    """评论区展示UP自己精选的评论"""

    close_comment: builtins.int
    """初始评论区是关闭状态"""

    fold_exclude: builtins.int
    """该动态不会被折叠
    目前仅抽奖开奖动态不会被折叠
    """

    audit_level: builtins.int
    """审核等级，仅服务端发布时有效
    100：自动过审
    非100：默认的内网审核
    默认为0
    """

    sync_to_comment: builtins.int
    """根据转发内容同步生成一条源动态/资源的评论
    仅转发和分享时有效
    """

    @property
    def video_share_info(self) -> global___VideoShareInfo:
        """"""
        pass
    @property
    def activity(self) -> global___CreateActivity:
        """"""
        pass
    def __init__(self,
        *,
        up_choose_comment: builtins.int = ...,
        close_comment: builtins.int = ...,
        fold_exclude: builtins.int = ...,
        audit_level: builtins.int = ...,
        sync_to_comment: builtins.int = ...,
        video_share_info: typing.Optional[global___VideoShareInfo] = ...,
        activity: typing.Optional[global___CreateActivity] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity",b"activity","video_share_info",b"video_share_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity",b"activity","audit_level",b"audit_level","close_comment",b"close_comment","fold_exclude",b"fold_exclude","sync_to_comment",b"sync_to_comment","up_choose_comment",b"up_choose_comment","video_share_info",b"video_share_info"]) -> None: ...
global___CreateOption = CreateOption

class CreatePic(google.protobuf.message.Message):
    """创建图文动态时的图片信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IMG_SRC_FIELD_NUMBER: builtins.int
    IMG_WIDTH_FIELD_NUMBER: builtins.int
    IMG_HEIGHT_FIELD_NUMBER: builtins.int
    IMG_SIZE_FIELD_NUMBER: builtins.int
    IMG_TAGS_FIELD_NUMBER: builtins.int
    img_src: typing.Text
    """上传图片URL"""

    img_width: builtins.float
    """图片宽度"""

    img_height: builtins.float
    """图片高度"""

    img_size: builtins.float
    """图片大小，单位KB"""

    @property
    def img_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreatePicTag]:
        """"""
        pass
    def __init__(self,
        *,
        img_src: typing.Text = ...,
        img_width: builtins.float = ...,
        img_height: builtins.float = ...,
        img_size: builtins.float = ...,
        img_tags: typing.Optional[typing.Iterable[global___CreatePicTag]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["img_height",b"img_height","img_size",b"img_size","img_src",b"img_src","img_tags",b"img_tags","img_width",b"img_width"]) -> None: ...
global___CreatePic = CreatePic

class CreatePicTag(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEM_ID_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_STRING_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ORIENTATION_FIELD_NUMBER: builtins.int
    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    POI_FIELD_NUMBER: builtins.int
    item_id: builtins.int
    """"""

    tid: builtins.int
    """"""

    mid: builtins.int
    """"""

    text: typing.Text
    """"""

    text_string: typing.Text
    """"""

    type: builtins.int
    """"""

    source_type: builtins.int
    """"""

    url: typing.Text
    """"""

    schema_url: typing.Text
    """"""

    jump_url: typing.Text
    """"""

    orientation: builtins.int
    """"""

    x: builtins.int
    """"""

    y: builtins.int
    """"""

    poi: typing.Text
    """"""

    def __init__(self,
        *,
        item_id: builtins.int = ...,
        tid: builtins.int = ...,
        mid: builtins.int = ...,
        text: typing.Text = ...,
        text_string: typing.Text = ...,
        type: builtins.int = ...,
        source_type: builtins.int = ...,
        url: typing.Text = ...,
        schema_url: typing.Text = ...,
        jump_url: typing.Text = ...,
        orientation: builtins.int = ...,
        x: builtins.int = ...,
        y: builtins.int = ...,
        poi: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_id",b"item_id","jump_url",b"jump_url","mid",b"mid","orientation",b"orientation","poi",b"poi","schema_url",b"schema_url","source_type",b"source_type","text",b"text","text_string",b"text_string","tid",b"tid","type",b"type","url",b"url","x",b"x","y",b"y"]) -> None: ...
global___CreatePicTag = CreatePicTag

class CreateResp(google.protobuf.message.Message):
    """创建动态-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DYN_ID_FIELD_NUMBER: builtins.int
    DYN_ID_STR_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    DYN_RID_FIELD_NUMBER: builtins.int
    FAKE_CARD_FIELD_NUMBER: builtins.int
    VIDEO_RESULT_FIELD_NUMBER: builtins.int
    dyn_id: builtins.int
    """动态id"""

    dyn_id_str: typing.Text
    """动态id str"""

    dyn_type: builtins.int
    """动态的类型"""

    dyn_rid: builtins.int
    """动态id"""

    @property
    def fake_card(self) -> bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem:
        """假卡"""
        pass
    @property
    def video_result(self) -> global___CreateDynVideoResult:
        """视频"""
        pass
    def __init__(self,
        *,
        dyn_id: builtins.int = ...,
        dyn_id_str: typing.Text = ...,
        dyn_type: builtins.int = ...,
        dyn_rid: builtins.int = ...,
        fake_card: typing.Optional[bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem] = ...,
        video_result: typing.Optional[global___CreateDynVideoResult] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fake_card",b"fake_card","video_result",b"video_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_id",b"dyn_id","dyn_id_str",b"dyn_id_str","dyn_rid",b"dyn_rid","dyn_type",b"dyn_type","fake_card",b"fake_card","video_result",b"video_result"]) -> None: ...
global___CreateResp = CreateResp

class CreateTag(google.protobuf.message.Message):
    """动态附带的小卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LBS_FIELD_NUMBER: builtins.int
    SDK_GAME_FIELD_NUMBER: builtins.int
    DIVERSION_FIELD_NUMBER: builtins.int
    @property
    def lbs(self) -> global___ExtLbs:
        """lbs小卡"""
        pass
    @property
    def sdk_game(self) -> global___BottomBusiness:
        """游戏通过SDK发布的动态需要带上游戏小卡"""
        pass
    @property
    def diversion(self) -> global___BottomBusiness:
        """必剪发布的动态需要带上必剪小卡"""
        pass
    def __init__(self,
        *,
        lbs: typing.Optional[global___ExtLbs] = ...,
        sdk_game: typing.Optional[global___BottomBusiness] = ...,
        diversion: typing.Optional[global___BottomBusiness] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["diversion",b"diversion","lbs",b"lbs","sdk_game",b"sdk_game"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["diversion",b"diversion","lbs",b"lbs","sdk_game",b"sdk_game"]) -> None: ...
global___CreateTag = CreateTag

class CreateTopic(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    name: typing.Text
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","name",b"name"]) -> None: ...
global___CreateTopic = CreateTopic

class DynIdentity(google.protobuf.message.Message):
    """动态的标识"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DYN_ID_FIELD_NUMBER: builtins.int
    REVS_ID_FIELD_NUMBER: builtins.int
    dyn_id: builtins.int
    """动态id"""

    @property
    def revs_id(self) -> global___DynRevsId:
        """动态反向id，通过(type+rid组合)也可以唯一标识一个动态，与dyn_id出现任意一个即可"""
        pass
    def __init__(self,
        *,
        dyn_id: builtins.int = ...,
        revs_id: typing.Optional[global___DynRevsId] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["revs_id",b"revs_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_id",b"dyn_id","revs_id",b"revs_id"]) -> None: ...
global___DynIdentity = DynIdentity

class DynRevsId(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DYN_TYPE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    dyn_type: builtins.int
    """动态类型"""

    rid: builtins.int
    """业务id"""

    def __init__(self,
        *,
        dyn_type: builtins.int = ...,
        rid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_type",b"dyn_type","rid",b"rid"]) -> None: ...
global___DynRevsId = DynRevsId

class DynVideoEditor(google.protobuf.message.Message):
    """动态视频分P视频编辑环境上报信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CID_FIELD_NUMBER: builtins.int
    UPFROM_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    FONTS_FIELD_NUMBER: builtins.int
    SUBTITLES_FIELD_NUMBER: builtins.int
    BGMS_FIELD_NUMBER: builtins.int
    STICKERS_FIELD_NUMBER: builtins.int
    VIDEOUP_STICKERS_FIELD_NUMBER: builtins.int
    TRANS_FIELD_NUMBER: builtins.int
    MAKEUPS_FIELD_NUMBER: builtins.int
    SURGERYS_FIELD_NUMBER: builtins.int
    VIDEOFXS_FIELD_NUMBER: builtins.int
    THEMES_FIELD_NUMBER: builtins.int
    COOPERATES_FIELD_NUMBER: builtins.int
    RHYTHMS_FIELD_NUMBER: builtins.int
    EFFECTS_FIELD_NUMBER: builtins.int
    BACKGROUNDS_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    SOUNDS_FIELD_NUMBER: builtins.int
    FLOWERS_FIELD_NUMBER: builtins.int
    COVER_TEMPLATES_FIELD_NUMBER: builtins.int
    TTS_FIELD_NUMBER: builtins.int
    OPENINGS_FIELD_NUMBER: builtins.int
    RECORD_TEXT_FIELD_NUMBER: builtins.int
    VUPERS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    BCUT_FEATURES_FIELD_NUMBER: builtins.int
    AUDIO_RECORD_FIELD_NUMBER: builtins.int
    CAMERA_FIELD_NUMBER: builtins.int
    SPEED_FIELD_NUMBER: builtins.int
    CAMERA_ROTATE_FIELD_NUMBER: builtins.int
    SCREEN_RECORD_FIELD_NUMBER: builtins.int
    DEFAULT_END_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    PIC_COUNT_FIELD_NUMBER: builtins.int
    VIDEO_COUNT_FIELD_NUMBER: builtins.int
    SHOT_DURATION_FIELD_NUMBER: builtins.int
    SHOT_GAME_FIELD_NUMBER: builtins.int
    HIGHLIGHT_FIELD_NUMBER: builtins.int
    HIGHLIGHT_CNT_FIELD_NUMBER: builtins.int
    PIP_COUNT_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """"""

    upfrom: builtins.int
    """"""

    filters: typing.Text
    """滤镜"""

    fonts: typing.Text
    """字体"""

    subtitles: typing.Text
    """字幕"""

    bgms: typing.Text
    """bgm"""

    stickers: typing.Text
    """3d拍摄贴纸"""

    videoup_stickers: typing.Text
    """2d投稿贴纸"""

    trans: typing.Text
    """视频转场特效"""

    makeups: typing.Text
    """编辑器的主题使用相关"""

    surgerys: typing.Text
    """整容之外科手术"""

    videofxs: typing.Text
    """美摄特定的videofx"""

    themes: typing.Text
    """编辑器的主题使用相关"""

    cooperates: typing.Text
    """拍摄之稿件合拍"""

    rhythms: typing.Text
    """拍摄之音乐卡点视频"""

    effects: typing.Text
    """mvp特效"""

    backgrounds: typing.Text
    """mvp背景"""

    videos: typing.Text
    """mvp视频"""

    sounds: typing.Text
    """mvp音效"""

    flowers: typing.Text
    """mvp花字"""

    cover_templates: typing.Text
    """mvp封面模板"""

    tts: typing.Text
    """tts"""

    openings: typing.Text
    """openings"""

    record_text: builtins.bool
    """录音题词"""

    vupers: typing.Text
    """虚拟形象上报"""

    features: typing.Text
    """"""

    bcut_features: typing.Text
    """"""

    audio_record: builtins.int
    """"""

    camera: builtins.int
    """"""

    speed: builtins.int
    """"""

    camera_rotate: builtins.int
    """"""

    screen_record: builtins.int
    """"""

    default_end: builtins.int
    """"""

    duration: builtins.int
    """"""

    pic_count: builtins.int
    """"""

    video_count: builtins.int
    """"""

    shot_duration: builtins.int
    """"""

    shot_game: typing.Text
    """"""

    highlight: builtins.bool
    """"""

    highlight_cnt: builtins.int
    """"""

    pip_count: builtins.int
    """"""

    def __init__(self,
        *,
        cid: builtins.int = ...,
        upfrom: builtins.int = ...,
        filters: typing.Text = ...,
        fonts: typing.Text = ...,
        subtitles: typing.Text = ...,
        bgms: typing.Text = ...,
        stickers: typing.Text = ...,
        videoup_stickers: typing.Text = ...,
        trans: typing.Text = ...,
        makeups: typing.Text = ...,
        surgerys: typing.Text = ...,
        videofxs: typing.Text = ...,
        themes: typing.Text = ...,
        cooperates: typing.Text = ...,
        rhythms: typing.Text = ...,
        effects: typing.Text = ...,
        backgrounds: typing.Text = ...,
        videos: typing.Text = ...,
        sounds: typing.Text = ...,
        flowers: typing.Text = ...,
        cover_templates: typing.Text = ...,
        tts: typing.Text = ...,
        openings: typing.Text = ...,
        record_text: builtins.bool = ...,
        vupers: typing.Text = ...,
        features: typing.Text = ...,
        bcut_features: typing.Text = ...,
        audio_record: builtins.int = ...,
        camera: builtins.int = ...,
        speed: builtins.int = ...,
        camera_rotate: builtins.int = ...,
        screen_record: builtins.int = ...,
        default_end: builtins.int = ...,
        duration: builtins.int = ...,
        pic_count: builtins.int = ...,
        video_count: builtins.int = ...,
        shot_duration: builtins.int = ...,
        shot_game: typing.Text = ...,
        highlight: builtins.bool = ...,
        highlight_cnt: builtins.int = ...,
        pip_count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_record",b"audio_record","backgrounds",b"backgrounds","bcut_features",b"bcut_features","bgms",b"bgms","camera",b"camera","camera_rotate",b"camera_rotate","cid",b"cid","cooperates",b"cooperates","cover_templates",b"cover_templates","default_end",b"default_end","duration",b"duration","effects",b"effects","features",b"features","filters",b"filters","flowers",b"flowers","fonts",b"fonts","highlight",b"highlight","highlight_cnt",b"highlight_cnt","makeups",b"makeups","openings",b"openings","pic_count",b"pic_count","pip_count",b"pip_count","record_text",b"record_text","rhythms",b"rhythms","screen_record",b"screen_record","shot_duration",b"shot_duration","shot_game",b"shot_game","sounds",b"sounds","speed",b"speed","stickers",b"stickers","subtitles",b"subtitles","surgerys",b"surgerys","themes",b"themes","trans",b"trans","tts",b"tts","upfrom",b"upfrom","video_count",b"video_count","videofxs",b"videofxs","videos",b"videos","videoup_stickers",b"videoup_stickers","vupers",b"vupers"]) -> None: ...
global___DynVideoEditor = DynVideoEditor

class DynVideoHotAct(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACT_ID_FIELD_NUMBER: builtins.int
    ETIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    act_id: builtins.int
    """"""

    etime: builtins.int
    """"""

    id: builtins.int
    """"""

    pic: typing.Text
    """"""

    stime: builtins.int
    """"""

    title: typing.Text
    """"""

    link: typing.Text
    """"""

    def __init__(self,
        *,
        act_id: builtins.int = ...,
        etime: builtins.int = ...,
        id: builtins.int = ...,
        pic: typing.Text = ...,
        stime: builtins.int = ...,
        title: typing.Text = ...,
        link: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_id",b"act_id","etime",b"etime","id",b"id","link",b"link","pic",b"pic","stime",b"stime","title",b"title"]) -> None: ...
global___DynVideoHotAct = DynVideoHotAct

class DynVideoMultiP(google.protobuf.message.Message):
    """动态视频分P聚合字段"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    title: typing.Text
    """分P标题"""

    filename: typing.Text
    """分P的文件名"""

    cid: builtins.int
    """"""

    @property
    def editor(self) -> global___DynVideoEditor:
        """编辑环境上报信息"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        filename: typing.Text = ...,
        cid: builtins.int = ...,
        editor: typing.Optional[global___DynVideoEditor] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["editor",b"editor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","editor",b"editor","filename",b"filename","title",b"title"]) -> None: ...
global___DynVideoMultiP = DynVideoMultiP

class DynVideoPushIntro(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHOW_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    show: builtins.int
    """"""

    text: typing.Text
    """"""

    def __init__(self,
        *,
        show: builtins.int = ...,
        text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show",b"show","text",b"text"]) -> None: ...
global___DynVideoPushIntro = DynVideoPushIntro

class DynVideoSubmitActBanner(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HOTACT_TEXT_FIELD_NUMBER: builtins.int
    HOTACT_URL_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    hotact_text: typing.Text
    """"""

    hotact_url: typing.Text
    """"""

    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynVideoHotAct]:
        """"""
        pass
    def __init__(self,
        *,
        hotact_text: typing.Text = ...,
        hotact_url: typing.Text = ...,
        list: typing.Optional[typing.Iterable[global___DynVideoHotAct]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hotact_text",b"hotact_text","hotact_url",b"hotact_url","list",b"list"]) -> None: ...
global___DynVideoSubmitActBanner = DynVideoSubmitActBanner

class DynVideoVote(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VOTE_ID_FIELD_NUMBER: builtins.int
    VOTE_TITLE_FIELD_NUMBER: builtins.int
    TOP_FOR_REPLY_FIELD_NUMBER: builtins.int
    vote_id: builtins.int
    """"""

    vote_title: typing.Text
    """"""

    top_for_reply: builtins.int
    """"""

    def __init__(self,
        *,
        vote_id: builtins.int = ...,
        vote_title: typing.Text = ...,
        top_for_reply: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["top_for_reply",b"top_for_reply","vote_id",b"vote_id","vote_title",b"vote_title"]) -> None: ...
global___DynVideoVote = DynVideoVote

class DynVideoWatermark(google.protobuf.message.Message):
    """动态视频水印信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    state: builtins.int
    """水印状态 
    0-关闭 1-打开 2-预览
    """

    type: builtins.int
    """类型
    1-用户昵称类型 2-用户id类型 3-用户名在logo下面
    """

    position: builtins.int
    """位置
    1-左上 2-右上 3-左下 4-右下
    """

    def __init__(self,
        *,
        state: builtins.int = ...,
        type: builtins.int = ...,
        position: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["position",b"position","state",b"state","type",b"type"]) -> None: ...
global___DynVideoWatermark = DynVideoWatermark

class ExtLbs(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    DISTANCE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    POI_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    SHOW_TITLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SHOW_DISTANCE_FIELD_NUMBER: builtins.int
    address: typing.Text
    """"""

    distance: builtins.int
    """"""

    type: builtins.int
    """"""

    poi: typing.Text
    """"""

    @property
    def location(self) -> global___LbsLoc:
        """"""
        pass
    show_title: typing.Text
    """"""

    title: typing.Text
    """"""

    show_distance: typing.Text
    """"""

    def __init__(self,
        *,
        address: typing.Text = ...,
        distance: builtins.int = ...,
        type: builtins.int = ...,
        poi: typing.Text = ...,
        location: typing.Optional[global___LbsLoc] = ...,
        show_title: typing.Text = ...,
        title: typing.Text = ...,
        show_distance: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location",b"location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","distance",b"distance","location",b"location","poi",b"poi","show_distance",b"show_distance","show_title",b"show_title","title",b"title","type",b"type"]) -> None: ...
global___ExtLbs = ExtLbs

class GetUidByNameReq(google.protobuf.message.Message):
    """根据name取uid-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAMES_FIELD_NUMBER: builtins.int
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """查询昵称列表"""
        pass
    def __init__(self,
        *,
        names: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["names",b"names"]) -> None: ...
global___GetUidByNameReq = GetUidByNameReq

class GetUidByNameRsp(google.protobuf.message.Message):
    """根据name取uid-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class UidsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: builtins.int
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    UIDS_FIELD_NUMBER: builtins.int
    @property
    def uids(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.int]:
        """k:昵称 v:mid"""
        pass
    def __init__(self,
        *,
        uids: typing.Optional[typing.Mapping[typing.Text, builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uids",b"uids"]) -> None: ...
global___GetUidByNameRsp = GetUidByNameRsp

class GoodsContent(google.protobuf.message.Message):
    """发布时附带的商品卡的详细内容"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    SHOP_ID_FIELD_NUMBER: builtins.int
    source_type: builtins.int
    """商品类型
    1淘宝、2会员购
    """

    item_id: builtins.int
    """商品的id"""

    shop_id: builtins.int
    """店铺的id，兼容老版本"""

    def __init__(self,
        *,
        source_type: builtins.int = ...,
        item_id: builtins.int = ...,
        shop_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_id",b"item_id","shop_id",b"shop_id","source_type",b"source_type"]) -> None: ...
global___GoodsContent = GoodsContent

class LaunchedActivity(google.protobuf.message.Message):
    """UP已经创建的活动列表"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_TITLE_FIELD_NUMBER: builtins.int
    ACTIVITIES_FIELD_NUMBER: builtins.int
    SHOW_MORE_FIELD_NUMBER: builtins.int
    module_title: typing.Text
    """模块名称，示例："已创建的活动" """

    @property
    def activities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchedActivityItem]:
        """已创建的活动列表"""
        pass
    @property
    def show_more(self) -> global___ShowMoreLaunchedActivity:
        """展示更多按钮
        已创建活动大于5个时下发
        """
        pass
    def __init__(self,
        *,
        module_title: typing.Text = ...,
        activities: typing.Optional[typing.Iterable[global___LaunchedActivityItem]] = ...,
        show_more: typing.Optional[global___ShowMoreLaunchedActivity] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["show_more",b"show_more"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activities",b"activities","module_title",b"module_title","show_more",b"show_more"]) -> None: ...
global___LaunchedActivity = LaunchedActivity

class LaunchedActivityItem(google.protobuf.message.Message):
    """UP已经创建的活动详情"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_NAME_FIELD_NUMBER: builtins.int
    ACTIVITY_STATE_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """活动id"""

    activity_name: typing.Text
    """活动名称"""

    activity_state: builtins.int
    """活动是否已上线
    0未上线 1已上线
    """

    def __init__(self,
        *,
        activity_id: builtins.int = ...,
        activity_name: typing.Text = ...,
        activity_state: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id",b"activity_id","activity_name",b"activity_name","activity_state",b"activity_state"]) -> None: ...
global___LaunchedActivityItem = LaunchedActivityItem

class LbsLoc(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    lat: builtins.float
    """经度"""

    lng: builtins.float
    """纬度"""

    def __init__(self,
        *,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lat",b"lat","lng",b"lng"]) -> None: ...
global___LbsLoc = LbsLoc

class MetaDataCtrl(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLATFORM_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TRACE_ID_FIELD_NUMBER: builtins.int
    TEENAGER_MODE_FIELD_NUMBER: builtins.int
    COLD_START_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    platform: typing.Text
    """客户端平台"""

    build: typing.Text
    """客户端build号"""

    mobi_app: typing.Text
    """客户端移动设备类型"""

    buvid: typing.Text
    """客户端buvid"""

    device: typing.Text
    """用户设备信息"""

    from_spmid: typing.Text
    """请求来源页面的spmid"""

    trace_id: typing.Text
    """请求的trace_id"""

    teenager_mode: builtins.int
    """青少年模式"""

    cold_start: builtins.int
    """0:正常 1:冷启动"""

    version: typing.Text
    """客户端版本号"""

    network: builtins.int
    """网络状态
    Unknown=0 WIFI=1 WWAN=2
    """

    ip: typing.Text
    """用户ip地址"""

    def __init__(self,
        *,
        platform: typing.Text = ...,
        build: typing.Text = ...,
        mobi_app: typing.Text = ...,
        buvid: typing.Text = ...,
        device: typing.Text = ...,
        from_spmid: typing.Text = ...,
        trace_id: typing.Text = ...,
        teenager_mode: builtins.int = ...,
        cold_start: builtins.int = ...,
        version: typing.Text = ...,
        network: builtins.int = ...,
        ip: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build",b"build","buvid",b"buvid","cold_start",b"cold_start","device",b"device","from",b"from","from_spmid",b"from_spmid","ip",b"ip","mobi_app",b"mobi_app","network",b"network","platform",b"platform","teenager_mode",b"teenager_mode","trace_id",b"trace_id","version",b"version"]) -> None: ...
global___MetaDataCtrl = MetaDataCtrl

class PlusRedDot(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLUS_HAS_RED_DOT_FIELD_NUMBER: builtins.int
    plus_has_red_dot: builtins.int
    """"""

    def __init__(self,
        *,
        plus_has_red_dot: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["plus_has_red_dot",b"plus_has_red_dot"]) -> None: ...
global___PlusRedDot = PlusRedDot

class Program(google.protobuf.message.Message):
    """小程序内容定义"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    PROGRAM_TEXT_FIELD_NUMBER: builtins.int
    JUMP_TEXT_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    desc: typing.Text
    """描述文字"""

    cover: typing.Text
    """封面图"""

    target_url: typing.Text
    """跳转链接"""

    icon: typing.Text
    """小程序icon"""

    program_text: typing.Text
    """小程序名称"""

    jump_text: typing.Text
    """跳转链接文案，如：去看看"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        cover: typing.Text = ...,
        target_url: typing.Text = ...,
        icon: typing.Text = ...,
        program_text: typing.Text = ...,
        jump_text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","desc",b"desc","icon",b"icon","jump_text",b"jump_text","program_text",b"program_text","target_url",b"target_url","title",b"title"]) -> None: ...
global___Program = Program

class PublishSetting(google.protobuf.message.Message):
    """发布相关的设置项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MIN_WORDS_TO_ARTICLE_FIELD_NUMBER: builtins.int
    MAX_WORDS_TO_ARTICLE_FIELD_NUMBER: builtins.int
    UPLOAD_SIZE_FIELD_NUMBER: builtins.int
    min_words_to_article: builtins.int
    """提示转为专栏的最小字数，使用utf-16编码计算字符数"""

    max_words_to_article: builtins.int
    """提示转为专栏的最大字数，使用utf-16编码计算字符数"""

    upload_size: builtins.int
    """gif上传的最大值，单位：MB"""

    def __init__(self,
        *,
        min_words_to_article: builtins.int = ...,
        max_words_to_article: builtins.int = ...,
        upload_size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_words_to_article",b"max_words_to_article","min_words_to_article",b"min_words_to_article","upload_size",b"upload_size"]) -> None: ...
global___PublishSetting = PublishSetting

class PublishYellowBar(google.protobuf.message.Message):
    """发布页小黄条"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    text: typing.Text
    """展示文案"""

    url: typing.Text
    """跳转链接"""

    icon: typing.Text
    """展示图标"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        url: typing.Text = ...,
        icon: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","text",b"text","url",b"url"]) -> None: ...
global___PublishYellowBar = PublishYellowBar

class RepostInitCheck(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REPOST_SRC_FIELD_NUMBER: builtins.int
    SHARE_ID_FIELD_NUMBER: builtins.int
    SHARE_MODE_FIELD_NUMBER: builtins.int
    @property
    def repost_src(self) -> global___DynIdentity:
        """"""
        pass
    share_id: typing.Text
    """"""

    share_mode: builtins.int
    """"""

    def __init__(self,
        *,
        repost_src: typing.Optional[global___DynIdentity] = ...,
        share_id: typing.Text = ...,
        share_mode: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repost_src",b"repost_src"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["repost_src",b"repost_src","share_id",b"share_id","share_mode",b"share_mode"]) -> None: ...
global___RepostInitCheck = RepostInitCheck

class ShareChannel(google.protobuf.message.Message):
    """分享渠道信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHARE_ORIGIN_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    SHARE_CHANNELS_FIELD_NUMBER: builtins.int
    share_origin: typing.Text
    """业务类型，如动态是"dynamic" """

    oid: typing.Text
    """业务资源id"""

    sid: typing.Text
    """辅助id, 非必返回字段"""

    @property
    def share_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareChannelItem]:
        """渠道列表"""
        pass
    def __init__(self,
        *,
        share_origin: typing.Text = ...,
        oid: typing.Text = ...,
        sid: typing.Text = ...,
        share_channels: typing.Optional[typing.Iterable[global___ShareChannelItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid",b"oid","share_channels",b"share_channels","share_origin",b"share_origin","sid",b"sid"]) -> None: ...
global___ShareChannel = ShareChannel

class ShareChannelItem(google.protobuf.message.Message):
    """渠道"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    SHARE_CHANNEL_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    name: typing.Text
    """展示文案"""

    picture: typing.Text
    """展示图标"""

    share_channel: typing.Text
    """渠道名称"""

    @property
    def reserve(self) -> global___ShareReserve:
        """预约卡分享图信息，仅分享有预约信息的动态时存在"""
        pass
    def __init__(self,
        *,
        name: typing.Text = ...,
        picture: typing.Text = ...,
        share_channel: typing.Text = ...,
        reserve: typing.Optional[global___ShareReserve] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reserve",b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name","picture",b"picture","reserve",b"reserve","share_channel",b"share_channel"]) -> None: ...
global___ShareChannelItem = ShareChannelItem

class ShareReserve(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    QR_CODE_ICON_FIELD_NUMBER: builtins.int
    QR_CODE_TEXT_FIELD_NUMBER: builtins.int
    QR_CODE_URL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    POSTER_FIELD_NUMBER: builtins.int
    RESERVE_LOTTERY_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    desc: typing.Text
    """描述（时间+类型）"""

    qr_code_icon: typing.Text
    """二维码附带icon"""

    qr_code_text: typing.Text
    """二维码附带文本"""

    qr_code_url: typing.Text
    """二维码链接"""

    name: typing.Text
    """"""

    face: typing.Text
    """"""

    @property
    def poster(self) -> global___ShareReservePoster:
        """"""
        pass
    @property
    def reserve_lottery(self) -> global___ShareReserveLottery:
        """"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        qr_code_icon: typing.Text = ...,
        qr_code_text: typing.Text = ...,
        qr_code_url: typing.Text = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        poster: typing.Optional[global___ShareReservePoster] = ...,
        reserve_lottery: typing.Optional[global___ShareReserveLottery] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["poster",b"poster","reserve_lottery",b"reserve_lottery"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","face",b"face","name",b"name","poster",b"poster","qr_code_icon",b"qr_code_icon","qr_code_text",b"qr_code_text","qr_code_url",b"qr_code_url","reserve_lottery",b"reserve_lottery","title",b"title"]) -> None: ...
global___ShareReserve = ShareReserve

class ShareReserveLottery(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    icon: typing.Text
    """"""

    text: typing.Text
    """"""

    def __init__(self,
        *,
        icon: typing.Text = ...,
        text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","text",b"text"]) -> None: ...
global___ShareReserveLottery = ShareReserveLottery

class ShareReservePoster(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    url: typing.Text
    """"""

    width: builtins.float
    """"""

    height: builtins.float
    """"""

    def __init__(self,
        *,
        url: typing.Text = ...,
        width: builtins.float = ...,
        height: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","url",b"url","width",b"width"]) -> None: ...
global___ShareReservePoster = ShareReservePoster

class ShareResult(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHARE_ENABLE_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    share_enable: builtins.int
    """"""

    toast: typing.Text
    """"""

    def __init__(self,
        *,
        share_enable: builtins.int = ...,
        toast: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_enable",b"share_enable","toast",b"toast"]) -> None: ...
global___ShareResult = ShareResult

class ShowMoreLaunchedActivity(google.protobuf.message.Message):
    """UP已经创建的活动列表中的展示更多按钮详情"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUTTON_TEXT_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    button_text: typing.Text
    """按钮的文案"""

    jump_url: typing.Text
    """按钮的跳转链接"""

    def __init__(self,
        *,
        button_text: typing.Text = ...,
        jump_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_text",b"button_text","jump_url",b"jump_url"]) -> None: ...
global___ShowMoreLaunchedActivity = ShowMoreLaunchedActivity

class Sketch(google.protobuf.message.Message):
    """通用模板的网页元内容(sketch结构)定义"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESC_TEXT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    COVER_URL_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    title: typing.Text
    """元内容标题，长度30限制"""

    desc_text: typing.Text
    """描述文字（文本内容第二行），长度233限制"""

    text: typing.Text
    """文本文字（文本内容第三行），仅限竖图通用卡片使用，长度233限制"""

    biz_id: builtins.int
    """表示业务方的id表示，对于在业务方有唯一标示的必填"""

    biz_type: builtins.int
    """业务类型，与展示时的右上角标有关，需要业务方向动态申请"""

    cover_url: typing.Text
    """封面图片链接地址，域名需要符合白名单"""

    target_url: typing.Text
    """跳转链接地址，域名需要符合白名单"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        desc_text: typing.Text = ...,
        text: typing.Text = ...,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
        cover_url: typing.Text = ...,
        target_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id",b"biz_id","biz_type",b"biz_type","cover_url",b"cover_url","desc_text",b"desc_text","target_url",b"target_url","text",b"text","title",b"title"]) -> None: ...
global___Sketch = Sketch

class UpPermission(google.protobuf.message.Message):
    """发布相关的权限内容"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    LAUNCHED_ACTIVITY_FIELD_NUMBER: builtins.int
    SHARE_RESULT_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpPermissionItem]:
        """通用权限列表"""
        pass
    @property
    def launched_activity(self) -> global___LaunchedActivity:
        """已经创建的活动列表"""
        pass
    @property
    def share_result(self) -> global___ShareResult:
        """"""
        pass
    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___UpPermissionItem]] = ...,
        launched_activity: typing.Optional[global___LaunchedActivity] = ...,
        share_result: typing.Optional[global___ShareResult] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["launched_activity",b"launched_activity","share_result",b"share_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items",b"items","launched_activity",b"launched_activity","share_result",b"share_result"]) -> None: ...
global___UpPermission = UpPermission

class UpPermissionItem(google.protobuf.message.Message):
    """通用发布权限内容的详细定义"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    HAS_RED_DOT_FIELD_NUMBER: builtins.int
    type: builtins.int
    """类型，enum UpPermissionType"""

    permission: builtins.int
    """UP是否有权限
    1-有，2-限制（展示但不可点，仅预约使用）
    """

    title: typing.Text
    """按钮文案"""

    subtitle: typing.Text
    """功能开关的副标题"""

    icon: typing.Text
    """按钮图标的url地址"""

    jump_url: typing.Text
    """跳转链接，permission=1时点击按钮跳到此链接"""

    toast: typing.Text
    """错误提示，permission=2时点击按钮会弹出此提示，目前仅预约使用"""

    has_red_dot: builtins.int
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        permission: builtins.int = ...,
        title: typing.Text = ...,
        subtitle: typing.Text = ...,
        icon: typing.Text = ...,
        jump_url: typing.Text = ...,
        toast: typing.Text = ...,
        has_red_dot: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_red_dot",b"has_red_dot","icon",b"icon","jump_url",b"jump_url","permission",b"permission","subtitle",b"subtitle","title",b"title","toast",b"toast","type",b"type"]) -> None: ...
global___UpPermissionItem = UpPermissionItem

class UserCreateMeta(google.protobuf.message.Message):
    """用户主动发布（app/web发布）时的meta信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    APP_META_FIELD_NUMBER: builtins.int
    LOC_FIELD_NUMBER: builtins.int
    REPOST_MODE_FIELD_NUMBER: builtins.int
    @property
    def app_meta(self) -> global___MetaDataCtrl:
        """用户发布客户端的meta信息"""
        pass
    @property
    def loc(self) -> global___LbsLoc:
        """用户发布时的位置信息（经纬度）"""
        pass
    repost_mode: builtins.int
    """1-发布页转发 2-立即转发"""

    def __init__(self,
        *,
        app_meta: typing.Optional[global___MetaDataCtrl] = ...,
        loc: typing.Optional[global___LbsLoc] = ...,
        repost_mode: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_meta",b"app_meta","loc",b"loc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_meta",b"app_meta","loc",b"loc","repost_mode",b"repost_mode"]) -> None: ...
global___UserCreateMeta = UserCreateMeta

class VideoShareInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CID_FIELD_NUMBER: builtins.int
    PART_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """"""

    part: builtins.int
    """"""

    def __init__(self,
        *,
        cid: builtins.int = ...,
        part: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","part",b"part"]) -> None: ...
global___VideoShareInfo = VideoShareInfo
