"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Metadata(google.protobuf.message.Message):
    """请求元数据
    gRPC头部:x-bili-metadata-bin
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACCESS_KEY_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    access_key: typing.Text
    """登录Token"""

    mobi_app: typing.Text
    """包类型"""

    device: typing.Text
    """运行设备"""

    build: builtins.int
    """构建id"""

    channel: typing.Text
    """渠道"""

    buvid: typing.Text
    """设备buvid"""

    platform: typing.Text
    """平台类型"""

    def __init__(self,
        *,
        access_key: typing.Text = ...,
        mobi_app: typing.Text = ...,
        device: typing.Text = ...,
        build: builtins.int = ...,
        channel: typing.Text = ...,
        buvid: typing.Text = ...,
        platform: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key",b"access_key","build",b"build","buvid",b"buvid","channel",b"channel","device",b"device","mobi_app",b"mobi_app","platform",b"platform"]) -> None: ...
global___Metadata = Metadata
