# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/splash/v1/splash.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#bilibili/app/splash/v1/splash.proto\x12\x16\x62ilibili.app.splash.v1\x1a\x19google/protobuf/any.proto\"8\n\x0cShowStrategy\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05stime\x18\x02 \x01(\x03\x12\r\n\x05\x65time\x18\x03 \x01(\x03\"\x91\x06\n\nSplashItem\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x11\n\tcard_type\x18\x03 \x01(\x05\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\x12\x12\n\nbegin_time\x18\x05 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x03\x12\r\n\x05thumb\x18\x07 \x01(\t\x12\x0c\n\x04hash\x18\x08 \x01(\t\x12\x10\n\x08logo_url\x18\t \x01(\t\x12\x11\n\tlogo_hash\x18\n \x01(\t\x12\x11\n\tvideo_url\x18\x0b \x01(\t\x12\x12\n\nvideo_hash\x18\x0c \x01(\t\x12\x13\n\x0bvideo_width\x18\r \x01(\x05\x12\x14\n\x0cvideo_height\x18\x0e \x01(\x05\x12\x0e\n\x06schema\x18\x0f \x01(\t\x12\x14\n\x0cschema_title\x18\x10 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x11 \x01(\t\x12\x1f\n\x17schema_callup_whiteList\x18\x12 \x03(\t\x12\x0c\n\x04skip\x18\x13 \x01(\x05\x12\x0b\n\x03uri\x18\x14 \x01(\t\x12\x11\n\turi_title\x18\x15 \x01(\t\x12\x0e\n\x06source\x18\x16 \x01(\x05\x12\x0f\n\x07\x63m_mark\x18\x17 \x01(\x05\x12\r\n\x05\x61\x64_cb\x18\x18 \x01(\t\x12\x13\n\x0bresource_id\x18\x19 \x01(\x03\x12\x12\n\nrequest_id\x18\x1a \x01(\t\x12\x11\n\tclient_ip\x18\x1b \x01(\t\x12\r\n\x05is_ad\x18\x1c \x01(\x08\x12\x11\n\tis_ad_loc\x18\x1d \x01(\x08\x12#\n\x05\x65xtra\x18\x1e \x01(\x0b\x32\x14.google.protobuf.Any\x12\x12\n\ncard_index\x18\x1f \x01(\x03\x12\x13\n\x0bserver_type\x18  \x01(\x03\x12\r\n\x05index\x18! \x01(\x03\x12\x11\n\tclick_url\x18\" \x01(\t\x12\x10\n\x08show_url\x18# \x01(\t\x12\x13\n\x0btime_target\x18$ \x01(\x05\x12\x12\n\nencryption\x18% \x01(\x05\x12\x1b\n\x13\x65nable_pre_download\x18& \x01(\x08\x12\"\n\x1a\x65nable_background_download\x18\' \x01(\x08\"\xb2\x01\n\x0bSplashReply\x12\x10\n\x08max_time\x18\x01 \x01(\x05\x12\x14\n\x0cmin_interval\x18\x02 \x01(\x05\x12\x15\n\rpull_interval\x18\x03 \x01(\x05\x12\x30\n\x04list\x18\x04 \x03(\x0b\x32\".bilibili.app.splash.v1.SplashItem\x12\x32\n\x04show\x18\x05 \x03(\x0b\x32$.bilibili.app.splash.v1.ShowStrategy\"\\\n\tSplashReq\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05\x62irth\x18\x03 \x01(\t\x12\x10\n\x08\x61\x64_extra\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t2X\n\x06Splash\x12N\n\x04List\x12!.bilibili.app.splash.v1.SplashReq\x1a#.bilibili.app.splash.v1.SplashReplyb\x06proto3')



_SHOWSTRATEGY = DESCRIPTOR.message_types_by_name['ShowStrategy']
_SPLASHITEM = DESCRIPTOR.message_types_by_name['SplashItem']
_SPLASHREPLY = DESCRIPTOR.message_types_by_name['SplashReply']
_SPLASHREQ = DESCRIPTOR.message_types_by_name['SplashReq']
ShowStrategy = _reflection.GeneratedProtocolMessageType('ShowStrategy', (_message.Message,), {
  'DESCRIPTOR' : _SHOWSTRATEGY,
  '__module__' : 'bilibili.app.splash.v1.splash_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.splash.v1.ShowStrategy)
  })
_sym_db.RegisterMessage(ShowStrategy)

SplashItem = _reflection.GeneratedProtocolMessageType('SplashItem', (_message.Message,), {
  'DESCRIPTOR' : _SPLASHITEM,
  '__module__' : 'bilibili.app.splash.v1.splash_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.splash.v1.SplashItem)
  })
_sym_db.RegisterMessage(SplashItem)

SplashReply = _reflection.GeneratedProtocolMessageType('SplashReply', (_message.Message,), {
  'DESCRIPTOR' : _SPLASHREPLY,
  '__module__' : 'bilibili.app.splash.v1.splash_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.splash.v1.SplashReply)
  })
_sym_db.RegisterMessage(SplashReply)

SplashReq = _reflection.GeneratedProtocolMessageType('SplashReq', (_message.Message,), {
  'DESCRIPTOR' : _SPLASHREQ,
  '__module__' : 'bilibili.app.splash.v1.splash_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.splash.v1.SplashReq)
  })
_sym_db.RegisterMessage(SplashReq)

_SPLASH = DESCRIPTOR.services_by_name['Splash']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SHOWSTRATEGY._serialized_start=90
  _SHOWSTRATEGY._serialized_end=146
  _SPLASHITEM._serialized_start=149
  _SPLASHITEM._serialized_end=934
  _SPLASHREPLY._serialized_start=937
  _SPLASHREPLY._serialized_end=1115
  _SPLASHREQ._serialized_start=1117
  _SPLASHREQ._serialized_end=1209
  _SPLASH._serialized_start=1211
  _SPLASH._serialized_end=1299
# @@protoc_insertion_point(module_scope)
