# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pgc/biz/room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12pgc/biz/room.proto\x12\x07pgc.biz\"\x1c\n\tRoomProto\x12\x0f\n\x07room_id\x18\x01 \x03(\tb\x06proto3')



_ROOMPROTO = DESCRIPTOR.message_types_by_name['RoomProto']
RoomProto = _reflection.GeneratedProtocolMessageType('RoomProto', (_message.Message,), {
  'DESCRIPTOR' : _ROOMPROTO,
  '__module__' : 'pgc.biz.room_pb2'
  # @@protoc_insertion_point(class_scope:pgc.biz.RoomProto)
  })
_sym_db.RegisterMessage(RoomProto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROOMPROTO._serialized_start=31
  _ROOMPROTO._serialized_end=59
# @@protoc_insertion_point(module_scope)
