# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/metadata/parabox/pararbox.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/metadata/parabox/pararbox.proto\x12\x19\x62ilibili.metadata.parabox\"!\n\x03\x45xp\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\x05\"4\n\x04\x45xps\x12,\n\x04\x65xps\x18\x01 \x03(\x0b\x32\x1e.bilibili.metadata.parabox.Expb\x06proto3')



_EXP = DESCRIPTOR.message_types_by_name['Exp']
_EXPS = DESCRIPTOR.message_types_by_name['Exps']
Exp = _reflection.GeneratedProtocolMessageType('Exp', (_message.Message,), {
  'DESCRIPTOR' : _EXP,
  '__module__' : 'bilibili.metadata.parabox.pararbox_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.metadata.parabox.Exp)
  })
_sym_db.RegisterMessage(Exp)

Exps = _reflection.GeneratedProtocolMessageType('Exps', (_message.Message,), {
  'DESCRIPTOR' : _EXPS,
  '__module__' : 'bilibili.metadata.parabox.pararbox_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.metadata.parabox.Exps)
  })
_sym_db.RegisterMessage(Exps)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXP._serialized_start=71
  _EXP._serialized_end=104
  _EXPS._serialized_start=106
  _EXPS._serialized_end=158
# @@protoc_insertion_point(module_scope)
