# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/listener/v1/listener.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/app/listener/v1/listener.proto\x12\x18\x62ilibili.app.listener.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"o\n\x06\x41uthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\x12:\n\x08relation\x18\x04 \x01(\x0b\x32(.bilibili.app.listener.v1.FollowRelation\"\x88\x01\n\x0f\x42KArcDetailsReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x42\n\nplayerArgs\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"F\n\x10\x42KArcDetailsResp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"\xe4\x01\n\tBKArchive\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\x0b\n\x03rid\x18\x06 \x01(\x05\x12\r\n\x05rname\x18\x07 \x01(\t\x12\x0f\n\x07publish\x18\x08 \x01(\x03\x12\x15\n\rdisplayed_oid\x18\t \x01(\t\x12\x11\n\tcopyright\x18\n \x01(\x05\x12\x35\n\x06rights\x18\x0b \x01(\x0b\x32%.bilibili.app.listener.v1.BKArcRights\"W\n\tBKArcPart\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0e\n\x06sub_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x0c\n\x04page\x18\x05 \x01(\x05\"!\n\x0b\x42KArcRights\x12\x12\n\nno_reprint\x18\x01 \x01(\x05\"\x98\x01\n\x06\x42KStat\x12\x0c\n\x04like\x18\x01 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x02 \x01(\x05\x12\x11\n\tfavourite\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\r\n\x05share\x18\x05 \x01(\x05\x12\x0c\n\x04view\x18\x06 \x01(\x05\x12\x10\n\x08has_like\x18\x07 \x01(\x08\x12\x10\n\x08has_coin\x18\x08 \x01(\x08\x12\x0f\n\x07has_fav\x18\t \x01(\x08\"\xee\x01\n\nCardModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\x05\x12=\n\rmodule_header\x18\x02 \x01(\x0b\x32$.bilibili.app.listener.v1.PkcmHeaderH\x00\x12?\n\x0emodule_archive\x18\x03 \x01(\x0b\x32%.bilibili.app.listener.v1.PkcmArchiveH\x00\x12\x41\n\x0bmodule_cbtn\x18\x04 \x01(\x0b\x32*.bilibili.app.listener.v1.PkcmCenterButtonH\x00\x42\x08\n\x06module\"]\n\nCoinAddReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12\x10\n\x08thumb_up\x18\x03 \x01(\x08\"\x1e\n\x0b\x43oinAddResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xdf\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\x05\x12\x11\n\tmime_type\x18\x05 \x01(\t\x12\x0e\n\x06\x63odecs\x18\x06 \x01(\t\x12?\n\x0csegment_base\x18\x0c \x01(\x0b\x32).bilibili.app.listener.v1.DashSegmentBase\x12\x0f\n\x07\x63odecid\x18\r \x01(\x05\x12\x0b\n\x03md5\x18\x0e \x01(\t\x12\x0c\n\x04size\x18\x0f \x01(\x03\">\n\x0f\x44\x61shSegmentBase\x12\x16\n\x0einitialization\x18\x01 \x01(\t\x12\x13\n\x0bindex_range\x18\x02 \x01(\t\"\xef\x03\n\nDetailItem\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x30\n\x03\x61rc\x18\x02 \x01(\x0b\x32#.bilibili.app.listener.v1.BKArchive\x12\x32\n\x05parts\x18\x03 \x03(\x0b\x32#.bilibili.app.listener.v1.BKArcPart\x12/\n\x05owner\x18\x04 \x01(\x0b\x32 .bilibili.app.listener.v1.Author\x12.\n\x04stat\x18\x05 \x01(\x0b\x32 .bilibili.app.listener.v1.BKStat\x12\x11\n\tlast_part\x18\x06 \x01(\x03\x12\x10\n\x08progress\x18\x07 \x01(\x03\x12\x10\n\x08playable\x18\x08 \x01(\x05\x12\x0f\n\x07message\x18\t \x01(\t\x12I\n\x0bplayer_info\x18\n \x03(\x0b\x32\x34.bilibili.app.listener.v1.DetailItem.PlayerInfoEntry\x1aU\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayInfo:\x02\x38\x01\"j\n\rEventTracking\x12\x10\n\x08operator\x18\x01 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x02 \x01(\t\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_type\x18\x04 \x01(\t\x12\x11\n\tentity_id\x18\x05 \x01(\t\"\xf4\x02\n\tFavFolder\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x38\n\x05owner\x18\x03 \x01(\x0b\x32).bilibili.app.listener.v1.FavFolderAuthor\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x06 \x01(\t\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x0c\n\x04\x61ttr\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\x05\x12\x0f\n\x07\x66\x61vored\x18\n \x01(\x05\x12\r\n\x05\x63time\x18\x0b \x01(\x03\x12\r\n\x05mtime\x18\x0c \x01(\x03\x12\x14\n\x0cstat_fav_cnt\x18\r \x01(\x05\x12\x16\n\x0estat_share_cnt\x18\x0e \x01(\x05\x12\x15\n\rstat_like_cnt\x18\x0f \x01(\x05\x12\x15\n\rstat_Play_cnt\x18\x10 \x01(\x05\x12\x16\n\x0estat_reply_cnt\x18\x11 \x01(\x05\x12\x11\n\tfav_state\x18\x12 \x01(\x05\"C\n\x0f\x46\x61vFolderAction\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x05\",\n\x0f\x46\x61vFolderAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x12\x46\x61vFolderCreateReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0e\n\x06public\x18\x03 \x01(\x05\x12\x13\n\x0b\x66older_type\x18\x04 \x01(\x05\"H\n\x13\x46\x61vFolderCreateResp\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x12\x46\x61vFolderDeleteReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\"&\n\x13\x46\x61vFolderDeleteResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xaa\x01\n\x12\x46\x61vFolderDetailReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0f\n\x07\x66\x61v_mid\x18\x03 \x01(\x03\x12\x34\n\tlast_item\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItem\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x18\n\x10need_folder_info\x18\x06 \x01(\x08\"\xa8\x01\n\x13\x46\x61vFolderDetailResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x11\n\treach_end\x18\x02 \x01(\x08\x12\x35\n\x04list\x18\x03 \x03(\x0b\x32\'.bilibili.app.listener.v1.FavItemDetail\x12\x38\n\x0b\x66older_info\x18\x04 \x01(\x0b\x32#.bilibili.app.listener.v1.FavFolder\"Z\n\x10\x46\x61vFolderListReq\x12\x14\n\x0c\x66older_types\x18\x01 \x03(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"F\n\x11\x46\x61vFolderListResp\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.bilibili.app.listener.v1.FavFolder\"1\n\rFavFolderMeta\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\"\x96\x01\n\x07\x46\x61vItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03\x66id\x18\x03 \x01(\x03\x12\x0b\n\x03mid\x18\x04 \x01(\x03\x12\r\n\x05mtime\x18\x05 \x01(\x03\x12\r\n\x05\x63time\x18\x06 \x01(\x03\x12\x33\n\x02\x65t\x18\x07 \x01(\x0b\x32\'.bilibili.app.listener.v1.EventTracking\"\x9f\x01\n\rFavItemAddReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x32\n\x04play\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"!\n\x0e\x46\x61vItemAddResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"*\n\rFavItemAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xbb\x01\n\x0f\x46\x61vItemBatchReq\x12:\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32).bilibili.app.listener.v1.FavFolderAction\x12\x32\n\x04play\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x03 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"#\n\x10\x46\x61vItemBatchResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x9f\x01\n\rFavItemDelReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x32\n\x04play\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"!\n\x0e\x46\x61vItemDelResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x8b\x02\n\rFavItemDetail\x12/\n\x04item\x18\x01 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItem\x12\x36\n\x05owner\x18\x02 \x01(\x0b\x32\'.bilibili.app.listener.v1.FavItemAuthor\x12\x33\n\x04stat\x18\x03 \x01(\x0b\x32%.bilibili.app.listener.v1.FavItemStat\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\r\n\x05parts\x18\t \x01(\x05\"*\n\x0b\x46\x61vItemStat\x12\x0c\n\x04view\x18\x01 \x01(\x05\x12\r\n\x05reply\x18\x02 \x01(\x05\"`\n\x16\x46\x61voredInAnyFoldersReq\x12\x14\n\x0c\x66older_types\x18\x01 \x03(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x85\x01\n\x17\x46\x61voredInAnyFoldersResp\x12\x38\n\x07\x66olders\x18\x01 \x03(\x0b\x32\'.bilibili.app.listener.v1.FavFolderMeta\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\" \n\x0e\x46ollowRelation\x12\x0e\n\x06status\x18\x01 \x01(\x05\"t\n\x11\x46ormatDescription\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x04 \x01(\t\x12\x13\n\x0bsuperscript\x18\x05 \x01(\t\"i\n\nPageOption\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x11\n\tdirection\x18\x02 \x01(\x05\x12\x35\n\tlast_item\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x81\x02\n\x0bPickArchive\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\r\n\x05title\x18\x02 \x01(\t\x12:\n\x05owner\x18\x03 \x01(\x0b\x32+.bilibili.app.listener.v1.PickArchiveAuthor\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\r\n\x05parts\x18\x06 \x01(\x05\x12\x11\n\tstat_view\x18\x07 \x01(\x05\x12\x12\n\nstat_reply\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\x05\x12\x0f\n\x07message\x18\n \x01(\t\".\n\x11PickArchiveAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x08PickCard\x12\x0f\n\x07pick_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63\x61rd_id\x18\x02 \x01(\x03\x12\x11\n\tcard_name\x18\x03 \x01(\t\x12\x35\n\x07modules\x18\x04 \x03(\x0b\x32$.bilibili.app.listener.v1.CardModule\"5\n\x11PickCardDetailReq\x12\x0f\n\x07\x63\x61rd_id\x18\x01 \x01(\x03\x12\x0f\n\x07pick_id\x18\x02 \x01(\x03\"m\n\x12PickCardDetailResp\x12\x0f\n\x07\x63\x61rd_id\x18\x01 \x01(\x03\x12\x0f\n\x07pick_id\x18\x02 \x01(\x03\x12\x35\n\x07modules\x18\x03 \x03(\x0b\x32$.bilibili.app.listener.v1.CardModule\"\x1d\n\x0bPickFeedReq\x12\x0e\n\x06offset\x18\x01 \x01(\x03\"Q\n\x0cPickFeedResp\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x31\n\x05\x63\x61rds\x18\x02 \x03(\x0b\x32\".bilibili.app.listener.v1.PickCard\"V\n\x0bPkcmArchive\x12\x32\n\x03\x61rc\x18\x01 \x01(\x0b\x32%.bilibili.app.listener.v1.PickArchive\x12\x13\n\x0bpick_reason\x18\x02 \x01(\t\"T\n\x10PkcmCenterButton\x12\x11\n\ticon_head\x18\x01 \x01(\t\x12\x11\n\ticon_tail\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"^\n\nPkcmHeader\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08\x62tn_icon\x18\x03 \x01(\t\x12\x10\n\x08\x62tn_text\x18\x04 \x01(\t\x12\x0f\n\x07\x62tn_uri\x18\x05 \x01(\t\"G\n\x13PlayActionReportReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"h\n\x08PlayDASH\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x12\x17\n\x0fmin_buffer_time\x18\x02 \x01(\x02\x12\x31\n\x05\x61udio\x18\x03 \x03(\x0b\x32\".bilibili.app.listener.v1.DashItem\"}\n\x11PlayHistoryAddReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x12\n\nplay_style\x18\x04 \x01(\x05\"X\n\x11PlayHistoryDelReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08truncate\x18\x02 \x01(\x08\"H\n\x0ePlayHistoryReq\x12\x36\n\x08page_opt\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.PageOption\"g\n\x0fPlayHistoryResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x11\n\treach_end\x18\x02 \x01(\x08\x12\x32\n\x04list\x18\x03 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"\xa4\x02\n\x08PlayInfo\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x0f\n\x07qn_type\x18\x03 \x01(\x05\x12\x35\n\x08play_url\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.PlayURLH\x00\x12\x37\n\tplay_dash\x18\x05 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayDASHH\x00\x12\r\n\x05\x66nver\x18\x06 \x01(\x05\x12\r\n\x05\x66nval\x18\x07 \x01(\x05\x12\x0f\n\x07\x66ormats\x18\x08 \x03(\x05\x12\x15\n\rvideo_codecid\x18\t \x01(\x05\x12\x0e\n\x06length\x18\n \x01(\x03\x12\x0c\n\x04\x63ode\x18\x0b \x01(\x05\x12\x0f\n\x07message\x18\x0c \x01(\tB\x06\n\x04info\"o\n\x08PlayItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x0e\n\x06sub_id\x18\x04 \x03(\x03\x12\x33\n\x02\x65t\x18\x05 \x01(\x0b\x32\'.bilibili.app.listener.v1.EventTracking\"\x9f\x01\n\x0ePlaylistAddReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x33\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x0e\n\x04head\x18\x03 \x01(\x08H\x00\x12\x0e\n\x04tail\x18\x04 \x01(\x08H\x00\x42\x05\n\x03pos\"U\n\x0ePlaylistDelReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08truncate\x18\x02 \x01(\x08\"\xea\x01\n\x0bPlaylistReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x32\n\x06\x61nchor\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x36\n\x08page_opt\x18\x04 \x01(\x0b\x32$.bilibili.app.listener.v1.PageOption\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08\x65xtra_id\x18\x06 \x01(\x03\"\xc7\x01\n\x0cPlaylistResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x13\n\x0breach_start\x18\x02 \x01(\x08\x12\x11\n\treach_end\x18\x03 \x01(\x08\x12\x32\n\x04list\x18\x04 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x35\n\tlast_play\x18\x05 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x15\n\rlast_progress\x18\x06 \x01(\x03\">\n\x07PlayURL\x12\x33\n\x04\x64url\x18\x01 \x03(\x0b\x32%.bilibili.app.listener.v1.ResponseUrl\"\x83\x01\n\nPlayURLReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x43\n\x0bplayer_args\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\x84\x02\n\x0bPlayURLResp\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08playable\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12I\n\nplayerInfo\x18\x04 \x03(\x0b\x32\x35.bilibili.app.listener.v1.PlayURLResp.PlayerInfoEntry\x1aU\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayInfo:\x02\x38\x01\"A\n\x0fRcmdPlaylistReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x14\n\x0cneed_history\x18\x03 \x01(\x08\"[\n\x10RcmdPlaylistResp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x13\n\x0bhistory_len\x18\x02 \x01(\x03\"\x86\x01\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\r\n\x05\x61head\x18\x04 \x01(\t\x12\r\n\x05vhead\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x12\n\nbackup_url\x18\x07 \x03(\t\x12\x0b\n\x03md5\x18\x08 \x01(\t\"N\n\nThumbUpReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"\x1e\n\x0bThumbUpResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"A\n\rTripleLikeReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"T\n\x0eTripleLikeResp\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08thumb_ok\x18\x02 \x01(\x08\x12\x0f\n\x07\x63oin_ok\x18\x03 \x01(\x08\x12\x0e\n\x06\x66\x61v_ok\x18\x04 \x01(\x08*\\\n\x0e\x43\x61rdModuleType\x12\x12\n\x0eModule_invalid\x10\x00\x12\x11\n\rModule_header\x10\x01\x12\x12\n\x0eModule_archive\x10\x02\x12\x0f\n\x0bModule_cbtn\x10\x03*\x96\x01\n\x0ePlaylistSource\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tMEM_SPACE\x10\x01\x12\x14\n\x10\x41UDIO_COLLECTION\x10\x02\x12\x0e\n\nAUDIO_CARD\x10\x03\x12\x12\n\x0eUSER_FAVOURITE\x10\x04\x12\x0e\n\nUP_ARCHIVE\x10\x05\x12\x0f\n\x0b\x41UDIO_CACHE\x10\x06\x12\r\n\tPICK_CARD\x10\x07\x32\x8a\x12\n\x08Listener\x12\x36\n\x04Ping\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12V\n\x07PlayUrl\x12$.bilibili.app.listener.v1.PlayURLReq\x1a%.bilibili.app.listener.v1.PlayURLResp\x12\x65\n\x0c\x42karcDetails\x12).bilibili.app.listener.v1.BKArcDetailsReq\x1a*.bilibili.app.listener.v1.BKArcDetailsResp\x12Y\n\x08Playlist\x12%.bilibili.app.listener.v1.PlaylistReq\x1a&.bilibili.app.listener.v1.PlaylistResp\x12O\n\x0bPlaylistAdd\x12(.bilibili.app.listener.v1.PlaylistAddReq\x1a\x16.google.protobuf.Empty\x12O\n\x0bPlaylistDel\x12(.bilibili.app.listener.v1.PlaylistDelReq\x1a\x16.google.protobuf.Empty\x12\x65\n\x0cRcmdPlaylist\x12).bilibili.app.listener.v1.RcmdPlaylistReq\x1a*.bilibili.app.listener.v1.RcmdPlaylistResp\x12\x62\n\x0bPlayHistory\x12(.bilibili.app.listener.v1.PlayHistoryReq\x1a).bilibili.app.listener.v1.PlayHistoryResp\x12U\n\x0ePlayHistoryAdd\x12+.bilibili.app.listener.v1.PlayHistoryAddReq\x1a\x16.google.protobuf.Empty\x12U\n\x0ePlayHistoryDel\x12+.bilibili.app.listener.v1.PlayHistoryDelReq\x1a\x16.google.protobuf.Empty\x12Y\n\x10PlayActionReport\x12-.bilibili.app.listener.v1.PlayActionReportReq\x1a\x16.google.protobuf.Empty\x12_\n\nTripleLike\x12\'.bilibili.app.listener.v1.TripleLikeReq\x1a(.bilibili.app.listener.v1.TripleLikeResp\x12V\n\x07ThumbUp\x12$.bilibili.app.listener.v1.ThumbUpReq\x1a%.bilibili.app.listener.v1.ThumbUpResp\x12V\n\x07\x43oinAdd\x12$.bilibili.app.listener.v1.CoinAddReq\x1a%.bilibili.app.listener.v1.CoinAddResp\x12_\n\nFavItemAdd\x12\'.bilibili.app.listener.v1.FavItemAddReq\x1a(.bilibili.app.listener.v1.FavItemAddResp\x12_\n\nFavItemDel\x12\'.bilibili.app.listener.v1.FavItemDelReq\x1a(.bilibili.app.listener.v1.FavItemDelResp\x12\x65\n\x0c\x46\x61vItemBatch\x12).bilibili.app.listener.v1.FavItemBatchReq\x1a*.bilibili.app.listener.v1.FavItemBatchResp\x12z\n\x13\x46\x61voredInAnyFolders\x12\x30.bilibili.app.listener.v1.FavoredInAnyFoldersReq\x1a\x31.bilibili.app.listener.v1.FavoredInAnyFoldersResp\x12h\n\rFavFolderList\x12*.bilibili.app.listener.v1.FavFolderListReq\x1a+.bilibili.app.listener.v1.FavFolderListResp\x12n\n\x0f\x46\x61vFolderDetail\x12,.bilibili.app.listener.v1.FavFolderDetailReq\x1a-.bilibili.app.listener.v1.FavFolderDetailResp\x12n\n\x0f\x46\x61vFolderCreate\x12,.bilibili.app.listener.v1.FavFolderCreateReq\x1a-.bilibili.app.listener.v1.FavFolderCreateResp\x12n\n\x0f\x46\x61vFolderDelete\x12,.bilibili.app.listener.v1.FavFolderDeleteReq\x1a-.bilibili.app.listener.v1.FavFolderDeleteResp\x12Y\n\x08PickFeed\x12%.bilibili.app.listener.v1.PickFeedReq\x1a&.bilibili.app.listener.v1.PickFeedResp\x12k\n\x0ePickCardDetail\x12+.bilibili.app.listener.v1.PickCardDetailReq\x1a,.bilibili.app.listener.v1.PickCardDetailRespb\x06proto3')

_CARDMODULETYPE = DESCRIPTOR.enum_types_by_name['CardModuleType']
CardModuleType = enum_type_wrapper.EnumTypeWrapper(_CARDMODULETYPE)
_PLAYLISTSOURCE = DESCRIPTOR.enum_types_by_name['PlaylistSource']
PlaylistSource = enum_type_wrapper.EnumTypeWrapper(_PLAYLISTSOURCE)
Module_invalid = 0
Module_header = 1
Module_archive = 2
Module_cbtn = 3
DEFAULT = 0
MEM_SPACE = 1
AUDIO_COLLECTION = 2
AUDIO_CARD = 3
USER_FAVOURITE = 4
UP_ARCHIVE = 5
AUDIO_CACHE = 6
PICK_CARD = 7


_AUTHOR = DESCRIPTOR.message_types_by_name['Author']
_BKARCDETAILSREQ = DESCRIPTOR.message_types_by_name['BKArcDetailsReq']
_BKARCDETAILSRESP = DESCRIPTOR.message_types_by_name['BKArcDetailsResp']
_BKARCHIVE = DESCRIPTOR.message_types_by_name['BKArchive']
_BKARCPART = DESCRIPTOR.message_types_by_name['BKArcPart']
_BKARCRIGHTS = DESCRIPTOR.message_types_by_name['BKArcRights']
_BKSTAT = DESCRIPTOR.message_types_by_name['BKStat']
_CARDMODULE = DESCRIPTOR.message_types_by_name['CardModule']
_COINADDREQ = DESCRIPTOR.message_types_by_name['CoinAddReq']
_COINADDRESP = DESCRIPTOR.message_types_by_name['CoinAddResp']
_DASHITEM = DESCRIPTOR.message_types_by_name['DashItem']
_DASHSEGMENTBASE = DESCRIPTOR.message_types_by_name['DashSegmentBase']
_DETAILITEM = DESCRIPTOR.message_types_by_name['DetailItem']
_DETAILITEM_PLAYERINFOENTRY = _DETAILITEM.nested_types_by_name['PlayerInfoEntry']
_EVENTTRACKING = DESCRIPTOR.message_types_by_name['EventTracking']
_FAVFOLDER = DESCRIPTOR.message_types_by_name['FavFolder']
_FAVFOLDERACTION = DESCRIPTOR.message_types_by_name['FavFolderAction']
_FAVFOLDERAUTHOR = DESCRIPTOR.message_types_by_name['FavFolderAuthor']
_FAVFOLDERCREATEREQ = DESCRIPTOR.message_types_by_name['FavFolderCreateReq']
_FAVFOLDERCREATERESP = DESCRIPTOR.message_types_by_name['FavFolderCreateResp']
_FAVFOLDERDELETEREQ = DESCRIPTOR.message_types_by_name['FavFolderDeleteReq']
_FAVFOLDERDELETERESP = DESCRIPTOR.message_types_by_name['FavFolderDeleteResp']
_FAVFOLDERDETAILREQ = DESCRIPTOR.message_types_by_name['FavFolderDetailReq']
_FAVFOLDERDETAILRESP = DESCRIPTOR.message_types_by_name['FavFolderDetailResp']
_FAVFOLDERLISTREQ = DESCRIPTOR.message_types_by_name['FavFolderListReq']
_FAVFOLDERLISTRESP = DESCRIPTOR.message_types_by_name['FavFolderListResp']
_FAVFOLDERMETA = DESCRIPTOR.message_types_by_name['FavFolderMeta']
_FAVITEM = DESCRIPTOR.message_types_by_name['FavItem']
_FAVITEMADDREQ = DESCRIPTOR.message_types_by_name['FavItemAddReq']
_FAVITEMADDRESP = DESCRIPTOR.message_types_by_name['FavItemAddResp']
_FAVITEMAUTHOR = DESCRIPTOR.message_types_by_name['FavItemAuthor']
_FAVITEMBATCHREQ = DESCRIPTOR.message_types_by_name['FavItemBatchReq']
_FAVITEMBATCHRESP = DESCRIPTOR.message_types_by_name['FavItemBatchResp']
_FAVITEMDELREQ = DESCRIPTOR.message_types_by_name['FavItemDelReq']
_FAVITEMDELRESP = DESCRIPTOR.message_types_by_name['FavItemDelResp']
_FAVITEMDETAIL = DESCRIPTOR.message_types_by_name['FavItemDetail']
_FAVITEMSTAT = DESCRIPTOR.message_types_by_name['FavItemStat']
_FAVOREDINANYFOLDERSREQ = DESCRIPTOR.message_types_by_name['FavoredInAnyFoldersReq']
_FAVOREDINANYFOLDERSRESP = DESCRIPTOR.message_types_by_name['FavoredInAnyFoldersResp']
_FOLLOWRELATION = DESCRIPTOR.message_types_by_name['FollowRelation']
_FORMATDESCRIPTION = DESCRIPTOR.message_types_by_name['FormatDescription']
_PAGEOPTION = DESCRIPTOR.message_types_by_name['PageOption']
_PICKARCHIVE = DESCRIPTOR.message_types_by_name['PickArchive']
_PICKARCHIVEAUTHOR = DESCRIPTOR.message_types_by_name['PickArchiveAuthor']
_PICKCARD = DESCRIPTOR.message_types_by_name['PickCard']
_PICKCARDDETAILREQ = DESCRIPTOR.message_types_by_name['PickCardDetailReq']
_PICKCARDDETAILRESP = DESCRIPTOR.message_types_by_name['PickCardDetailResp']
_PICKFEEDREQ = DESCRIPTOR.message_types_by_name['PickFeedReq']
_PICKFEEDRESP = DESCRIPTOR.message_types_by_name['PickFeedResp']
_PKCMARCHIVE = DESCRIPTOR.message_types_by_name['PkcmArchive']
_PKCMCENTERBUTTON = DESCRIPTOR.message_types_by_name['PkcmCenterButton']
_PKCMHEADER = DESCRIPTOR.message_types_by_name['PkcmHeader']
_PLAYACTIONREPORTREQ = DESCRIPTOR.message_types_by_name['PlayActionReportReq']
_PLAYDASH = DESCRIPTOR.message_types_by_name['PlayDASH']
_PLAYHISTORYADDREQ = DESCRIPTOR.message_types_by_name['PlayHistoryAddReq']
_PLAYHISTORYDELREQ = DESCRIPTOR.message_types_by_name['PlayHistoryDelReq']
_PLAYHISTORYREQ = DESCRIPTOR.message_types_by_name['PlayHistoryReq']
_PLAYHISTORYRESP = DESCRIPTOR.message_types_by_name['PlayHistoryResp']
_PLAYINFO = DESCRIPTOR.message_types_by_name['PlayInfo']
_PLAYITEM = DESCRIPTOR.message_types_by_name['PlayItem']
_PLAYLISTADDREQ = DESCRIPTOR.message_types_by_name['PlaylistAddReq']
_PLAYLISTDELREQ = DESCRIPTOR.message_types_by_name['PlaylistDelReq']
_PLAYLISTREQ = DESCRIPTOR.message_types_by_name['PlaylistReq']
_PLAYLISTRESP = DESCRIPTOR.message_types_by_name['PlaylistResp']
_PLAYURL = DESCRIPTOR.message_types_by_name['PlayURL']
_PLAYURLREQ = DESCRIPTOR.message_types_by_name['PlayURLReq']
_PLAYURLRESP = DESCRIPTOR.message_types_by_name['PlayURLResp']
_PLAYURLRESP_PLAYERINFOENTRY = _PLAYURLRESP.nested_types_by_name['PlayerInfoEntry']
_RCMDPLAYLISTREQ = DESCRIPTOR.message_types_by_name['RcmdPlaylistReq']
_RCMDPLAYLISTRESP = DESCRIPTOR.message_types_by_name['RcmdPlaylistResp']
_RESPONSEURL = DESCRIPTOR.message_types_by_name['ResponseUrl']
_THUMBUPREQ = DESCRIPTOR.message_types_by_name['ThumbUpReq']
_THUMBUPRESP = DESCRIPTOR.message_types_by_name['ThumbUpResp']
_TRIPLELIKEREQ = DESCRIPTOR.message_types_by_name['TripleLikeReq']
_TRIPLELIKERESP = DESCRIPTOR.message_types_by_name['TripleLikeResp']
Author = _reflection.GeneratedProtocolMessageType('Author', (_message.Message,), {
  'DESCRIPTOR' : _AUTHOR,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.Author)
  })
_sym_db.RegisterMessage(Author)

BKArcDetailsReq = _reflection.GeneratedProtocolMessageType('BKArcDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _BKARCDETAILSREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArcDetailsReq)
  })
_sym_db.RegisterMessage(BKArcDetailsReq)

BKArcDetailsResp = _reflection.GeneratedProtocolMessageType('BKArcDetailsResp', (_message.Message,), {
  'DESCRIPTOR' : _BKARCDETAILSRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArcDetailsResp)
  })
_sym_db.RegisterMessage(BKArcDetailsResp)

BKArchive = _reflection.GeneratedProtocolMessageType('BKArchive', (_message.Message,), {
  'DESCRIPTOR' : _BKARCHIVE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArchive)
  })
_sym_db.RegisterMessage(BKArchive)

BKArcPart = _reflection.GeneratedProtocolMessageType('BKArcPart', (_message.Message,), {
  'DESCRIPTOR' : _BKARCPART,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArcPart)
  })
_sym_db.RegisterMessage(BKArcPart)

BKArcRights = _reflection.GeneratedProtocolMessageType('BKArcRights', (_message.Message,), {
  'DESCRIPTOR' : _BKARCRIGHTS,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArcRights)
  })
_sym_db.RegisterMessage(BKArcRights)

BKStat = _reflection.GeneratedProtocolMessageType('BKStat', (_message.Message,), {
  'DESCRIPTOR' : _BKSTAT,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKStat)
  })
_sym_db.RegisterMessage(BKStat)

CardModule = _reflection.GeneratedProtocolMessageType('CardModule', (_message.Message,), {
  'DESCRIPTOR' : _CARDMODULE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.CardModule)
  })
_sym_db.RegisterMessage(CardModule)

CoinAddReq = _reflection.GeneratedProtocolMessageType('CoinAddReq', (_message.Message,), {
  'DESCRIPTOR' : _COINADDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.CoinAddReq)
  })
_sym_db.RegisterMessage(CoinAddReq)

CoinAddResp = _reflection.GeneratedProtocolMessageType('CoinAddResp', (_message.Message,), {
  'DESCRIPTOR' : _COINADDRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.CoinAddResp)
  })
_sym_db.RegisterMessage(CoinAddResp)

DashItem = _reflection.GeneratedProtocolMessageType('DashItem', (_message.Message,), {
  'DESCRIPTOR' : _DASHITEM,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.DashItem)
  })
_sym_db.RegisterMessage(DashItem)

DashSegmentBase = _reflection.GeneratedProtocolMessageType('DashSegmentBase', (_message.Message,), {
  'DESCRIPTOR' : _DASHSEGMENTBASE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.DashSegmentBase)
  })
_sym_db.RegisterMessage(DashSegmentBase)

DetailItem = _reflection.GeneratedProtocolMessageType('DetailItem', (_message.Message,), {

  'PlayerInfoEntry' : _reflection.GeneratedProtocolMessageType('PlayerInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _DETAILITEM_PLAYERINFOENTRY,
    '__module__' : 'bilibili.app.listener.v1.listener_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.DetailItem.PlayerInfoEntry)
    })
  ,
  'DESCRIPTOR' : _DETAILITEM,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.DetailItem)
  })
_sym_db.RegisterMessage(DetailItem)
_sym_db.RegisterMessage(DetailItem.PlayerInfoEntry)

EventTracking = _reflection.GeneratedProtocolMessageType('EventTracking', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTRACKING,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.EventTracking)
  })
_sym_db.RegisterMessage(EventTracking)

FavFolder = _reflection.GeneratedProtocolMessageType('FavFolder', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDER,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolder)
  })
_sym_db.RegisterMessage(FavFolder)

FavFolderAction = _reflection.GeneratedProtocolMessageType('FavFolderAction', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERACTION,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderAction)
  })
_sym_db.RegisterMessage(FavFolderAction)

FavFolderAuthor = _reflection.GeneratedProtocolMessageType('FavFolderAuthor', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERAUTHOR,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderAuthor)
  })
_sym_db.RegisterMessage(FavFolderAuthor)

FavFolderCreateReq = _reflection.GeneratedProtocolMessageType('FavFolderCreateReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERCREATEREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderCreateReq)
  })
_sym_db.RegisterMessage(FavFolderCreateReq)

FavFolderCreateResp = _reflection.GeneratedProtocolMessageType('FavFolderCreateResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERCREATERESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderCreateResp)
  })
_sym_db.RegisterMessage(FavFolderCreateResp)

FavFolderDeleteReq = _reflection.GeneratedProtocolMessageType('FavFolderDeleteReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERDELETEREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderDeleteReq)
  })
_sym_db.RegisterMessage(FavFolderDeleteReq)

FavFolderDeleteResp = _reflection.GeneratedProtocolMessageType('FavFolderDeleteResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERDELETERESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderDeleteResp)
  })
_sym_db.RegisterMessage(FavFolderDeleteResp)

FavFolderDetailReq = _reflection.GeneratedProtocolMessageType('FavFolderDetailReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERDETAILREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderDetailReq)
  })
_sym_db.RegisterMessage(FavFolderDetailReq)

FavFolderDetailResp = _reflection.GeneratedProtocolMessageType('FavFolderDetailResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERDETAILRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderDetailResp)
  })
_sym_db.RegisterMessage(FavFolderDetailResp)

FavFolderListReq = _reflection.GeneratedProtocolMessageType('FavFolderListReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERLISTREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderListReq)
  })
_sym_db.RegisterMessage(FavFolderListReq)

FavFolderListResp = _reflection.GeneratedProtocolMessageType('FavFolderListResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERLISTRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderListResp)
  })
_sym_db.RegisterMessage(FavFolderListResp)

FavFolderMeta = _reflection.GeneratedProtocolMessageType('FavFolderMeta', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERMETA,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderMeta)
  })
_sym_db.RegisterMessage(FavFolderMeta)

FavItem = _reflection.GeneratedProtocolMessageType('FavItem', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEM,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItem)
  })
_sym_db.RegisterMessage(FavItem)

FavItemAddReq = _reflection.GeneratedProtocolMessageType('FavItemAddReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMADDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemAddReq)
  })
_sym_db.RegisterMessage(FavItemAddReq)

FavItemAddResp = _reflection.GeneratedProtocolMessageType('FavItemAddResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMADDRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemAddResp)
  })
_sym_db.RegisterMessage(FavItemAddResp)

FavItemAuthor = _reflection.GeneratedProtocolMessageType('FavItemAuthor', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMAUTHOR,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemAuthor)
  })
_sym_db.RegisterMessage(FavItemAuthor)

FavItemBatchReq = _reflection.GeneratedProtocolMessageType('FavItemBatchReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMBATCHREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemBatchReq)
  })
_sym_db.RegisterMessage(FavItemBatchReq)

FavItemBatchResp = _reflection.GeneratedProtocolMessageType('FavItemBatchResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMBATCHRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemBatchResp)
  })
_sym_db.RegisterMessage(FavItemBatchResp)

FavItemDelReq = _reflection.GeneratedProtocolMessageType('FavItemDelReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMDELREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemDelReq)
  })
_sym_db.RegisterMessage(FavItemDelReq)

FavItemDelResp = _reflection.GeneratedProtocolMessageType('FavItemDelResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMDELRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemDelResp)
  })
_sym_db.RegisterMessage(FavItemDelResp)

FavItemDetail = _reflection.GeneratedProtocolMessageType('FavItemDetail', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMDETAIL,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemDetail)
  })
_sym_db.RegisterMessage(FavItemDetail)

FavItemStat = _reflection.GeneratedProtocolMessageType('FavItemStat', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMSTAT,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemStat)
  })
_sym_db.RegisterMessage(FavItemStat)

FavoredInAnyFoldersReq = _reflection.GeneratedProtocolMessageType('FavoredInAnyFoldersReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVOREDINANYFOLDERSREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavoredInAnyFoldersReq)
  })
_sym_db.RegisterMessage(FavoredInAnyFoldersReq)

FavoredInAnyFoldersResp = _reflection.GeneratedProtocolMessageType('FavoredInAnyFoldersResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVOREDINANYFOLDERSRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavoredInAnyFoldersResp)
  })
_sym_db.RegisterMessage(FavoredInAnyFoldersResp)

FollowRelation = _reflection.GeneratedProtocolMessageType('FollowRelation', (_message.Message,), {
  'DESCRIPTOR' : _FOLLOWRELATION,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FollowRelation)
  })
_sym_db.RegisterMessage(FollowRelation)

FormatDescription = _reflection.GeneratedProtocolMessageType('FormatDescription', (_message.Message,), {
  'DESCRIPTOR' : _FORMATDESCRIPTION,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FormatDescription)
  })
_sym_db.RegisterMessage(FormatDescription)

PageOption = _reflection.GeneratedProtocolMessageType('PageOption', (_message.Message,), {
  'DESCRIPTOR' : _PAGEOPTION,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PageOption)
  })
_sym_db.RegisterMessage(PageOption)

PickArchive = _reflection.GeneratedProtocolMessageType('PickArchive', (_message.Message,), {
  'DESCRIPTOR' : _PICKARCHIVE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickArchive)
  })
_sym_db.RegisterMessage(PickArchive)

PickArchiveAuthor = _reflection.GeneratedProtocolMessageType('PickArchiveAuthor', (_message.Message,), {
  'DESCRIPTOR' : _PICKARCHIVEAUTHOR,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickArchiveAuthor)
  })
_sym_db.RegisterMessage(PickArchiveAuthor)

PickCard = _reflection.GeneratedProtocolMessageType('PickCard', (_message.Message,), {
  'DESCRIPTOR' : _PICKCARD,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickCard)
  })
_sym_db.RegisterMessage(PickCard)

PickCardDetailReq = _reflection.GeneratedProtocolMessageType('PickCardDetailReq', (_message.Message,), {
  'DESCRIPTOR' : _PICKCARDDETAILREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickCardDetailReq)
  })
_sym_db.RegisterMessage(PickCardDetailReq)

PickCardDetailResp = _reflection.GeneratedProtocolMessageType('PickCardDetailResp', (_message.Message,), {
  'DESCRIPTOR' : _PICKCARDDETAILRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickCardDetailResp)
  })
_sym_db.RegisterMessage(PickCardDetailResp)

PickFeedReq = _reflection.GeneratedProtocolMessageType('PickFeedReq', (_message.Message,), {
  'DESCRIPTOR' : _PICKFEEDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickFeedReq)
  })
_sym_db.RegisterMessage(PickFeedReq)

PickFeedResp = _reflection.GeneratedProtocolMessageType('PickFeedResp', (_message.Message,), {
  'DESCRIPTOR' : _PICKFEEDRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickFeedResp)
  })
_sym_db.RegisterMessage(PickFeedResp)

PkcmArchive = _reflection.GeneratedProtocolMessageType('PkcmArchive', (_message.Message,), {
  'DESCRIPTOR' : _PKCMARCHIVE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PkcmArchive)
  })
_sym_db.RegisterMessage(PkcmArchive)

PkcmCenterButton = _reflection.GeneratedProtocolMessageType('PkcmCenterButton', (_message.Message,), {
  'DESCRIPTOR' : _PKCMCENTERBUTTON,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PkcmCenterButton)
  })
_sym_db.RegisterMessage(PkcmCenterButton)

PkcmHeader = _reflection.GeneratedProtocolMessageType('PkcmHeader', (_message.Message,), {
  'DESCRIPTOR' : _PKCMHEADER,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PkcmHeader)
  })
_sym_db.RegisterMessage(PkcmHeader)

PlayActionReportReq = _reflection.GeneratedProtocolMessageType('PlayActionReportReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYACTIONREPORTREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayActionReportReq)
  })
_sym_db.RegisterMessage(PlayActionReportReq)

PlayDASH = _reflection.GeneratedProtocolMessageType('PlayDASH', (_message.Message,), {
  'DESCRIPTOR' : _PLAYDASH,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayDASH)
  })
_sym_db.RegisterMessage(PlayDASH)

PlayHistoryAddReq = _reflection.GeneratedProtocolMessageType('PlayHistoryAddReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYHISTORYADDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayHistoryAddReq)
  })
_sym_db.RegisterMessage(PlayHistoryAddReq)

PlayHistoryDelReq = _reflection.GeneratedProtocolMessageType('PlayHistoryDelReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYHISTORYDELREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayHistoryDelReq)
  })
_sym_db.RegisterMessage(PlayHistoryDelReq)

PlayHistoryReq = _reflection.GeneratedProtocolMessageType('PlayHistoryReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYHISTORYREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayHistoryReq)
  })
_sym_db.RegisterMessage(PlayHistoryReq)

PlayHistoryResp = _reflection.GeneratedProtocolMessageType('PlayHistoryResp', (_message.Message,), {
  'DESCRIPTOR' : _PLAYHISTORYRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayHistoryResp)
  })
_sym_db.RegisterMessage(PlayHistoryResp)

PlayInfo = _reflection.GeneratedProtocolMessageType('PlayInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLAYINFO,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayInfo)
  })
_sym_db.RegisterMessage(PlayInfo)

PlayItem = _reflection.GeneratedProtocolMessageType('PlayItem', (_message.Message,), {
  'DESCRIPTOR' : _PLAYITEM,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayItem)
  })
_sym_db.RegisterMessage(PlayItem)

PlaylistAddReq = _reflection.GeneratedProtocolMessageType('PlaylistAddReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYLISTADDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlaylistAddReq)
  })
_sym_db.RegisterMessage(PlaylistAddReq)

PlaylistDelReq = _reflection.GeneratedProtocolMessageType('PlaylistDelReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYLISTDELREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlaylistDelReq)
  })
_sym_db.RegisterMessage(PlaylistDelReq)

PlaylistReq = _reflection.GeneratedProtocolMessageType('PlaylistReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYLISTREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlaylistReq)
  })
_sym_db.RegisterMessage(PlaylistReq)

PlaylistResp = _reflection.GeneratedProtocolMessageType('PlaylistResp', (_message.Message,), {
  'DESCRIPTOR' : _PLAYLISTRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlaylistResp)
  })
_sym_db.RegisterMessage(PlaylistResp)

PlayURL = _reflection.GeneratedProtocolMessageType('PlayURL', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURL,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayURL)
  })
_sym_db.RegisterMessage(PlayURL)

PlayURLReq = _reflection.GeneratedProtocolMessageType('PlayURLReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURLREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayURLReq)
  })
_sym_db.RegisterMessage(PlayURLReq)

PlayURLResp = _reflection.GeneratedProtocolMessageType('PlayURLResp', (_message.Message,), {

  'PlayerInfoEntry' : _reflection.GeneratedProtocolMessageType('PlayerInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLAYURLRESP_PLAYERINFOENTRY,
    '__module__' : 'bilibili.app.listener.v1.listener_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayURLResp.PlayerInfoEntry)
    })
  ,
  'DESCRIPTOR' : _PLAYURLRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayURLResp)
  })
_sym_db.RegisterMessage(PlayURLResp)
_sym_db.RegisterMessage(PlayURLResp.PlayerInfoEntry)

RcmdPlaylistReq = _reflection.GeneratedProtocolMessageType('RcmdPlaylistReq', (_message.Message,), {
  'DESCRIPTOR' : _RCMDPLAYLISTREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.RcmdPlaylistReq)
  })
_sym_db.RegisterMessage(RcmdPlaylistReq)

RcmdPlaylistResp = _reflection.GeneratedProtocolMessageType('RcmdPlaylistResp', (_message.Message,), {
  'DESCRIPTOR' : _RCMDPLAYLISTRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.RcmdPlaylistResp)
  })
_sym_db.RegisterMessage(RcmdPlaylistResp)

ResponseUrl = _reflection.GeneratedProtocolMessageType('ResponseUrl', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEURL,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.ResponseUrl)
  })
_sym_db.RegisterMessage(ResponseUrl)

ThumbUpReq = _reflection.GeneratedProtocolMessageType('ThumbUpReq', (_message.Message,), {
  'DESCRIPTOR' : _THUMBUPREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.ThumbUpReq)
  })
_sym_db.RegisterMessage(ThumbUpReq)

ThumbUpResp = _reflection.GeneratedProtocolMessageType('ThumbUpResp', (_message.Message,), {
  'DESCRIPTOR' : _THUMBUPRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.ThumbUpResp)
  })
_sym_db.RegisterMessage(ThumbUpResp)

TripleLikeReq = _reflection.GeneratedProtocolMessageType('TripleLikeReq', (_message.Message,), {
  'DESCRIPTOR' : _TRIPLELIKEREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.TripleLikeReq)
  })
_sym_db.RegisterMessage(TripleLikeReq)

TripleLikeResp = _reflection.GeneratedProtocolMessageType('TripleLikeResp', (_message.Message,), {
  'DESCRIPTOR' : _TRIPLELIKERESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.TripleLikeResp)
  })
_sym_db.RegisterMessage(TripleLikeResp)

_LISTENER = DESCRIPTOR.services_by_name['Listener']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETAILITEM_PLAYERINFOENTRY._options = None
  _DETAILITEM_PLAYERINFOENTRY._serialized_options = b'8\001'
  _PLAYURLRESP_PLAYERINFOENTRY._options = None
  _PLAYURLRESP_PLAYERINFOENTRY._serialized_options = b'8\001'
  _CARDMODULETYPE._serialized_start=8849
  _CARDMODULETYPE._serialized_end=8941
  _PLAYLISTSOURCE._serialized_start=8944
  _PLAYLISTSOURCE._serialized_end=9094
  _AUTHOR._serialized_start=148
  _AUTHOR._serialized_end=259
  _BKARCDETAILSREQ._serialized_start=262
  _BKARCDETAILSREQ._serialized_end=398
  _BKARCDETAILSRESP._serialized_start=400
  _BKARCDETAILSRESP._serialized_end=470
  _BKARCHIVE._serialized_start=473
  _BKARCHIVE._serialized_end=701
  _BKARCPART._serialized_start=703
  _BKARCPART._serialized_end=790
  _BKARCRIGHTS._serialized_start=792
  _BKARCRIGHTS._serialized_end=825
  _BKSTAT._serialized_start=828
  _BKSTAT._serialized_end=980
  _CARDMODULE._serialized_start=983
  _CARDMODULE._serialized_end=1221
  _COINADDREQ._serialized_start=1223
  _COINADDREQ._serialized_end=1316
  _COINADDRESP._serialized_start=1318
  _COINADDRESP._serialized_end=1348
  _DASHITEM._serialized_start=1351
  _DASHITEM._serialized_end=1574
  _DASHSEGMENTBASE._serialized_start=1576
  _DASHSEGMENTBASE._serialized_end=1638
  _DETAILITEM._serialized_start=1641
  _DETAILITEM._serialized_end=2136
  _DETAILITEM_PLAYERINFOENTRY._serialized_start=2051
  _DETAILITEM_PLAYERINFOENTRY._serialized_end=2136
  _EVENTTRACKING._serialized_start=2138
  _EVENTTRACKING._serialized_end=2244
  _FAVFOLDER._serialized_start=2247
  _FAVFOLDER._serialized_end=2619
  _FAVFOLDERACTION._serialized_start=2621
  _FAVFOLDERACTION._serialized_end=2688
  _FAVFOLDERAUTHOR._serialized_start=2690
  _FAVFOLDERAUTHOR._serialized_end=2734
  _FAVFOLDERCREATEREQ._serialized_start=2736
  _FAVFOLDERCREATEREQ._serialized_end=2821
  _FAVFOLDERCREATERESP._serialized_start=2823
  _FAVFOLDERCREATERESP._serialized_end=2895
  _FAVFOLDERDELETEREQ._serialized_start=2897
  _FAVFOLDERDELETEREQ._serialized_end=2951
  _FAVFOLDERDELETERESP._serialized_start=2953
  _FAVFOLDERDELETERESP._serialized_end=2991
  _FAVFOLDERDETAILREQ._serialized_start=2994
  _FAVFOLDERDETAILREQ._serialized_end=3164
  _FAVFOLDERDETAILRESP._serialized_start=3167
  _FAVFOLDERDETAILRESP._serialized_end=3335
  _FAVFOLDERLISTREQ._serialized_start=3337
  _FAVFOLDERLISTREQ._serialized_end=3427
  _FAVFOLDERLISTRESP._serialized_start=3429
  _FAVFOLDERLISTRESP._serialized_end=3499
  _FAVFOLDERMETA._serialized_start=3501
  _FAVFOLDERMETA._serialized_end=3550
  _FAVITEM._serialized_start=3553
  _FAVITEM._serialized_end=3703
  _FAVITEMADDREQ._serialized_start=3706
  _FAVITEMADDREQ._serialized_end=3865
  _FAVITEMADDRESP._serialized_start=3867
  _FAVITEMADDRESP._serialized_end=3900
  _FAVITEMAUTHOR._serialized_start=3902
  _FAVITEMAUTHOR._serialized_end=3944
  _FAVITEMBATCHREQ._serialized_start=3947
  _FAVITEMBATCHREQ._serialized_end=4134
  _FAVITEMBATCHRESP._serialized_start=4136
  _FAVITEMBATCHRESP._serialized_end=4171
  _FAVITEMDELREQ._serialized_start=4174
  _FAVITEMDELREQ._serialized_end=4333
  _FAVITEMDELRESP._serialized_start=4335
  _FAVITEMDELRESP._serialized_end=4368
  _FAVITEMDETAIL._serialized_start=4371
  _FAVITEMDETAIL._serialized_end=4638
  _FAVITEMSTAT._serialized_start=4640
  _FAVITEMSTAT._serialized_end=4682
  _FAVOREDINANYFOLDERSREQ._serialized_start=4684
  _FAVOREDINANYFOLDERSREQ._serialized_end=4780
  _FAVOREDINANYFOLDERSRESP._serialized_start=4783
  _FAVOREDINANYFOLDERSRESP._serialized_end=4916
  _FOLLOWRELATION._serialized_start=4918
  _FOLLOWRELATION._serialized_end=4950
  _FORMATDESCRIPTION._serialized_start=4952
  _FORMATDESCRIPTION._serialized_end=5068
  _PAGEOPTION._serialized_start=5070
  _PAGEOPTION._serialized_end=5175
  _PICKARCHIVE._serialized_start=5178
  _PICKARCHIVE._serialized_end=5435
  _PICKARCHIVEAUTHOR._serialized_start=5437
  _PICKARCHIVEAUTHOR._serialized_end=5483
  _PICKCARD._serialized_start=5485
  _PICKCARD._serialized_end=5603
  _PICKCARDDETAILREQ._serialized_start=5605
  _PICKCARDDETAILREQ._serialized_end=5658
  _PICKCARDDETAILRESP._serialized_start=5660
  _PICKCARDDETAILRESP._serialized_end=5769
  _PICKFEEDREQ._serialized_start=5771
  _PICKFEEDREQ._serialized_end=5800
  _PICKFEEDRESP._serialized_start=5802
  _PICKFEEDRESP._serialized_end=5883
  _PKCMARCHIVE._serialized_start=5885
  _PKCMARCHIVE._serialized_end=5971
  _PKCMCENTERBUTTON._serialized_start=5973
  _PKCMCENTERBUTTON._serialized_end=6057
  _PKCMHEADER._serialized_start=6059
  _PKCMHEADER._serialized_end=6153
  _PLAYACTIONREPORTREQ._serialized_start=6155
  _PLAYACTIONREPORTREQ._serialized_end=6226
  _PLAYDASH._serialized_start=6228
  _PLAYDASH._serialized_end=6332
  _PLAYHISTORYADDREQ._serialized_start=6334
  _PLAYHISTORYADDREQ._serialized_end=6459
  _PLAYHISTORYDELREQ._serialized_start=6461
  _PLAYHISTORYDELREQ._serialized_end=6549
  _PLAYHISTORYREQ._serialized_start=6551
  _PLAYHISTORYREQ._serialized_end=6623
  _PLAYHISTORYRESP._serialized_start=6625
  _PLAYHISTORYRESP._serialized_end=6728
  _PLAYINFO._serialized_start=6731
  _PLAYINFO._serialized_end=7023
  _PLAYITEM._serialized_start=7025
  _PLAYITEM._serialized_end=7136
  _PLAYLISTADDREQ._serialized_start=7139
  _PLAYLISTADDREQ._serialized_end=7298
  _PLAYLISTDELREQ._serialized_start=7300
  _PLAYLISTDELREQ._serialized_end=7385
  _PLAYLISTREQ._serialized_start=7388
  _PLAYLISTREQ._serialized_end=7622
  _PLAYLISTRESP._serialized_start=7625
  _PLAYLISTRESP._serialized_end=7824
  _PLAYURL._serialized_start=7826
  _PLAYURL._serialized_end=7888
  _PLAYURLREQ._serialized_start=7891
  _PLAYURLREQ._serialized_end=8022
  _PLAYURLRESP._serialized_start=8025
  _PLAYURLRESP._serialized_end=8285
  _PLAYURLRESP_PLAYERINFOENTRY._serialized_start=2051
  _PLAYURLRESP_PLAYERINFOENTRY._serialized_end=2136
  _RCMDPLAYLISTREQ._serialized_start=8287
  _RCMDPLAYLISTREQ._serialized_end=8352
  _RCMDPLAYLISTRESP._serialized_start=8354
  _RCMDPLAYLISTRESP._serialized_end=8445
  _RESPONSEURL._serialized_start=8448
  _RESPONSEURL._serialized_end=8582
  _THUMBUPREQ._serialized_start=8584
  _THUMBUPREQ._serialized_end=8662
  _THUMBUPRESP._serialized_start=8664
  _THUMBUPRESP._serialized_end=8694
  _TRIPLELIKEREQ._serialized_start=8696
  _TRIPLELIKEREQ._serialized_end=8761
  _TRIPLELIKERESP._serialized_start=8763
  _TRIPLELIKERESP._serialized_end=8847
  _LISTENER._serialized_start=9097
  _LISTENER._serialized_end=11411
# @@protoc_insertion_point(module_scope)
