# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/polymer/contract/contract.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/polymer/contract/contract.proto\x12\x19\x62ilibili.polymer.contract\x1a\x1bgoogle/protobuf/empty.proto\"p\n\x0e\x41\x64\x64\x43ontractReq\x12\x34\n\x06\x63ommon\x18\x01 \x01(\x0b\x32$.bilibili.polymer.contract.CommonReq\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\"x\n\tCommonReq\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05\x62uild\x18\x02 \x01(\x05\x12\r\n\x05\x62uvid\x18\x03 \x01(\t\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\t\x12\r\n\x05spmid\x18\x07 \x01(\t2\\\n\x08\x43ontract\x12P\n\x0b\x41\x64\x64\x43ontract\x12).bilibili.polymer.contract.AddContractReq\x1a\x16.google.protobuf.Emptyb\x06proto3')



_ADDCONTRACTREQ = DESCRIPTOR.message_types_by_name['AddContractReq']
_COMMONREQ = DESCRIPTOR.message_types_by_name['CommonReq']
AddContractReq = _reflection.GeneratedProtocolMessageType('AddContractReq', (_message.Message,), {
  'DESCRIPTOR' : _ADDCONTRACTREQ,
  '__module__' : 'bilibili.polymer.contract.contract_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.contract.AddContractReq)
  })
_sym_db.RegisterMessage(AddContractReq)

CommonReq = _reflection.GeneratedProtocolMessageType('CommonReq', (_message.Message,), {
  'DESCRIPTOR' : _COMMONREQ,
  '__module__' : 'bilibili.polymer.contract.contract_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.contract.CommonReq)
  })
_sym_db.RegisterMessage(CommonReq)

_CONTRACT = DESCRIPTOR.services_by_name['Contract']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADDCONTRACTREQ._serialized_start=100
  _ADDCONTRACTREQ._serialized_end=212
  _COMMONREQ._serialized_start=214
  _COMMONREQ._serialized_end=334
  _CONTRACT._serialized_start=336
  _CONTRACT._serialized_end=428
# @@protoc_insertion_point(module_scope)
