"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.rpc.status_pb2
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RoomErrorEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> bilibili.rpc.status_pb2.Status:
        """"""
        pass
    def __init__(self,
        *,
        status: typing.Optional[bilibili.rpc.status_pb2.Status] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["status",b"status"]) -> None: ...
global___RoomErrorEvent = RoomErrorEvent

class RoomJoinEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RoomJoinEvent = RoomJoinEvent

class RoomLeaveEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RoomLeaveEvent = RoomLeaveEvent

class RoomMessageEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TARGET_PATH_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    target_path: typing.Text
    """"""

    @property
    def body(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    def __init__(self,
        *,
        target_path: typing.Text = ...,
        body: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body",b"body"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body",b"body","target_path",b"target_path"]) -> None: ...
global___RoomMessageEvent = RoomMessageEvent

class RoomOnlineEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ONLINE_FIELD_NUMBER: builtins.int
    ALL_ONLINE_FIELD_NUMBER: builtins.int
    online: builtins.int
    """"""

    all_online: builtins.int
    """"""

    def __init__(self,
        *,
        online: builtins.int = ...,
        all_online: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_online",b"all_online","online",b"online"]) -> None: ...
global___RoomOnlineEvent = RoomOnlineEvent

class RoomReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    JOIN_FIELD_NUMBER: builtins.int
    LEAVE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    id: typing.Text
    """{type}://{room_id}"""

    @property
    def join(self) -> global___RoomJoinEvent:
        """"""
        pass
    @property
    def leave(self) -> global___RoomLeaveEvent:
        """"""
        pass
    @property
    def online(self) -> global___RoomOnlineEvent:
        """"""
        pass
    @property
    def msg(self) -> global___RoomMessageEvent:
        """"""
        pass
    def __init__(self,
        *,
        id: typing.Text = ...,
        join: typing.Optional[global___RoomJoinEvent] = ...,
        leave: typing.Optional[global___RoomLeaveEvent] = ...,
        online: typing.Optional[global___RoomOnlineEvent] = ...,
        msg: typing.Optional[global___RoomMessageEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event",b"event","join",b"join","leave",b"leave","msg",b"msg","online",b"online"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event",b"event","id",b"id","join",b"join","leave",b"leave","msg",b"msg","online",b"online"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event",b"event"]) -> typing.Optional[typing_extensions.Literal["join","leave","online","msg"]]: ...
global___RoomReq = RoomReq

class RoomResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    JOIN_FIELD_NUMBER: builtins.int
    LEAVE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    ERR_FIELD_NUMBER: builtins.int
    id: typing.Text
    """{type}://{room_id}"""

    @property
    def join(self) -> global___RoomJoinEvent:
        """"""
        pass
    @property
    def leave(self) -> global___RoomLeaveEvent:
        """"""
        pass
    @property
    def online(self) -> global___RoomOnlineEvent:
        """"""
        pass
    @property
    def msg(self) -> global___RoomMessageEvent:
        """"""
        pass
    @property
    def err(self) -> global___RoomErrorEvent:
        """"""
        pass
    def __init__(self,
        *,
        id: typing.Text = ...,
        join: typing.Optional[global___RoomJoinEvent] = ...,
        leave: typing.Optional[global___RoomLeaveEvent] = ...,
        online: typing.Optional[global___RoomOnlineEvent] = ...,
        msg: typing.Optional[global___RoomMessageEvent] = ...,
        err: typing.Optional[global___RoomErrorEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["err",b"err","event",b"event","join",b"join","leave",b"leave","msg",b"msg","online",b"online"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["err",b"err","event",b"event","id",b"id","join",b"join","leave",b"leave","msg",b"msg","online",b"online"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event",b"event"]) -> typing.Optional[typing_extensions.Literal["join","leave","online","msg","err"]]: ...
global___RoomResp = RoomResp
