# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/cheese/gateway/player/v1/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.playurl.v1 import playurl_pb2 as bilibili_dot_app_dot_playurl_dot_v1_dot_playurl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/cheese/gateway/player/v1/playurl.proto\x12!bilibili.cheese.gateway.player.v1\x1a%bilibili/app/playurl/v1/playurl.proto\"\x95\x02\n\x0bPlayViewReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x0b \x01(\x05\x12<\n\x11prefer_codec_type\x18\x0c \x01(\x0e\x32!.bilibili.app.playurl.v1.CodeType\x12\x12\n\nis_preview\x18\r \x01(\x08\"\xe3\x01\n\nProjectReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x10\n\x08protocol\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x65vice_type\x18\x0c \x01(\x05\x12\x10\n\x08\x66lv_proj\x18\r \x01(\x08\"\x8e\x01\n\rPlayViewReply\x12\x36\n\nvideo_info\x18\x01 \x01(\x0b\x32\".bilibili.app.playurl.v1.VideoInfo\x12\x45\n\tplay_conf\x18\x02 \x01(\x0b\x32\x32.bilibili.cheese.gateway.player.v1.PlayAbilityConf\"\xa5\x05\n\x0fPlayAbilityConf\x12\x1f\n\x17\x62\x61\x63kground_play_disable\x18\x01 \x01(\x08\x12\x14\n\x0c\x66lip_disable\x18\x02 \x01(\x08\x12\x14\n\x0c\x63\x61st_disable\x18\x03 \x01(\x08\x12\x18\n\x10\x66\x65\x65\x64\x62\x61\x63k_disable\x18\x04 \x01(\x08\x12\x18\n\x10subtitle_disable\x18\x05 \x01(\x08\x12\x1d\n\x15playback_rate_disable\x18\x06 \x01(\x08\x12\x17\n\x0ftime_up_disable\x18\x07 \x01(\x08\x12\x1d\n\x15playback_mode_disable\x18\x08 \x01(\x08\x12\x1a\n\x12scale_mode_disable\x18\t \x01(\x08\x12\x14\n\x0clike_disable\x18\n \x01(\x08\x12\x17\n\x0f\x64islike_disable\x18\x0b \x01(\x08\x12\x14\n\x0c\x63oin_disable\x18\x0c \x01(\x08\x12\x14\n\x0c\x65lec_disable\x18\r \x01(\x08\x12\x15\n\rshare_disable\x18\x0e \x01(\x08\x12\x1b\n\x13screen_shot_disable\x18\x0f \x01(\x08\x12\x1b\n\x13lock_screen_disable\x18\x10 \x01(\x08\x12\x19\n\x11recommend_disable\x18\x11 \x01(\x08\x12\x1e\n\x16playback_speed_disable\x18\x12 \x01(\x08\x12\x1a\n\x12\x64\x65\x66inition_disable\x18\x13 \x01(\x08\x12\x1a\n\x12selections_disable\x18\x14 \x01(\x08\x12\x14\n\x0cnext_disable\x18\x15 \x01(\x08\x12\x17\n\x0f\x65\x64it_dm_disable\x18\x16 \x01(\x08\x12\x18\n\x10outer_dm_disable\x18\x19 \x01(\x08\x12\x18\n\x10inner_dm_disable\x18\x1a \x01(\x08\x12\x1c\n\x14small_window_disable\x18\x1b \x01(\x08\"F\n\x0cProjectReply\x12\x36\n\x07project\x18\x01 \x01(\x0b\x32%.bilibili.app.playurl.v1.PlayURLReply2\xe2\x01\n\x07PlayURL\x12l\n\x08PlayView\x12..bilibili.cheese.gateway.player.v1.PlayViewReq\x1a\x30.bilibili.cheese.gateway.player.v1.PlayViewReply\x12i\n\x07Project\x12-.bilibili.cheese.gateway.player.v1.ProjectReq\x1a/.bilibili.cheese.gateway.player.v1.ProjectReplyb\x06proto3')



_PLAYVIEWREQ = DESCRIPTOR.message_types_by_name['PlayViewReq']
_PROJECTREQ = DESCRIPTOR.message_types_by_name['ProjectReq']
_PLAYVIEWREPLY = DESCRIPTOR.message_types_by_name['PlayViewReply']
_PLAYABILITYCONF = DESCRIPTOR.message_types_by_name['PlayAbilityConf']
_PROJECTREPLY = DESCRIPTOR.message_types_by_name['ProjectReply']
PlayViewReq = _reflection.GeneratedProtocolMessageType('PlayViewReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYVIEWREQ,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.PlayViewReq)
  })
_sym_db.RegisterMessage(PlayViewReq)

ProjectReq = _reflection.GeneratedProtocolMessageType('ProjectReq', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREQ,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.ProjectReq)
  })
_sym_db.RegisterMessage(ProjectReq)

PlayViewReply = _reflection.GeneratedProtocolMessageType('PlayViewReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYVIEWREPLY,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.PlayViewReply)
  })
_sym_db.RegisterMessage(PlayViewReply)

PlayAbilityConf = _reflection.GeneratedProtocolMessageType('PlayAbilityConf', (_message.Message,), {
  'DESCRIPTOR' : _PLAYABILITYCONF,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.PlayAbilityConf)
  })
_sym_db.RegisterMessage(PlayAbilityConf)

ProjectReply = _reflection.GeneratedProtocolMessageType('ProjectReply', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREPLY,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.ProjectReply)
  })
_sym_db.RegisterMessage(ProjectReply)

_PLAYURL = DESCRIPTOR.services_by_name['PlayURL']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLAYVIEWREQ._serialized_start=126
  _PLAYVIEWREQ._serialized_end=403
  _PROJECTREQ._serialized_start=406
  _PROJECTREQ._serialized_end=633
  _PLAYVIEWREPLY._serialized_start=636
  _PLAYVIEWREPLY._serialized_end=778
  _PLAYABILITYCONF._serialized_start=781
  _PLAYABILITYCONF._serialized_end=1458
  _PROJECTREPLY._serialized_start=1460
  _PROJECTREPLY._serialized_end=1530
  _PLAYURL._serialized_start=1533
  _PLAYURL._serialized_end=1759
# @@protoc_insertion_point(module_scope)
