# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/gaia/gw/gw_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x62ilibili/gaia/gw/gw_api.proto\x12\x10\x62ilibili.gaia.gw\x1a\x1bgoogle/protobuf/empty.proto\"O\n\rDeviceAppList\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x17\n\x0fsystem_app_list\x18\x02 \x03(\t\x12\x15\n\ruser_app_list\x18\x03 \x03(\t\"L\n\x13\x46\x65tchPublicKeyReply\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x03 \x01(\x03\"\xe7\x02\n\x13GaiaDeviceBasicInfo\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x10\n\x08mobi_app\x18\x03 \x01(\t\x12\x0e\n\x06origin\x18\x04 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x05 \x01(\t\x12\x0e\n\x06sdkver\x18\x06 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x07 \x01(\t\x12\x18\n\x10\x61pp_version_code\x18\x08 \x01(\t\x12\r\n\x05\x62uild\x18\t \x01(\t\x12\x0f\n\x07\x63hannel\x18\n \x01(\t\x12\r\n\x05\x62rand\x18\x0b \x01(\t\x12\r\n\x05model\x18\x0c \x01(\t\x12\r\n\x05osver\x18\r \x01(\t\x12\x12\n\nuser_agent\x18\x0e \x01(\t\x12\x13\n\x0b\x62uvid_local\x18\x0f \x01(\t\x12\r\n\x05\x62uvid\x18\x10 \x01(\t\x12\x0b\n\x03mid\x18\x11 \x01(\t\x12\x0b\n\x03\x66ts\x18\x12 \x01(\x03\x12\r\n\x05\x66irst\x18\x13 \x01(\x05\x12\x0f\n\x07network\x18\x14 \x01(\t\"]\n\x11GaiaEncryptMsgReq\x12/\n\x06header\x18\x01 \x01(\x0b\x32\x1f.bilibili.gaia.gw.GaiaMsgHeader\x12\x17\n\x0f\x65ncrypt_payload\x18\x02 \x01(\x0c\"\x9d\x01\n\rGaiaMsgHeader\x12\x32\n\x0b\x65ncode_type\x18\x01 \x01(\x0e\x32\x1d.bilibili.gaia.gw.EncryptType\x12\x33\n\x0cpayload_type\x18\x02 \x01(\x0e\x32\x1d.bilibili.gaia.gw.PayloadType\x12\x17\n\x0f\x65ncoded_aes_key\x18\x03 \x01(\x0c\x12\n\n\x02ts\x18\x04 \x01(\x03\"&\n\x12UploadAppListReply\x12\x10\n\x08trace_id\x18\x01 \x01(\t*K\n\x0b\x45ncryptType\x12\x18\n\x14INVALID_ENCRYPT_TYPE\x10\x00\x12\x0e\n\nCLIENT_AES\x10\x01\x12\x12\n\x0eSERVER_RSA_AES\x10\x02*7\n\x0bPayloadType\x12\x13\n\x0fINVALID_PAYLOAD\x10\x00\x12\x13\n\x0f\x44\x45VICE_APP_LIST\x10\x01\x32\xb7\x01\n\x04Gaia\x12\\\n\x0f\x45xUploadAppList\x12#.bilibili.gaia.gw.GaiaEncryptMsgReq\x1a$.bilibili.gaia.gw.UploadAppListReply\x12Q\n\x10\x45xFetchPublicKey\x12\x16.google.protobuf.Empty\x1a%.bilibili.gaia.gw.FetchPublicKeyReplyb\x06proto3')

_ENCRYPTTYPE = DESCRIPTOR.enum_types_by_name['EncryptType']
EncryptType = enum_type_wrapper.EnumTypeWrapper(_ENCRYPTTYPE)
_PAYLOADTYPE = DESCRIPTOR.enum_types_by_name['PayloadType']
PayloadType = enum_type_wrapper.EnumTypeWrapper(_PAYLOADTYPE)
INVALID_ENCRYPT_TYPE = 0
CLIENT_AES = 1
SERVER_RSA_AES = 2
INVALID_PAYLOAD = 0
DEVICE_APP_LIST = 1


_DEVICEAPPLIST = DESCRIPTOR.message_types_by_name['DeviceAppList']
_FETCHPUBLICKEYREPLY = DESCRIPTOR.message_types_by_name['FetchPublicKeyReply']
_GAIADEVICEBASICINFO = DESCRIPTOR.message_types_by_name['GaiaDeviceBasicInfo']
_GAIAENCRYPTMSGREQ = DESCRIPTOR.message_types_by_name['GaiaEncryptMsgReq']
_GAIAMSGHEADER = DESCRIPTOR.message_types_by_name['GaiaMsgHeader']
_UPLOADAPPLISTREPLY = DESCRIPTOR.message_types_by_name['UploadAppListReply']
DeviceAppList = _reflection.GeneratedProtocolMessageType('DeviceAppList', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEAPPLIST,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.DeviceAppList)
  })
_sym_db.RegisterMessage(DeviceAppList)

FetchPublicKeyReply = _reflection.GeneratedProtocolMessageType('FetchPublicKeyReply', (_message.Message,), {
  'DESCRIPTOR' : _FETCHPUBLICKEYREPLY,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.FetchPublicKeyReply)
  })
_sym_db.RegisterMessage(FetchPublicKeyReply)

GaiaDeviceBasicInfo = _reflection.GeneratedProtocolMessageType('GaiaDeviceBasicInfo', (_message.Message,), {
  'DESCRIPTOR' : _GAIADEVICEBASICINFO,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.GaiaDeviceBasicInfo)
  })
_sym_db.RegisterMessage(GaiaDeviceBasicInfo)

GaiaEncryptMsgReq = _reflection.GeneratedProtocolMessageType('GaiaEncryptMsgReq', (_message.Message,), {
  'DESCRIPTOR' : _GAIAENCRYPTMSGREQ,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.GaiaEncryptMsgReq)
  })
_sym_db.RegisterMessage(GaiaEncryptMsgReq)

GaiaMsgHeader = _reflection.GeneratedProtocolMessageType('GaiaMsgHeader', (_message.Message,), {
  'DESCRIPTOR' : _GAIAMSGHEADER,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.GaiaMsgHeader)
  })
_sym_db.RegisterMessage(GaiaMsgHeader)

UploadAppListReply = _reflection.GeneratedProtocolMessageType('UploadAppListReply', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADAPPLISTREPLY,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.UploadAppListReply)
  })
_sym_db.RegisterMessage(UploadAppListReply)

_GAIA = DESCRIPTOR.services_by_name['Gaia']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENCRYPTTYPE._serialized_start=896
  _ENCRYPTTYPE._serialized_end=971
  _PAYLOADTYPE._serialized_start=973
  _PAYLOADTYPE._serialized_end=1028
  _DEVICEAPPLIST._serialized_start=80
  _DEVICEAPPLIST._serialized_end=159
  _FETCHPUBLICKEYREPLY._serialized_start=161
  _FETCHPUBLICKEYREPLY._serialized_end=237
  _GAIADEVICEBASICINFO._serialized_start=240
  _GAIADEVICEBASICINFO._serialized_end=599
  _GAIAENCRYPTMSGREQ._serialized_start=601
  _GAIAENCRYPTMSGREQ._serialized_end=694
  _GAIAMSGHEADER._serialized_start=697
  _GAIAMSGHEADER._serialized_end=854
  _UPLOADAPPLISTREPLY._serialized_start=856
  _UPLOADAPPLISTREPLY._serialized_end=894
  _GAIA._serialized_start=1031
  _GAIA._serialized_end=1214
# @@protoc_insertion_point(module_scope)
