"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Sync(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NOTE_ID_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    note_id: builtins.int
    """笔记id"""

    hash: typing.Text
    """唯一标示"""

    def __init__(self,
        *,
        note_id: builtins.int = ...,
        hash: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash",b"hash","note_id",b"note_id"]) -> None: ...
global___Sync = Sync
