# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/main/native.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/broadcast/message/main/native.proto\x12\x1f\x62ilibili.broadcast.message.main\x1a\x1bgoogle/protobuf/empty.proto\"\\\n\x0fNativePageEvent\x12\x0e\n\x06PageID\x18\x01 \x01(\x03\x12\x39\n\x05Items\x18\x02 \x03(\x0b\x32*.bilibili.broadcast.message.main.EventItem\"m\n\tEventItem\x12\x0e\n\x06ItemID\x18\x01 \x01(\x03\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x0b\n\x03Num\x18\x03 \x01(\x03\x12\x12\n\nDisplayNum\x18\x04 \x01(\t\x12\x0e\n\x06WebKey\x18\x05 \x01(\t\x12\x11\n\tdimension\x18\x06 \x01(\x03\x32g\n\nNativePage\x12Y\n\x0bWatchNotify\x12\x16.google.protobuf.Empty\x1a\x30.bilibili.broadcast.message.main.NativePageEvent0\x01\x62\x06proto3')



_NATIVEPAGEEVENT = DESCRIPTOR.message_types_by_name['NativePageEvent']
_EVENTITEM = DESCRIPTOR.message_types_by_name['EventItem']
NativePageEvent = _reflection.GeneratedProtocolMessageType('NativePageEvent', (_message.Message,), {
  'DESCRIPTOR' : _NATIVEPAGEEVENT,
  '__module__' : 'bilibili.broadcast.message.main.native_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.main.NativePageEvent)
  })
_sym_db.RegisterMessage(NativePageEvent)

EventItem = _reflection.GeneratedProtocolMessageType('EventItem', (_message.Message,), {
  'DESCRIPTOR' : _EVENTITEM,
  '__module__' : 'bilibili.broadcast.message.main.native_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.main.EventItem)
  })
_sym_db.RegisterMessage(EventItem)

_NATIVEPAGE = DESCRIPTOR.services_by_name['NativePage']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NATIVEPAGEEVENT._serialized_start=110
  _NATIVEPAGEEVENT._serialized_end=202
  _EVENTITEM._serialized_start=204
  _EVENTITEM._serialized_end=313
  _NATIVEPAGE._serialized_start=315
  _NATIVEPAGE._serialized_end=418
# @@protoc_insertion_point(module_scope)
