"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Device(google.protobuf.message.Message):
    """设备信息
    gRPC头部:x-bili-device-bin
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    APP_ID_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BRAND_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    OSVER_FIELD_NUMBER: builtins.int
    FP_LOCAL_FIELD_NUMBER: builtins.int
    FP_REMOTE_FIELD_NUMBER: builtins.int
    VERSION_NAME_FIELD_NUMBER: builtins.int
    FP_FIELD_NUMBER: builtins.int
    FTS_FIELD_NUMBER: builtins.int
    app_id: builtins.int
    """产品id
    粉 白 蓝 直播姬 HD 海外 OTT 漫画 TV野版 小视频 网易漫画 网易漫画 网易漫画HD 国际版
    1  2  3    4    5   6    7   8     9     10      11       12       13       14
    """

    build: builtins.int
    """构建id"""

    buvid: typing.Text
    """设备buvid"""

    mobi_app: typing.Text
    """包类型"""

    platform: typing.Text
    """平台类型
    ios android
    """

    device: typing.Text
    """设备类型"""

    channel: typing.Text
    """渠道"""

    brand: typing.Text
    """手机品牌"""

    model: typing.Text
    """手机型号"""

    osver: typing.Text
    """系统版本"""

    fp_local: typing.Text
    """本地设备指纹"""

    fp_remote: typing.Text
    """远程设备指纹"""

    version_name: typing.Text
    """APP版本号"""

    fp: typing.Text
    """设备指纹, 不区分本地或远程设备指纹，作为推送目标的索引"""

    fts: builtins.int
    """"""

    def __init__(self,
        *,
        app_id: builtins.int = ...,
        build: builtins.int = ...,
        buvid: typing.Text = ...,
        mobi_app: typing.Text = ...,
        platform: typing.Text = ...,
        device: typing.Text = ...,
        channel: typing.Text = ...,
        brand: typing.Text = ...,
        model: typing.Text = ...,
        osver: typing.Text = ...,
        fp_local: typing.Text = ...,
        fp_remote: typing.Text = ...,
        version_name: typing.Text = ...,
        fp: typing.Text = ...,
        fts: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id",b"app_id","brand",b"brand","build",b"build","buvid",b"buvid","channel",b"channel","device",b"device","fp",b"fp","fp_local",b"fp_local","fp_remote",b"fp_remote","fts",b"fts","mobi_app",b"mobi_app","model",b"model","osver",b"osver","platform",b"platform","version_name",b"version_name"]) -> None: ...
global___Device = Device
