# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.interfaces.v1 import space_pb2 as bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2


class SpaceStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SearchTab = channel.unary_unary(
                '/bilibili.app.interfaces.v1.Space/SearchTab',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchTabReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchTabReply.FromString,
                )
        self.SearchArchive = channel.unary_unary(
                '/bilibili.app.interfaces.v1.Space/SearchArchive',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchArchiveReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchArchiveReply.FromString,
                )
        self.SearchDynamic = channel.unary_unary(
                '/bilibili.app.interfaces.v1.Space/SearchDynamic',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchDynamicReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchDynamicReply.FromString,
                )


class SpaceServicer(object):
    """
    """

    def SearchTab(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchArchive(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchDynamic(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SpaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SearchTab': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchTab,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchTabReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchTabReply.SerializeToString,
            ),
            'SearchArchive': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchArchive,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchArchiveReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchArchiveReply.SerializeToString,
            ),
            'SearchDynamic': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchDynamic,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchDynamicReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchDynamicReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.interfaces.v1.Space', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Space(object):
    """
    """

    @staticmethod
    def SearchTab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interfaces.v1.Space/SearchTab',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchTabReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchTabReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchArchive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interfaces.v1.Space/SearchArchive',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchArchiveReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchArchiveReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchDynamic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interfaces.v1.Space/SearchDynamic',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchDynamicReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_space__pb2.SearchDynamicReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
