"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RegionConfig(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SCENES_NAME_FIELD_NUMBER: builtins.int
    SCENES_TYPE_FIELD_NUMBER: builtins.int
    scenes_name: typing.Text
    """"""

    scenes_type: typing.Text
    """"""

    def __init__(self,
        *,
        scenes_name: typing.Text = ...,
        scenes_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scenes_name",b"scenes_name","scenes_type",b"scenes_type"]) -> None: ...
global___RegionConfig = RegionConfig

class RegionInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TID_FIELD_NUMBER: builtins.int
    REID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOGO_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    IS_BANGUMI_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    tid: builtins.int
    """"""

    reid: builtins.int
    """"""

    name: typing.Text
    """"""

    logo: typing.Text
    """"""

    goto: typing.Text
    """"""

    param: typing.Text
    """"""

    uri: typing.Text
    """"""

    type: builtins.int
    """"""

    is_bangumi: builtins.int
    """"""

    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionInfo]:
        """"""
        pass
    @property
    def config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionConfig]:
        """"""
        pass
    def __init__(self,
        *,
        tid: builtins.int = ...,
        reid: builtins.int = ...,
        name: typing.Text = ...,
        logo: typing.Text = ...,
        goto: typing.Text = ...,
        param: typing.Text = ...,
        uri: typing.Text = ...,
        type: builtins.int = ...,
        is_bangumi: builtins.int = ...,
        children: typing.Optional[typing.Iterable[global___RegionInfo]] = ...,
        config: typing.Optional[typing.Iterable[global___RegionConfig]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["children",b"children","config",b"config","goto",b"goto","is_bangumi",b"is_bangumi","logo",b"logo","name",b"name","param",b"param","reid",b"reid","tid",b"tid","type",b"type","uri",b"uri"]) -> None: ...
global___RegionInfo = RegionInfo

class RegionReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REGIONS_FIELD_NUMBER: builtins.int
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionInfo]:
        """"""
        pass
    def __init__(self,
        *,
        regions: typing.Optional[typing.Iterable[global___RegionInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["regions",b"regions"]) -> None: ...
global___RegionReply = RegionReply

class RegionReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LANG_FIELD_NUMBER: builtins.int
    lang: typing.Text
    """"""

    def __init__(self,
        *,
        lang: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lang",b"lang"]) -> None: ...
global___RegionReq = RegionReq
