# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/community/service/govern/v1/govern.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1bilibili/community/service/govern/v1/govern.proto\x12$bilibili.community.service.govern.v1\x1a\x1bgoogle/protobuf/empty.proto\"\xc1\x01\n\x0cQoeReportReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05scene\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0e\n\x06\x63\x61ncel\x18\x04 \x01(\x08\x12\x15\n\rbusiness_type\x18\x05 \x01(\t\x12J\n\x0cscore_result\x18\x06 \x01(\x0b\x32\x34.bilibili.community.service.govern.v1.QoeScoreResult\x12\x15\n\rbusiness_data\x18\x07 \x01(\t\"\x1f\n\x0eQoeScoreResult\x12\r\n\x05score\x18\x01 \x01(\x02\x32^\n\x03Qoe\x12W\n\tQoeReport\x12\x32.bilibili.community.service.govern.v1.QoeReportReq\x1a\x16.google.protobuf.Emptyb\x06proto3')



_QOEREPORTREQ = DESCRIPTOR.message_types_by_name['QoeReportReq']
_QOESCORERESULT = DESCRIPTOR.message_types_by_name['QoeScoreResult']
QoeReportReq = _reflection.GeneratedProtocolMessageType('QoeReportReq', (_message.Message,), {
  'DESCRIPTOR' : _QOEREPORTREQ,
  '__module__' : 'bilibili.community.service.govern.v1.govern_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.govern.v1.QoeReportReq)
  })
_sym_db.RegisterMessage(QoeReportReq)

QoeScoreResult = _reflection.GeneratedProtocolMessageType('QoeScoreResult', (_message.Message,), {
  'DESCRIPTOR' : _QOESCORERESULT,
  '__module__' : 'bilibili.community.service.govern.v1.govern_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.govern.v1.QoeScoreResult)
  })
_sym_db.RegisterMessage(QoeScoreResult)

_QOE = DESCRIPTOR.services_by_name['Qoe']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QOEREPORTREQ._serialized_start=121
  _QOEREPORTREQ._serialized_end=314
  _QOESCORERESULT._serialized_start=316
  _QOESCORERESULT._serialized_end=347
  _QOE._serialized_start=349
  _QOE._serialized_end=443
# @@protoc_insertion_point(module_scope)
