# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/dynamic/v2/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/dynamic/v2/dynamic.proto\x12\x17\x62ilibili.app.dynamic.v2\x1a\x19google/protobuf/any.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"/\n\x07\x41\x64Param\x12\x10\n\x08\x61\x64_extra\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\x9f\x02\n\x0e\x41\x64\x64itionCommon\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x39\n\x06\x62utton\x18\x07 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x32\n\x05style\x18\t \x01(\x0e\x32#.bilibili.app.dynamic.v2.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\"\xbb\x01\n\x0e\x41\x64\x64itionEsport\x12\x33\n\x05style\x18\x01 \x01(\x0e\x32$.bilibili.app.dynamic.v2.EspaceStyle\x12K\n\x14\x61\x64\x64ition_esport_moba\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v2.AdditionEsportMobaH\x00\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x11\n\tcard_type\x18\x04 \x01(\tB\x06\n\x04item\"\xd5\x02\n\x12\x41\x64\x64itionEsportMoba\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x36\n\nmatch_team\x18\x03 \x03(\x0b\x32\".bilibili.app.dynamic.v2.MatchTeam\x12V\n\x1b\x61\x64\x64ition_esport_moba_status\x18\x04 \x01(\x0b\x32\x31.bilibili.app.dynamic.v2.AdditionEsportMobaStatus\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x39\n\x06\x62utton\x18\x06 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\tsub_title\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\x12\x11\n\thead_icon\x18\x0c \x01(\t\"\xbe\x01\n\x18\x41\x64\x64itionEsportMobaStatus\x12_\n addition_esport_moba_status_desc\x18\x01 \x03(\x0b\x32\x35.bilibili.app.dynamic.v2.AdditionEsportMobaStatusDesc\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"Q\n\x1c\x41\x64\x64itionEsportMobaStatusDesc\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\x13\n\x0bnight_color\x18\x03 \x01(\t\"\x9e\x01\n\rAdditionGoods\x12\x11\n\trcmd_desc\x18\x01 \x01(\t\x12\x37\n\x0bgoods_items\x18\x02 \x03(\x0b\x32\".bilibili.app.dynamic.v2.GoodsItem\x12\x11\n\tcard_type\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\x05\"\x99\x04\n\nAdditionUP\x12\r\n\x05title\x18\x01 \x01(\t\x12;\n\x0b\x64\x65sc_text_1\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.HighlightText\x12\x13\n\x0b\x64\x65sc_text_2\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x39\n\x06\x62utton\x18\x05 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\tcard_type\x18\x06 \x01(\t\x12\x15\n\rreserve_total\x18\x07 \x01(\x03\x12<\n\x08\x61\x63t_skin\x18\x08 \x01(\x0b\x32*.bilibili.app.dynamic.v2.AdditionalActSkin\x12\x0b\n\x03rid\x18\t \x01(\x03\x12\x14\n\x0clottery_type\x18\n \x01(\x05\x12:\n\ndesc_text3\x18\x0b \x01(\x0b\x32&.bilibili.app.dynamic.v2.HighlightText\x12\x0e\n\x06up_mid\x18\x0c \x01(\x03\x12<\n\tuser_info\x18\r \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionUserInfo\x12\x12\n\ndynamic_id\x18\x0e \x01(\t\x12\x12\n\nshow_text2\x18\x0f \x01(\x08\x12\x10\n\x08\x64yn_type\x18\x10 \x01(\x03\x12\x13\n\x0b\x62usiness_id\x18\x11 \x01(\t\"\xad\x01\n\x0b\x41\x64\x64itionUgc\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08\x64uration\x18\x07 \x01(\t\x12\x11\n\tline_feed\x18\x08 \x01(\x08\x12\x11\n\tcard_type\x18\t \x01(\t\".\n\x10\x41\x64\x64itionUserInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\"b\n\x0c\x41\x64\x64itionVote\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06text_1\x18\x03 \x01(\t\x12\x13\n\x0b\x62utton_text\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\x87\x05\n\rAdditionVote2\x12\x45\n\x12\x61\x64\x64ition_vote_type\x18\x01 \x01(\x0e\x32).bilibili.app.dynamic.v2.AdditionVoteType\x12\x0f\n\x07vote_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x05 \x01(\x03\x12\x11\n\topen_text\x18\x06 \x01(\t\x12\x12\n\nclose_text\x18\x07 \x01(\t\x12\x12\n\nvoted_text\x18\x08 \x01(\t\x12\x39\n\x05state\x18\t \x01(\x0e\x32*.bilibili.app.dynamic.v2.AdditionVoteState\x12G\n\x12\x61\x64\x64ition_vote_word\x18\n \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionVoteWordH\x00\x12\x45\n\x11\x61\x64\x64ition_vote_pic\x18\x0b \x01(\x0b\x32(.bilibili.app.dynamic.v2.AdditionVotePicH\x00\x12M\n\x15\x61\x64\x64ition_vote_defaule\x18\x0c \x01(\x0b\x32,.bilibili.app.dynamic.v2.AdditionVoteDefauleH\x00\x12\x10\n\x08\x62iz_type\x18\r \x01(\x05\x12\r\n\x05total\x18\x0e \x01(\x03\x12\x11\n\tcard_type\x18\x0f \x01(\t\x12\x0c\n\x04tips\x18\x10 \x01(\t\x12\x0b\n\x03uri\x18\x11 \x01(\t\x12\x10\n\x08is_voted\x18\x12 \x01(\x08\x12\x12\n\nchoice_cnt\x18\x13 \x01(\x05\x12\x1c\n\x14\x64\x65\x66\x61ule_select_share\x18\x14 \x01(\x08\x42\x06\n\x04item\"$\n\x13\x41\x64\x64itionVoteDefaule\x12\r\n\x05\x63over\x18\x01 \x03(\t\"M\n\x0f\x41\x64\x64itionVotePic\x12:\n\x04item\x18\x01 \x03(\x0b\x32,.bilibili.app.dynamic.v2.AdditionVotePicItem\"\x8c\x01\n\x13\x41\x64\x64itionVotePicItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\r\n\x05title\x18\x06 \x01(\t\x12\x15\n\ris_max_option\x18\x07 \x01(\x08\"O\n\x10\x41\x64\x64itionVoteWord\x12;\n\x04item\x18\x01 \x03(\x0b\x32-.bilibili.app.dynamic.v2.AdditionVoteWordItem\"~\n\x14\x41\x64\x64itionVoteWordItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\x15\n\ris_max_option\x18\x06 \x01(\x08\"I\n\x11\x41\x64\x64itionalActSkin\x12\x0c\n\x04svga\x18\x01 \x01(\t\x12\x12\n\nlast_image\x18\x02 \x01(\t\x12\x12\n\nplay_times\x18\x03 \x01(\x03\"\xa7\x03\n\x10\x41\x64\x64itionalButton\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.AddButtonType\x12\x42\n\njump_style\x18\x02 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12?\n\x07uncheck\x18\x04 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12=\n\x05\x63heck\x18\x05 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonStyle\x12?\n\x06status\x18\x06 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\x12\x46\n\nclick_type\x18\x07 \x01(\x0e\x32\x32.bilibili.app.dynamic.v2.AdditionalButtonClickType\"\\\n\x1b\x41\x64\x64itionalButtonInteractive\x12\x0e\n\x06popups\x18\x01 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"A\n\x15\x41\x64\x64itionalButtonShare\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xc1\x02\n\x15\x41\x64\x64itionalButtonStyle\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12I\n\x0binteractive\x18\x03 \x01(\x0b\x32\x34.bilibili.app.dynamic.v2.AdditionalButtonInteractive\x12;\n\x08\x62g_style\x18\x04 \x01(\x0e\x32).bilibili.app.dynamic.v2.AddButtonBgStyle\x12\r\n\x05toast\x18\x05 \x01(\t\x12\x36\n\x07\x64isable\x18\x06 \x01(\x0e\x32%.bilibili.app.dynamic.v2.DisableState\x12=\n\x05share\x18\x07 \x01(\x0b\x32..bilibili.app.dynamic.v2.AdditionalButtonShare\"\x8b\x02\n\rAdditionalPGC\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x39\n\x06\x62utton\x18\x07 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x32\n\x05style\x18\t \x01(\x0e\x32#.bilibili.app.dynamic.v2.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\"X\n\x13\x41lumniDynamicsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\"\xa1\x01\n\x11\x41lumniDynamicsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x12\n\nfirst_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x05\"3\n\x10\x43\x61mpusBannerInfo\x12\r\n\x05image\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"\xfc\x01\n\x14\x43\x61mpusBillBoardReply\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08help_uri\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x61mpus_name\x18\x03 \x01(\t\x12\x12\n\nbuild_time\x18\x04 \x01(\x03\x12\x14\n\x0cversion_code\x18\x05 \x01(\t\x12\x33\n\x04list\x18\x06 \x03(\x0b\x32%.bilibili.app.dynamic.v2.OfficialItem\x12\x11\n\tshare_uri\x18\x07 \x01(\t\x12\x13\n\x0b\x62ind_notice\x18\x08 \x01(\x05\x12\x14\n\x0cupdate_toast\x18\t \x01(\t\x12\x11\n\tcampus_id\x18\n \x01(\x03\"\x82\x01\n\x12\x43\x61mpusBillBoardReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x14\n\x0cversion_code\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"R\n\x1a\x43\x61mpusBillboardInternalReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x11\n\tcampus_id\x18\x02 \x01(\x03\x12\x14\n\x0cversion_code\x18\x03 \x01(\t\"Y\n\x12\x43\x61mpusFeedbackInfo\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\x05\x12\x0e\n\x06\x62iz_id\x18\x02 \x01(\x03\x12\x11\n\tcampus_id\x18\x03 \x01(\x03\x12\x0e\n\x06reason\x18\x04 \x01(\t\"&\n\x13\x43\x61mpusFeedbackReply\x12\x0f\n\x07message\x18\x01 \x01(\t\"]\n\x11\x43\x61mpusFeedbackReq\x12:\n\x05infos\x18\x01 \x03(\x0b\x32+.bilibili.app.dynamic.v2.CampusFeedbackInfo\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\"R\n\nCampusInfo\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0e\n\x06online\x18\x04 \x01(\x03\"6\n\x0b\x43\x61mpusLabel\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\"N\n\x17\x43\x61mpusMateLikeListReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\"+\n\x15\x43\x61mpusMateLikeListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\x03\"e\n\x10\x43\x61mpusNoticeInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x34\n\x06\x62utton\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\"\xb4\x01\n\x13\x43\x61mpusRcmdFeedReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\x12\x38\n\tguide_bar\x18\x03 \x01(\x0b\x32%.bilibili.app.dynamic.v2.GuideBarInfo\x12\x10\n\x08has_more\x18\x04 \x01(\x08\x12\x0e\n\x06update\x18\x05 \x01(\x08\"\xc6\x01\n\x11\x43\x61mpusRcmdFeedReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x12\n\nfirst_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x05\x12\x0e\n\x06scroll\x18\x06 \x01(\x05\x12\x13\n\x0bview_dyn_id\x18\x07 \x01(\t\"W\n\x0e\x43\x61mpusRcmdInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.CampusRcmdItem\"\x9f\x01\n\x0e\x43\x61mpusRcmdItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x11\n\tcampus_id\x18\x03 \x01(\x03\x12\x39\n\x0b\x65ntry_label\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\"\xc8\x01\n\x0f\x43\x61mpusRcmdReply\x12\x33\n\x03top\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CampusRcmdTop\x12\x35\n\x04rcmd\x18\x02 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.CampusRcmdInfo\x12\x36\n\ncampus_top\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.CampusTop\x12\x11\n\tpage_type\x18\x04 \x01(\x05\"\x96\x01\n\rCampusRcmdReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lng\x18\x04 \x01(\x01\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xc1\x03\n\rCampusRcmdTop\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\x05\x12\x36\n\x06\x62utton\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.RcmdTopButton\x12:\n\x0cswitch_label\x18\x07 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12:\n\x0cnotice_label\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05\x64\x65sc2\x18\t \x01(\t\x12\r\n\x05\x64\x65sc3\x18\n \x01(\t\x12:\n\x0cinvite_label\x18\x0b \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12;\n\rreserve_label\x18\x0c \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x16\n\x0ereserve_number\x18\r \x01(\x03\"$\n\x11\x43\x61mpusRedDotReply\x12\x0f\n\x07red_dot\x18\x01 \x01(\x05\"$\n\x0f\x43\x61mpusRedDotReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\"M\n\x11\x43\x61mpusShowTabInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0f\n\x07red_dot\x18\x04 \x01(\x05\"\xdb\x03\n\tCampusTop\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x38\n\x04tabs\x18\x03 \x03(\x0b\x32*.bilibili.app.dynamic.v2.CampusShowTabInfo\x12:\n\x0cswitch_label\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05title\x18\x05 \x01(\t\x12\x39\n\x06\x62\x61nner\x18\x06 \x03(\x0b\x32).bilibili.app.dynamic.v2.CampusBannerInfo\x12:\n\x0cinvite_label\x18\x07 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x39\n\x06notice\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.CampusNoticeInfo\x12>\n\x0ctopic_square\x18\t \x01(\x0b\x32(.bilibili.app.dynamic.v2.TopicSquareInfo\x12\x14\n\x0c\x63\x61mpus_badge\x18\n \x01(\t\x12\x19\n\x11\x63\x61mpus_background\x18\x0b \x01(\t\"\x7f\n\x18\x43\x61mpusTopicRcmdFeedReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05toast\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x0e\n\x06offset\x18\x04 \x01(\t\"\x94\x01\n\x16\x43\x61mpusTopicRcmdFeedReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\"\x9d\x01\n\x10\x43\x61rdVideoDynList\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"c\n\x13\x43\x61rdVideoFollowList\x12\x15\n\rview_all_link\x18\x01 \x01(\t\x12\x35\n\x04list\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.FollowListItem\"\x9e\x02\n\x0f\x43\x61rdVideoUpList\x12\r\n\x05title\x18\x01 \x01(\t\x12\x31\n\x04list\x18\x02 \x03(\x0b\x32#.bilibili.app.dynamic.v2.UpListItem\x12\x11\n\tfootprint\x18\x03 \x01(\t\x12\x15\n\rshow_live_num\x18\x04 \x01(\x05\x12<\n\nmore_label\x18\x05 \x01(\x0b\x32(.bilibili.app.dynamic.v2.UpListMoreLabel\x12\x14\n\x0ctitle_switch\x18\x06 \x01(\x05\x12\x17\n\x0fshow_more_label\x18\x07 \x01(\x08\x12\x18\n\x10show_in_personal\x18\x08 \x01(\x08\x12\x18\n\x10show_more_button\x18\t \x01(\x08\"\xbc\x01\n\x0b\x43hannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x10\n\x08is_atten\x18\x04 \x01(\x08\x12\x11\n\ttype_icon\x18\x05 \x01(\t\x12\x30\n\x05items\x18\x06 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\x10\n\x08jump_uri\x18\x08 \x01(\t\"G\n\x0b\x43mtShowItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\"3\n\rCommentDetail\x12\x12\n\ncan_modify\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x03\"P\n\x0b\x44\x65\x63oCardFan\x12\x0e\n\x06is_fan\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\x12\n\nnumber_str\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"q\n\x0c\x44\x65\x63orateCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x31\n\x03\x66\x61n\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DecoCardFan\"\xb7\x02\n\x0b\x44\x65scription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.bilibili.app.dynamic.v2.DescType\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x36\n\nemoji_type\x18\x04 \x01(\x0e\x32\".bilibili.app.dynamic.v2.EmojiType\x12\x12\n\ngoods_type\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x11\n\ticon_name\x18\x07 \x01(\t\x12\x0b\n\x03rid\x18\x08 \x01(\t\x12\x37\n\x05goods\x18\t \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleDescGoods\x12\x11\n\torig_text\x18\n \x01(\t\x12\x12\n\nemoji_size\x18\x0b \x01(\x05\":\n\tDimension\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"_\n\x1c\x44ynAdditionCommonFollowReply\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\"\x80\x01\n\x1a\x44ynAdditionCommonFollowReq\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.bilibili.app.dynamic.v2.AdditionalButtonStatus\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x11\n\tcard_type\x18\x03 \x01(\t\"\xf2\x01\n\x13\x44ynAllPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x33\n\x08relation\x18\x05 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12;\n\x0b\x61\x64\x64ition_up\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopAdditionUP\"\x8f\x02\n\x11\x44ynAllPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xae\x02\n\x0b\x44ynAllReply\x12:\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\x12\x39\n\x07up_list\x18\x02 \x01(\x0b\x32(.bilibili.app.dynamic.v2.CardVideoUpList\x12\x36\n\ntopic_list\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.TopicList\x12\x33\n\x08unfollow\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Unfollow\x12;\n\x0bregion_rcmd\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v2.DynRegionRcmd\"\xf0\x03\n\tDynAllReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x36\n\x0crefresh_type\x18\x04 \x01(\x0e\x32 .bilibili.app.dynamic.v2.Refresh\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12=\n\x0ercmd_ups_param\x18\x08 \x01(\x0b\x32%.bilibili.app.dynamic.v2.RcmdUPsParam\x12\x32\n\x08\x61\x64_param\x18\t \x01(\x0b\x32 .bilibili.app.dynamic.v2.AdParam\x12\x12\n\ncold_start\x18\n \x01(\x05\x12\x0c\n\x04\x66rom\x18\x0b \x01(\t\x12\x43\n\x0bplayer_args\x18\x0c \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x16\n\x0etab_recall_uid\x18\r \x01(\x03\x12\x17\n\x0ftab_recall_type\x18\x0e \x01(\x05\"N\n\x12\x44ynAllUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\"D\n\x0e\x44ynDetailReply\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"\xa0\x02\n\x0c\x44ynDetailReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x12\n\ndynamic_id\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0b\n\x03rid\x18\x04 \x01(\x03\x12\x32\n\x08\x61\x64_param\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v2.AdParam\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\x12\x43\n\x0bplayer_args\x18\x07 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08share_id\x18\x08 \x01(\t\x12\x12\n\nshare_mode\x18\t \x01(\x05\x12\x12\n\nlocal_time\x18\n \x01(\x05\x12\x0f\n\x07pattern\x18\x0b \x01(\t\"E\n\x0f\x44ynDetailsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"\xbb\x01\n\rDynDetailsReq\x12\x13\n\x0b\x64ynamic_ids\x18\x01 \x01(\t\x12<\n\rplayurl_param\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"F\n\x10\x44ynFakeCardReply\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"!\n\x0e\x44ynFakeCardReq\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"K\n\rDynLightReply\x12:\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\"\xbf\x01\n\x0b\x44ynLightReq\x12\x16\n\x0ehistory_offset\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x11\n\tfrom_type\x18\x06 \x01(\x05\x12\x10\n\x08\x66\x61ke_uid\x18\x07 \x01(\x03\"\xdf\x01\n\x19\x44ynMixUpListViewMoreReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v2.MixUpListItem\x12\x1b\n\x13search_default_text\x18\x02 \x01(\t\x12\x35\n\nsort_types\x18\x03 \x03(\x0b\x32!.bilibili.app.dynamic.v2.SortType\x12\x1c\n\x14show_more_sort_types\x18\x04 \x01(\x08\x12\x19\n\x11\x64\x65\x66\x61ult_sort_type\x18\x05 \x01(\x05\",\n\x17\x44ynMixUpListViewMoreReq\x12\x11\n\tsort_type\x18\x01 \x01(\x05\"\x87\x01\n\x0c\x44ynRcmdReply\x12;\n\x0bregion_rcmd\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.DynRegionRcmd\x12:\n\x0c\x64ynamic_list\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicList\"\x8b\x01\n\nDynRcmdReq\x12\x43\n\x0bplayer_args\x18\x01 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x02 \x01(\x05\x12\x10\n\x08\x66\x61ke_uid\x18\x03 \x01(\x03\x12\x12\n\nis_refresh\x18\x04 \x01(\x08\"M\n\x16\x44ynRcmdUpExchangeReply\x12\x33\n\x08unfollow\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Unfollow\"D\n\x14\x44ynRcmdUpExchangeReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\tdislikeTs\x18\x02 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\"}\n\rDynRegionRcmd\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32*.bilibili.app.dynamic.v2.DynRegionRcmdItem\x12\x31\n\x04opts\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v2.RcmdOption\"c\n\x11\x44ynRegionRcmdItem\x12\x0b\n\x03rid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x32\n\x05items\x18\x03 \x03(\x0b\x32#.bilibili.app.dynamic.v2.ModuleRcmd\"\xc4\x01\n\x0e\x44ynSearchReply\x12<\n\x0c\x63hannel_info\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.SearchChannel\x12:\n\x0csearch_topic\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.SearchTopic\x12\x38\n\x0bsearch_info\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v2.SearchInfo\"\x86\x01\n\x0c\x44ynSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xb5\x01\n\x15\x44ynServerDetailsReply\x12H\n\x05items\x18\x01 \x03(\x0b\x32\x39.bilibili.app.dynamic.v2.DynServerDetailsReply.ItemsEntry\x1aR\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem:\x02\x38\x01\"\xe0\x01\n\x13\x44ynServerDetailsReq\x12\x12\n\nlocal_time\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\r\n\x05\x62uvid\x18\x06 \x01(\t\x12\r\n\x05\x62uild\x18\x07 \x01(\x03\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x10\n\x08platform\x18\t \x01(\t\x12\x11\n\tis_master\x18\n \x01(\x08\"\xac\x01\n\x0b\x44ynSpaceReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x02 \x01(\t\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x06 \x01(\t\"k\n\x0b\x44ynSpaceRsp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x16\n\x0ehistory_offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\"\xbf\x01\n\x1a\x44ynSpaceSearchDetailsReply\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReply.ItemsEntry\x1aR\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem:\x02\x38\x01\"\x97\x02\n\x18\x44ynSpaceSearchDetailsReq\x12\x14\n\x0csearch_words\x18\x02 \x03(\t\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08mobi_app\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\r\n\x05\x62uvid\x18\x07 \x01(\t\x12\r\n\x05\x62uild\x18\x08 \x01(\x03\x12\x0b\n\x03mid\x18\t \x01(\x03\x12\x10\n\x08platform\x18\n \x01(\t\x12\n\n\x02ip\x18\x0b \x01(\t\x12\x10\n\x08net_type\x18\x0c \x01(\x05\x12\x0f\n\x07tf_type\x18\r \x01(\x05\"\xa8\x02\n\x06\x44ynTab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06\x62ubble\x18\x03 \x01(\t\x12\x11\n\tred_point\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ity_id\x18\x05 \x01(\x03\x12\x10\n\x08is_popup\x18\x06 \x01(\x05\x12-\n\x05popup\x18\x07 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v2.Popup\x12\x13\n\x0b\x64\x65\x66\x61ult_tab\x18\x08 \x01(\x08\x12\x11\n\tsub_title\x18\t \x01(\t\x12\x0e\n\x06\x61nchor\x18\n \x01(\t\x12\x15\n\rinternal_test\x18\x0b \x01(\t\x12\x0c\n\x04type\x18\x0c \x01(\x05\x12\x30\n\x07\x62\x61\x63k_up\x18\r \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.DynTab\"?\n\x0b\x44ynTabReply\x12\x30\n\x07\x64yn_tab\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v2.DynTab\"#\n\tDynTabReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\"{\n\x0b\x44ynThumbReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0b\n\x03rid\x18\x04 \x01(\t\x12\x30\n\x04type\x18\x05 \x01(\x0e\x32\".bilibili.app.dynamic.v2.ThumbType\"\xf4\x01\n\x15\x44ynVideoPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x33\n\x08relation\x18\x05 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12;\n\x0b\x61\x64\x64ition_up\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopAdditionUP\"\x91\x02\n\x13\x44ynVideoPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\xda\x01\n\rDynVideoReply\x12?\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32).bilibili.app.dynamic.v2.CardVideoDynList\x12?\n\rvideo_up_list\x18\x02 \x01(\x0b\x32(.bilibili.app.dynamic.v2.CardVideoUpList\x12G\n\x11video_follow_list\x18\x03 \x01(\x0b\x32,.bilibili.app.dynamic.v2.CardVideoFollowList\"\xba\x02\n\x0b\x44ynVideoReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x36\n\x0crefresh_type\x18\x04 \x01(\x0e\x32 .bilibili.app.dynamic.v2.Refresh\x12<\n\rplayurl_param\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x43\n\x0bplayer_args\x18\t \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"P\n\x14\x44ynVideoUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\"S\n\x0c\x44ynVoteReply\x12\x34\n\x04item\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionVote2\x12\r\n\x05toast\x18\x02 \x01(\t\"\x84\x01\n\nDynVoteReq\x12\x0f\n\x07vote_id\x18\x01 \x01(\x03\x12\r\n\x05votes\x18\x02 \x03(\x03\x12\x33\n\x06status\x18\x03 \x01(\x0e\x32#.bilibili.app.dynamic.v2.VoteStatus\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\r\n\x05share\x18\x05 \x01(\x08\"\x89\x02\n\x0b\x44ynamicItem\x12\x37\n\tcard_type\x18\x01 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x37\n\titem_type\x18\x02 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x30\n\x07modules\x18\x03 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v2.Module\x12/\n\x06\x65xtend\x18\x04 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Extend\x12\x10\n\x08has_fold\x18\x05 \x01(\x05\x12\x13\n\x0bserver_info\x18\x06 \x01(\t\"\x98\x01\n\x0b\x44ynamicList\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"\xe2\x01\n\rExtInfoCommon\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\x12\x34\n\x04type\x18\x05 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynExtendType\x12\x12\n\nsub_module\x18\x06 \x01(\t\x12\x13\n\x0b\x61\x63tion_text\x18\x07 \x01(\t\x12\x12\n\naction_url\x18\x08 \x01(\t\x12\x0b\n\x03rid\x18\t \x01(\x03\x12\x15\n\ris_show_light\x18\n \x01(\x08\"7\n\x0b\x45xtInfoGame\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"6\n\nExtInfoHot\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"H\n\nExtInfoLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"@\n\nExtInfoOGV\x12\x32\n\x08info_ogv\x18\x01 \x03(\x0b\x32 .bilibili.app.dynamic.v2.InfoOGV\"8\n\x0c\x45xtInfoTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"\x94\x04\n\x06\x45xtend\x12\x12\n\ndyn_id_str\x18\x01 \x01(\t\x12\x13\n\x0b\x62usiness_id\x18\x02 \x01(\t\x12\x17\n\x0forig_dyn_id_str\x18\x03 \x01(\t\x12\x11\n\torig_name\x18\x04 \x01(\t\x12\x14\n\x0corig_img_url\x18\x05 \x01(\t\x12\x37\n\torig_desc\x18\x06 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x32\n\x04\x64\x65sc\x18\x07 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12;\n\rorig_dyn_type\x18\x08 \x01(\x0e\x32$.bilibili.app.dynamic.v2.DynamicType\x12\x12\n\nshare_type\x18\t \x01(\t\x12\x13\n\x0bshare_scene\x18\n \x01(\t\x12\x15\n\ris_fast_share\x18\x0b \x01(\x08\x12\x0e\n\x06r_type\x18\x0c \x01(\x05\x12\x10\n\x08\x64yn_type\x18\r \x01(\x03\x12\x0b\n\x03uid\x18\x0e \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x0f \x01(\t\x12,\n\x0esource_content\x18\x10 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\torig_face\x18\x11 \x01(\t\x12\x33\n\x05reply\x18\x12 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ExtendReply\"U\n\x0b\x45xtendReply\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x39\n\x06params\x18\x02 \x03(\x0b\x32).bilibili.app.dynamic.v2.ExtendReplyParam\".\n\x10\x45xtendReplyParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9e\x01\n\x0e\x46ollowListItem\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12.\n\x06new_ep\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v2.NewEP\x12\x11\n\tsub_title\x18\x06 \x01(\t\x12\x0b\n\x03pos\x18\x07 \x01(\x03\"\x82\x02\n\tGoodsItem\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x02 \x01(\t\x12\x13\n\x0bsource_type\x18\x03 \x01(\x05\x12\x10\n\x08jump_url\x18\x04 \x01(\t\x12\x11\n\tjump_desc\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x62rief\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\t\x12\x0f\n\x07item_id\x18\t \x01(\x03\x12\x12\n\nschema_url\x18\n \x01(\t\x12\x17\n\x0fopen_white_list\x18\x0b \x03(\t\x12\x13\n\x0buser_web_v2\x18\x0c \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\r \x01(\t\"t\n\x0cGuideBarInfo\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x10\n\x08position\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x11\n\tjump_page\x18\x05 \x01(\x05\x12\x15\n\rjump_position\x18\x06 \x01(\x05\"~\n\rHighlightText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12?\n\ntext_style\x18\x02 \x01(\x0e\x32+.bilibili.app.dynamic.v2.HighlightTextStyle\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\".\n\tIconBadge\x12\x13\n\x0bicon_bg_url\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"R\n\nIconButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x11\n\ticon_head\x18\x02 \x01(\t\x12\x11\n\ticon_tail\x18\x03 \x01(\t\x12\x10\n\x08jump_uri\x18\x04 \x01(\t\"G\n\x07InfoOGV\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x12\n\nsub_module\x18\x04 \x01(\t\",\n\x0fInteractionFace\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\"\xb5\x02\n\x0fInteractionItem\x12\x39\n\ticon_type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.LocalIconType\x12\x32\n\x04\x64\x65sc\x18\x02 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\x13\n\x0b\x63omment_mid\x18\x06 \x01(\x03\x12\x37\n\x05\x66\x61\x63\x65s\x18\x07 \x03(\x0b\x32(.bilibili.app.dynamic.v2.InteractionFace\x12\x36\n\x04stat\x18\x08 \x01(\x0b\x32(.bilibili.app.dynamic.v2.InteractionStat\x12\x0c\n\x04icon\x18\t \x01(\t\"\x1f\n\x0fInteractionStat\x12\x0c\n\x04like\x18\x01 \x01(\x03\"O\n\rLikeAnimation\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\t\x12\x0c\n\x04proc\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x14\n\x0clike_icon_id\x18\x04 \x01(\x03\"V\n\x08LikeInfo\x12\x39\n\tanimation\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.LikeAnimation\x12\x0f\n\x07is_like\x18\x02 \x01(\x08\"k\n\rLikeListReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x13\n\x0btotal_count\x18\x03 \x01(\x03\"b\n\x0bLikeListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x03\x12\x12\n\nuid_offset\x18\x04 \x01(\x03\x12\x0c\n\x04page\x18\x05 \x01(\x05\"3\n\x08LikeUser\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"b\n\x08LiveInfo\x12\x11\n\tis_living\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x36\n\nlive_state\x18\x03 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\"=\n\x0bLivePendant\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x12\n\npendant_id\x18\x03 \x01(\x03\"X\n\tMatchTeam\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"\x8b\x01\n\x0cMdlDynApplet\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x11\n\tsub_title\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\r\n\x05label\x18\x08 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\t \x01(\t\"\xdd\x05\n\rMdlDynArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\x03\x12\x0b\n\x03\x63id\x18\x08 \x01(\x03\x12\x36\n\nmedia_type\x18\t \x01(\x0e\x32\".bilibili.app.dynamic.v2.MediaType\x12\x35\n\tdimension\x18\n \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0b \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x08\x12\x31\n\x05stype\x18\r \x01(\x0e\x32\".bilibili.app.dynamic.v2.VideoType\x12\r\n\x05isPGC\x18\x0e \x01(\x08\x12\x11\n\tinlineURL\x18\x0f \x01(\t\x12\x11\n\tEpisodeId\x18\x10 \x01(\x03\x12\x0f\n\x07SubType\x18\x11 \x01(\x05\x12\x13\n\x0bPgcSeasonId\x18\x12 \x01(\x03\x12\x11\n\tplay_icon\x18\x13 \x01(\t\x12\x10\n\x08\x64uration\x18\x14 \x01(\x03\x12\x10\n\x08jump_url\x18\x15 \x01(\t\x12\x12\n\nis_preview\x18\x16 \x01(\x08\x12;\n\x0e\x62\x61\x64ge_category\x18\x17 \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x12\n\nis_feature\x18\x18 \x01(\x08\x12:\n\x0creserve_type\x18\x19 \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\x12\x0c\n\x04\x62vid\x18\x1a \x01(\t\x12\x0c\n\x04view\x18\x1b \x01(\x05\"x\n\rMdlDynArticle\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0e\n\x06\x63overs\x18\x05 \x03(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x12\n\ntemplateID\x18\x07 \x01(\x05\"\xaf\x02\n\x0cMdlDynCommon\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x0f\n\x07\x62izType\x18\x07 \x01(\x05\x12\x10\n\x08sketchID\x18\x08 \x01(\x03\x12\x38\n\x05style\x18\t \x01(\x0e\x32).bilibili.app.dynamic.v2.MdlDynCommonType\x12\x32\n\x05\x62\x61\x64ge\x18\n \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x39\n\x06\x62utton\x18\x0b \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\"\xa3\x01\n\x0fMdlDynCourBatch\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0e\n\x06text_2\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\"\xa2\x01\n\x10MdlDynCourSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\"]\n\nMdlDynDraw\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynDrawItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\"\x80\x01\n\x0eMdlDynDrawItem\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04size\x18\x04 \x01(\x02\x12\x34\n\x04tags\x18\x05 \x03(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynDrawTag\"\x83\x01\n\rMdlDynDrawTag\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.bilibili.app.dynamic.v2.MdlDynDrawTagType\x12\x38\n\x04item\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.MdlDynDrawTagItem\"\xb5\x01\n\x11MdlDynDrawTagItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x03\x12\t\n\x01y\x18\x04 \x01(\x03\x12\x13\n\x0borientation\x18\x05 \x01(\x05\x12\x0e\n\x06source\x18\x06 \x01(\x05\x12\x0f\n\x07item_id\x18\x07 \x01(\x03\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x0b\n\x03tid\x18\t \x01(\x03\x12\x0b\n\x03poi\x18\n \x01(\t\x12\x12\n\nschema_url\x18\x0b \x01(\t\"R\n\rMdlDynForward\x12\x32\n\x04item\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\r\n\x05rtype\x18\x02 \x01(\x05\"\x96\x02\n\nMdlDynLive\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x13\n\x0b\x63over_label\x18\x05 \x01(\t\x12\x14\n\x0c\x63over_label2\x18\x06 \x01(\t\x12\x36\n\nlive_state\x18\x07 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x32\n\x05\x62\x61\x64ge\x18\x08 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12:\n\x0creserve_type\x18\t \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\"\x94\x01\n\x0eMdlDynLiveRcmd\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12:\n\x0creserve_type\x18\x02 \x01(\x0e\x32$.bilibili.app.dynamic.v2.ReserveType\x12\x35\n\x07pendant\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.LivePendant\"\xa3\x01\n\x0fMdlDynMedialist\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x12\n\ncover_type\x18\x06 \x01(\x05\x12\x32\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\"r\n\x0bMdlDynMusic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05up_id\x18\x03 \x01(\x03\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0e\n\x06label1\x18\x06 \x01(\t\x12\r\n\x05upper\x18\x07 \x01(\t\"\x80\x05\n\tMdlDynPGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\x0b\n\x03\x61id\x18\n \x01(\x03\x12\x36\n\nmedia_type\x18\x0b \x01(\x0e\x32\".bilibili.app.dynamic.v2.MediaType\x12\x37\n\x08sub_type\x18\x0c \x01(\x0e\x32%.bilibili.app.dynamic.v2.VideoSubType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x35\n\tdimension\x18\x0e \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0f \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x10 \x01(\x08\x12\x32\n\x06season\x18\x11 \x01(\x0b\x32\".bilibili.app.dynamic.v2.PGCSeason\x12\x11\n\tplay_icon\x18\x12 \x01(\t\x12\x10\n\x08\x64uration\x18\x13 \x01(\x03\x12\x10\n\x08jump_url\x18\x14 \x01(\t\x12;\n\x0e\x62\x61\x64ge_category\x18\x15 \x03(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x12\n\nis_feature\x18\x16 \x01(\x08\"\xae\x01\n\x12MdlDynSubscription\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05\x61\x64_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x10\n\x08\x61\x64_title\x18\x06 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.VideoBadge\x12\x0c\n\x04tips\x18\x08 \x01(\t\"\xee\x01\n\x15MdlDynSubscriptionNew\x12\x42\n\x05style\x18\x01 \x01(\x0e\x32\x33.bilibili.app.dynamic.v2.MdlDynSubscriptionNewStyle\x12G\n\x10\x64yn_subscription\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v2.MdlDynSubscriptionH\x00\x12@\n\rdyn_live_rcmd\x18\x03 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynLiveRcmdH\x00\x42\x06\n\x04item\"\xc7\x02\n\x0fMdlDynUGCSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\x03\x12\x11\n\tinlineURL\x18\x08 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\t \x01(\x08\x12\x11\n\tplay_icon\x18\n \x01(\t\x12\x0c\n\x04\x61vid\x18\x0b \x01(\x03\x12\x0b\n\x03\x63id\x18\x0c \x01(\x03\x12\x35\n\tdimension\x18\r \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\x12\x10\n\x08\x64uration\x18\x0e \x01(\x03\x12\x10\n\x08jump_url\x18\x0f \x01(\t\"\xc7\x02\n\rMixUpListItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x19\n\x11special_attention\x18\x02 \x01(\x05\x12\x14\n\x0creddot_state\x18\x03 \x01(\x05\x12=\n\tlive_info\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v2.MixUpListLiveItem\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\x33\n\x08relation\x18\t \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\"A\n\x11MixUpListLiveItem\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x93\x0e\n\x06Module\x12;\n\x0bmodule_type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynModuleType\x12>\n\rmodule_author\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthorH\x00\x12@\n\x0emodule_dispute\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleDisputeH\x00\x12:\n\x0bmodule_desc\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleDescH\x00\x12@\n\x0emodule_dynamic\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleDynamicH\x00\x12\x42\n\x0fmodule_likeUser\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ModuleLikeUserH\x00\x12>\n\rmodule_extend\x18\x07 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleExtendH\x00\x12\x46\n\x11module_additional\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleAdditionalH\x00\x12:\n\x0bmodule_stat\x18\t \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStatH\x00\x12:\n\x0bmodule_fold\x18\n \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleFoldH\x00\x12@\n\x0emodule_comment\x18\x0b \x01(\x0b\x32&.bilibili.app.dynamic.v2.ModuleCommentH\x00\x12H\n\x12module_interaction\x18\x0c \x01(\x0b\x32*.bilibili.app.dynamic.v2.ModuleInteractionH\x00\x12M\n\x15module_author_forward\x18\r \x01(\x0b\x32,.bilibili.app.dynamic.v2.ModuleAuthorForwardH\x00\x12\x36\n\tmodule_ad\x18\x0e \x01(\x0b\x32!.bilibili.app.dynamic.v2.ModuleAdH\x00\x12>\n\rmodule_banner\x18\x0f \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleBannerH\x00\x12\x43\n\x10module_item_null\x18\x10 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ModuleItemNullH\x00\x12\x45\n\x11module_share_info\x18\x11 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleShareInfoH\x00\x12\x44\n\x10module_recommend\x18\x12 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ModuleRecommendH\x00\x12\x38\n\nmodule_top\x18\x13 \x01(\x0b\x32\".bilibili.app.dynamic.v2.ModuleTopH\x00\x12>\n\rmodule_buttom\x18\x14 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleButtomH\x00\x12\x42\n\x13module_stat_forward\x18\x15 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStatH\x00\x12<\n\x0cmodule_story\x18\x16 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleStoryH\x00\x12<\n\x0cmodule_topic\x18\x17 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleTopicH\x00\x12R\n\x18module_topic_details_ext\x18\x18 \x01(\x0b\x32..bilibili.app.dynamic.v2.ModuleTopicDetailsExtH\x00\x12?\n\x0emodule_top_tag\x18\x19 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleTopTagH\x00\x12G\n\x12module_topic_brief\x18\x1a \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleTopicBriefH\x00\x12<\n\x0cmodule_title\x18\x1b \x01(\x0b\x32$.bilibili.app.dynamic.v2.ModuleTitleH\x00\x42\r\n\x0bmodule_item\"\xdd\x01\n\x08ModuleAd\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12<\n\rmodule_author\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ModuleAuthor\x12\x17\n\x0f\x61\x64_content_type\x18\x03 \x01(\x05\x12\x18\n\x10\x63over_left_text1\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text2\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_text3\x18\x06 \x01(\t\"\xb9\x04\n\x10ModuleAdditional\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.AdditionalType\x12\x35\n\x03pgc\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionalPGCH\x00\x12\x37\n\x05goods\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionGoodsH\x00\x12\x35\n\x04vote\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.AdditionVoteH\x00\x12\x39\n\x06\x63ommon\x18\x05 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.AdditionCommonH\x00\x12\x39\n\x06\x65sport\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.AdditionEsportH\x00\x12\x37\n\x05vote2\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.AdditionVote2H\x00\x12\x33\n\x03ugc\x18\t \x01(\x0b\x32$.bilibili.app.dynamic.v2.AdditionUgcH\x00\x12\x31\n\x02up\x18\n \x01(\x0b\x32#.bilibili.app.dynamic.v2.AdditionUPH\x00\x12\x0b\n\x03rid\x18\x07 \x01(\x03\x12\x1b\n\x13need_write_calender\x18\x0b \x01(\x08\x42\x06\n\x04item\"\x94\x04\n\x0cModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x02 \x01(\t\x12\x31\n\x06\x61uthor\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12<\n\rdecorate_card\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.DecorateCard\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x38\n\x07tp_list\x18\x06 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\x12\x42\n\nbadge_type\x18\x07 \x01(\x0e\x32..bilibili.app.dynamic.v2.ModuleAuthorBadgeType\x12\x46\n\x0c\x62\x61\x64ge_button\x18\x08 \x01(\x0b\x32\x30.bilibili.app.dynamic.v2.ModuleAuthorBadgeButton\x12\x0e\n\x06\x61ttend\x18\t \x01(\x05\x12\x33\n\x08relation\x18\n \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12/\n\x06weight\x18\x0b \x01(\x0b\x32\x1f.bilibili.app.dynamic.v2.Weight\x12\x13\n\x0bshow_follow\x18\x0c \x01(\x08\x12\x0e\n\x06is_top\x18\r \x01(\x08\"Q\n\x17ModuleAuthorBadgeButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\x03\"\xa1\x02\n\x13ModuleAuthorForward\x12@\n\x05title\x18\x01 \x03(\x0b\x32\x31.bilibili.app.dynamic.v2.ModuleAuthorForwardTitle\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x04 \x01(\t\x12\x13\n\x0bshow_follow\x18\x05 \x01(\x08\x12\x10\n\x08\x66\x61\x63\x65_url\x18\x06 \x01(\t\x12\x33\n\x08relation\x18\x07 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x38\n\x07tp_list\x18\x08 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\"5\n\x18ModuleAuthorForwardTitle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\xc5\x01\n\x0cModuleBanner\x12\r\n\x05title\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).bilibili.app.dynamic.v2.ModuleBannerType\x12\x39\n\x04user\x18\x03 \x01(\x0b\x32).bilibili.app.dynamic.v2.ModuleBannerUserH\x00\x12\x14\n\x0c\x64islike_text\x18\x04 \x01(\t\x12\x14\n\x0c\x64islike_icon\x18\x05 \x01(\tB\x06\n\x04item\"O\n\x10ModuleBannerUser\x12;\n\x04list\x18\x01 \x03(\x0b\x32-.bilibili.app.dynamic.v2.ModuleBannerUserItem\"\xb8\x02\n\x14ModuleBannerUserItem\x12\x0c\n\x04\x66\x61\x63\x65\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x36\n\nlive_state\x18\x04 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x39\n\x08official\x18\x05 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x06 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\r\n\x05label\x18\x07 \x01(\t\x12\x39\n\x06\x62utton\x18\x08 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x0b\n\x03uri\x18\t \x01(\t\"H\n\x0cModuleButtom\x12\x38\n\x0bmodule_stat\x18\x01 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ModuleStat\"J\n\rModuleComment\x12\x39\n\x0b\x63mtShowItem\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.CmtShowItem\"`\n\nModuleDesc\x12\x32\n\x04\x64\x65sc\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.Description\x12\x10\n\x08jump_uri\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xb9\x01\n\x0fModuleDescGoods\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x12\n\nschema_url\x18\x03 \x01(\t\x12\x0f\n\x07item_id\x18\x04 \x01(\x03\x12\x17\n\x0fopen_white_list\x18\x05 \x03(\t\x12\x13\n\x0buser_web_v2\x18\x06 \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\x07 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x08 \x01(\t\"9\n\rModuleDispute\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xe6\x08\n\rModuleDynamic\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.bilibili.app.dynamic.v2.ModuleDynamicType\x12=\n\x0b\x64yn_archive\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynArchiveH\x00\x12\x35\n\x07\x64yn_pgc\x18\x03 \x01(\x0b\x32\".bilibili.app.dynamic.v2.MdlDynPGCH\x00\x12\x44\n\x0f\x64yn_cour_season\x18\x04 \x01(\x0b\x32).bilibili.app.dynamic.v2.MdlDynCourSeasonH\x00\x12\x42\n\x0e\x64yn_cour_batch\x18\x05 \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynCourBatchH\x00\x12=\n\x0b\x64yn_forward\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynForwardH\x00\x12\x37\n\x08\x64yn_draw\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.MdlDynDrawH\x00\x12=\n\x0b\x64yn_article\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.MdlDynArticleH\x00\x12\x39\n\tdyn_music\x18\t \x01(\x0b\x32$.bilibili.app.dynamic.v2.MdlDynMusicH\x00\x12;\n\ndyn_common\x18\n \x01(\x0b\x32%.bilibili.app.dynamic.v2.MdlDynCommonH\x00\x12>\n\x0f\x64yn_common_live\x18\x0b \x01(\x0b\x32#.bilibili.app.dynamic.v2.MdlDynLiveH\x00\x12\x41\n\rdyn_medialist\x18\x0c \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynMedialistH\x00\x12;\n\ndyn_applet\x18\r \x01(\x0b\x32%.bilibili.app.dynamic.v2.MdlDynAppletH\x00\x12G\n\x10\x64yn_subscription\x18\x0e \x01(\x0b\x32+.bilibili.app.dynamic.v2.MdlDynSubscriptionH\x00\x12@\n\rdyn_live_rcmd\x18\x0f \x01(\x0b\x32\'.bilibili.app.dynamic.v2.MdlDynLiveRcmdH\x00\x12\x42\n\x0e\x64yn_ugc_season\x18\x10 \x01(\x0b\x32(.bilibili.app.dynamic.v2.MdlDynUGCSeasonH\x00\x12N\n\x14\x64yn_subscription_new\x18\x11 \x01(\x0b\x32..bilibili.app.dynamic.v2.MdlDynSubscriptionNewH\x00\x42\r\n\x0bmodule_item\"V\n\x0cModuleExtend\x12\x39\n\x06\x65xtend\x18\x01 \x03(\x0b\x32).bilibili.app.dynamic.v2.ModuleExtendItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xcc\x03\n\x10ModuleExtendItem\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.bilibili.app.dynamic.v2.DynExtendType\x12?\n\x0e\x65xt_info_topic\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ExtInfoTopicH\x00\x12;\n\x0c\x65xt_info_lbs\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoLBSH\x00\x12;\n\x0c\x65xt_info_hot\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoHotH\x00\x12=\n\rext_info_game\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v2.ExtInfoGameH\x00\x12\x41\n\x0f\x65xt_info_common\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v2.ExtInfoCommonH\x00\x12;\n\x0c\x65xt_info_ogv\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.ExtInfoOGVH\x00\x42\x08\n\x06\x65xtend\"\x99\x01\n\nModuleFold\x12\x34\n\tfold_type\x18\x01 \x01(\x0e\x32!.bilibili.app.dynamic.v2.FoldType\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08\x66old_ids\x18\x03 \x01(\t\x12\x35\n\nfold_users\x18\x04 \x03(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\"W\n\x11ModuleInteraction\x12\x42\n\x10interaction_item\x18\x01 \x03(\x0b\x32(.bilibili.app.dynamic.v2.InteractionItem\",\n\x0eModuleItemNull\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"]\n\x0eModuleLikeUser\x12\x35\n\nlike_users\x18\x01 \x03(\x0b\x32!.bilibili.app.dynamic.v2.LikeUser\x12\x14\n\x0c\x64isplay_text\x18\x02 \x01(\t\"\x88\x01\n\nModuleRcmd\x12\x33\n\x06\x61uthor\x18\x01 \x01(\x0b\x32#.bilibili.app.dynamic.v2.RcmdAuthor\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.bilibili.app.dynamic.v2.RcmdItem\x12\x13\n\x0bserver_info\x18\x03 \x01(\t\"\x86\x01\n\x0fModuleRecommend\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x10\n\x08jump_url\x18\x05 \x01(\t\x12 \n\x02\x61\x64\x18\x06 \x03(\x0b\x32\x14.google.protobuf.Any\"\x8f\x01\n\x0fModuleShareInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12=\n\x0eshare_channels\x18\x02 \x03(\x0b\x32%.bilibili.app.dynamic.v2.ShareChannel\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\"\xdc\x01\n\nModuleStat\x12\x0e\n\x06repost\x18\x01 \x01(\x03\x12\x0c\n\x04like\x18\x02 \x01(\x03\x12\r\n\x05reply\x18\x03 \x01(\x03\x12\x34\n\tlike_info\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.LikeInfo\x12\x12\n\nno_comment\x18\x05 \x01(\x08\x12\x12\n\nno_forward\x18\x06 \x01(\x08\x12\x11\n\treply_url\x18\x07 \x01(\t\x12\x17\n\x0fno_comment_text\x18\x08 \x01(\t\x12\x17\n\x0fno_forward_text\x18\t \x01(\t\"\xb4\x01\n\x0bModuleStory\x12\r\n\x05title\x18\x01 \x01(\t\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".bilibili.app.dynamic.v2.StoryItem\x12\x1d\n\x15show_publish_entrance\x18\x03 \x01(\x08\x12\x12\n\nfold_state\x18\x04 \x01(\x03\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x14\n\x0cpublish_text\x18\x07 \x01(\t\"T\n\x0bModuleTitle\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\tright_btn\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v2.IconButton\"E\n\tModuleTop\x12\x38\n\x07tp_list\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointItem\" \n\x0cModuleTopTag\x12\x10\n\x08tag_name\x18\x01 \x01(\t\"4\n\x0bModuleTopic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"E\n\x10ModuleTopicBrief\x12\x31\n\x05topic\x18\x01 \x01(\x0b\x32\".bilibili.app.dynamic.v2.TopicItem\".\n\x15ModuleTopicDetailsExt\x12\x15\n\rcomment_guide\x18\x01 \x01(\t\"l\n\tNameplate\x12\x0b\n\x03nid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"6\n\x05NewEP\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nindex_show\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\t\n\x07NoReply\"\x07\n\x05NoReq\"\xbf\x01\n\x13OfficialAccountInfo\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x33\n\x08relation\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_text2\x18\x06 \x01(\t\"v\n\x15OfficialAccountsReply\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.bilibili.app.dynamic.v2.OfficialAccountInfo\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"M\n\x13OfficialAccountsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"\xb4\x01\n\x15OfficialDynamicsReply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.dynamic.v2.OfficialItem\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"M\n\x13OfficialDynamicsReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"\xb5\x01\n\x0cOfficialItem\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x44\n\x0crcmd_archive\x18\x02 \x01(\x0b\x32,.bilibili.app.dynamic.v2.OfficialRcmdArchiveH\x00\x12\x44\n\x0crcmd_dynamic\x18\x03 \x01(\x0b\x32,.bilibili.app.dynamic.v2.OfficialRcmdDynamicH\x00\x42\x0b\n\trcmd_item\"\x9d\x02\n\x13OfficialRcmdArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x03 \x01(\t\x12\x12\n\ndesc_icon1\x18\x04 \x01(\x05\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_icon2\x18\x06 \x01(\x05\x12\x12\n\ndesc_text2\x18\x07 \x01(\t\x12\x0e\n\x06reason\x18\x08 \x01(\t\x12\x18\n\x10show_three_point\x18\t \x01(\x08\x12\x0b\n\x03uri\x18\n \x01(\t\x12\x0b\n\x03\x61id\x18\x0b \x01(\x03\x12\x0b\n\x03mid\x18\x0c \x01(\x03\x12\x0c\n\x04name\x18\r \x01(\t\x12\x12\n\ndynamic_id\x18\x0e \x01(\x03\x12\x0b\n\x03\x63id\x18\x0f \x01(\x03\"\xff\x01\n\x13OfficialRcmdDynamic\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x1c\n\x14\x63over_right_top_text\x18\x03 \x01(\t\x12\x12\n\ndesc_icon1\x18\x04 \x01(\x05\x12\x12\n\ndesc_text1\x18\x05 \x01(\t\x12\x12\n\ndesc_icon2\x18\x06 \x01(\x05\x12\x12\n\ndesc_text2\x18\x07 \x01(\t\x12\x0e\n\x06reason\x18\x08 \x01(\t\x12\x0b\n\x03uri\x18\t \x01(\t\x12\x12\n\ndynamic_id\x18\n \x01(\x03\x12\x0b\n\x03mid\x18\x0b \x01(\x03\x12\x11\n\tuser_name\x18\x0c \x01(\t\x12\x0b\n\x03rid\x18\r \x01(\x03\">\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08is_atten\x18\x03 \x01(\x05\";\n\tPGCSeason\x12\x11\n\tis_finish\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"[\n\x0cPlayurlParam\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\r\n\x05\x66nver\x18\x02 \x01(\x05\x12\r\n\x05\x66nval\x18\x03 \x01(\x05\x12\x12\n\nforce_host\x18\x04 \x01(\x05\x12\r\n\x05\x66ourk\x18\x05 \x01(\x05\"1\n\x05Popup\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xca\x02\n\x0bRcmdArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12=\n\x11\x63over_left_icon_1\x18\x03 \x01(\x0e\x32\".bilibili.app.dynamic.v2.CoverIcon\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x0e\n\x06is_pgc\x18\x06 \x01(\x08\x12\x0b\n\x03\x61id\x18\x07 \x01(\x03\x12\x31\n\x05\x62\x61\x64ge\x18\x08 \x01(\x0b\x32\".bilibili.app.dynamic.v2.IconBadge\x12\x18\n\x10\x63over_left_icon2\x18\t \x01(\x05\x12\x18\n\x10\x63over_left_text2\x18\n \x01(\t\x12\x18\n\x10\x63over_left_icon3\x18\x0b \x01(\x05\x12\x18\n\x10\x63over_left_text3\x18\x0c \x01(\t\"\x82\x01\n\nRcmdAuthor\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x33\n\x08relation\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v2.Relation\"\x86\x01\n\x08RcmdItem\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.bilibili.app.dynamic.v2.RcmdType\x12<\n\x0crcmd_archive\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.RcmdArchiveH\x00\x42\x0b\n\trcmd_item\" \n\nRcmdOption\x12\x12\n\nshow_title\x18\x01 \x01(\x08\"*\n\rRcmdTopButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\"\n\x0cRcmdUPsParam\x12\x12\n\ndislike_ts\x18\x01 \x01(\x03\"z\n\x08Relation\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.RelationStatus\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\"\x9a\x01\n\rRepostListReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x03\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x0c\n\x04\x66rom\x18\x05 \x01(\t\x12\x38\n\x0brepost_type\x18\x06 \x01(\x0e\x32#.bilibili.app.dynamic.v2.RepostType\"\xb4\x01\n\rRepostListRsp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0btotal_count\x18\x04 \x01(\x03\x12\x38\n\x0brepost_type\x18\x05 \x01(\x0e\x32#.bilibili.app.dynamic.v2.RepostType\"J\n\x14SchoolRecommendReply\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.CampusInfo\".\n\x12SchoolRecommendReq\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lng\x18\x02 \x01(\x02\"|\n\x11SchoolSearchReply\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.CampusInfo\x12\x33\n\x05toast\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.SearchToast\"\"\n\x0fSchoolSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\"\x97\x01\n\rSearchChannel\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0bmore_button\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.SearchTopicButton\x12\x36\n\x08\x63hannels\x18\x03 \x03(\x0b\x32$.bilibili.app.dynamic.v2.ChannelInfo\"\x93\x01\n\nSearchInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x32\n\x04list\x18\x02 \x03(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\r\n\x05total\x18\x04 \x01(\x03\x12\x10\n\x08has_more\x18\x05 \x01(\x08\x12\x0f\n\x07version\x18\x06 \x01(\t\"5\n\x0bSearchToast\x12\x12\n\ndesc_text1\x18\x01 \x01(\t\x12\x12\n\ndesc_text2\x18\x02 \x01(\t\"\x96\x01\n\x0bSearchTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0bmore_button\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.SearchTopicButton\x12\x37\n\x05items\x18\x03 \x03(\x0b\x32(.bilibili.app.dynamic.v2.SearchTopicItem\"4\n\x11SearchTopicButton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08jump_uri\x18\x02 \x01(\t\"g\n\x0fSearchTopicItem\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x13\n\x0bis_activity\x18\x05 \x01(\x08\" \n\x0eSetDecisionReq\x12\x0e\n\x06result\x18\x01 \x01(\x05\"<\n\x12SetRecentCampusReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\"t\n\x0cShareChannel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\t\x12\x36\n\x07reserve\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ShareReserve\"\xaa\x01\n\x0cShareReserve\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x14\n\x0cqr_code_icon\x18\x03 \x01(\t\x12\x14\n\x0cqr_code_text\x18\x04 \x01(\t\x12\x13\n\x0bqr_code_url\x18\x05 \x01(\t\x12<\n\tuser_info\x18\x06 \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionUserInfo\"5\n\x08SortType\x12\x11\n\tsort_type\x18\x01 \x01(\x05\x12\x16\n\x0esort_type_name\x18\x02 \x01(\t\"n\n\x0cStoryArchive\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x35\n\tdimension\x18\x04 \x01(\x0b\x32\".bilibili.app.dynamic.v2.Dimension\"\xb7\x01\n\tStoryItem\x12\x31\n\x06\x61uthor\x18\x01 \x01(\x0b\x32!.bilibili.app.dynamic.v2.UserInfo\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12>\n\rstory_archive\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.StoryArchiveH\x00\x42\x0b\n\trcmd_item\"<\n\x12SubscribeCampusReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mpus_name\x18\x02 \x01(\t\"\xc1\x01\n\x13ThreePointAttention\x12\x16\n\x0e\x61ttention_icon\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttention_text\x18\x02 \x01(\t\x12\x1a\n\x12not_attention_icon\x18\x03 \x01(\t\x12\x1a\n\x12not_attention_text\x18\x04 \x01(\t\x12\x42\n\x06status\x18\x05 \x01(\x0e\x32\x32.bilibili.app.dynamic.v2.ThreePointAttentionStatus\"\xe2\x01\n\x12ThreePointAutoPlay\x12\x11\n\topen_icon\x18\x01 \x01(\t\x12\x11\n\topen_text\x18\x02 \x01(\t\x12\x12\n\nclose_icon\x18\x03 \x01(\t\x12\x12\n\nclose_text\x18\x04 \x01(\t\x12\x14\n\x0copen_text_v2\x18\x05 \x01(\t\x12\x15\n\rclose_text_v2\x18\x06 \x01(\t\x12\x11\n\tonly_icon\x18\x07 \x01(\t\x12\x11\n\tonly_text\x18\x08 \x01(\t\x12\x14\n\x0copen_icon_v2\x18\t \x01(\t\x12\x15\n\rclose_icon_v2\x18\n \x01(\t\"\xa8\x01\n\x11ThreePointComment\x12<\n\x0cup_selection\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CommentDetail\x12\x38\n\x08up_close\x18\x02 \x01(\x0b\x32&.bilibili.app.dynamic.v2.CommentDetail\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"\x89\x01\n\x11ThreePointDefault\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12>\n\x05toast\x18\x05 \x01(\x0b\x32/.bilibili.app.dynamic.v2.ThreePointDefaultToast\"5\n\x16ThreePointDefaultToast\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"0\n\x11ThreePointDislike\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"~\n\x12ThreePointFavorite\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x14\n\x0cis_favourite\x18\x04 \x01(\x08\x12\x13\n\x0b\x63\x61ncel_icon\x18\x05 \x01(\t\x12\x14\n\x0c\x63\x61ncel_title\x18\x06 \x01(\t\"\x9d\x01\n\x0eThreePointHide\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12G\n\x0binteractive\x18\x03 \x01(\x0b\x32\x32.bilibili.app.dynamic.v2.ThreePointHideInteractive\x12\x11\n\tblook_fid\x18\x04 \x01(\x03\x12\x12\n\nblook_type\x18\x05 \x01(\t\"Z\n\x19ThreePointHideInteractive\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x03 \x01(\t\x12\r\n\x05toast\x18\x04 \x01(\t\"\x88\x06\n\x0eThreePointItem\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v2.ThreePointType\x12=\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointDefaultH\x00\x12\x42\n\x0b\x61uto_player\x18\x03 \x01(\x0b\x32+.bilibili.app.dynamic.v2.ThreePointAutoPlayH\x00\x12\x39\n\x05share\x18\x04 \x01(\x0b\x32(.bilibili.app.dynamic.v2.ThreePointShareH\x00\x12\x41\n\tattention\x18\x05 \x01(\x0b\x32,.bilibili.app.dynamic.v2.ThreePointAttentionH\x00\x12\x37\n\x04wait\x18\x06 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointWaitH\x00\x12=\n\x07\x64islike\x18\x07 \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointDislikeH\x00\x12?\n\x08\x66\x61vorite\x18\x08 \x01(\x0b\x32+.bilibili.app.dynamic.v2.ThreePointFavoriteH\x00\x12\x35\n\x03top\x18\t \x01(\x0b\x32&.bilibili.app.dynamic.v2.ThreePointTopH\x00\x12=\n\x07\x63omment\x18\n \x01(\x0b\x32*.bilibili.app.dynamic.v2.ThreePointCommentH\x00\x12\x37\n\x04hide\x18\x0b \x01(\x0b\x32\'.bilibili.app.dynamic.v2.ThreePointHideH\x00\x12N\n\x10topic_irrelevant\x18\x0c \x01(\x0b\x32\x32.bilibili.app.dynamic.v2.ThreePointTopicIrrelevantH\x00\x42\x06\n\x04item\"\xbe\x01\n\x0fThreePointShare\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12@\n\x07\x63hannel\x18\x03 \x03(\x0b\x32/.bilibili.app.dynamic.v2.ThreePointShareChannel\x12\x14\n\x0c\x63hannel_name\x18\x04 \x01(\t\x12\x36\n\x07reserve\x18\x05 \x01(\x0b\x32%.bilibili.app.dynamic.v2.ShareReserve\"5\n\x16ThreePointShareChannel\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\\\n\rThreePointTop\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .bilibili.app.dynamic.v2.TopType\"\x8b\x01\n\x19ThreePointTopicIrrelevant\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05toast\x18\x03 \x01(\t\x12\x10\n\x08topic_id\x18\x04 \x01(\x03\x12\x0e\n\x06res_id\x18\x05 \x01(\x03\x12\x10\n\x08res_type\x18\x06 \x01(\x03\x12\x0e\n\x06reason\x18\x07 \x01(\t\"~\n\x0eThreePointWait\x12\x15\n\raddition_icon\x18\x01 \x01(\t\x12\x15\n\raddition_text\x18\x02 \x01(\t\x12\x18\n\x10no_addition_icon\x18\x03 \x01(\t\x12\x18\n\x10no_addition_text\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\"R\n\rTopAdditionUP\x12/\n\x02up\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v2.AdditionUP\x12\x10\n\x08has_fold\x18\x02 \x01(\x05\"M\n\x0bTopicButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x10\n\x08jump_uri\x18\x03 \x01(\t\x12\x0f\n\x07red_dot\x18\x04 \x01(\x08\"n\n\tTopicItem\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x05 \x01(\t\x12\x11\n\trcmd_desc\x18\x06 \x01(\t\"\xe5\x01\n\tTopicList\x12\r\n\x05title\x18\x01 \x01(\t\x12?\n\x0ftopic_list_item\x18\x02 \x03(\x0b\x32&.bilibili.app.dynamic.v2.TopicListItem\x12\x38\n\nact_button\x18\x03 \x01(\x0b\x32$.bilibili.app.dynamic.v2.TopicButton\x12\x39\n\x0bmore_button\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.TopicButton\x12\x13\n\x0bserver_info\x18\x05 \x01(\t\"\xd7\x01\n\rTopicListItem\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_title\x18\x02 \x01(\t\x12\x10\n\x08topic_id\x18\x03 \x01(\x03\x12\x12\n\ntopic_name\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x0b\n\x03pos\x18\x06 \x01(\x03\x12\x13\n\x0bserver_info\x18\x07 \x01(\t\x12\x15\n\rhead_icon_url\x18\x08 \x01(\t\x12\x0e\n\x06up_mid\x18\t \x01(\x03\x12\x15\n\rtail_icon_url\x18\n \x01(\t\x12\x11\n\textension\x18\x0b \x01(\t\"e\n\x0eTopicListReply\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.dynamic.v2.TopicItem\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\x03 \x01(\t\"1\n\x0cTopicListReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\"\xab\x01\n\rTopicRcmdCard\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x34\n\x06\x62utton\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\r\n\x05\x64\x65sc1\x18\x05 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x06 \x01(\t\x12\x13\n\x0bupdate_desc\x18\x07 \x01(\t\"\x8c\x01\n\x0fTopicSquareInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x34\n\x06\x62utton\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.CampusLabel\x12\x34\n\x04rcmd\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.TopicRcmdCard\"J\n\x10TopicSquareReply\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.bilibili.app.dynamic.v2.TopicSquareInfo\"#\n\x0eTopicSquareReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\"c\n\x08Unfollow\x12\r\n\x05title\x18\x01 \x01(\t\x12\x37\n\x04list\x18\x02 \x03(\x0b\x32).bilibili.app.dynamic.v2.UnfollowUserItem\x12\x0f\n\x07TrackId\x18\x03 \x01(\t\"\xe3\x02\n\x10UnfollowUserItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x05\x12\x36\n\nlive_state\x18\x06 \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12\x0c\n\x04sign\x18\t \x01(\t\x12\r\n\x05label\x18\n \x01(\t\x12\x39\n\x06\x62utton\x18\x0b \x01(\x0b\x32).bilibili.app.dynamic.v2.AdditionalButton\x12\x0b\n\x03uri\x18\x0c \x01(\t\"\x9a\x03\n\nUpListItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x03\x12=\n\x0euser_item_type\x18\x06 \x01(\x0e\x32%.bilibili.app.dynamic.v2.UserItemType\x12\x41\n\x11\x64isplay_style_day\x18\x07 \x01(\x0b\x32&.bilibili.app.dynamic.v2.UserItemStyle\x12\x43\n\x13\x64isplay_style_night\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v2.UserItemStyle\x12\x10\n\x08style_id\x18\t \x01(\x03\x12\x36\n\nlive_state\x18\n \x01(\x0e\x32\".bilibili.app.dynamic.v2.LiveState\x12\x11\n\tseparator\x18\x0b \x01(\x08\x12\x0b\n\x03uri\x18\x0c \x01(\t\x12\x11\n\tis_recall\x18\r \x01(\x08\"-\n\x0fUpListMoreLabel\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\x8e\x03\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x39\n\x08official\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v2.OfficialVerify\x12-\n\x03vip\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v2.VipInfo\x12/\n\x04live\x18\x06 \x01(\x0b\x32!.bilibili.app.dynamic.v2.LiveInfo\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x35\n\x07pendant\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v2.UserPendant\x12\x35\n\tnameplate\x18\t \x01(\x0b\x32\".bilibili.app.dynamic.v2.Nameplate\x12\r\n\x05level\x18\n \x01(\x05\x12\x0c\n\x04sign\x18\x0b \x01(\t\x12\x10\n\x08\x66\x61\x63\x65_nft\x18\x0c \x01(\x05\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\r \x01(\x05\"~\n\rUserItemStyle\x12\x11\n\trect_text\x18\x01 \x01(\t\x12\x17\n\x0frect_text_color\x18\x02 \x01(\t\x12\x11\n\trect_icon\x18\x03 \x01(\t\x12\x15\n\rrect_bg_color\x18\x04 \x01(\t\x12\x17\n\x0fouter_animation\x18\x05 \x01(\t\"G\n\x0bUserPendant\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"\xe0\x01\n\nVideoBadge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x12\x10\n\x08\x62g_alpha\x18\t \x01(\x05\x12\x16\n\x0e\x62g_alpha_night\x18\n \x01(\x05\"\xb1\x01\n\x07VipInfo\x12\x0c\n\x04Type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x30\n\x05label\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v2.VipLabel\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x18\n\x10\x61vatar_subscript\x18\x06 \x01(\x05\x12\x16\n\x0enickname_color\x18\x07 \x01(\t\";\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0blabel_theme\x18\x03 \x01(\t\"Y\n\x06Weight\x12\r\n\x05title\x18\x01 \x01(\t\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.bilibili.app.dynamic.v2.WeightItem\x12\x0c\n\x04icon\x18\x03 \x01(\t\"/\n\x0cWeightButton\x12\x10\n\x08jump_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"6\n\rWeightDislike\x12\x16\n\x0e\x66\x65\x65\x64_back_type\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\xbb\x01\n\nWeightItem\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.bilibili.app.dynamic.v2.WeightType\x12\x37\n\x06\x62utton\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v2.WeightButtonH\x00\x12\x39\n\x07\x64islike\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.WeightDislikeH\x00\x42\x06\n\x04item*2\n\x10\x41\x64\x64\x42uttonBgStyle\x12\x08\n\x04\x66ill\x10\x00\x12\n\n\x06stroke\x10\x01\x12\x08\n\x04gray\x10\x02*8\n\rAddButtonType\x12\x0b\n\x07\x62t_none\x10\x00\x12\x0b\n\x07\x62t_jump\x10\x01\x12\r\n\tbt_button\x10\x02*n\n\x11\x41\x64\x64itionVoteState\x12\x1c\n\x18\x61\x64\x64ition_vote_state_none\x10\x00\x12\x1c\n\x18\x61\x64\x64ition_vote_state_open\x10\x01\x12\x1d\n\x19\x61\x64\x64ition_vote_state_close\x10\x02*\x88\x01\n\x10\x41\x64\x64itionVoteType\x12\x1b\n\x17\x61\x64\x64ition_vote_type_none\x10\x00\x12\x1b\n\x17\x61\x64\x64ition_vote_type_word\x10\x01\x12\x1a\n\x16\x61\x64\x64ition_vote_type_pic\x10\x02\x12\x1e\n\x1a\x61\x64\x64ition_vote_type_default\x10\x03*9\n\x19\x41\x64\x64itionalButtonClickType\x12\x0e\n\nclick_none\x10\x00\x12\x0c\n\x08\x63lick_up\x10\x01*:\n\x16\x41\x64\x64itionalButtonStatus\x12\x08\n\x04none\x10\x00\x12\x0b\n\x07uncheck\x10\x01\x12\t\n\x05\x63heck\x10\x02*3\n\x17\x41\x64\x64itionalShareShowType\x12\x0b\n\x07st_none\x10\x00\x12\x0b\n\x07st_show\x10\x01*\x85\x02\n\x0e\x41\x64\x64itionalType\x12\x13\n\x0f\x61\x64\x64itional_none\x10\x00\x12\x17\n\x13\x61\x64\x64itional_type_pgc\x10\x01\x12\x19\n\x15\x61\x64\x64itional_type_goods\x10\x02\x12\x18\n\x14\x61\x64\x64itional_type_vote\x10\x03\x12\x1a\n\x16\x61\x64\x64itional_type_common\x10\x04\x12\x1a\n\x16\x61\x64\x64itional_type_esport\x10\x05\x12\x1b\n\x17\x61\x64\x64itional_type_up_rcmd\x10\x06\x12\x17\n\x13\x61\x64\x64itional_type_ugc\x10\x07\x12\"\n\x1e\x61\x64\x64itional_type_up_reservation\x10\x08*\x83\x01\n\rCampusTabType\x12\x0f\n\x0b\x63\x61mpus_none\x10\x00\x12\x11\n\rcampus_school\x10\x01\x12\x12\n\x0e\x63\x61mpus_dynamic\x10\x02\x12\x12\n\x0e\x63\x61mpus_account\x10\x03\x12\x14\n\x10\x63\x61mpus_billboard\x10\x04\x12\x10\n\x0c\x63\x61mpus_topic\x10\x05*5\n\tCoverIcon\x12\x13\n\x0f\x63over_icon_none\x10\x00\x12\x13\n\x0f\x63over_icon_play\x10\x01*\x94\x03\n\x08\x44\x65scType\x12\x12\n\x0e\x64\x65sc_type_none\x10\x00\x12\x12\n\x0e\x64\x65sc_type_text\x10\x01\x12\x12\n\x0e\x64\x65sc_type_aite\x10\x02\x12\x15\n\x11\x64\x65sc_type_lottery\x10\x03\x12\x12\n\x0e\x64\x65sc_type_vote\x10\x04\x12\x13\n\x0f\x64\x65sc_type_topic\x10\x05\x12\x13\n\x0f\x64\x65sc_type_goods\x10\x06\x12\x10\n\x0c\x64\x65sc_type_bv\x10\x07\x12\x10\n\x0c\x64\x65sc_type_av\x10\x08\x12\x13\n\x0f\x64\x65sc_type_emoji\x10\t\x12\x12\n\x0e\x64\x65sc_type_user\x10\n\x12\x10\n\x0c\x64\x65sc_type_cv\x10\x0b\x12\x10\n\x0c\x64\x65sc_type_vc\x10\x0c\x12\x11\n\rdesc_type_web\x10\r\x12\x14\n\x10\x64\x65sc_type_taobao\x10\x0e\x12\x12\n\x0e\x64\x65sc_type_mail\x10\x0f\x12\x18\n\x14\x64\x65sc_type_ogv_season\x10\x10\x12\x14\n\x10\x64\x65sc_type_ogv_ep\x10\x11\x12\x19\n\x15\x64\x65sc_type_search_word\x10\x12*\'\n\x0c\x44isableState\x12\r\n\thighlight\x10\x00\x12\x08\n\x04gary\x10\x01*\xe5\x01\n\rDynExtendType\x12\x15\n\x11\x64yn_ext_type_none\x10\x00\x12\x16\n\x12\x64yn_ext_type_topic\x10\x01\x12\x14\n\x10\x64yn_ext_type_lbs\x10\x02\x12\x14\n\x10\x64yn_ext_type_hot\x10\x03\x12\x15\n\x11\x64yn_ext_type_game\x10\x04\x12\x17\n\x13\x64yn_ext_type_common\x10\x05\x12\x18\n\x14\x64yn_ext_type_biliCut\x10\x06\x12\x14\n\x10\x64yn_ext_type_ogv\x10\x07\x12\x19\n\x15\x64yn_ext_type_auto_ogv\x10\x08*\xc9\x04\n\rDynModuleType\x12\x0f\n\x0bmodule_none\x10\x00\x12\x11\n\rmodule_author\x10\x01\x12\x12\n\x0emodule_dispute\x10\x02\x12\x0f\n\x0bmodule_desc\x10\x03\x12\x12\n\x0emodule_dynamic\x10\x04\x12\x12\n\x0emodule_forward\x10\x05\x12\x13\n\x0fmodule_likeUser\x10\x06\x12\x11\n\rmodule_extend\x10\x07\x12\x15\n\x11module_additional\x10\x08\x12\x0f\n\x0bmodule_stat\x10\t\x12\x0f\n\x0bmodule_fold\x10\n\x12\x12\n\x0emodule_comment\x10\x0b\x12\x16\n\x12module_interaction\x10\x0c\x12\x19\n\x15module_author_forward\x10\r\x12\r\n\tmodule_ad\x10\x0e\x12\x11\n\rmodule_banner\x10\x0f\x12\x14\n\x10module_item_null\x10\x10\x12\x15\n\x11module_share_info\x10\x11\x12\x14\n\x10module_recommend\x10\x12\x12\x17\n\x13module_stat_forward\x10\x13\x12\x0e\n\nmodule_top\x10\x14\x12\x11\n\rmodule_bottom\x10\x15\x12\x10\n\x0cmodule_story\x10\x16\x12\x10\n\x0cmodule_topic\x10\x17\x12\x1c\n\x18module_topic_details_ext\x10\x18\x12\x12\n\x0emodule_top_tag\x10\x19\x12\x16\n\x12module_topic_brief\x10\x1a\x12\x10\n\x0cmodule_title\x10\x1b*U\n\nDynUriType\x12\x15\n\x11\x64yn_uri_type_none\x10\x00\x12\x17\n\x13\x64yn_uri_type_direct\x10\x01\x12\x17\n\x13\x64yn_uri_type_suffix\x10\x02*\xd3\x02\n\x0b\x44ynamicType\x12\x0c\n\x08\x64yn_none\x10\x00\x12\x0b\n\x07\x66orward\x10\x01\x12\x06\n\x02\x61v\x10\x02\x12\x07\n\x03pgc\x10\x03\x12\x0b\n\x07\x63ourses\x10\x04\x12\x08\n\x04\x66old\x10\x05\x12\x08\n\x04word\x10\x06\x12\x08\n\x04\x64raw\x10\x07\x12\x0b\n\x07\x61rticle\x10\x08\x12\t\n\x05music\x10\t\x12\x11\n\rcommon_square\x10\n\x12\x13\n\x0f\x63ommon_vertical\x10\x0b\x12\x08\n\x04live\x10\x0c\x12\r\n\tmedialist\x10\r\x12\x12\n\x0e\x63ourses_season\x10\x0e\x12\x06\n\x02\x61\x64\x10\x0f\x12\n\n\x06\x61pplet\x10\x10\x12\x10\n\x0csubscription\x10\x11\x12\r\n\tlive_rcmd\x10\x12\x12\n\n\x06\x62\x61nner\x10\x13\x12\x0e\n\nugc_season\x10\x14\x12\x14\n\x10subscription_new\x10\x15\x12\t\n\x05story\x10\x16\x12\x0e\n\ntopic_rcmd\x10\x17*B\n\tEmojiType\x12\x0e\n\nemoji_none\x10\x00\x12\r\n\temoji_old\x10\x01\x12\r\n\temoji_new\x10\x02\x12\x07\n\x03vip\x10\x03*\x17\n\x0b\x45spaceStyle\x12\x08\n\x04moba\x10\x00*m\n\x08\x46oldType\x12\x10\n\x0c\x46oldTypeZore\x10\x00\x12\x13\n\x0f\x46oldTypePublish\x10\x01\x12\x14\n\x10\x46oldTypeFrequent\x10\x02\x12\x11\n\rFoldTypeUnite\x10\x03\x12\x11\n\rFoldTypeLimit\x10\x04*.\n\nFollowType\x12\x11\n\rft_not_follow\x10\x00\x12\r\n\tft_follow\x10\x01*9\n\x12HighlightTextStyle\x12\x0e\n\nstyle_none\x10\x00\x12\x13\n\x0fstyle_highlight\x10\x01*:\n\nImageStyle\x12\x16\n\x12\x61\x64\x64_style_vertical\x10\x00\x12\x14\n\x10\x61\x64\x64_style_square\x10\x01*1\n\rLightFromType\x12\x0e\n\nfrom_login\x10\x00\x12\x10\n\x0c\x66rom_unlogin\x10\x01*<\n\tLiveState\x12\r\n\tlive_none\x10\x00\x12\r\n\tlive_live\x10\x01\x12\x11\n\rlive_rotation\x10\x02*<\n\rLocalIconType\x12\x16\n\x12local_icon_comment\x10\x00\x12\x13\n\x0flocal_icon_like\x10\x01*b\n\x10MdlDynCommonType\x12\x17\n\x13mdl_dyn_common_none\x10\x00\x12\x19\n\x15mdl_dyn_common_square\x10\x01\x12\x1a\n\x16mdl_dyn_common_vertica\x10\x02*\xa0\x01\n\x11MdlDynDrawTagType\x12\x15\n\x11mdl_draw_tag_none\x10\x00\x12\x17\n\x13mdl_draw_tag_common\x10\x01\x12\x16\n\x12mdl_draw_tag_goods\x10\x02\x12\x15\n\x11mdl_draw_tag_user\x10\x03\x12\x16\n\x12mdl_draw_tag_topic\x10\x04\x12\x14\n\x10mdl_draw_tag_lbs\x10\x05*\x97\x01\n\x1aMdlDynSubscriptionNewStyle\x12\'\n#mdl_dyn_subscription_new_style_nont\x10\x00\x12\'\n#mdl_dyn_subscription_new_style_live\x10\x01\x12\'\n#mdl_dyn_subscription_new_style_draw\x10\x02*g\n\tMediaType\x12\x11\n\rMediaTypeNone\x10\x00\x12\x10\n\x0cMediaTypeUGC\x10\x01\x12\x10\n\x0cMediaTypePGC\x10\x02\x12\x11\n\rMediaTypeLive\x10\x03\x12\x10\n\x0cMediaTypeVCS\x10\x04*\xad\x01\n\x15ModuleAuthorBadgeType\x12!\n\x1dmodule_author_badge_type_none\x10\x00\x12\'\n#module_author_badge_type_threePoint\x10\x01\x12#\n\x1fmodule_author_badge_type_button\x10\x02\x12#\n\x1fmodule_author_badge_type_weight\x10\x03*L\n\x10ModuleBannerType\x12\x1b\n\x17module_banner_type_none\x10\x00\x12\x1b\n\x17module_banner_type_user\x10\x01*\xf1\x02\n\x11ModuleDynamicType\x12\x13\n\x0fmdl_dyn_archive\x10\x00\x12\x0f\n\x0bmdl_dyn_pgc\x10\x01\x12\x17\n\x13mdl_dyn_cour_season\x10\x02\x12\x16\n\x12mdl_dyn_cour_batch\x10\x03\x12\x13\n\x0fmdl_dyn_forward\x10\x04\x12\x10\n\x0cmdl_dyn_draw\x10\x05\x12\x13\n\x0fmdl_dyn_article\x10\x06\x12\x11\n\rmdl_dyn_music\x10\x07\x12\x12\n\x0emdl_dyn_common\x10\x08\x12\x10\n\x0cmdl_dyn_live\x10\t\x12\x15\n\x11mdl_dyn_medialist\x10\n\x12\x12\n\x0emdl_dyn_applet\x10\x0b\x12\x18\n\x14mdl_dyn_subscription\x10\x0c\x12\x15\n\x11mdl_dyn_live_rcmd\x10\r\x12\x16\n\x12mdl_dyn_ugc_season\x10\x0e\x12\x1c\n\x18mdl_dyn_subscription_new\x10\x0f*^\n\x0bNetworkType\x12\x0e\n\nNT_UNKNOWN\x10\x00\x12\x08\n\x04WIFI\x10\x01\x12\x0c\n\x08\x43\x45LLULAR\x10\x02\x12\x0b\n\x07OFFLINE\x10\x03\x12\x0c\n\x08OTHERNET\x10\x04\x12\x0c\n\x08\x45THERNET\x10\x05*.\n\x08RcmdType\x12\x10\n\x0crcmd_archive\x10\x00\x12\x10\n\x0crcmd_dynamic\x10\x01*/\n\x07Refresh\x12\x0f\n\x0brefresh_new\x10\x00\x12\x13\n\x0frefresh_history\x10\x01*\xc3\x01\n\x0eRelationStatus\x12\x18\n\x14relation_status_none\x10\x00\x12\x1c\n\x18relation_status_nofollow\x10\x01\x12\x1a\n\x16relation_status_follow\x10\x02\x12\x1c\n\x18relation_status_followed\x10\x03\x12\"\n\x1erelation_status_mutual_concern\x10\x04\x12\x1b\n\x17relation_status_special\x10\x05*0\n\nRepostType\x12\x0e\n\nrepost_hot\x10\x00\x12\x12\n\x0erepost_general\x10\x01*o\n\x1aReserveRelationLotteryType\x12)\n%reserve_relation_lottery_type_default\x10\x00\x12&\n\"reserve_relation_lottery_type_cron\x10\x01*3\n\x0bReserveType\x12\x10\n\x0creserve_none\x10\x00\x12\x12\n\x0ereserve_recall\x10\x01*4\n\x08ShowType\x12\x12\n\x0eshow_type_none\x10\x00\x12\x14\n\x10show_type_backup\x10\x01*L\n\tStyleType\x12\x13\n\x0fSTYLE_TYPE_NONE\x10\x00\x12\x13\n\x0fSTYLE_TYPE_LIVE\x10\x01\x12\x15\n\x11STYLE_TYPE_DYN_UP\x10\x02*M\n\x06TFType\x12\n\n\x06U_CARD\x10\x00\x12\t\n\x05U_PKG\x10\x01\x12\n\n\x06\x43_CARD\x10\x02\x12\t\n\x05\x43_PKG\x10\x03\x12\n\n\x06T_CARD\x10\x04\x12\t\n\x05T_PKG\x10\x05*C\n\x19ThreePointAttentionStatus\x12\x14\n\x10tp_not_attention\x10\x00\x12\x10\n\x0ctp_attention\x10\x01*\xdc\x01\n\x0eThreePointType\x12\x0b\n\x07tp_none\x10\x00\x12\x0e\n\nbackground\x10\x01\x12\r\n\tauto_play\x10\x02\x12\t\n\x05share\x10\x03\x12\x08\n\x04wait\x10\x04\x12\r\n\tattention\x10\x05\x12\n\n\x06report\x10\x06\x12\n\n\x06\x64\x65lete\x10\x07\x12\x0b\n\x07\x64islike\x10\x08\x12\x0c\n\x08\x66\x61vorite\x10\t\x12\x07\n\x03top\x10\n\x12\x0b\n\x07\x63omment\x10\x0b\x12\x08\n\x04hide\x10\x0c\x12\x11\n\rcampus_delete\x10\r\x12\x14\n\x10topic_irrelevant\x10\x0e*\"\n\tThumbType\x12\n\n\x06\x63\x61ncel\x10\x00\x12\t\n\x05thumb\x10\x01*\'\n\x07TopType\x12\x0c\n\x08top_none\x10\x00\x12\x0e\n\ntop_cancel\x10\x01*\x96\x01\n\x0cUserItemType\x12\x17\n\x13user_item_type_none\x10\x00\x12\x17\n\x13user_item_type_live\x10\x01\x12\x1e\n\x1auser_item_type_live_custom\x10\x02\x12\x19\n\x15user_item_type_normal\x10\x03\x12\x19\n\x15user_item_type_extend\x10\x04*\xa5\x01\n\x0cVideoSubType\x12\x14\n\x10VideoSubTypeNone\x10\x00\x12\x17\n\x13VideoSubTypeBangumi\x10\x01\x12\x15\n\x11VideoSubTypeMovie\x10\x02\x12\x1b\n\x17VideoSubTypeDocumentary\x10\x03\x12\x18\n\x14VideoSubTypeDomestic\x10\x04\x12\x18\n\x14VideoSubTypeTeleplay\x10\x05*j\n\tVideoType\x12\x16\n\x12video_type_general\x10\x00\x12\x16\n\x12video_type_dynamic\x10\x01\x12\x17\n\x13video_type_playback\x10\x02\x12\x14\n\x10video_type_story\x10\x03*\'\n\nVoteStatus\x12\n\n\x06normal\x10\x00\x12\r\n\tanonymous\x10\x01*B\n\nWeightType\x12\x0f\n\x0bweight_none\x10\x00\x12\x12\n\x0eweight_dislike\x10\x01\x12\x0f\n\x0bweight_jump\x10\x02\x32\x91!\n\x07\x44ynamic\x12X\n\x08\x44ynVideo\x12$.bilibili.app.dynamic.v2.DynVideoReq\x1a&.bilibili.app.dynamic.v2.DynVideoReply\x12R\n\x06\x44ynAll\x12\".bilibili.app.dynamic.v2.DynAllReq\x1a$.bilibili.app.dynamic.v2.DynAllReply\x12^\n\nDynDetails\x12&.bilibili.app.dynamic.v2.DynDetailsReq\x1a(.bilibili.app.dynamic.v2.DynDetailsReply\x12p\n\x10\x44ynVideoPersonal\x12,.bilibili.app.dynamic.v2.DynVideoPersonalReq\x1a..bilibili.app.dynamic.v2.DynVideoPersonalReply\x12\x64\n\x11\x44ynVideoUpdOffset\x12-.bilibili.app.dynamic.v2.DynVideoUpdOffsetReq\x1a .bilibili.app.dynamic.v2.NoReply\x12\x85\x01\n\x17\x44ynAdditionCommonFollow\x12\x33.bilibili.app.dynamic.v2.DynAdditionCommonFollowReq\x1a\x35.bilibili.app.dynamic.v2.DynAdditionCommonFollowReply\x12R\n\x08\x44ynThumb\x12$.bilibili.app.dynamic.v2.DynThumbReq\x1a .bilibili.app.dynamic.v2.NoReply\x12\x61\n\x0b\x44ynFakeCard\x12\'.bilibili.app.dynamic.v2.DynFakeCardReq\x1a).bilibili.app.dynamic.v2.DynFakeCardReply\x12s\n\x11\x44ynRcmdUpExchange\x12-.bilibili.app.dynamic.v2.DynRcmdUpExchangeReq\x1a/.bilibili.app.dynamic.v2.DynRcmdUpExchangeReply\x12j\n\x0e\x44ynAllPersonal\x12*.bilibili.app.dynamic.v2.DynAllPersonalReq\x1a,.bilibili.app.dynamic.v2.DynAllPersonalReply\x12`\n\x0f\x44ynAllUpdOffset\x12+.bilibili.app.dynamic.v2.DynAllUpdOffsetReq\x1a .bilibili.app.dynamic.v2.NoReply\x12U\n\x07\x44ynVote\x12#.bilibili.app.dynamic.v2.DynVoteReq\x1a%.bilibili.app.dynamic.v2.DynVoteReply\x12|\n\x14\x44ynMixUpListViewMore\x12\x30.bilibili.app.dynamic.v2.DynMixUpListViewMoreReq\x1a\x32.bilibili.app.dynamic.v2.DynMixUpListViewMoreReply\x12X\n\x08\x44ynLight\x12$.bilibili.app.dynamic.v2.DynLightReq\x1a&.bilibili.app.dynamic.v2.DynLightReply\x12[\n\tDynDetail\x12%.bilibili.app.dynamic.v2.DynDetailReq\x1a\'.bilibili.app.dynamic.v2.DynDetailReply\x12X\n\x08LikeList\x12$.bilibili.app.dynamic.v2.LikeListReq\x1a&.bilibili.app.dynamic.v2.LikeListReply\x12\\\n\nRepostList\x12&.bilibili.app.dynamic.v2.RepostListReq\x1a&.bilibili.app.dynamic.v2.RepostListRsp\x12V\n\x08\x44ynSpace\x12$.bilibili.app.dynamic.v2.DynSpaceReq\x1a$.bilibili.app.dynamic.v2.DynSpaceRsp\x12\\\n\x0e\x44ynUnLoginRcmd\x12#.bilibili.app.dynamic.v2.DynRcmdReq\x1a%.bilibili.app.dynamic.v2.DynRcmdReply\x12p\n\x10\x44ynServerDetails\x12,.bilibili.app.dynamic.v2.DynServerDetailsReq\x1a..bilibili.app.dynamic.v2.DynServerDetailsReply\x12[\n\tDynSearch\x12%.bilibili.app.dynamic.v2.DynSearchReq\x1a\'.bilibili.app.dynamic.v2.DynSearchReply\x12X\n\x0bSetDecision\x12\'.bilibili.app.dynamic.v2.SetDecisionReq\x1a .bilibili.app.dynamic.v2.NoReply\x12j\n\x0e\x41lumniDynamics\x12*.bilibili.app.dynamic.v2.AlumniDynamicsReq\x1a,.bilibili.app.dynamic.v2.AlumniDynamicsReply\x12^\n\nCampusRcmd\x12&.bilibili.app.dynamic.v2.CampusRcmdReq\x1a(.bilibili.app.dynamic.v2.CampusRcmdReply\x12`\n\x0fSubscribeCampus\x12+.bilibili.app.dynamic.v2.SubscribeCampusReq\x1a .bilibili.app.dynamic.v2.NoReply\x12`\n\x0fSetRecentCampus\x12+.bilibili.app.dynamic.v2.SetRecentCampusReq\x1a .bilibili.app.dynamic.v2.NoReply\x12R\n\x06\x44ynTab\x12\".bilibili.app.dynamic.v2.DynTabReq\x1a$.bilibili.app.dynamic.v2.DynTabReply\x12\x64\n\x0cSchoolSearch\x12(.bilibili.app.dynamic.v2.SchoolSearchReq\x1a*.bilibili.app.dynamic.v2.SchoolSearchReply\x12m\n\x0fSchoolRecommend\x12+.bilibili.app.dynamic.v2.SchoolRecommendReq\x1a-.bilibili.app.dynamic.v2.SchoolRecommendReply\x12\x7f\n\x15\x44ynSpaceSearchDetails\x12\x31.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReq\x1a\x33.bilibili.app.dynamic.v2.DynSpaceSearchDetailsReply\x12p\n\x10OfficialAccounts\x12,.bilibili.app.dynamic.v2.OfficialAccountsReq\x1a..bilibili.app.dynamic.v2.OfficialAccountsReply\x12p\n\x10OfficialDynamics\x12,.bilibili.app.dynamic.v2.OfficialDynamicsReq\x1a..bilibili.app.dynamic.v2.OfficialDynamicsReply\x12\x64\n\x0c\x43\x61mpusRedDot\x12(.bilibili.app.dynamic.v2.CampusRedDotReq\x1a*.bilibili.app.dynamic.v2.CampusRedDotReply\x12j\n\x0e\x43\x61mpusRcmdFeed\x12*.bilibili.app.dynamic.v2.CampusRcmdFeedReq\x1a,.bilibili.app.dynamic.v2.CampusRcmdFeedReply\x12\x61\n\x0bTopicSquare\x12\'.bilibili.app.dynamic.v2.TopicSquareReq\x1a).bilibili.app.dynamic.v2.TopicSquareReply\x12[\n\tTopicList\x12%.bilibili.app.dynamic.v2.TopicListReq\x1a\'.bilibili.app.dynamic.v2.TopicListReply\x12v\n\x12\x43\x61mpusMateLikeList\x12..bilibili.app.dynamic.v2.CampusMateLikeListReq\x1a\x30.bilibili.app.dynamic.v2.CampusMateLikeListReply\x12j\n\x0e\x43\x61mpusFeedback\x12*.bilibili.app.dynamic.v2.CampusFeedbackReq\x1a,.bilibili.app.dynamic.v2.CampusFeedbackReply\x12m\n\x0f\x43\x61mpusBillboard\x12+.bilibili.app.dynamic.v2.CampusBillBoardReq\x1a-.bilibili.app.dynamic.v2.CampusBillBoardReply\x12}\n\x17\x43\x61mpusBillboardInternal\x12\x33.bilibili.app.dynamic.v2.CampusBillboardInternalReq\x1a-.bilibili.app.dynamic.v2.CampusBillBoardReply\x12y\n\x13\x43\x61mpusTopicRcmdFeed\x12/.bilibili.app.dynamic.v2.CampusTopicRcmdFeedReq\x1a\x31.bilibili.app.dynamic.v2.CampusTopicRcmdFeedReplyb\x06proto3')

_ADDBUTTONBGSTYLE = DESCRIPTOR.enum_types_by_name['AddButtonBgStyle']
AddButtonBgStyle = enum_type_wrapper.EnumTypeWrapper(_ADDBUTTONBGSTYLE)
_ADDBUTTONTYPE = DESCRIPTOR.enum_types_by_name['AddButtonType']
AddButtonType = enum_type_wrapper.EnumTypeWrapper(_ADDBUTTONTYPE)
_ADDITIONVOTESTATE = DESCRIPTOR.enum_types_by_name['AdditionVoteState']
AdditionVoteState = enum_type_wrapper.EnumTypeWrapper(_ADDITIONVOTESTATE)
_ADDITIONVOTETYPE = DESCRIPTOR.enum_types_by_name['AdditionVoteType']
AdditionVoteType = enum_type_wrapper.EnumTypeWrapper(_ADDITIONVOTETYPE)
_ADDITIONALBUTTONCLICKTYPE = DESCRIPTOR.enum_types_by_name['AdditionalButtonClickType']
AdditionalButtonClickType = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALBUTTONCLICKTYPE)
_ADDITIONALBUTTONSTATUS = DESCRIPTOR.enum_types_by_name['AdditionalButtonStatus']
AdditionalButtonStatus = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALBUTTONSTATUS)
_ADDITIONALSHARESHOWTYPE = DESCRIPTOR.enum_types_by_name['AdditionalShareShowType']
AdditionalShareShowType = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALSHARESHOWTYPE)
_ADDITIONALTYPE = DESCRIPTOR.enum_types_by_name['AdditionalType']
AdditionalType = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALTYPE)
_CAMPUSTABTYPE = DESCRIPTOR.enum_types_by_name['CampusTabType']
CampusTabType = enum_type_wrapper.EnumTypeWrapper(_CAMPUSTABTYPE)
_COVERICON = DESCRIPTOR.enum_types_by_name['CoverIcon']
CoverIcon = enum_type_wrapper.EnumTypeWrapper(_COVERICON)
_DESCTYPE = DESCRIPTOR.enum_types_by_name['DescType']
DescType = enum_type_wrapper.EnumTypeWrapper(_DESCTYPE)
_DISABLESTATE = DESCRIPTOR.enum_types_by_name['DisableState']
DisableState = enum_type_wrapper.EnumTypeWrapper(_DISABLESTATE)
_DYNEXTENDTYPE = DESCRIPTOR.enum_types_by_name['DynExtendType']
DynExtendType = enum_type_wrapper.EnumTypeWrapper(_DYNEXTENDTYPE)
_DYNMODULETYPE = DESCRIPTOR.enum_types_by_name['DynModuleType']
DynModuleType = enum_type_wrapper.EnumTypeWrapper(_DYNMODULETYPE)
_DYNURITYPE = DESCRIPTOR.enum_types_by_name['DynUriType']
DynUriType = enum_type_wrapper.EnumTypeWrapper(_DYNURITYPE)
_DYNAMICTYPE = DESCRIPTOR.enum_types_by_name['DynamicType']
DynamicType = enum_type_wrapper.EnumTypeWrapper(_DYNAMICTYPE)
_EMOJITYPE = DESCRIPTOR.enum_types_by_name['EmojiType']
EmojiType = enum_type_wrapper.EnumTypeWrapper(_EMOJITYPE)
_ESPACESTYLE = DESCRIPTOR.enum_types_by_name['EspaceStyle']
EspaceStyle = enum_type_wrapper.EnumTypeWrapper(_ESPACESTYLE)
_FOLDTYPE = DESCRIPTOR.enum_types_by_name['FoldType']
FoldType = enum_type_wrapper.EnumTypeWrapper(_FOLDTYPE)
_FOLLOWTYPE = DESCRIPTOR.enum_types_by_name['FollowType']
FollowType = enum_type_wrapper.EnumTypeWrapper(_FOLLOWTYPE)
_HIGHLIGHTTEXTSTYLE = DESCRIPTOR.enum_types_by_name['HighlightTextStyle']
HighlightTextStyle = enum_type_wrapper.EnumTypeWrapper(_HIGHLIGHTTEXTSTYLE)
_IMAGESTYLE = DESCRIPTOR.enum_types_by_name['ImageStyle']
ImageStyle = enum_type_wrapper.EnumTypeWrapper(_IMAGESTYLE)
_LIGHTFROMTYPE = DESCRIPTOR.enum_types_by_name['LightFromType']
LightFromType = enum_type_wrapper.EnumTypeWrapper(_LIGHTFROMTYPE)
_LIVESTATE = DESCRIPTOR.enum_types_by_name['LiveState']
LiveState = enum_type_wrapper.EnumTypeWrapper(_LIVESTATE)
_LOCALICONTYPE = DESCRIPTOR.enum_types_by_name['LocalIconType']
LocalIconType = enum_type_wrapper.EnumTypeWrapper(_LOCALICONTYPE)
_MDLDYNCOMMONTYPE = DESCRIPTOR.enum_types_by_name['MdlDynCommonType']
MdlDynCommonType = enum_type_wrapper.EnumTypeWrapper(_MDLDYNCOMMONTYPE)
_MDLDYNDRAWTAGTYPE = DESCRIPTOR.enum_types_by_name['MdlDynDrawTagType']
MdlDynDrawTagType = enum_type_wrapper.EnumTypeWrapper(_MDLDYNDRAWTAGTYPE)
_MDLDYNSUBSCRIPTIONNEWSTYLE = DESCRIPTOR.enum_types_by_name['MdlDynSubscriptionNewStyle']
MdlDynSubscriptionNewStyle = enum_type_wrapper.EnumTypeWrapper(_MDLDYNSUBSCRIPTIONNEWSTYLE)
_MEDIATYPE = DESCRIPTOR.enum_types_by_name['MediaType']
MediaType = enum_type_wrapper.EnumTypeWrapper(_MEDIATYPE)
_MODULEAUTHORBADGETYPE = DESCRIPTOR.enum_types_by_name['ModuleAuthorBadgeType']
ModuleAuthorBadgeType = enum_type_wrapper.EnumTypeWrapper(_MODULEAUTHORBADGETYPE)
_MODULEBANNERTYPE = DESCRIPTOR.enum_types_by_name['ModuleBannerType']
ModuleBannerType = enum_type_wrapper.EnumTypeWrapper(_MODULEBANNERTYPE)
_MODULEDYNAMICTYPE = DESCRIPTOR.enum_types_by_name['ModuleDynamicType']
ModuleDynamicType = enum_type_wrapper.EnumTypeWrapper(_MODULEDYNAMICTYPE)
_NETWORKTYPE = DESCRIPTOR.enum_types_by_name['NetworkType']
NetworkType = enum_type_wrapper.EnumTypeWrapper(_NETWORKTYPE)
_RCMDTYPE = DESCRIPTOR.enum_types_by_name['RcmdType']
RcmdType = enum_type_wrapper.EnumTypeWrapper(_RCMDTYPE)
_REFRESH = DESCRIPTOR.enum_types_by_name['Refresh']
Refresh = enum_type_wrapper.EnumTypeWrapper(_REFRESH)
_RELATIONSTATUS = DESCRIPTOR.enum_types_by_name['RelationStatus']
RelationStatus = enum_type_wrapper.EnumTypeWrapper(_RELATIONSTATUS)
_REPOSTTYPE = DESCRIPTOR.enum_types_by_name['RepostType']
RepostType = enum_type_wrapper.EnumTypeWrapper(_REPOSTTYPE)
_RESERVERELATIONLOTTERYTYPE = DESCRIPTOR.enum_types_by_name['ReserveRelationLotteryType']
ReserveRelationLotteryType = enum_type_wrapper.EnumTypeWrapper(_RESERVERELATIONLOTTERYTYPE)
_RESERVETYPE = DESCRIPTOR.enum_types_by_name['ReserveType']
ReserveType = enum_type_wrapper.EnumTypeWrapper(_RESERVETYPE)
_SHOWTYPE = DESCRIPTOR.enum_types_by_name['ShowType']
ShowType = enum_type_wrapper.EnumTypeWrapper(_SHOWTYPE)
_STYLETYPE = DESCRIPTOR.enum_types_by_name['StyleType']
StyleType = enum_type_wrapper.EnumTypeWrapper(_STYLETYPE)
_TFTYPE = DESCRIPTOR.enum_types_by_name['TFType']
TFType = enum_type_wrapper.EnumTypeWrapper(_TFTYPE)
_THREEPOINTATTENTIONSTATUS = DESCRIPTOR.enum_types_by_name['ThreePointAttentionStatus']
ThreePointAttentionStatus = enum_type_wrapper.EnumTypeWrapper(_THREEPOINTATTENTIONSTATUS)
_THREEPOINTTYPE = DESCRIPTOR.enum_types_by_name['ThreePointType']
ThreePointType = enum_type_wrapper.EnumTypeWrapper(_THREEPOINTTYPE)
_THUMBTYPE = DESCRIPTOR.enum_types_by_name['ThumbType']
ThumbType = enum_type_wrapper.EnumTypeWrapper(_THUMBTYPE)
_TOPTYPE = DESCRIPTOR.enum_types_by_name['TopType']
TopType = enum_type_wrapper.EnumTypeWrapper(_TOPTYPE)
_USERITEMTYPE = DESCRIPTOR.enum_types_by_name['UserItemType']
UserItemType = enum_type_wrapper.EnumTypeWrapper(_USERITEMTYPE)
_VIDEOSUBTYPE = DESCRIPTOR.enum_types_by_name['VideoSubType']
VideoSubType = enum_type_wrapper.EnumTypeWrapper(_VIDEOSUBTYPE)
_VIDEOTYPE = DESCRIPTOR.enum_types_by_name['VideoType']
VideoType = enum_type_wrapper.EnumTypeWrapper(_VIDEOTYPE)
_VOTESTATUS = DESCRIPTOR.enum_types_by_name['VoteStatus']
VoteStatus = enum_type_wrapper.EnumTypeWrapper(_VOTESTATUS)
_WEIGHTTYPE = DESCRIPTOR.enum_types_by_name['WeightType']
WeightType = enum_type_wrapper.EnumTypeWrapper(_WEIGHTTYPE)
fill = 0
stroke = 1
gray = 2
bt_none = 0
bt_jump = 1
bt_button = 2
addition_vote_state_none = 0
addition_vote_state_open = 1
addition_vote_state_close = 2
addition_vote_type_none = 0
addition_vote_type_word = 1
addition_vote_type_pic = 2
addition_vote_type_default = 3
click_none = 0
click_up = 1
none = 0
uncheck = 1
check = 2
st_none = 0
st_show = 1
additional_none = 0
additional_type_pgc = 1
additional_type_goods = 2
additional_type_vote = 3
additional_type_common = 4
additional_type_esport = 5
additional_type_up_rcmd = 6
additional_type_ugc = 7
additional_type_up_reservation = 8
campus_none = 0
campus_school = 1
campus_dynamic = 2
campus_account = 3
campus_billboard = 4
campus_topic = 5
cover_icon_none = 0
cover_icon_play = 1
desc_type_none = 0
desc_type_text = 1
desc_type_aite = 2
desc_type_lottery = 3
desc_type_vote = 4
desc_type_topic = 5
desc_type_goods = 6
desc_type_bv = 7
desc_type_av = 8
desc_type_emoji = 9
desc_type_user = 10
desc_type_cv = 11
desc_type_vc = 12
desc_type_web = 13
desc_type_taobao = 14
desc_type_mail = 15
desc_type_ogv_season = 16
desc_type_ogv_ep = 17
desc_type_search_word = 18
highlight = 0
gary = 1
dyn_ext_type_none = 0
dyn_ext_type_topic = 1
dyn_ext_type_lbs = 2
dyn_ext_type_hot = 3
dyn_ext_type_game = 4
dyn_ext_type_common = 5
dyn_ext_type_biliCut = 6
dyn_ext_type_ogv = 7
dyn_ext_type_auto_ogv = 8
module_none = 0
module_author = 1
module_dispute = 2
module_desc = 3
module_dynamic = 4
module_forward = 5
module_likeUser = 6
module_extend = 7
module_additional = 8
module_stat = 9
module_fold = 10
module_comment = 11
module_interaction = 12
module_author_forward = 13
module_ad = 14
module_banner = 15
module_item_null = 16
module_share_info = 17
module_recommend = 18
module_stat_forward = 19
module_top = 20
module_bottom = 21
module_story = 22
module_topic = 23
module_topic_details_ext = 24
module_top_tag = 25
module_topic_brief = 26
module_title = 27
dyn_uri_type_none = 0
dyn_uri_type_direct = 1
dyn_uri_type_suffix = 2
dyn_none = 0
forward = 1
av = 2
pgc = 3
courses = 4
fold = 5
word = 6
draw = 7
article = 8
music = 9
common_square = 10
common_vertical = 11
live = 12
medialist = 13
courses_season = 14
ad = 15
applet = 16
subscription = 17
live_rcmd = 18
banner = 19
ugc_season = 20
subscription_new = 21
story = 22
topic_rcmd = 23
emoji_none = 0
emoji_old = 1
emoji_new = 2
vip = 3
moba = 0
FoldTypeZore = 0
FoldTypePublish = 1
FoldTypeFrequent = 2
FoldTypeUnite = 3
FoldTypeLimit = 4
ft_not_follow = 0
ft_follow = 1
style_none = 0
style_highlight = 1
add_style_vertical = 0
add_style_square = 1
from_login = 0
from_unlogin = 1
live_none = 0
live_live = 1
live_rotation = 2
local_icon_comment = 0
local_icon_like = 1
mdl_dyn_common_none = 0
mdl_dyn_common_square = 1
mdl_dyn_common_vertica = 2
mdl_draw_tag_none = 0
mdl_draw_tag_common = 1
mdl_draw_tag_goods = 2
mdl_draw_tag_user = 3
mdl_draw_tag_topic = 4
mdl_draw_tag_lbs = 5
mdl_dyn_subscription_new_style_nont = 0
mdl_dyn_subscription_new_style_live = 1
mdl_dyn_subscription_new_style_draw = 2
MediaTypeNone = 0
MediaTypeUGC = 1
MediaTypePGC = 2
MediaTypeLive = 3
MediaTypeVCS = 4
module_author_badge_type_none = 0
module_author_badge_type_threePoint = 1
module_author_badge_type_button = 2
module_author_badge_type_weight = 3
module_banner_type_none = 0
module_banner_type_user = 1
mdl_dyn_archive = 0
mdl_dyn_pgc = 1
mdl_dyn_cour_season = 2
mdl_dyn_cour_batch = 3
mdl_dyn_forward = 4
mdl_dyn_draw = 5
mdl_dyn_article = 6
mdl_dyn_music = 7
mdl_dyn_common = 8
mdl_dyn_live = 9
mdl_dyn_medialist = 10
mdl_dyn_applet = 11
mdl_dyn_subscription = 12
mdl_dyn_live_rcmd = 13
mdl_dyn_ugc_season = 14
mdl_dyn_subscription_new = 15
NT_UNKNOWN = 0
WIFI = 1
CELLULAR = 2
OFFLINE = 3
OTHERNET = 4
ETHERNET = 5
rcmd_archive = 0
rcmd_dynamic = 1
refresh_new = 0
refresh_history = 1
relation_status_none = 0
relation_status_nofollow = 1
relation_status_follow = 2
relation_status_followed = 3
relation_status_mutual_concern = 4
relation_status_special = 5
repost_hot = 0
repost_general = 1
reserve_relation_lottery_type_default = 0
reserve_relation_lottery_type_cron = 1
reserve_none = 0
reserve_recall = 1
show_type_none = 0
show_type_backup = 1
STYLE_TYPE_NONE = 0
STYLE_TYPE_LIVE = 1
STYLE_TYPE_DYN_UP = 2
U_CARD = 0
U_PKG = 1
C_CARD = 2
C_PKG = 3
T_CARD = 4
T_PKG = 5
tp_not_attention = 0
tp_attention = 1
tp_none = 0
background = 1
auto_play = 2
share = 3
wait = 4
attention = 5
report = 6
delete = 7
dislike = 8
favorite = 9
top = 10
comment = 11
hide = 12
campus_delete = 13
topic_irrelevant = 14
cancel = 0
thumb = 1
top_none = 0
top_cancel = 1
user_item_type_none = 0
user_item_type_live = 1
user_item_type_live_custom = 2
user_item_type_normal = 3
user_item_type_extend = 4
VideoSubTypeNone = 0
VideoSubTypeBangumi = 1
VideoSubTypeMovie = 2
VideoSubTypeDocumentary = 3
VideoSubTypeDomestic = 4
VideoSubTypeTeleplay = 5
video_type_general = 0
video_type_dynamic = 1
video_type_playback = 2
video_type_story = 3
normal = 0
anonymous = 1
weight_none = 0
weight_dislike = 1
weight_jump = 2


_ADPARAM = DESCRIPTOR.message_types_by_name['AdParam']
_ADDITIONCOMMON = DESCRIPTOR.message_types_by_name['AdditionCommon']
_ADDITIONESPORT = DESCRIPTOR.message_types_by_name['AdditionEsport']
_ADDITIONESPORTMOBA = DESCRIPTOR.message_types_by_name['AdditionEsportMoba']
_ADDITIONESPORTMOBASTATUS = DESCRIPTOR.message_types_by_name['AdditionEsportMobaStatus']
_ADDITIONESPORTMOBASTATUSDESC = DESCRIPTOR.message_types_by_name['AdditionEsportMobaStatusDesc']
_ADDITIONGOODS = DESCRIPTOR.message_types_by_name['AdditionGoods']
_ADDITIONUP = DESCRIPTOR.message_types_by_name['AdditionUP']
_ADDITIONUGC = DESCRIPTOR.message_types_by_name['AdditionUgc']
_ADDITIONUSERINFO = DESCRIPTOR.message_types_by_name['AdditionUserInfo']
_ADDITIONVOTE = DESCRIPTOR.message_types_by_name['AdditionVote']
_ADDITIONVOTE2 = DESCRIPTOR.message_types_by_name['AdditionVote2']
_ADDITIONVOTEDEFAULE = DESCRIPTOR.message_types_by_name['AdditionVoteDefaule']
_ADDITIONVOTEPIC = DESCRIPTOR.message_types_by_name['AdditionVotePic']
_ADDITIONVOTEPICITEM = DESCRIPTOR.message_types_by_name['AdditionVotePicItem']
_ADDITIONVOTEWORD = DESCRIPTOR.message_types_by_name['AdditionVoteWord']
_ADDITIONVOTEWORDITEM = DESCRIPTOR.message_types_by_name['AdditionVoteWordItem']
_ADDITIONALACTSKIN = DESCRIPTOR.message_types_by_name['AdditionalActSkin']
_ADDITIONALBUTTON = DESCRIPTOR.message_types_by_name['AdditionalButton']
_ADDITIONALBUTTONINTERACTIVE = DESCRIPTOR.message_types_by_name['AdditionalButtonInteractive']
_ADDITIONALBUTTONSHARE = DESCRIPTOR.message_types_by_name['AdditionalButtonShare']
_ADDITIONALBUTTONSTYLE = DESCRIPTOR.message_types_by_name['AdditionalButtonStyle']
_ADDITIONALPGC = DESCRIPTOR.message_types_by_name['AdditionalPGC']
_ALUMNIDYNAMICSREPLY = DESCRIPTOR.message_types_by_name['AlumniDynamicsReply']
_ALUMNIDYNAMICSREQ = DESCRIPTOR.message_types_by_name['AlumniDynamicsReq']
_CAMPUSBANNERINFO = DESCRIPTOR.message_types_by_name['CampusBannerInfo']
_CAMPUSBILLBOARDREPLY = DESCRIPTOR.message_types_by_name['CampusBillBoardReply']
_CAMPUSBILLBOARDREQ = DESCRIPTOR.message_types_by_name['CampusBillBoardReq']
_CAMPUSBILLBOARDINTERNALREQ = DESCRIPTOR.message_types_by_name['CampusBillboardInternalReq']
_CAMPUSFEEDBACKINFO = DESCRIPTOR.message_types_by_name['CampusFeedbackInfo']
_CAMPUSFEEDBACKREPLY = DESCRIPTOR.message_types_by_name['CampusFeedbackReply']
_CAMPUSFEEDBACKREQ = DESCRIPTOR.message_types_by_name['CampusFeedbackReq']
_CAMPUSINFO = DESCRIPTOR.message_types_by_name['CampusInfo']
_CAMPUSLABEL = DESCRIPTOR.message_types_by_name['CampusLabel']
_CAMPUSMATELIKELISTREPLY = DESCRIPTOR.message_types_by_name['CampusMateLikeListReply']
_CAMPUSMATELIKELISTREQ = DESCRIPTOR.message_types_by_name['CampusMateLikeListReq']
_CAMPUSNOTICEINFO = DESCRIPTOR.message_types_by_name['CampusNoticeInfo']
_CAMPUSRCMDFEEDREPLY = DESCRIPTOR.message_types_by_name['CampusRcmdFeedReply']
_CAMPUSRCMDFEEDREQ = DESCRIPTOR.message_types_by_name['CampusRcmdFeedReq']
_CAMPUSRCMDINFO = DESCRIPTOR.message_types_by_name['CampusRcmdInfo']
_CAMPUSRCMDITEM = DESCRIPTOR.message_types_by_name['CampusRcmdItem']
_CAMPUSRCMDREPLY = DESCRIPTOR.message_types_by_name['CampusRcmdReply']
_CAMPUSRCMDREQ = DESCRIPTOR.message_types_by_name['CampusRcmdReq']
_CAMPUSRCMDTOP = DESCRIPTOR.message_types_by_name['CampusRcmdTop']
_CAMPUSREDDOTREPLY = DESCRIPTOR.message_types_by_name['CampusRedDotReply']
_CAMPUSREDDOTREQ = DESCRIPTOR.message_types_by_name['CampusRedDotReq']
_CAMPUSSHOWTABINFO = DESCRIPTOR.message_types_by_name['CampusShowTabInfo']
_CAMPUSTOP = DESCRIPTOR.message_types_by_name['CampusTop']
_CAMPUSTOPICRCMDFEEDREPLY = DESCRIPTOR.message_types_by_name['CampusTopicRcmdFeedReply']
_CAMPUSTOPICRCMDFEEDREQ = DESCRIPTOR.message_types_by_name['CampusTopicRcmdFeedReq']
_CARDVIDEODYNLIST = DESCRIPTOR.message_types_by_name['CardVideoDynList']
_CARDVIDEOFOLLOWLIST = DESCRIPTOR.message_types_by_name['CardVideoFollowList']
_CARDVIDEOUPLIST = DESCRIPTOR.message_types_by_name['CardVideoUpList']
_CHANNELINFO = DESCRIPTOR.message_types_by_name['ChannelInfo']
_CMTSHOWITEM = DESCRIPTOR.message_types_by_name['CmtShowItem']
_COMMENTDETAIL = DESCRIPTOR.message_types_by_name['CommentDetail']
_DECOCARDFAN = DESCRIPTOR.message_types_by_name['DecoCardFan']
_DECORATECARD = DESCRIPTOR.message_types_by_name['DecorateCard']
_DESCRIPTION = DESCRIPTOR.message_types_by_name['Description']
_DIMENSION = DESCRIPTOR.message_types_by_name['Dimension']
_DYNADDITIONCOMMONFOLLOWREPLY = DESCRIPTOR.message_types_by_name['DynAdditionCommonFollowReply']
_DYNADDITIONCOMMONFOLLOWREQ = DESCRIPTOR.message_types_by_name['DynAdditionCommonFollowReq']
_DYNALLPERSONALREPLY = DESCRIPTOR.message_types_by_name['DynAllPersonalReply']
_DYNALLPERSONALREQ = DESCRIPTOR.message_types_by_name['DynAllPersonalReq']
_DYNALLREPLY = DESCRIPTOR.message_types_by_name['DynAllReply']
_DYNALLREQ = DESCRIPTOR.message_types_by_name['DynAllReq']
_DYNALLUPDOFFSETREQ = DESCRIPTOR.message_types_by_name['DynAllUpdOffsetReq']
_DYNDETAILREPLY = DESCRIPTOR.message_types_by_name['DynDetailReply']
_DYNDETAILREQ = DESCRIPTOR.message_types_by_name['DynDetailReq']
_DYNDETAILSREPLY = DESCRIPTOR.message_types_by_name['DynDetailsReply']
_DYNDETAILSREQ = DESCRIPTOR.message_types_by_name['DynDetailsReq']
_DYNFAKECARDREPLY = DESCRIPTOR.message_types_by_name['DynFakeCardReply']
_DYNFAKECARDREQ = DESCRIPTOR.message_types_by_name['DynFakeCardReq']
_DYNLIGHTREPLY = DESCRIPTOR.message_types_by_name['DynLightReply']
_DYNLIGHTREQ = DESCRIPTOR.message_types_by_name['DynLightReq']
_DYNMIXUPLISTVIEWMOREREPLY = DESCRIPTOR.message_types_by_name['DynMixUpListViewMoreReply']
_DYNMIXUPLISTVIEWMOREREQ = DESCRIPTOR.message_types_by_name['DynMixUpListViewMoreReq']
_DYNRCMDREPLY = DESCRIPTOR.message_types_by_name['DynRcmdReply']
_DYNRCMDREQ = DESCRIPTOR.message_types_by_name['DynRcmdReq']
_DYNRCMDUPEXCHANGEREPLY = DESCRIPTOR.message_types_by_name['DynRcmdUpExchangeReply']
_DYNRCMDUPEXCHANGEREQ = DESCRIPTOR.message_types_by_name['DynRcmdUpExchangeReq']
_DYNREGIONRCMD = DESCRIPTOR.message_types_by_name['DynRegionRcmd']
_DYNREGIONRCMDITEM = DESCRIPTOR.message_types_by_name['DynRegionRcmdItem']
_DYNSEARCHREPLY = DESCRIPTOR.message_types_by_name['DynSearchReply']
_DYNSEARCHREQ = DESCRIPTOR.message_types_by_name['DynSearchReq']
_DYNSERVERDETAILSREPLY = DESCRIPTOR.message_types_by_name['DynServerDetailsReply']
_DYNSERVERDETAILSREPLY_ITEMSENTRY = _DYNSERVERDETAILSREPLY.nested_types_by_name['ItemsEntry']
_DYNSERVERDETAILSREQ = DESCRIPTOR.message_types_by_name['DynServerDetailsReq']
_DYNSPACEREQ = DESCRIPTOR.message_types_by_name['DynSpaceReq']
_DYNSPACERSP = DESCRIPTOR.message_types_by_name['DynSpaceRsp']
_DYNSPACESEARCHDETAILSREPLY = DESCRIPTOR.message_types_by_name['DynSpaceSearchDetailsReply']
_DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY = _DYNSPACESEARCHDETAILSREPLY.nested_types_by_name['ItemsEntry']
_DYNSPACESEARCHDETAILSREQ = DESCRIPTOR.message_types_by_name['DynSpaceSearchDetailsReq']
_DYNTAB = DESCRIPTOR.message_types_by_name['DynTab']
_DYNTABREPLY = DESCRIPTOR.message_types_by_name['DynTabReply']
_DYNTABREQ = DESCRIPTOR.message_types_by_name['DynTabReq']
_DYNTHUMBREQ = DESCRIPTOR.message_types_by_name['DynThumbReq']
_DYNVIDEOPERSONALREPLY = DESCRIPTOR.message_types_by_name['DynVideoPersonalReply']
_DYNVIDEOPERSONALREQ = DESCRIPTOR.message_types_by_name['DynVideoPersonalReq']
_DYNVIDEOREPLY = DESCRIPTOR.message_types_by_name['DynVideoReply']
_DYNVIDEOREQ = DESCRIPTOR.message_types_by_name['DynVideoReq']
_DYNVIDEOUPDOFFSETREQ = DESCRIPTOR.message_types_by_name['DynVideoUpdOffsetReq']
_DYNVOTEREPLY = DESCRIPTOR.message_types_by_name['DynVoteReply']
_DYNVOTEREQ = DESCRIPTOR.message_types_by_name['DynVoteReq']
_DYNAMICITEM = DESCRIPTOR.message_types_by_name['DynamicItem']
_DYNAMICLIST = DESCRIPTOR.message_types_by_name['DynamicList']
_EXTINFOCOMMON = DESCRIPTOR.message_types_by_name['ExtInfoCommon']
_EXTINFOGAME = DESCRIPTOR.message_types_by_name['ExtInfoGame']
_EXTINFOHOT = DESCRIPTOR.message_types_by_name['ExtInfoHot']
_EXTINFOLBS = DESCRIPTOR.message_types_by_name['ExtInfoLBS']
_EXTINFOOGV = DESCRIPTOR.message_types_by_name['ExtInfoOGV']
_EXTINFOTOPIC = DESCRIPTOR.message_types_by_name['ExtInfoTopic']
_EXTEND = DESCRIPTOR.message_types_by_name['Extend']
_EXTENDREPLY = DESCRIPTOR.message_types_by_name['ExtendReply']
_EXTENDREPLYPARAM = DESCRIPTOR.message_types_by_name['ExtendReplyParam']
_FOLLOWLISTITEM = DESCRIPTOR.message_types_by_name['FollowListItem']
_GOODSITEM = DESCRIPTOR.message_types_by_name['GoodsItem']
_GUIDEBARINFO = DESCRIPTOR.message_types_by_name['GuideBarInfo']
_HIGHLIGHTTEXT = DESCRIPTOR.message_types_by_name['HighlightText']
_ICONBADGE = DESCRIPTOR.message_types_by_name['IconBadge']
_ICONBUTTON = DESCRIPTOR.message_types_by_name['IconButton']
_INFOOGV = DESCRIPTOR.message_types_by_name['InfoOGV']
_INTERACTIONFACE = DESCRIPTOR.message_types_by_name['InteractionFace']
_INTERACTIONITEM = DESCRIPTOR.message_types_by_name['InteractionItem']
_INTERACTIONSTAT = DESCRIPTOR.message_types_by_name['InteractionStat']
_LIKEANIMATION = DESCRIPTOR.message_types_by_name['LikeAnimation']
_LIKEINFO = DESCRIPTOR.message_types_by_name['LikeInfo']
_LIKELISTREPLY = DESCRIPTOR.message_types_by_name['LikeListReply']
_LIKELISTREQ = DESCRIPTOR.message_types_by_name['LikeListReq']
_LIKEUSER = DESCRIPTOR.message_types_by_name['LikeUser']
_LIVEINFO = DESCRIPTOR.message_types_by_name['LiveInfo']
_LIVEPENDANT = DESCRIPTOR.message_types_by_name['LivePendant']
_MATCHTEAM = DESCRIPTOR.message_types_by_name['MatchTeam']
_MDLDYNAPPLET = DESCRIPTOR.message_types_by_name['MdlDynApplet']
_MDLDYNARCHIVE = DESCRIPTOR.message_types_by_name['MdlDynArchive']
_MDLDYNARTICLE = DESCRIPTOR.message_types_by_name['MdlDynArticle']
_MDLDYNCOMMON = DESCRIPTOR.message_types_by_name['MdlDynCommon']
_MDLDYNCOURBATCH = DESCRIPTOR.message_types_by_name['MdlDynCourBatch']
_MDLDYNCOURSEASON = DESCRIPTOR.message_types_by_name['MdlDynCourSeason']
_MDLDYNDRAW = DESCRIPTOR.message_types_by_name['MdlDynDraw']
_MDLDYNDRAWITEM = DESCRIPTOR.message_types_by_name['MdlDynDrawItem']
_MDLDYNDRAWTAG = DESCRIPTOR.message_types_by_name['MdlDynDrawTag']
_MDLDYNDRAWTAGITEM = DESCRIPTOR.message_types_by_name['MdlDynDrawTagItem']
_MDLDYNFORWARD = DESCRIPTOR.message_types_by_name['MdlDynForward']
_MDLDYNLIVE = DESCRIPTOR.message_types_by_name['MdlDynLive']
_MDLDYNLIVERCMD = DESCRIPTOR.message_types_by_name['MdlDynLiveRcmd']
_MDLDYNMEDIALIST = DESCRIPTOR.message_types_by_name['MdlDynMedialist']
_MDLDYNMUSIC = DESCRIPTOR.message_types_by_name['MdlDynMusic']
_MDLDYNPGC = DESCRIPTOR.message_types_by_name['MdlDynPGC']
_MDLDYNSUBSCRIPTION = DESCRIPTOR.message_types_by_name['MdlDynSubscription']
_MDLDYNSUBSCRIPTIONNEW = DESCRIPTOR.message_types_by_name['MdlDynSubscriptionNew']
_MDLDYNUGCSEASON = DESCRIPTOR.message_types_by_name['MdlDynUGCSeason']
_MIXUPLISTITEM = DESCRIPTOR.message_types_by_name['MixUpListItem']
_MIXUPLISTLIVEITEM = DESCRIPTOR.message_types_by_name['MixUpListLiveItem']
_MODULE = DESCRIPTOR.message_types_by_name['Module']
_MODULEAD = DESCRIPTOR.message_types_by_name['ModuleAd']
_MODULEADDITIONAL = DESCRIPTOR.message_types_by_name['ModuleAdditional']
_MODULEAUTHOR = DESCRIPTOR.message_types_by_name['ModuleAuthor']
_MODULEAUTHORBADGEBUTTON = DESCRIPTOR.message_types_by_name['ModuleAuthorBadgeButton']
_MODULEAUTHORFORWARD = DESCRIPTOR.message_types_by_name['ModuleAuthorForward']
_MODULEAUTHORFORWARDTITLE = DESCRIPTOR.message_types_by_name['ModuleAuthorForwardTitle']
_MODULEBANNER = DESCRIPTOR.message_types_by_name['ModuleBanner']
_MODULEBANNERUSER = DESCRIPTOR.message_types_by_name['ModuleBannerUser']
_MODULEBANNERUSERITEM = DESCRIPTOR.message_types_by_name['ModuleBannerUserItem']
_MODULEBUTTOM = DESCRIPTOR.message_types_by_name['ModuleButtom']
_MODULECOMMENT = DESCRIPTOR.message_types_by_name['ModuleComment']
_MODULEDESC = DESCRIPTOR.message_types_by_name['ModuleDesc']
_MODULEDESCGOODS = DESCRIPTOR.message_types_by_name['ModuleDescGoods']
_MODULEDISPUTE = DESCRIPTOR.message_types_by_name['ModuleDispute']
_MODULEDYNAMIC = DESCRIPTOR.message_types_by_name['ModuleDynamic']
_MODULEEXTEND = DESCRIPTOR.message_types_by_name['ModuleExtend']
_MODULEEXTENDITEM = DESCRIPTOR.message_types_by_name['ModuleExtendItem']
_MODULEFOLD = DESCRIPTOR.message_types_by_name['ModuleFold']
_MODULEINTERACTION = DESCRIPTOR.message_types_by_name['ModuleInteraction']
_MODULEITEMNULL = DESCRIPTOR.message_types_by_name['ModuleItemNull']
_MODULELIKEUSER = DESCRIPTOR.message_types_by_name['ModuleLikeUser']
_MODULERCMD = DESCRIPTOR.message_types_by_name['ModuleRcmd']
_MODULERECOMMEND = DESCRIPTOR.message_types_by_name['ModuleRecommend']
_MODULESHAREINFO = DESCRIPTOR.message_types_by_name['ModuleShareInfo']
_MODULESTAT = DESCRIPTOR.message_types_by_name['ModuleStat']
_MODULESTORY = DESCRIPTOR.message_types_by_name['ModuleStory']
_MODULETITLE = DESCRIPTOR.message_types_by_name['ModuleTitle']
_MODULETOP = DESCRIPTOR.message_types_by_name['ModuleTop']
_MODULETOPTAG = DESCRIPTOR.message_types_by_name['ModuleTopTag']
_MODULETOPIC = DESCRIPTOR.message_types_by_name['ModuleTopic']
_MODULETOPICBRIEF = DESCRIPTOR.message_types_by_name['ModuleTopicBrief']
_MODULETOPICDETAILSEXT = DESCRIPTOR.message_types_by_name['ModuleTopicDetailsExt']
_NAMEPLATE = DESCRIPTOR.message_types_by_name['Nameplate']
_NEWEP = DESCRIPTOR.message_types_by_name['NewEP']
_NOREPLY = DESCRIPTOR.message_types_by_name['NoReply']
_NOREQ = DESCRIPTOR.message_types_by_name['NoReq']
_OFFICIALACCOUNTINFO = DESCRIPTOR.message_types_by_name['OfficialAccountInfo']
_OFFICIALACCOUNTSREPLY = DESCRIPTOR.message_types_by_name['OfficialAccountsReply']
_OFFICIALACCOUNTSREQ = DESCRIPTOR.message_types_by_name['OfficialAccountsReq']
_OFFICIALDYNAMICSREPLY = DESCRIPTOR.message_types_by_name['OfficialDynamicsReply']
_OFFICIALDYNAMICSREQ = DESCRIPTOR.message_types_by_name['OfficialDynamicsReq']
_OFFICIALITEM = DESCRIPTOR.message_types_by_name['OfficialItem']
_OFFICIALRCMDARCHIVE = DESCRIPTOR.message_types_by_name['OfficialRcmdArchive']
_OFFICIALRCMDDYNAMIC = DESCRIPTOR.message_types_by_name['OfficialRcmdDynamic']
_OFFICIALVERIFY = DESCRIPTOR.message_types_by_name['OfficialVerify']
_PGCSEASON = DESCRIPTOR.message_types_by_name['PGCSeason']
_PLAYURLPARAM = DESCRIPTOR.message_types_by_name['PlayurlParam']
_POPUP = DESCRIPTOR.message_types_by_name['Popup']
_RCMDARCHIVE = DESCRIPTOR.message_types_by_name['RcmdArchive']
_RCMDAUTHOR = DESCRIPTOR.message_types_by_name['RcmdAuthor']
_RCMDITEM = DESCRIPTOR.message_types_by_name['RcmdItem']
_RCMDOPTION = DESCRIPTOR.message_types_by_name['RcmdOption']
_RCMDTOPBUTTON = DESCRIPTOR.message_types_by_name['RcmdTopButton']
_RCMDUPSPARAM = DESCRIPTOR.message_types_by_name['RcmdUPsParam']
_RELATION = DESCRIPTOR.message_types_by_name['Relation']
_REPOSTLISTREQ = DESCRIPTOR.message_types_by_name['RepostListReq']
_REPOSTLISTRSP = DESCRIPTOR.message_types_by_name['RepostListRsp']
_SCHOOLRECOMMENDREPLY = DESCRIPTOR.message_types_by_name['SchoolRecommendReply']
_SCHOOLRECOMMENDREQ = DESCRIPTOR.message_types_by_name['SchoolRecommendReq']
_SCHOOLSEARCHREPLY = DESCRIPTOR.message_types_by_name['SchoolSearchReply']
_SCHOOLSEARCHREQ = DESCRIPTOR.message_types_by_name['SchoolSearchReq']
_SEARCHCHANNEL = DESCRIPTOR.message_types_by_name['SearchChannel']
_SEARCHINFO = DESCRIPTOR.message_types_by_name['SearchInfo']
_SEARCHTOAST = DESCRIPTOR.message_types_by_name['SearchToast']
_SEARCHTOPIC = DESCRIPTOR.message_types_by_name['SearchTopic']
_SEARCHTOPICBUTTON = DESCRIPTOR.message_types_by_name['SearchTopicButton']
_SEARCHTOPICITEM = DESCRIPTOR.message_types_by_name['SearchTopicItem']
_SETDECISIONREQ = DESCRIPTOR.message_types_by_name['SetDecisionReq']
_SETRECENTCAMPUSREQ = DESCRIPTOR.message_types_by_name['SetRecentCampusReq']
_SHARECHANNEL = DESCRIPTOR.message_types_by_name['ShareChannel']
_SHARERESERVE = DESCRIPTOR.message_types_by_name['ShareReserve']
_SORTTYPE = DESCRIPTOR.message_types_by_name['SortType']
_STORYARCHIVE = DESCRIPTOR.message_types_by_name['StoryArchive']
_STORYITEM = DESCRIPTOR.message_types_by_name['StoryItem']
_SUBSCRIBECAMPUSREQ = DESCRIPTOR.message_types_by_name['SubscribeCampusReq']
_THREEPOINTATTENTION = DESCRIPTOR.message_types_by_name['ThreePointAttention']
_THREEPOINTAUTOPLAY = DESCRIPTOR.message_types_by_name['ThreePointAutoPlay']
_THREEPOINTCOMMENT = DESCRIPTOR.message_types_by_name['ThreePointComment']
_THREEPOINTDEFAULT = DESCRIPTOR.message_types_by_name['ThreePointDefault']
_THREEPOINTDEFAULTTOAST = DESCRIPTOR.message_types_by_name['ThreePointDefaultToast']
_THREEPOINTDISLIKE = DESCRIPTOR.message_types_by_name['ThreePointDislike']
_THREEPOINTFAVORITE = DESCRIPTOR.message_types_by_name['ThreePointFavorite']
_THREEPOINTHIDE = DESCRIPTOR.message_types_by_name['ThreePointHide']
_THREEPOINTHIDEINTERACTIVE = DESCRIPTOR.message_types_by_name['ThreePointHideInteractive']
_THREEPOINTITEM = DESCRIPTOR.message_types_by_name['ThreePointItem']
_THREEPOINTSHARE = DESCRIPTOR.message_types_by_name['ThreePointShare']
_THREEPOINTSHARECHANNEL = DESCRIPTOR.message_types_by_name['ThreePointShareChannel']
_THREEPOINTTOP = DESCRIPTOR.message_types_by_name['ThreePointTop']
_THREEPOINTTOPICIRRELEVANT = DESCRIPTOR.message_types_by_name['ThreePointTopicIrrelevant']
_THREEPOINTWAIT = DESCRIPTOR.message_types_by_name['ThreePointWait']
_TOPADDITIONUP = DESCRIPTOR.message_types_by_name['TopAdditionUP']
_TOPICBUTTON = DESCRIPTOR.message_types_by_name['TopicButton']
_TOPICITEM = DESCRIPTOR.message_types_by_name['TopicItem']
_TOPICLIST = DESCRIPTOR.message_types_by_name['TopicList']
_TOPICLISTITEM = DESCRIPTOR.message_types_by_name['TopicListItem']
_TOPICLISTREPLY = DESCRIPTOR.message_types_by_name['TopicListReply']
_TOPICLISTREQ = DESCRIPTOR.message_types_by_name['TopicListReq']
_TOPICRCMDCARD = DESCRIPTOR.message_types_by_name['TopicRcmdCard']
_TOPICSQUAREINFO = DESCRIPTOR.message_types_by_name['TopicSquareInfo']
_TOPICSQUAREREPLY = DESCRIPTOR.message_types_by_name['TopicSquareReply']
_TOPICSQUAREREQ = DESCRIPTOR.message_types_by_name['TopicSquareReq']
_UNFOLLOW = DESCRIPTOR.message_types_by_name['Unfollow']
_UNFOLLOWUSERITEM = DESCRIPTOR.message_types_by_name['UnfollowUserItem']
_UPLISTITEM = DESCRIPTOR.message_types_by_name['UpListItem']
_UPLISTMORELABEL = DESCRIPTOR.message_types_by_name['UpListMoreLabel']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_USERITEMSTYLE = DESCRIPTOR.message_types_by_name['UserItemStyle']
_USERPENDANT = DESCRIPTOR.message_types_by_name['UserPendant']
_VIDEOBADGE = DESCRIPTOR.message_types_by_name['VideoBadge']
_VIPINFO = DESCRIPTOR.message_types_by_name['VipInfo']
_VIPLABEL = DESCRIPTOR.message_types_by_name['VipLabel']
_WEIGHT = DESCRIPTOR.message_types_by_name['Weight']
_WEIGHTBUTTON = DESCRIPTOR.message_types_by_name['WeightButton']
_WEIGHTDISLIKE = DESCRIPTOR.message_types_by_name['WeightDislike']
_WEIGHTITEM = DESCRIPTOR.message_types_by_name['WeightItem']
AdParam = _reflection.GeneratedProtocolMessageType('AdParam', (_message.Message,), {
  'DESCRIPTOR' : _ADPARAM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdParam)
  })
_sym_db.RegisterMessage(AdParam)

AdditionCommon = _reflection.GeneratedProtocolMessageType('AdditionCommon', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONCOMMON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionCommon)
  })
_sym_db.RegisterMessage(AdditionCommon)

AdditionEsport = _reflection.GeneratedProtocolMessageType('AdditionEsport', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONESPORT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionEsport)
  })
_sym_db.RegisterMessage(AdditionEsport)

AdditionEsportMoba = _reflection.GeneratedProtocolMessageType('AdditionEsportMoba', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONESPORTMOBA,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionEsportMoba)
  })
_sym_db.RegisterMessage(AdditionEsportMoba)

AdditionEsportMobaStatus = _reflection.GeneratedProtocolMessageType('AdditionEsportMobaStatus', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONESPORTMOBASTATUS,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionEsportMobaStatus)
  })
_sym_db.RegisterMessage(AdditionEsportMobaStatus)

AdditionEsportMobaStatusDesc = _reflection.GeneratedProtocolMessageType('AdditionEsportMobaStatusDesc', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONESPORTMOBASTATUSDESC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionEsportMobaStatusDesc)
  })
_sym_db.RegisterMessage(AdditionEsportMobaStatusDesc)

AdditionGoods = _reflection.GeneratedProtocolMessageType('AdditionGoods', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONGOODS,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionGoods)
  })
_sym_db.RegisterMessage(AdditionGoods)

AdditionUP = _reflection.GeneratedProtocolMessageType('AdditionUP', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONUP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionUP)
  })
_sym_db.RegisterMessage(AdditionUP)

AdditionUgc = _reflection.GeneratedProtocolMessageType('AdditionUgc', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONUGC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionUgc)
  })
_sym_db.RegisterMessage(AdditionUgc)

AdditionUserInfo = _reflection.GeneratedProtocolMessageType('AdditionUserInfo', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONUSERINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionUserInfo)
  })
_sym_db.RegisterMessage(AdditionUserInfo)

AdditionVote = _reflection.GeneratedProtocolMessageType('AdditionVote', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionVote)
  })
_sym_db.RegisterMessage(AdditionVote)

AdditionVote2 = _reflection.GeneratedProtocolMessageType('AdditionVote2', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTE2,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionVote2)
  })
_sym_db.RegisterMessage(AdditionVote2)

AdditionVoteDefaule = _reflection.GeneratedProtocolMessageType('AdditionVoteDefaule', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEDEFAULE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionVoteDefaule)
  })
_sym_db.RegisterMessage(AdditionVoteDefaule)

AdditionVotePic = _reflection.GeneratedProtocolMessageType('AdditionVotePic', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEPIC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionVotePic)
  })
_sym_db.RegisterMessage(AdditionVotePic)

AdditionVotePicItem = _reflection.GeneratedProtocolMessageType('AdditionVotePicItem', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEPICITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionVotePicItem)
  })
_sym_db.RegisterMessage(AdditionVotePicItem)

AdditionVoteWord = _reflection.GeneratedProtocolMessageType('AdditionVoteWord', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEWORD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionVoteWord)
  })
_sym_db.RegisterMessage(AdditionVoteWord)

AdditionVoteWordItem = _reflection.GeneratedProtocolMessageType('AdditionVoteWordItem', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONVOTEWORDITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionVoteWordItem)
  })
_sym_db.RegisterMessage(AdditionVoteWordItem)

AdditionalActSkin = _reflection.GeneratedProtocolMessageType('AdditionalActSkin', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALACTSKIN,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionalActSkin)
  })
_sym_db.RegisterMessage(AdditionalActSkin)

AdditionalButton = _reflection.GeneratedProtocolMessageType('AdditionalButton', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALBUTTON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionalButton)
  })
_sym_db.RegisterMessage(AdditionalButton)

AdditionalButtonInteractive = _reflection.GeneratedProtocolMessageType('AdditionalButtonInteractive', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALBUTTONINTERACTIVE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionalButtonInteractive)
  })
_sym_db.RegisterMessage(AdditionalButtonInteractive)

AdditionalButtonShare = _reflection.GeneratedProtocolMessageType('AdditionalButtonShare', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALBUTTONSHARE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionalButtonShare)
  })
_sym_db.RegisterMessage(AdditionalButtonShare)

AdditionalButtonStyle = _reflection.GeneratedProtocolMessageType('AdditionalButtonStyle', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALBUTTONSTYLE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionalButtonStyle)
  })
_sym_db.RegisterMessage(AdditionalButtonStyle)

AdditionalPGC = _reflection.GeneratedProtocolMessageType('AdditionalPGC', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALPGC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AdditionalPGC)
  })
_sym_db.RegisterMessage(AdditionalPGC)

AlumniDynamicsReply = _reflection.GeneratedProtocolMessageType('AlumniDynamicsReply', (_message.Message,), {
  'DESCRIPTOR' : _ALUMNIDYNAMICSREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AlumniDynamicsReply)
  })
_sym_db.RegisterMessage(AlumniDynamicsReply)

AlumniDynamicsReq = _reflection.GeneratedProtocolMessageType('AlumniDynamicsReq', (_message.Message,), {
  'DESCRIPTOR' : _ALUMNIDYNAMICSREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.AlumniDynamicsReq)
  })
_sym_db.RegisterMessage(AlumniDynamicsReq)

CampusBannerInfo = _reflection.GeneratedProtocolMessageType('CampusBannerInfo', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSBANNERINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusBannerInfo)
  })
_sym_db.RegisterMessage(CampusBannerInfo)

CampusBillBoardReply = _reflection.GeneratedProtocolMessageType('CampusBillBoardReply', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSBILLBOARDREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusBillBoardReply)
  })
_sym_db.RegisterMessage(CampusBillBoardReply)

CampusBillBoardReq = _reflection.GeneratedProtocolMessageType('CampusBillBoardReq', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSBILLBOARDREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusBillBoardReq)
  })
_sym_db.RegisterMessage(CampusBillBoardReq)

CampusBillboardInternalReq = _reflection.GeneratedProtocolMessageType('CampusBillboardInternalReq', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSBILLBOARDINTERNALREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusBillboardInternalReq)
  })
_sym_db.RegisterMessage(CampusBillboardInternalReq)

CampusFeedbackInfo = _reflection.GeneratedProtocolMessageType('CampusFeedbackInfo', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSFEEDBACKINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusFeedbackInfo)
  })
_sym_db.RegisterMessage(CampusFeedbackInfo)

CampusFeedbackReply = _reflection.GeneratedProtocolMessageType('CampusFeedbackReply', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSFEEDBACKREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusFeedbackReply)
  })
_sym_db.RegisterMessage(CampusFeedbackReply)

CampusFeedbackReq = _reflection.GeneratedProtocolMessageType('CampusFeedbackReq', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSFEEDBACKREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusFeedbackReq)
  })
_sym_db.RegisterMessage(CampusFeedbackReq)

CampusInfo = _reflection.GeneratedProtocolMessageType('CampusInfo', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusInfo)
  })
_sym_db.RegisterMessage(CampusInfo)

CampusLabel = _reflection.GeneratedProtocolMessageType('CampusLabel', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSLABEL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusLabel)
  })
_sym_db.RegisterMessage(CampusLabel)

CampusMateLikeListReply = _reflection.GeneratedProtocolMessageType('CampusMateLikeListReply', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSMATELIKELISTREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusMateLikeListReply)
  })
_sym_db.RegisterMessage(CampusMateLikeListReply)

CampusMateLikeListReq = _reflection.GeneratedProtocolMessageType('CampusMateLikeListReq', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSMATELIKELISTREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusMateLikeListReq)
  })
_sym_db.RegisterMessage(CampusMateLikeListReq)

CampusNoticeInfo = _reflection.GeneratedProtocolMessageType('CampusNoticeInfo', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSNOTICEINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusNoticeInfo)
  })
_sym_db.RegisterMessage(CampusNoticeInfo)

CampusRcmdFeedReply = _reflection.GeneratedProtocolMessageType('CampusRcmdFeedReply', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSRCMDFEEDREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRcmdFeedReply)
  })
_sym_db.RegisterMessage(CampusRcmdFeedReply)

CampusRcmdFeedReq = _reflection.GeneratedProtocolMessageType('CampusRcmdFeedReq', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSRCMDFEEDREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRcmdFeedReq)
  })
_sym_db.RegisterMessage(CampusRcmdFeedReq)

CampusRcmdInfo = _reflection.GeneratedProtocolMessageType('CampusRcmdInfo', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSRCMDINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRcmdInfo)
  })
_sym_db.RegisterMessage(CampusRcmdInfo)

CampusRcmdItem = _reflection.GeneratedProtocolMessageType('CampusRcmdItem', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSRCMDITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRcmdItem)
  })
_sym_db.RegisterMessage(CampusRcmdItem)

CampusRcmdReply = _reflection.GeneratedProtocolMessageType('CampusRcmdReply', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSRCMDREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRcmdReply)
  })
_sym_db.RegisterMessage(CampusRcmdReply)

CampusRcmdReq = _reflection.GeneratedProtocolMessageType('CampusRcmdReq', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSRCMDREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRcmdReq)
  })
_sym_db.RegisterMessage(CampusRcmdReq)

CampusRcmdTop = _reflection.GeneratedProtocolMessageType('CampusRcmdTop', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSRCMDTOP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRcmdTop)
  })
_sym_db.RegisterMessage(CampusRcmdTop)

CampusRedDotReply = _reflection.GeneratedProtocolMessageType('CampusRedDotReply', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSREDDOTREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRedDotReply)
  })
_sym_db.RegisterMessage(CampusRedDotReply)

CampusRedDotReq = _reflection.GeneratedProtocolMessageType('CampusRedDotReq', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSREDDOTREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusRedDotReq)
  })
_sym_db.RegisterMessage(CampusRedDotReq)

CampusShowTabInfo = _reflection.GeneratedProtocolMessageType('CampusShowTabInfo', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSSHOWTABINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusShowTabInfo)
  })
_sym_db.RegisterMessage(CampusShowTabInfo)

CampusTop = _reflection.GeneratedProtocolMessageType('CampusTop', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSTOP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusTop)
  })
_sym_db.RegisterMessage(CampusTop)

CampusTopicRcmdFeedReply = _reflection.GeneratedProtocolMessageType('CampusTopicRcmdFeedReply', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSTOPICRCMDFEEDREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusTopicRcmdFeedReply)
  })
_sym_db.RegisterMessage(CampusTopicRcmdFeedReply)

CampusTopicRcmdFeedReq = _reflection.GeneratedProtocolMessageType('CampusTopicRcmdFeedReq', (_message.Message,), {
  'DESCRIPTOR' : _CAMPUSTOPICRCMDFEEDREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CampusTopicRcmdFeedReq)
  })
_sym_db.RegisterMessage(CampusTopicRcmdFeedReq)

CardVideoDynList = _reflection.GeneratedProtocolMessageType('CardVideoDynList', (_message.Message,), {
  'DESCRIPTOR' : _CARDVIDEODYNLIST,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CardVideoDynList)
  })
_sym_db.RegisterMessage(CardVideoDynList)

CardVideoFollowList = _reflection.GeneratedProtocolMessageType('CardVideoFollowList', (_message.Message,), {
  'DESCRIPTOR' : _CARDVIDEOFOLLOWLIST,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CardVideoFollowList)
  })
_sym_db.RegisterMessage(CardVideoFollowList)

CardVideoUpList = _reflection.GeneratedProtocolMessageType('CardVideoUpList', (_message.Message,), {
  'DESCRIPTOR' : _CARDVIDEOUPLIST,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CardVideoUpList)
  })
_sym_db.RegisterMessage(CardVideoUpList)

ChannelInfo = _reflection.GeneratedProtocolMessageType('ChannelInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ChannelInfo)
  })
_sym_db.RegisterMessage(ChannelInfo)

CmtShowItem = _reflection.GeneratedProtocolMessageType('CmtShowItem', (_message.Message,), {
  'DESCRIPTOR' : _CMTSHOWITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CmtShowItem)
  })
_sym_db.RegisterMessage(CmtShowItem)

CommentDetail = _reflection.GeneratedProtocolMessageType('CommentDetail', (_message.Message,), {
  'DESCRIPTOR' : _COMMENTDETAIL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.CommentDetail)
  })
_sym_db.RegisterMessage(CommentDetail)

DecoCardFan = _reflection.GeneratedProtocolMessageType('DecoCardFan', (_message.Message,), {
  'DESCRIPTOR' : _DECOCARDFAN,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DecoCardFan)
  })
_sym_db.RegisterMessage(DecoCardFan)

DecorateCard = _reflection.GeneratedProtocolMessageType('DecorateCard', (_message.Message,), {
  'DESCRIPTOR' : _DECORATECARD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DecorateCard)
  })
_sym_db.RegisterMessage(DecorateCard)

Description = _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIPTION,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Description)
  })
_sym_db.RegisterMessage(Description)

Dimension = _reflection.GeneratedProtocolMessageType('Dimension', (_message.Message,), {
  'DESCRIPTOR' : _DIMENSION,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Dimension)
  })
_sym_db.RegisterMessage(Dimension)

DynAdditionCommonFollowReply = _reflection.GeneratedProtocolMessageType('DynAdditionCommonFollowReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNADDITIONCOMMONFOLLOWREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynAdditionCommonFollowReply)
  })
_sym_db.RegisterMessage(DynAdditionCommonFollowReply)

DynAdditionCommonFollowReq = _reflection.GeneratedProtocolMessageType('DynAdditionCommonFollowReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNADDITIONCOMMONFOLLOWREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynAdditionCommonFollowReq)
  })
_sym_db.RegisterMessage(DynAdditionCommonFollowReq)

DynAllPersonalReply = _reflection.GeneratedProtocolMessageType('DynAllPersonalReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLPERSONALREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynAllPersonalReply)
  })
_sym_db.RegisterMessage(DynAllPersonalReply)

DynAllPersonalReq = _reflection.GeneratedProtocolMessageType('DynAllPersonalReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLPERSONALREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynAllPersonalReq)
  })
_sym_db.RegisterMessage(DynAllPersonalReq)

DynAllReply = _reflection.GeneratedProtocolMessageType('DynAllReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynAllReply)
  })
_sym_db.RegisterMessage(DynAllReply)

DynAllReq = _reflection.GeneratedProtocolMessageType('DynAllReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynAllReq)
  })
_sym_db.RegisterMessage(DynAllReq)

DynAllUpdOffsetReq = _reflection.GeneratedProtocolMessageType('DynAllUpdOffsetReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNALLUPDOFFSETREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynAllUpdOffsetReq)
  })
_sym_db.RegisterMessage(DynAllUpdOffsetReq)

DynDetailReply = _reflection.GeneratedProtocolMessageType('DynDetailReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNDETAILREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynDetailReply)
  })
_sym_db.RegisterMessage(DynDetailReply)

DynDetailReq = _reflection.GeneratedProtocolMessageType('DynDetailReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNDETAILREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynDetailReq)
  })
_sym_db.RegisterMessage(DynDetailReq)

DynDetailsReply = _reflection.GeneratedProtocolMessageType('DynDetailsReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNDETAILSREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynDetailsReply)
  })
_sym_db.RegisterMessage(DynDetailsReply)

DynDetailsReq = _reflection.GeneratedProtocolMessageType('DynDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNDETAILSREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynDetailsReq)
  })
_sym_db.RegisterMessage(DynDetailsReq)

DynFakeCardReply = _reflection.GeneratedProtocolMessageType('DynFakeCardReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNFAKECARDREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynFakeCardReply)
  })
_sym_db.RegisterMessage(DynFakeCardReply)

DynFakeCardReq = _reflection.GeneratedProtocolMessageType('DynFakeCardReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNFAKECARDREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynFakeCardReq)
  })
_sym_db.RegisterMessage(DynFakeCardReq)

DynLightReply = _reflection.GeneratedProtocolMessageType('DynLightReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNLIGHTREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynLightReply)
  })
_sym_db.RegisterMessage(DynLightReply)

DynLightReq = _reflection.GeneratedProtocolMessageType('DynLightReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNLIGHTREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynLightReq)
  })
_sym_db.RegisterMessage(DynLightReq)

DynMixUpListViewMoreReply = _reflection.GeneratedProtocolMessageType('DynMixUpListViewMoreReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNMIXUPLISTVIEWMOREREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynMixUpListViewMoreReply)
  })
_sym_db.RegisterMessage(DynMixUpListViewMoreReply)

DynMixUpListViewMoreReq = _reflection.GeneratedProtocolMessageType('DynMixUpListViewMoreReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNMIXUPLISTVIEWMOREREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynMixUpListViewMoreReq)
  })
_sym_db.RegisterMessage(DynMixUpListViewMoreReq)

DynRcmdReply = _reflection.GeneratedProtocolMessageType('DynRcmdReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNRCMDREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynRcmdReply)
  })
_sym_db.RegisterMessage(DynRcmdReply)

DynRcmdReq = _reflection.GeneratedProtocolMessageType('DynRcmdReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNRCMDREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynRcmdReq)
  })
_sym_db.RegisterMessage(DynRcmdReq)

DynRcmdUpExchangeReply = _reflection.GeneratedProtocolMessageType('DynRcmdUpExchangeReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNRCMDUPEXCHANGEREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynRcmdUpExchangeReply)
  })
_sym_db.RegisterMessage(DynRcmdUpExchangeReply)

DynRcmdUpExchangeReq = _reflection.GeneratedProtocolMessageType('DynRcmdUpExchangeReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNRCMDUPEXCHANGEREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynRcmdUpExchangeReq)
  })
_sym_db.RegisterMessage(DynRcmdUpExchangeReq)

DynRegionRcmd = _reflection.GeneratedProtocolMessageType('DynRegionRcmd', (_message.Message,), {
  'DESCRIPTOR' : _DYNREGIONRCMD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynRegionRcmd)
  })
_sym_db.RegisterMessage(DynRegionRcmd)

DynRegionRcmdItem = _reflection.GeneratedProtocolMessageType('DynRegionRcmdItem', (_message.Message,), {
  'DESCRIPTOR' : _DYNREGIONRCMDITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynRegionRcmdItem)
  })
_sym_db.RegisterMessage(DynRegionRcmdItem)

DynSearchReply = _reflection.GeneratedProtocolMessageType('DynSearchReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNSEARCHREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynSearchReply)
  })
_sym_db.RegisterMessage(DynSearchReply)

DynSearchReq = _reflection.GeneratedProtocolMessageType('DynSearchReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNSEARCHREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynSearchReq)
  })
_sym_db.RegisterMessage(DynSearchReq)

DynServerDetailsReply = _reflection.GeneratedProtocolMessageType('DynServerDetailsReply', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DYNSERVERDETAILSREPLY_ITEMSENTRY,
    '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynServerDetailsReply.ItemsEntry)
    })
  ,
  'DESCRIPTOR' : _DYNSERVERDETAILSREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynServerDetailsReply)
  })
_sym_db.RegisterMessage(DynServerDetailsReply)
_sym_db.RegisterMessage(DynServerDetailsReply.ItemsEntry)

DynServerDetailsReq = _reflection.GeneratedProtocolMessageType('DynServerDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNSERVERDETAILSREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynServerDetailsReq)
  })
_sym_db.RegisterMessage(DynServerDetailsReq)

DynSpaceReq = _reflection.GeneratedProtocolMessageType('DynSpaceReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNSPACEREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynSpaceReq)
  })
_sym_db.RegisterMessage(DynSpaceReq)

DynSpaceRsp = _reflection.GeneratedProtocolMessageType('DynSpaceRsp', (_message.Message,), {
  'DESCRIPTOR' : _DYNSPACERSP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynSpaceRsp)
  })
_sym_db.RegisterMessage(DynSpaceRsp)

DynSpaceSearchDetailsReply = _reflection.GeneratedProtocolMessageType('DynSpaceSearchDetailsReply', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY,
    '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynSpaceSearchDetailsReply.ItemsEntry)
    })
  ,
  'DESCRIPTOR' : _DYNSPACESEARCHDETAILSREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynSpaceSearchDetailsReply)
  })
_sym_db.RegisterMessage(DynSpaceSearchDetailsReply)
_sym_db.RegisterMessage(DynSpaceSearchDetailsReply.ItemsEntry)

DynSpaceSearchDetailsReq = _reflection.GeneratedProtocolMessageType('DynSpaceSearchDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNSPACESEARCHDETAILSREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynSpaceSearchDetailsReq)
  })
_sym_db.RegisterMessage(DynSpaceSearchDetailsReq)

DynTab = _reflection.GeneratedProtocolMessageType('DynTab', (_message.Message,), {
  'DESCRIPTOR' : _DYNTAB,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynTab)
  })
_sym_db.RegisterMessage(DynTab)

DynTabReply = _reflection.GeneratedProtocolMessageType('DynTabReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNTABREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynTabReply)
  })
_sym_db.RegisterMessage(DynTabReply)

DynTabReq = _reflection.GeneratedProtocolMessageType('DynTabReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNTABREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynTabReq)
  })
_sym_db.RegisterMessage(DynTabReq)

DynThumbReq = _reflection.GeneratedProtocolMessageType('DynThumbReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNTHUMBREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynThumbReq)
  })
_sym_db.RegisterMessage(DynThumbReq)

DynVideoPersonalReply = _reflection.GeneratedProtocolMessageType('DynVideoPersonalReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOPERSONALREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynVideoPersonalReply)
  })
_sym_db.RegisterMessage(DynVideoPersonalReply)

DynVideoPersonalReq = _reflection.GeneratedProtocolMessageType('DynVideoPersonalReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOPERSONALREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynVideoPersonalReq)
  })
_sym_db.RegisterMessage(DynVideoPersonalReq)

DynVideoReply = _reflection.GeneratedProtocolMessageType('DynVideoReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynVideoReply)
  })
_sym_db.RegisterMessage(DynVideoReply)

DynVideoReq = _reflection.GeneratedProtocolMessageType('DynVideoReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynVideoReq)
  })
_sym_db.RegisterMessage(DynVideoReq)

DynVideoUpdOffsetReq = _reflection.GeneratedProtocolMessageType('DynVideoUpdOffsetReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOUPDOFFSETREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynVideoUpdOffsetReq)
  })
_sym_db.RegisterMessage(DynVideoUpdOffsetReq)

DynVoteReply = _reflection.GeneratedProtocolMessageType('DynVoteReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNVOTEREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynVoteReply)
  })
_sym_db.RegisterMessage(DynVoteReply)

DynVoteReq = _reflection.GeneratedProtocolMessageType('DynVoteReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVOTEREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynVoteReq)
  })
_sym_db.RegisterMessage(DynVoteReq)

DynamicItem = _reflection.GeneratedProtocolMessageType('DynamicItem', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynamicItem)
  })
_sym_db.RegisterMessage(DynamicItem)

DynamicList = _reflection.GeneratedProtocolMessageType('DynamicList', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICLIST,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.DynamicList)
  })
_sym_db.RegisterMessage(DynamicList)

ExtInfoCommon = _reflection.GeneratedProtocolMessageType('ExtInfoCommon', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOCOMMON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ExtInfoCommon)
  })
_sym_db.RegisterMessage(ExtInfoCommon)

ExtInfoGame = _reflection.GeneratedProtocolMessageType('ExtInfoGame', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOGAME,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ExtInfoGame)
  })
_sym_db.RegisterMessage(ExtInfoGame)

ExtInfoHot = _reflection.GeneratedProtocolMessageType('ExtInfoHot', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOHOT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ExtInfoHot)
  })
_sym_db.RegisterMessage(ExtInfoHot)

ExtInfoLBS = _reflection.GeneratedProtocolMessageType('ExtInfoLBS', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOLBS,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ExtInfoLBS)
  })
_sym_db.RegisterMessage(ExtInfoLBS)

ExtInfoOGV = _reflection.GeneratedProtocolMessageType('ExtInfoOGV', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOOGV,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ExtInfoOGV)
  })
_sym_db.RegisterMessage(ExtInfoOGV)

ExtInfoTopic = _reflection.GeneratedProtocolMessageType('ExtInfoTopic', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOTOPIC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ExtInfoTopic)
  })
_sym_db.RegisterMessage(ExtInfoTopic)

Extend = _reflection.GeneratedProtocolMessageType('Extend', (_message.Message,), {
  'DESCRIPTOR' : _EXTEND,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Extend)
  })
_sym_db.RegisterMessage(Extend)

ExtendReply = _reflection.GeneratedProtocolMessageType('ExtendReply', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ExtendReply)
  })
_sym_db.RegisterMessage(ExtendReply)

ExtendReplyParam = _reflection.GeneratedProtocolMessageType('ExtendReplyParam', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDREPLYPARAM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ExtendReplyParam)
  })
_sym_db.RegisterMessage(ExtendReplyParam)

FollowListItem = _reflection.GeneratedProtocolMessageType('FollowListItem', (_message.Message,), {
  'DESCRIPTOR' : _FOLLOWLISTITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.FollowListItem)
  })
_sym_db.RegisterMessage(FollowListItem)

GoodsItem = _reflection.GeneratedProtocolMessageType('GoodsItem', (_message.Message,), {
  'DESCRIPTOR' : _GOODSITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.GoodsItem)
  })
_sym_db.RegisterMessage(GoodsItem)

GuideBarInfo = _reflection.GeneratedProtocolMessageType('GuideBarInfo', (_message.Message,), {
  'DESCRIPTOR' : _GUIDEBARINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.GuideBarInfo)
  })
_sym_db.RegisterMessage(GuideBarInfo)

HighlightText = _reflection.GeneratedProtocolMessageType('HighlightText', (_message.Message,), {
  'DESCRIPTOR' : _HIGHLIGHTTEXT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.HighlightText)
  })
_sym_db.RegisterMessage(HighlightText)

IconBadge = _reflection.GeneratedProtocolMessageType('IconBadge', (_message.Message,), {
  'DESCRIPTOR' : _ICONBADGE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.IconBadge)
  })
_sym_db.RegisterMessage(IconBadge)

IconButton = _reflection.GeneratedProtocolMessageType('IconButton', (_message.Message,), {
  'DESCRIPTOR' : _ICONBUTTON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.IconButton)
  })
_sym_db.RegisterMessage(IconButton)

InfoOGV = _reflection.GeneratedProtocolMessageType('InfoOGV', (_message.Message,), {
  'DESCRIPTOR' : _INFOOGV,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.InfoOGV)
  })
_sym_db.RegisterMessage(InfoOGV)

InteractionFace = _reflection.GeneratedProtocolMessageType('InteractionFace', (_message.Message,), {
  'DESCRIPTOR' : _INTERACTIONFACE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.InteractionFace)
  })
_sym_db.RegisterMessage(InteractionFace)

InteractionItem = _reflection.GeneratedProtocolMessageType('InteractionItem', (_message.Message,), {
  'DESCRIPTOR' : _INTERACTIONITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.InteractionItem)
  })
_sym_db.RegisterMessage(InteractionItem)

InteractionStat = _reflection.GeneratedProtocolMessageType('InteractionStat', (_message.Message,), {
  'DESCRIPTOR' : _INTERACTIONSTAT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.InteractionStat)
  })
_sym_db.RegisterMessage(InteractionStat)

LikeAnimation = _reflection.GeneratedProtocolMessageType('LikeAnimation', (_message.Message,), {
  'DESCRIPTOR' : _LIKEANIMATION,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.LikeAnimation)
  })
_sym_db.RegisterMessage(LikeAnimation)

LikeInfo = _reflection.GeneratedProtocolMessageType('LikeInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIKEINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.LikeInfo)
  })
_sym_db.RegisterMessage(LikeInfo)

LikeListReply = _reflection.GeneratedProtocolMessageType('LikeListReply', (_message.Message,), {
  'DESCRIPTOR' : _LIKELISTREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.LikeListReply)
  })
_sym_db.RegisterMessage(LikeListReply)

LikeListReq = _reflection.GeneratedProtocolMessageType('LikeListReq', (_message.Message,), {
  'DESCRIPTOR' : _LIKELISTREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.LikeListReq)
  })
_sym_db.RegisterMessage(LikeListReq)

LikeUser = _reflection.GeneratedProtocolMessageType('LikeUser', (_message.Message,), {
  'DESCRIPTOR' : _LIKEUSER,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.LikeUser)
  })
_sym_db.RegisterMessage(LikeUser)

LiveInfo = _reflection.GeneratedProtocolMessageType('LiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIVEINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.LiveInfo)
  })
_sym_db.RegisterMessage(LiveInfo)

LivePendant = _reflection.GeneratedProtocolMessageType('LivePendant', (_message.Message,), {
  'DESCRIPTOR' : _LIVEPENDANT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.LivePendant)
  })
_sym_db.RegisterMessage(LivePendant)

MatchTeam = _reflection.GeneratedProtocolMessageType('MatchTeam', (_message.Message,), {
  'DESCRIPTOR' : _MATCHTEAM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MatchTeam)
  })
_sym_db.RegisterMessage(MatchTeam)

MdlDynApplet = _reflection.GeneratedProtocolMessageType('MdlDynApplet', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNAPPLET,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynApplet)
  })
_sym_db.RegisterMessage(MdlDynApplet)

MdlDynArchive = _reflection.GeneratedProtocolMessageType('MdlDynArchive', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNARCHIVE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynArchive)
  })
_sym_db.RegisterMessage(MdlDynArchive)

MdlDynArticle = _reflection.GeneratedProtocolMessageType('MdlDynArticle', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNARTICLE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynArticle)
  })
_sym_db.RegisterMessage(MdlDynArticle)

MdlDynCommon = _reflection.GeneratedProtocolMessageType('MdlDynCommon', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNCOMMON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynCommon)
  })
_sym_db.RegisterMessage(MdlDynCommon)

MdlDynCourBatch = _reflection.GeneratedProtocolMessageType('MdlDynCourBatch', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNCOURBATCH,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynCourBatch)
  })
_sym_db.RegisterMessage(MdlDynCourBatch)

MdlDynCourSeason = _reflection.GeneratedProtocolMessageType('MdlDynCourSeason', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNCOURSEASON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynCourSeason)
  })
_sym_db.RegisterMessage(MdlDynCourSeason)

MdlDynDraw = _reflection.GeneratedProtocolMessageType('MdlDynDraw', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNDRAW,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynDraw)
  })
_sym_db.RegisterMessage(MdlDynDraw)

MdlDynDrawItem = _reflection.GeneratedProtocolMessageType('MdlDynDrawItem', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNDRAWITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynDrawItem)
  })
_sym_db.RegisterMessage(MdlDynDrawItem)

MdlDynDrawTag = _reflection.GeneratedProtocolMessageType('MdlDynDrawTag', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNDRAWTAG,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynDrawTag)
  })
_sym_db.RegisterMessage(MdlDynDrawTag)

MdlDynDrawTagItem = _reflection.GeneratedProtocolMessageType('MdlDynDrawTagItem', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNDRAWTAGITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynDrawTagItem)
  })
_sym_db.RegisterMessage(MdlDynDrawTagItem)

MdlDynForward = _reflection.GeneratedProtocolMessageType('MdlDynForward', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNFORWARD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynForward)
  })
_sym_db.RegisterMessage(MdlDynForward)

MdlDynLive = _reflection.GeneratedProtocolMessageType('MdlDynLive', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNLIVE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynLive)
  })
_sym_db.RegisterMessage(MdlDynLive)

MdlDynLiveRcmd = _reflection.GeneratedProtocolMessageType('MdlDynLiveRcmd', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNLIVERCMD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynLiveRcmd)
  })
_sym_db.RegisterMessage(MdlDynLiveRcmd)

MdlDynMedialist = _reflection.GeneratedProtocolMessageType('MdlDynMedialist', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNMEDIALIST,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynMedialist)
  })
_sym_db.RegisterMessage(MdlDynMedialist)

MdlDynMusic = _reflection.GeneratedProtocolMessageType('MdlDynMusic', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNMUSIC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynMusic)
  })
_sym_db.RegisterMessage(MdlDynMusic)

MdlDynPGC = _reflection.GeneratedProtocolMessageType('MdlDynPGC', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNPGC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynPGC)
  })
_sym_db.RegisterMessage(MdlDynPGC)

MdlDynSubscription = _reflection.GeneratedProtocolMessageType('MdlDynSubscription', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNSUBSCRIPTION,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynSubscription)
  })
_sym_db.RegisterMessage(MdlDynSubscription)

MdlDynSubscriptionNew = _reflection.GeneratedProtocolMessageType('MdlDynSubscriptionNew', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNSUBSCRIPTIONNEW,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynSubscriptionNew)
  })
_sym_db.RegisterMessage(MdlDynSubscriptionNew)

MdlDynUGCSeason = _reflection.GeneratedProtocolMessageType('MdlDynUGCSeason', (_message.Message,), {
  'DESCRIPTOR' : _MDLDYNUGCSEASON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MdlDynUGCSeason)
  })
_sym_db.RegisterMessage(MdlDynUGCSeason)

MixUpListItem = _reflection.GeneratedProtocolMessageType('MixUpListItem', (_message.Message,), {
  'DESCRIPTOR' : _MIXUPLISTITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MixUpListItem)
  })
_sym_db.RegisterMessage(MixUpListItem)

MixUpListLiveItem = _reflection.GeneratedProtocolMessageType('MixUpListLiveItem', (_message.Message,), {
  'DESCRIPTOR' : _MIXUPLISTLIVEITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.MixUpListLiveItem)
  })
_sym_db.RegisterMessage(MixUpListLiveItem)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Module)
  })
_sym_db.RegisterMessage(Module)

ModuleAd = _reflection.GeneratedProtocolMessageType('ModuleAd', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleAd)
  })
_sym_db.RegisterMessage(ModuleAd)

ModuleAdditional = _reflection.GeneratedProtocolMessageType('ModuleAdditional', (_message.Message,), {
  'DESCRIPTOR' : _MODULEADDITIONAL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleAdditional)
  })
_sym_db.RegisterMessage(ModuleAdditional)

ModuleAuthor = _reflection.GeneratedProtocolMessageType('ModuleAuthor', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHOR,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleAuthor)
  })
_sym_db.RegisterMessage(ModuleAuthor)

ModuleAuthorBadgeButton = _reflection.GeneratedProtocolMessageType('ModuleAuthorBadgeButton', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHORBADGEBUTTON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleAuthorBadgeButton)
  })
_sym_db.RegisterMessage(ModuleAuthorBadgeButton)

ModuleAuthorForward = _reflection.GeneratedProtocolMessageType('ModuleAuthorForward', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHORFORWARD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleAuthorForward)
  })
_sym_db.RegisterMessage(ModuleAuthorForward)

ModuleAuthorForwardTitle = _reflection.GeneratedProtocolMessageType('ModuleAuthorForwardTitle', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHORFORWARDTITLE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleAuthorForwardTitle)
  })
_sym_db.RegisterMessage(ModuleAuthorForwardTitle)

ModuleBanner = _reflection.GeneratedProtocolMessageType('ModuleBanner', (_message.Message,), {
  'DESCRIPTOR' : _MODULEBANNER,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleBanner)
  })
_sym_db.RegisterMessage(ModuleBanner)

ModuleBannerUser = _reflection.GeneratedProtocolMessageType('ModuleBannerUser', (_message.Message,), {
  'DESCRIPTOR' : _MODULEBANNERUSER,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleBannerUser)
  })
_sym_db.RegisterMessage(ModuleBannerUser)

ModuleBannerUserItem = _reflection.GeneratedProtocolMessageType('ModuleBannerUserItem', (_message.Message,), {
  'DESCRIPTOR' : _MODULEBANNERUSERITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleBannerUserItem)
  })
_sym_db.RegisterMessage(ModuleBannerUserItem)

ModuleButtom = _reflection.GeneratedProtocolMessageType('ModuleButtom', (_message.Message,), {
  'DESCRIPTOR' : _MODULEBUTTOM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleButtom)
  })
_sym_db.RegisterMessage(ModuleButtom)

ModuleComment = _reflection.GeneratedProtocolMessageType('ModuleComment', (_message.Message,), {
  'DESCRIPTOR' : _MODULECOMMENT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleComment)
  })
_sym_db.RegisterMessage(ModuleComment)

ModuleDesc = _reflection.GeneratedProtocolMessageType('ModuleDesc', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDESC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleDesc)
  })
_sym_db.RegisterMessage(ModuleDesc)

ModuleDescGoods = _reflection.GeneratedProtocolMessageType('ModuleDescGoods', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDESCGOODS,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleDescGoods)
  })
_sym_db.RegisterMessage(ModuleDescGoods)

ModuleDispute = _reflection.GeneratedProtocolMessageType('ModuleDispute', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDISPUTE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleDispute)
  })
_sym_db.RegisterMessage(ModuleDispute)

ModuleDynamic = _reflection.GeneratedProtocolMessageType('ModuleDynamic', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDYNAMIC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleDynamic)
  })
_sym_db.RegisterMessage(ModuleDynamic)

ModuleExtend = _reflection.GeneratedProtocolMessageType('ModuleExtend', (_message.Message,), {
  'DESCRIPTOR' : _MODULEEXTEND,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleExtend)
  })
_sym_db.RegisterMessage(ModuleExtend)

ModuleExtendItem = _reflection.GeneratedProtocolMessageType('ModuleExtendItem', (_message.Message,), {
  'DESCRIPTOR' : _MODULEEXTENDITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleExtendItem)
  })
_sym_db.RegisterMessage(ModuleExtendItem)

ModuleFold = _reflection.GeneratedProtocolMessageType('ModuleFold', (_message.Message,), {
  'DESCRIPTOR' : _MODULEFOLD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleFold)
  })
_sym_db.RegisterMessage(ModuleFold)

ModuleInteraction = _reflection.GeneratedProtocolMessageType('ModuleInteraction', (_message.Message,), {
  'DESCRIPTOR' : _MODULEINTERACTION,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleInteraction)
  })
_sym_db.RegisterMessage(ModuleInteraction)

ModuleItemNull = _reflection.GeneratedProtocolMessageType('ModuleItemNull', (_message.Message,), {
  'DESCRIPTOR' : _MODULEITEMNULL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleItemNull)
  })
_sym_db.RegisterMessage(ModuleItemNull)

ModuleLikeUser = _reflection.GeneratedProtocolMessageType('ModuleLikeUser', (_message.Message,), {
  'DESCRIPTOR' : _MODULELIKEUSER,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleLikeUser)
  })
_sym_db.RegisterMessage(ModuleLikeUser)

ModuleRcmd = _reflection.GeneratedProtocolMessageType('ModuleRcmd', (_message.Message,), {
  'DESCRIPTOR' : _MODULERCMD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleRcmd)
  })
_sym_db.RegisterMessage(ModuleRcmd)

ModuleRecommend = _reflection.GeneratedProtocolMessageType('ModuleRecommend', (_message.Message,), {
  'DESCRIPTOR' : _MODULERECOMMEND,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleRecommend)
  })
_sym_db.RegisterMessage(ModuleRecommend)

ModuleShareInfo = _reflection.GeneratedProtocolMessageType('ModuleShareInfo', (_message.Message,), {
  'DESCRIPTOR' : _MODULESHAREINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleShareInfo)
  })
_sym_db.RegisterMessage(ModuleShareInfo)

ModuleStat = _reflection.GeneratedProtocolMessageType('ModuleStat', (_message.Message,), {
  'DESCRIPTOR' : _MODULESTAT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleStat)
  })
_sym_db.RegisterMessage(ModuleStat)

ModuleStory = _reflection.GeneratedProtocolMessageType('ModuleStory', (_message.Message,), {
  'DESCRIPTOR' : _MODULESTORY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleStory)
  })
_sym_db.RegisterMessage(ModuleStory)

ModuleTitle = _reflection.GeneratedProtocolMessageType('ModuleTitle', (_message.Message,), {
  'DESCRIPTOR' : _MODULETITLE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleTitle)
  })
_sym_db.RegisterMessage(ModuleTitle)

ModuleTop = _reflection.GeneratedProtocolMessageType('ModuleTop', (_message.Message,), {
  'DESCRIPTOR' : _MODULETOP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleTop)
  })
_sym_db.RegisterMessage(ModuleTop)

ModuleTopTag = _reflection.GeneratedProtocolMessageType('ModuleTopTag', (_message.Message,), {
  'DESCRIPTOR' : _MODULETOPTAG,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleTopTag)
  })
_sym_db.RegisterMessage(ModuleTopTag)

ModuleTopic = _reflection.GeneratedProtocolMessageType('ModuleTopic', (_message.Message,), {
  'DESCRIPTOR' : _MODULETOPIC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleTopic)
  })
_sym_db.RegisterMessage(ModuleTopic)

ModuleTopicBrief = _reflection.GeneratedProtocolMessageType('ModuleTopicBrief', (_message.Message,), {
  'DESCRIPTOR' : _MODULETOPICBRIEF,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleTopicBrief)
  })
_sym_db.RegisterMessage(ModuleTopicBrief)

ModuleTopicDetailsExt = _reflection.GeneratedProtocolMessageType('ModuleTopicDetailsExt', (_message.Message,), {
  'DESCRIPTOR' : _MODULETOPICDETAILSEXT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ModuleTopicDetailsExt)
  })
_sym_db.RegisterMessage(ModuleTopicDetailsExt)

Nameplate = _reflection.GeneratedProtocolMessageType('Nameplate', (_message.Message,), {
  'DESCRIPTOR' : _NAMEPLATE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Nameplate)
  })
_sym_db.RegisterMessage(Nameplate)

NewEP = _reflection.GeneratedProtocolMessageType('NewEP', (_message.Message,), {
  'DESCRIPTOR' : _NEWEP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.NewEP)
  })
_sym_db.RegisterMessage(NewEP)

NoReply = _reflection.GeneratedProtocolMessageType('NoReply', (_message.Message,), {
  'DESCRIPTOR' : _NOREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.NoReply)
  })
_sym_db.RegisterMessage(NoReply)

NoReq = _reflection.GeneratedProtocolMessageType('NoReq', (_message.Message,), {
  'DESCRIPTOR' : _NOREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.NoReq)
  })
_sym_db.RegisterMessage(NoReq)

OfficialAccountInfo = _reflection.GeneratedProtocolMessageType('OfficialAccountInfo', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALACCOUNTINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialAccountInfo)
  })
_sym_db.RegisterMessage(OfficialAccountInfo)

OfficialAccountsReply = _reflection.GeneratedProtocolMessageType('OfficialAccountsReply', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALACCOUNTSREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialAccountsReply)
  })
_sym_db.RegisterMessage(OfficialAccountsReply)

OfficialAccountsReq = _reflection.GeneratedProtocolMessageType('OfficialAccountsReq', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALACCOUNTSREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialAccountsReq)
  })
_sym_db.RegisterMessage(OfficialAccountsReq)

OfficialDynamicsReply = _reflection.GeneratedProtocolMessageType('OfficialDynamicsReply', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALDYNAMICSREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialDynamicsReply)
  })
_sym_db.RegisterMessage(OfficialDynamicsReply)

OfficialDynamicsReq = _reflection.GeneratedProtocolMessageType('OfficialDynamicsReq', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALDYNAMICSREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialDynamicsReq)
  })
_sym_db.RegisterMessage(OfficialDynamicsReq)

OfficialItem = _reflection.GeneratedProtocolMessageType('OfficialItem', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialItem)
  })
_sym_db.RegisterMessage(OfficialItem)

OfficialRcmdArchive = _reflection.GeneratedProtocolMessageType('OfficialRcmdArchive', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALRCMDARCHIVE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialRcmdArchive)
  })
_sym_db.RegisterMessage(OfficialRcmdArchive)

OfficialRcmdDynamic = _reflection.GeneratedProtocolMessageType('OfficialRcmdDynamic', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALRCMDDYNAMIC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialRcmdDynamic)
  })
_sym_db.RegisterMessage(OfficialRcmdDynamic)

OfficialVerify = _reflection.GeneratedProtocolMessageType('OfficialVerify', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALVERIFY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.OfficialVerify)
  })
_sym_db.RegisterMessage(OfficialVerify)

PGCSeason = _reflection.GeneratedProtocolMessageType('PGCSeason', (_message.Message,), {
  'DESCRIPTOR' : _PGCSEASON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.PGCSeason)
  })
_sym_db.RegisterMessage(PGCSeason)

PlayurlParam = _reflection.GeneratedProtocolMessageType('PlayurlParam', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURLPARAM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.PlayurlParam)
  })
_sym_db.RegisterMessage(PlayurlParam)

Popup = _reflection.GeneratedProtocolMessageType('Popup', (_message.Message,), {
  'DESCRIPTOR' : _POPUP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Popup)
  })
_sym_db.RegisterMessage(Popup)

RcmdArchive = _reflection.GeneratedProtocolMessageType('RcmdArchive', (_message.Message,), {
  'DESCRIPTOR' : _RCMDARCHIVE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.RcmdArchive)
  })
_sym_db.RegisterMessage(RcmdArchive)

RcmdAuthor = _reflection.GeneratedProtocolMessageType('RcmdAuthor', (_message.Message,), {
  'DESCRIPTOR' : _RCMDAUTHOR,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.RcmdAuthor)
  })
_sym_db.RegisterMessage(RcmdAuthor)

RcmdItem = _reflection.GeneratedProtocolMessageType('RcmdItem', (_message.Message,), {
  'DESCRIPTOR' : _RCMDITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.RcmdItem)
  })
_sym_db.RegisterMessage(RcmdItem)

RcmdOption = _reflection.GeneratedProtocolMessageType('RcmdOption', (_message.Message,), {
  'DESCRIPTOR' : _RCMDOPTION,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.RcmdOption)
  })
_sym_db.RegisterMessage(RcmdOption)

RcmdTopButton = _reflection.GeneratedProtocolMessageType('RcmdTopButton', (_message.Message,), {
  'DESCRIPTOR' : _RCMDTOPBUTTON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.RcmdTopButton)
  })
_sym_db.RegisterMessage(RcmdTopButton)

RcmdUPsParam = _reflection.GeneratedProtocolMessageType('RcmdUPsParam', (_message.Message,), {
  'DESCRIPTOR' : _RCMDUPSPARAM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.RcmdUPsParam)
  })
_sym_db.RegisterMessage(RcmdUPsParam)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), {
  'DESCRIPTOR' : _RELATION,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Relation)
  })
_sym_db.RegisterMessage(Relation)

RepostListReq = _reflection.GeneratedProtocolMessageType('RepostListReq', (_message.Message,), {
  'DESCRIPTOR' : _REPOSTLISTREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.RepostListReq)
  })
_sym_db.RegisterMessage(RepostListReq)

RepostListRsp = _reflection.GeneratedProtocolMessageType('RepostListRsp', (_message.Message,), {
  'DESCRIPTOR' : _REPOSTLISTRSP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.RepostListRsp)
  })
_sym_db.RegisterMessage(RepostListRsp)

SchoolRecommendReply = _reflection.GeneratedProtocolMessageType('SchoolRecommendReply', (_message.Message,), {
  'DESCRIPTOR' : _SCHOOLRECOMMENDREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SchoolRecommendReply)
  })
_sym_db.RegisterMessage(SchoolRecommendReply)

SchoolRecommendReq = _reflection.GeneratedProtocolMessageType('SchoolRecommendReq', (_message.Message,), {
  'DESCRIPTOR' : _SCHOOLRECOMMENDREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SchoolRecommendReq)
  })
_sym_db.RegisterMessage(SchoolRecommendReq)

SchoolSearchReply = _reflection.GeneratedProtocolMessageType('SchoolSearchReply', (_message.Message,), {
  'DESCRIPTOR' : _SCHOOLSEARCHREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SchoolSearchReply)
  })
_sym_db.RegisterMessage(SchoolSearchReply)

SchoolSearchReq = _reflection.GeneratedProtocolMessageType('SchoolSearchReq', (_message.Message,), {
  'DESCRIPTOR' : _SCHOOLSEARCHREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SchoolSearchReq)
  })
_sym_db.RegisterMessage(SchoolSearchReq)

SearchChannel = _reflection.GeneratedProtocolMessageType('SearchChannel', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHCHANNEL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SearchChannel)
  })
_sym_db.RegisterMessage(SearchChannel)

SearchInfo = _reflection.GeneratedProtocolMessageType('SearchInfo', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SearchInfo)
  })
_sym_db.RegisterMessage(SearchInfo)

SearchToast = _reflection.GeneratedProtocolMessageType('SearchToast', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHTOAST,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SearchToast)
  })
_sym_db.RegisterMessage(SearchToast)

SearchTopic = _reflection.GeneratedProtocolMessageType('SearchTopic', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHTOPIC,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SearchTopic)
  })
_sym_db.RegisterMessage(SearchTopic)

SearchTopicButton = _reflection.GeneratedProtocolMessageType('SearchTopicButton', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHTOPICBUTTON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SearchTopicButton)
  })
_sym_db.RegisterMessage(SearchTopicButton)

SearchTopicItem = _reflection.GeneratedProtocolMessageType('SearchTopicItem', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHTOPICITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SearchTopicItem)
  })
_sym_db.RegisterMessage(SearchTopicItem)

SetDecisionReq = _reflection.GeneratedProtocolMessageType('SetDecisionReq', (_message.Message,), {
  'DESCRIPTOR' : _SETDECISIONREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SetDecisionReq)
  })
_sym_db.RegisterMessage(SetDecisionReq)

SetRecentCampusReq = _reflection.GeneratedProtocolMessageType('SetRecentCampusReq', (_message.Message,), {
  'DESCRIPTOR' : _SETRECENTCAMPUSREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SetRecentCampusReq)
  })
_sym_db.RegisterMessage(SetRecentCampusReq)

ShareChannel = _reflection.GeneratedProtocolMessageType('ShareChannel', (_message.Message,), {
  'DESCRIPTOR' : _SHARECHANNEL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ShareChannel)
  })
_sym_db.RegisterMessage(ShareChannel)

ShareReserve = _reflection.GeneratedProtocolMessageType('ShareReserve', (_message.Message,), {
  'DESCRIPTOR' : _SHARERESERVE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ShareReserve)
  })
_sym_db.RegisterMessage(ShareReserve)

SortType = _reflection.GeneratedProtocolMessageType('SortType', (_message.Message,), {
  'DESCRIPTOR' : _SORTTYPE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SortType)
  })
_sym_db.RegisterMessage(SortType)

StoryArchive = _reflection.GeneratedProtocolMessageType('StoryArchive', (_message.Message,), {
  'DESCRIPTOR' : _STORYARCHIVE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.StoryArchive)
  })
_sym_db.RegisterMessage(StoryArchive)

StoryItem = _reflection.GeneratedProtocolMessageType('StoryItem', (_message.Message,), {
  'DESCRIPTOR' : _STORYITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.StoryItem)
  })
_sym_db.RegisterMessage(StoryItem)

SubscribeCampusReq = _reflection.GeneratedProtocolMessageType('SubscribeCampusReq', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBECAMPUSREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.SubscribeCampusReq)
  })
_sym_db.RegisterMessage(SubscribeCampusReq)

ThreePointAttention = _reflection.GeneratedProtocolMessageType('ThreePointAttention', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTATTENTION,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointAttention)
  })
_sym_db.RegisterMessage(ThreePointAttention)

ThreePointAutoPlay = _reflection.GeneratedProtocolMessageType('ThreePointAutoPlay', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTAUTOPLAY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointAutoPlay)
  })
_sym_db.RegisterMessage(ThreePointAutoPlay)

ThreePointComment = _reflection.GeneratedProtocolMessageType('ThreePointComment', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTCOMMENT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointComment)
  })
_sym_db.RegisterMessage(ThreePointComment)

ThreePointDefault = _reflection.GeneratedProtocolMessageType('ThreePointDefault', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTDEFAULT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointDefault)
  })
_sym_db.RegisterMessage(ThreePointDefault)

ThreePointDefaultToast = _reflection.GeneratedProtocolMessageType('ThreePointDefaultToast', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTDEFAULTTOAST,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointDefaultToast)
  })
_sym_db.RegisterMessage(ThreePointDefaultToast)

ThreePointDislike = _reflection.GeneratedProtocolMessageType('ThreePointDislike', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTDISLIKE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointDislike)
  })
_sym_db.RegisterMessage(ThreePointDislike)

ThreePointFavorite = _reflection.GeneratedProtocolMessageType('ThreePointFavorite', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTFAVORITE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointFavorite)
  })
_sym_db.RegisterMessage(ThreePointFavorite)

ThreePointHide = _reflection.GeneratedProtocolMessageType('ThreePointHide', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTHIDE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointHide)
  })
_sym_db.RegisterMessage(ThreePointHide)

ThreePointHideInteractive = _reflection.GeneratedProtocolMessageType('ThreePointHideInteractive', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTHIDEINTERACTIVE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointHideInteractive)
  })
_sym_db.RegisterMessage(ThreePointHideInteractive)

ThreePointItem = _reflection.GeneratedProtocolMessageType('ThreePointItem', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointItem)
  })
_sym_db.RegisterMessage(ThreePointItem)

ThreePointShare = _reflection.GeneratedProtocolMessageType('ThreePointShare', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTSHARE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointShare)
  })
_sym_db.RegisterMessage(ThreePointShare)

ThreePointShareChannel = _reflection.GeneratedProtocolMessageType('ThreePointShareChannel', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTSHARECHANNEL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointShareChannel)
  })
_sym_db.RegisterMessage(ThreePointShareChannel)

ThreePointTop = _reflection.GeneratedProtocolMessageType('ThreePointTop', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTTOP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointTop)
  })
_sym_db.RegisterMessage(ThreePointTop)

ThreePointTopicIrrelevant = _reflection.GeneratedProtocolMessageType('ThreePointTopicIrrelevant', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTTOPICIRRELEVANT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointTopicIrrelevant)
  })
_sym_db.RegisterMessage(ThreePointTopicIrrelevant)

ThreePointWait = _reflection.GeneratedProtocolMessageType('ThreePointWait', (_message.Message,), {
  'DESCRIPTOR' : _THREEPOINTWAIT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.ThreePointWait)
  })
_sym_db.RegisterMessage(ThreePointWait)

TopAdditionUP = _reflection.GeneratedProtocolMessageType('TopAdditionUP', (_message.Message,), {
  'DESCRIPTOR' : _TOPADDITIONUP,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopAdditionUP)
  })
_sym_db.RegisterMessage(TopAdditionUP)

TopicButton = _reflection.GeneratedProtocolMessageType('TopicButton', (_message.Message,), {
  'DESCRIPTOR' : _TOPICBUTTON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicButton)
  })
_sym_db.RegisterMessage(TopicButton)

TopicItem = _reflection.GeneratedProtocolMessageType('TopicItem', (_message.Message,), {
  'DESCRIPTOR' : _TOPICITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicItem)
  })
_sym_db.RegisterMessage(TopicItem)

TopicList = _reflection.GeneratedProtocolMessageType('TopicList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICLIST,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicList)
  })
_sym_db.RegisterMessage(TopicList)

TopicListItem = _reflection.GeneratedProtocolMessageType('TopicListItem', (_message.Message,), {
  'DESCRIPTOR' : _TOPICLISTITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicListItem)
  })
_sym_db.RegisterMessage(TopicListItem)

TopicListReply = _reflection.GeneratedProtocolMessageType('TopicListReply', (_message.Message,), {
  'DESCRIPTOR' : _TOPICLISTREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicListReply)
  })
_sym_db.RegisterMessage(TopicListReply)

TopicListReq = _reflection.GeneratedProtocolMessageType('TopicListReq', (_message.Message,), {
  'DESCRIPTOR' : _TOPICLISTREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicListReq)
  })
_sym_db.RegisterMessage(TopicListReq)

TopicRcmdCard = _reflection.GeneratedProtocolMessageType('TopicRcmdCard', (_message.Message,), {
  'DESCRIPTOR' : _TOPICRCMDCARD,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicRcmdCard)
  })
_sym_db.RegisterMessage(TopicRcmdCard)

TopicSquareInfo = _reflection.GeneratedProtocolMessageType('TopicSquareInfo', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSQUAREINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicSquareInfo)
  })
_sym_db.RegisterMessage(TopicSquareInfo)

TopicSquareReply = _reflection.GeneratedProtocolMessageType('TopicSquareReply', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSQUAREREPLY,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicSquareReply)
  })
_sym_db.RegisterMessage(TopicSquareReply)

TopicSquareReq = _reflection.GeneratedProtocolMessageType('TopicSquareReq', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSQUAREREQ,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.TopicSquareReq)
  })
_sym_db.RegisterMessage(TopicSquareReq)

Unfollow = _reflection.GeneratedProtocolMessageType('Unfollow', (_message.Message,), {
  'DESCRIPTOR' : _UNFOLLOW,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Unfollow)
  })
_sym_db.RegisterMessage(Unfollow)

UnfollowUserItem = _reflection.GeneratedProtocolMessageType('UnfollowUserItem', (_message.Message,), {
  'DESCRIPTOR' : _UNFOLLOWUSERITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.UnfollowUserItem)
  })
_sym_db.RegisterMessage(UnfollowUserItem)

UpListItem = _reflection.GeneratedProtocolMessageType('UpListItem', (_message.Message,), {
  'DESCRIPTOR' : _UPLISTITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.UpListItem)
  })
_sym_db.RegisterMessage(UpListItem)

UpListMoreLabel = _reflection.GeneratedProtocolMessageType('UpListMoreLabel', (_message.Message,), {
  'DESCRIPTOR' : _UPLISTMORELABEL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.UpListMoreLabel)
  })
_sym_db.RegisterMessage(UpListMoreLabel)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

UserItemStyle = _reflection.GeneratedProtocolMessageType('UserItemStyle', (_message.Message,), {
  'DESCRIPTOR' : _USERITEMSTYLE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.UserItemStyle)
  })
_sym_db.RegisterMessage(UserItemStyle)

UserPendant = _reflection.GeneratedProtocolMessageType('UserPendant', (_message.Message,), {
  'DESCRIPTOR' : _USERPENDANT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.UserPendant)
  })
_sym_db.RegisterMessage(UserPendant)

VideoBadge = _reflection.GeneratedProtocolMessageType('VideoBadge', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOBADGE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.VideoBadge)
  })
_sym_db.RegisterMessage(VideoBadge)

VipInfo = _reflection.GeneratedProtocolMessageType('VipInfo', (_message.Message,), {
  'DESCRIPTOR' : _VIPINFO,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.VipInfo)
  })
_sym_db.RegisterMessage(VipInfo)

VipLabel = _reflection.GeneratedProtocolMessageType('VipLabel', (_message.Message,), {
  'DESCRIPTOR' : _VIPLABEL,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.VipLabel)
  })
_sym_db.RegisterMessage(VipLabel)

Weight = _reflection.GeneratedProtocolMessageType('Weight', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHT,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.Weight)
  })
_sym_db.RegisterMessage(Weight)

WeightButton = _reflection.GeneratedProtocolMessageType('WeightButton', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTBUTTON,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.WeightButton)
  })
_sym_db.RegisterMessage(WeightButton)

WeightDislike = _reflection.GeneratedProtocolMessageType('WeightDislike', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTDISLIKE,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.WeightDislike)
  })
_sym_db.RegisterMessage(WeightDislike)

WeightItem = _reflection.GeneratedProtocolMessageType('WeightItem', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTITEM,
  '__module__' : 'bilibili.app.dynamic.v2.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v2.WeightItem)
  })
_sym_db.RegisterMessage(WeightItem)

_DYNAMIC = DESCRIPTOR.services_by_name['Dynamic']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._options = None
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._serialized_options = b'8\001'
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._options = None
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._serialized_options = b'8\001'
  _ADDBUTTONBGSTYLE._serialized_start=44163
  _ADDBUTTONBGSTYLE._serialized_end=44213
  _ADDBUTTONTYPE._serialized_start=44215
  _ADDBUTTONTYPE._serialized_end=44271
  _ADDITIONVOTESTATE._serialized_start=44273
  _ADDITIONVOTESTATE._serialized_end=44383
  _ADDITIONVOTETYPE._serialized_start=44386
  _ADDITIONVOTETYPE._serialized_end=44522
  _ADDITIONALBUTTONCLICKTYPE._serialized_start=44524
  _ADDITIONALBUTTONCLICKTYPE._serialized_end=44581
  _ADDITIONALBUTTONSTATUS._serialized_start=44583
  _ADDITIONALBUTTONSTATUS._serialized_end=44641
  _ADDITIONALSHARESHOWTYPE._serialized_start=44643
  _ADDITIONALSHARESHOWTYPE._serialized_end=44694
  _ADDITIONALTYPE._serialized_start=44697
  _ADDITIONALTYPE._serialized_end=44958
  _CAMPUSTABTYPE._serialized_start=44961
  _CAMPUSTABTYPE._serialized_end=45092
  _COVERICON._serialized_start=45094
  _COVERICON._serialized_end=45147
  _DESCTYPE._serialized_start=45150
  _DESCTYPE._serialized_end=45554
  _DISABLESTATE._serialized_start=45556
  _DISABLESTATE._serialized_end=45595
  _DYNEXTENDTYPE._serialized_start=45598
  _DYNEXTENDTYPE._serialized_end=45827
  _DYNMODULETYPE._serialized_start=45830
  _DYNMODULETYPE._serialized_end=46415
  _DYNURITYPE._serialized_start=46417
  _DYNURITYPE._serialized_end=46502
  _DYNAMICTYPE._serialized_start=46505
  _DYNAMICTYPE._serialized_end=46844
  _EMOJITYPE._serialized_start=46846
  _EMOJITYPE._serialized_end=46912
  _ESPACESTYLE._serialized_start=46914
  _ESPACESTYLE._serialized_end=46937
  _FOLDTYPE._serialized_start=46939
  _FOLDTYPE._serialized_end=47048
  _FOLLOWTYPE._serialized_start=47050
  _FOLLOWTYPE._serialized_end=47096
  _HIGHLIGHTTEXTSTYLE._serialized_start=47098
  _HIGHLIGHTTEXTSTYLE._serialized_end=47155
  _IMAGESTYLE._serialized_start=47157
  _IMAGESTYLE._serialized_end=47215
  _LIGHTFROMTYPE._serialized_start=47217
  _LIGHTFROMTYPE._serialized_end=47266
  _LIVESTATE._serialized_start=47268
  _LIVESTATE._serialized_end=47328
  _LOCALICONTYPE._serialized_start=47330
  _LOCALICONTYPE._serialized_end=47390
  _MDLDYNCOMMONTYPE._serialized_start=47392
  _MDLDYNCOMMONTYPE._serialized_end=47490
  _MDLDYNDRAWTAGTYPE._serialized_start=47493
  _MDLDYNDRAWTAGTYPE._serialized_end=47653
  _MDLDYNSUBSCRIPTIONNEWSTYLE._serialized_start=47656
  _MDLDYNSUBSCRIPTIONNEWSTYLE._serialized_end=47807
  _MEDIATYPE._serialized_start=47809
  _MEDIATYPE._serialized_end=47912
  _MODULEAUTHORBADGETYPE._serialized_start=47915
  _MODULEAUTHORBADGETYPE._serialized_end=48088
  _MODULEBANNERTYPE._serialized_start=48090
  _MODULEBANNERTYPE._serialized_end=48166
  _MODULEDYNAMICTYPE._serialized_start=48169
  _MODULEDYNAMICTYPE._serialized_end=48538
  _NETWORKTYPE._serialized_start=48540
  _NETWORKTYPE._serialized_end=48634
  _RCMDTYPE._serialized_start=48636
  _RCMDTYPE._serialized_end=48682
  _REFRESH._serialized_start=48684
  _REFRESH._serialized_end=48731
  _RELATIONSTATUS._serialized_start=48734
  _RELATIONSTATUS._serialized_end=48929
  _REPOSTTYPE._serialized_start=48931
  _REPOSTTYPE._serialized_end=48979
  _RESERVERELATIONLOTTERYTYPE._serialized_start=48981
  _RESERVERELATIONLOTTERYTYPE._serialized_end=49092
  _RESERVETYPE._serialized_start=49094
  _RESERVETYPE._serialized_end=49145
  _SHOWTYPE._serialized_start=49147
  _SHOWTYPE._serialized_end=49199
  _STYLETYPE._serialized_start=49201
  _STYLETYPE._serialized_end=49277
  _TFTYPE._serialized_start=49279
  _TFTYPE._serialized_end=49356
  _THREEPOINTATTENTIONSTATUS._serialized_start=49358
  _THREEPOINTATTENTIONSTATUS._serialized_end=49425
  _THREEPOINTTYPE._serialized_start=49428
  _THREEPOINTTYPE._serialized_end=49648
  _THUMBTYPE._serialized_start=49650
  _THUMBTYPE._serialized_end=49684
  _TOPTYPE._serialized_start=49686
  _TOPTYPE._serialized_end=49725
  _USERITEMTYPE._serialized_start=49728
  _USERITEMTYPE._serialized_end=49878
  _VIDEOSUBTYPE._serialized_start=49881
  _VIDEOSUBTYPE._serialized_end=50046
  _VIDEOTYPE._serialized_start=50048
  _VIDEOTYPE._serialized_end=50154
  _VOTESTATUS._serialized_start=50156
  _VOTESTATUS._serialized_end=50195
  _WEIGHTTYPE._serialized_start=50197
  _WEIGHTTYPE._serialized_end=50263
  _ADPARAM._serialized_start=143
  _ADPARAM._serialized_end=190
  _ADDITIONCOMMON._serialized_start=193
  _ADDITIONCOMMON._serialized_end=480
  _ADDITIONESPORT._serialized_start=483
  _ADDITIONESPORT._serialized_end=670
  _ADDITIONESPORTMOBA._serialized_start=673
  _ADDITIONESPORTMOBA._serialized_end=1014
  _ADDITIONESPORTMOBASTATUS._serialized_start=1017
  _ADDITIONESPORTMOBASTATUS._serialized_end=1207
  _ADDITIONESPORTMOBASTATUSDESC._serialized_start=1209
  _ADDITIONESPORTMOBASTATUSDESC._serialized_end=1290
  _ADDITIONGOODS._serialized_start=1293
  _ADDITIONGOODS._serialized_end=1451
  _ADDITIONUP._serialized_start=1454
  _ADDITIONUP._serialized_end=1991
  _ADDITIONUGC._serialized_start=1994
  _ADDITIONUGC._serialized_end=2167
  _ADDITIONUSERINFO._serialized_start=2169
  _ADDITIONUSERINFO._serialized_end=2215
  _ADDITIONVOTE._serialized_start=2217
  _ADDITIONVOTE._serialized_end=2315
  _ADDITIONVOTE2._serialized_start=2318
  _ADDITIONVOTE2._serialized_end=2965
  _ADDITIONVOTEDEFAULE._serialized_start=2967
  _ADDITIONVOTEDEFAULE._serialized_end=3003
  _ADDITIONVOTEPIC._serialized_start=3005
  _ADDITIONVOTEPIC._serialized_end=3082
  _ADDITIONVOTEPICITEM._serialized_start=3085
  _ADDITIONVOTEPICITEM._serialized_end=3225
  _ADDITIONVOTEWORD._serialized_start=3227
  _ADDITIONVOTEWORD._serialized_end=3306
  _ADDITIONVOTEWORDITEM._serialized_start=3308
  _ADDITIONVOTEWORDITEM._serialized_end=3434
  _ADDITIONALACTSKIN._serialized_start=3436
  _ADDITIONALACTSKIN._serialized_end=3509
  _ADDITIONALBUTTON._serialized_start=3512
  _ADDITIONALBUTTON._serialized_end=3935
  _ADDITIONALBUTTONINTERACTIVE._serialized_start=3937
  _ADDITIONALBUTTONINTERACTIVE._serialized_end=4029
  _ADDITIONALBUTTONSHARE._serialized_start=4031
  _ADDITIONALBUTTONSHARE._serialized_end=4096
  _ADDITIONALBUTTONSTYLE._serialized_start=4099
  _ADDITIONALBUTTONSTYLE._serialized_end=4420
  _ADDITIONALPGC._serialized_start=4423
  _ADDITIONALPGC._serialized_end=4690
  _ALUMNIDYNAMICSREPLY._serialized_start=4692
  _ALUMNIDYNAMICSREPLY._serialized_end=4780
  _ALUMNIDYNAMICSREQ._serialized_start=4783
  _ALUMNIDYNAMICSREQ._serialized_end=4944
  _CAMPUSBANNERINFO._serialized_start=4946
  _CAMPUSBANNERINFO._serialized_end=4997
  _CAMPUSBILLBOARDREPLY._serialized_start=5000
  _CAMPUSBILLBOARDREPLY._serialized_end=5252
  _CAMPUSBILLBOARDREQ._serialized_start=5255
  _CAMPUSBILLBOARDREQ._serialized_end=5385
  _CAMPUSBILLBOARDINTERNALREQ._serialized_start=5387
  _CAMPUSBILLBOARDINTERNALREQ._serialized_end=5469
  _CAMPUSFEEDBACKINFO._serialized_start=5471
  _CAMPUSFEEDBACKINFO._serialized_end=5560
  _CAMPUSFEEDBACKREPLY._serialized_start=5562
  _CAMPUSFEEDBACKREPLY._serialized_end=5600
  _CAMPUSFEEDBACKREQ._serialized_start=5602
  _CAMPUSFEEDBACKREQ._serialized_end=5695
  _CAMPUSINFO._serialized_start=5697
  _CAMPUSINFO._serialized_end=5779
  _CAMPUSLABEL._serialized_start=5781
  _CAMPUSLABEL._serialized_end=5835
  _CAMPUSMATELIKELISTREPLY._serialized_start=5837
  _CAMPUSMATELIKELISTREPLY._serialized_end=5915
  _CAMPUSMATELIKELISTREQ._serialized_start=5917
  _CAMPUSMATELIKELISTREQ._serialized_end=5960
  _CAMPUSNOTICEINFO._serialized_start=5962
  _CAMPUSNOTICEINFO._serialized_end=6063
  _CAMPUSRCMDFEEDREPLY._serialized_start=6066
  _CAMPUSRCMDFEEDREPLY._serialized_end=6246
  _CAMPUSRCMDFEEDREQ._serialized_start=6249
  _CAMPUSRCMDFEEDREQ._serialized_end=6447
  _CAMPUSRCMDINFO._serialized_start=6449
  _CAMPUSRCMDINFO._serialized_end=6536
  _CAMPUSRCMDITEM._serialized_start=6539
  _CAMPUSRCMDITEM._serialized_end=6698
  _CAMPUSRCMDREPLY._serialized_start=6701
  _CAMPUSRCMDREPLY._serialized_end=6901
  _CAMPUSRCMDREQ._serialized_start=6904
  _CAMPUSRCMDREQ._serialized_end=7054
  _CAMPUSRCMDTOP._serialized_start=7057
  _CAMPUSRCMDTOP._serialized_end=7506
  _CAMPUSREDDOTREPLY._serialized_start=7508
  _CAMPUSREDDOTREPLY._serialized_end=7544
  _CAMPUSREDDOTREQ._serialized_start=7546
  _CAMPUSREDDOTREQ._serialized_end=7582
  _CAMPUSSHOWTABINFO._serialized_start=7584
  _CAMPUSSHOWTABINFO._serialized_end=7661
  _CAMPUSTOP._serialized_start=7664
  _CAMPUSTOP._serialized_end=8139
  _CAMPUSTOPICRCMDFEEDREPLY._serialized_start=8141
  _CAMPUSTOPICRCMDFEEDREPLY._serialized_end=8268
  _CAMPUSTOPICRCMDFEEDREQ._serialized_start=8271
  _CAMPUSTOPICRCMDFEEDREQ._serialized_end=8419
  _CARDVIDEODYNLIST._serialized_start=8422
  _CARDVIDEODYNLIST._serialized_end=8579
  _CARDVIDEOFOLLOWLIST._serialized_start=8581
  _CARDVIDEOFOLLOWLIST._serialized_end=8680
  _CARDVIDEOUPLIST._serialized_start=8683
  _CARDVIDEOUPLIST._serialized_end=8969
  _CHANNELINFO._serialized_start=8972
  _CHANNELINFO._serialized_end=9160
  _CMTSHOWITEM._serialized_start=9162
  _CMTSHOWITEM._serialized_end=9233
  _COMMENTDETAIL._serialized_start=9235
  _COMMENTDETAIL._serialized_end=9286
  _DECOCARDFAN._serialized_start=9288
  _DECOCARDFAN._serialized_end=9368
  _DECORATECARD._serialized_start=9370
  _DECORATECARD._serialized_end=9483
  _DESCRIPTION._serialized_start=9486
  _DESCRIPTION._serialized_end=9797
  _DIMENSION._serialized_start=9799
  _DIMENSION._serialized_end=9857
  _DYNADDITIONCOMMONFOLLOWREPLY._serialized_start=9859
  _DYNADDITIONCOMMONFOLLOWREPLY._serialized_end=9954
  _DYNADDITIONCOMMONFOLLOWREQ._serialized_start=9957
  _DYNADDITIONCOMMONFOLLOWREQ._serialized_end=10085
  _DYNALLPERSONALREPLY._serialized_start=10088
  _DYNALLPERSONALREPLY._serialized_end=10330
  _DYNALLPERSONALREQ._serialized_start=10333
  _DYNALLPERSONALREQ._serialized_end=10604
  _DYNALLREPLY._serialized_start=10607
  _DYNALLREPLY._serialized_end=10909
  _DYNALLREQ._serialized_start=10912
  _DYNALLREQ._serialized_end=11408
  _DYNALLUPDOFFSETREQ._serialized_start=11410
  _DYNALLUPDOFFSETREQ._serialized_end=11488
  _DYNDETAILREPLY._serialized_start=11490
  _DYNDETAILREPLY._serialized_end=11558
  _DYNDETAILREQ._serialized_start=11561
  _DYNDETAILREQ._serialized_end=11849
  _DYNDETAILSREPLY._serialized_start=11851
  _DYNDETAILSREPLY._serialized_end=11920
  _DYNDETAILSREQ._serialized_start=11923
  _DYNDETAILSREQ._serialized_end=12110
  _DYNFAKECARDREPLY._serialized_start=12112
  _DYNFAKECARDREPLY._serialized_end=12182
  _DYNFAKECARDREQ._serialized_start=12184
  _DYNFAKECARDREQ._serialized_end=12217
  _DYNLIGHTREPLY._serialized_start=12219
  _DYNLIGHTREPLY._serialized_end=12294
  _DYNLIGHTREQ._serialized_start=12297
  _DYNLIGHTREQ._serialized_end=12488
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_start=12491
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_end=12714
  _DYNMIXUPLISTVIEWMOREREQ._serialized_start=12716
  _DYNMIXUPLISTVIEWMOREREQ._serialized_end=12760
  _DYNRCMDREPLY._serialized_start=12763
  _DYNRCMDREPLY._serialized_end=12898
  _DYNRCMDREQ._serialized_start=12901
  _DYNRCMDREQ._serialized_end=13040
  _DYNRCMDUPEXCHANGEREPLY._serialized_start=13042
  _DYNRCMDUPEXCHANGEREPLY._serialized_end=13119
  _DYNRCMDUPEXCHANGEREQ._serialized_start=13121
  _DYNRCMDUPEXCHANGEREQ._serialized_end=13189
  _DYNREGIONRCMD._serialized_start=13191
  _DYNREGIONRCMD._serialized_end=13316
  _DYNREGIONRCMDITEM._serialized_start=13318
  _DYNREGIONRCMDITEM._serialized_end=13417
  _DYNSEARCHREPLY._serialized_start=13420
  _DYNSEARCHREPLY._serialized_end=13616
  _DYNSEARCHREQ._serialized_start=13619
  _DYNSEARCHREQ._serialized_end=13753
  _DYNSERVERDETAILSREPLY._serialized_start=13756
  _DYNSERVERDETAILSREPLY._serialized_end=13937
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._serialized_start=13855
  _DYNSERVERDETAILSREPLY_ITEMSENTRY._serialized_end=13937
  _DYNSERVERDETAILSREQ._serialized_start=13940
  _DYNSERVERDETAILSREQ._serialized_end=14164
  _DYNSPACEREQ._serialized_start=14167
  _DYNSPACEREQ._serialized_end=14339
  _DYNSPACERSP._serialized_start=14341
  _DYNSPACERSP._serialized_end=14448
  _DYNSPACESEARCHDETAILSREPLY._serialized_start=14451
  _DYNSPACESEARCHDETAILSREPLY._serialized_end=14642
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._serialized_start=13855
  _DYNSPACESEARCHDETAILSREPLY_ITEMSENTRY._serialized_end=13937
  _DYNSPACESEARCHDETAILSREQ._serialized_start=14645
  _DYNSPACESEARCHDETAILSREQ._serialized_end=14924
  _DYNTAB._serialized_start=14927
  _DYNTAB._serialized_end=15223
  _DYNTABREPLY._serialized_start=15225
  _DYNTABREPLY._serialized_end=15288
  _DYNTABREQ._serialized_start=15290
  _DYNTABREQ._serialized_end=15325
  _DYNTHUMBREQ._serialized_start=15327
  _DYNTHUMBREQ._serialized_end=15450
  _DYNVIDEOPERSONALREPLY._serialized_start=15453
  _DYNVIDEOPERSONALREPLY._serialized_end=15697
  _DYNVIDEOPERSONALREQ._serialized_start=15700
  _DYNVIDEOPERSONALREQ._serialized_end=15973
  _DYNVIDEOREPLY._serialized_start=15976
  _DYNVIDEOREPLY._serialized_end=16194
  _DYNVIDEOREQ._serialized_start=16197
  _DYNVIDEOREQ._serialized_end=16511
  _DYNVIDEOUPDOFFSETREQ._serialized_start=16513
  _DYNVIDEOUPDOFFSETREQ._serialized_end=16593
  _DYNVOTEREPLY._serialized_start=16595
  _DYNVOTEREPLY._serialized_end=16678
  _DYNVOTEREQ._serialized_start=16681
  _DYNVOTEREQ._serialized_end=16813
  _DYNAMICITEM._serialized_start=16816
  _DYNAMICITEM._serialized_end=17081
  _DYNAMICLIST._serialized_start=17084
  _DYNAMICLIST._serialized_end=17236
  _EXTINFOCOMMON._serialized_start=17239
  _EXTINFOCOMMON._serialized_end=17465
  _EXTINFOGAME._serialized_start=17467
  _EXTINFOGAME._serialized_end=17522
  _EXTINFOHOT._serialized_start=17524
  _EXTINFOHOT._serialized_end=17578
  _EXTINFOLBS._serialized_start=17580
  _EXTINFOLBS._serialized_end=17652
  _EXTINFOOGV._serialized_start=17654
  _EXTINFOOGV._serialized_end=17718
  _EXTINFOTOPIC._serialized_start=17720
  _EXTINFOTOPIC._serialized_end=17776
  _EXTEND._serialized_start=17779
  _EXTEND._serialized_end=18311
  _EXTENDREPLY._serialized_start=18313
  _EXTENDREPLY._serialized_end=18398
  _EXTENDREPLYPARAM._serialized_start=18400
  _EXTENDREPLYPARAM._serialized_end=18446
  _FOLLOWLISTITEM._serialized_start=18449
  _FOLLOWLISTITEM._serialized_end=18607
  _GOODSITEM._serialized_start=18610
  _GOODSITEM._serialized_end=18868
  _GUIDEBARINFO._serialized_start=18870
  _GUIDEBARINFO._serialized_end=18986
  _HIGHLIGHTTEXT._serialized_start=18988
  _HIGHLIGHTTEXT._serialized_end=19114
  _ICONBADGE._serialized_start=19116
  _ICONBADGE._serialized_end=19162
  _ICONBUTTON._serialized_start=19164
  _ICONBUTTON._serialized_end=19246
  _INFOOGV._serialized_start=19248
  _INFOOGV._serialized_end=19319
  _INTERACTIONFACE._serialized_start=19321
  _INTERACTIONFACE._serialized_end=19365
  _INTERACTIONITEM._serialized_start=19368
  _INTERACTIONITEM._serialized_end=19677
  _INTERACTIONSTAT._serialized_start=19679
  _INTERACTIONSTAT._serialized_end=19710
  _LIKEANIMATION._serialized_start=19712
  _LIKEANIMATION._serialized_end=19791
  _LIKEINFO._serialized_start=19793
  _LIKEINFO._serialized_end=19879
  _LIKELISTREPLY._serialized_start=19881
  _LIKELISTREPLY._serialized_end=19988
  _LIKELISTREQ._serialized_start=19990
  _LIKELISTREQ._serialized_end=20088
  _LIKEUSER._serialized_start=20090
  _LIKEUSER._serialized_end=20141
  _LIVEINFO._serialized_start=20143
  _LIVEINFO._serialized_end=20241
  _LIVEPENDANT._serialized_start=20243
  _LIVEPENDANT._serialized_end=20304
  _MATCHTEAM._serialized_start=20306
  _MATCHTEAM._serialized_end=20394
  _MDLDYNAPPLET._serialized_start=20397
  _MDLDYNAPPLET._serialized_end=20536
  _MDLDYNARCHIVE._serialized_start=20539
  _MDLDYNARCHIVE._serialized_end=21272
  _MDLDYNARTICLE._serialized_start=21274
  _MDLDYNARTICLE._serialized_end=21394
  _MDLDYNCOMMON._serialized_start=21397
  _MDLDYNCOMMON._serialized_end=21700
  _MDLDYNCOURBATCH._serialized_start=21703
  _MDLDYNCOURBATCH._serialized_end=21866
  _MDLDYNCOURSEASON._serialized_start=21869
  _MDLDYNCOURSEASON._serialized_end=22031
  _MDLDYNDRAW._serialized_start=22033
  _MDLDYNDRAW._serialized_end=22126
  _MDLDYNDRAWITEM._serialized_start=22129
  _MDLDYNDRAWITEM._serialized_end=22257
  _MDLDYNDRAWTAG._serialized_start=22260
  _MDLDYNDRAWTAG._serialized_end=22391
  _MDLDYNDRAWTAGITEM._serialized_start=22394
  _MDLDYNDRAWTAGITEM._serialized_end=22575
  _MDLDYNFORWARD._serialized_start=22577
  _MDLDYNFORWARD._serialized_end=22659
  _MDLDYNLIVE._serialized_start=22662
  _MDLDYNLIVE._serialized_end=22940
  _MDLDYNLIVERCMD._serialized_start=22943
  _MDLDYNLIVERCMD._serialized_end=23091
  _MDLDYNMEDIALIST._serialized_start=23094
  _MDLDYNMEDIALIST._serialized_end=23257
  _MDLDYNMUSIC._serialized_start=23259
  _MDLDYNMUSIC._serialized_end=23373
  _MDLDYNPGC._serialized_start=23376
  _MDLDYNPGC._serialized_end=24016
  _MDLDYNSUBSCRIPTION._serialized_start=24019
  _MDLDYNSUBSCRIPTION._serialized_end=24193
  _MDLDYNSUBSCRIPTIONNEW._serialized_start=24196
  _MDLDYNSUBSCRIPTIONNEW._serialized_end=24434
  _MDLDYNUGCSEASON._serialized_start=24437
  _MDLDYNUGCSEASON._serialized_end=24764
  _MIXUPLISTITEM._serialized_start=24767
  _MIXUPLISTITEM._serialized_end=25094
  _MIXUPLISTLIVEITEM._serialized_start=25096
  _MIXUPLISTLIVEITEM._serialized_end=25161
  _MODULE._serialized_start=25164
  _MODULE._serialized_end=26975
  _MODULEAD._serialized_start=26978
  _MODULEAD._serialized_end=27199
  _MODULEADDITIONAL._serialized_start=27202
  _MODULEADDITIONAL._serialized_end=27771
  _MODULEAUTHOR._serialized_start=27774
  _MODULEAUTHOR._serialized_end=28306
  _MODULEAUTHORBADGEBUTTON._serialized_start=28308
  _MODULEAUTHORBADGEBUTTON._serialized_end=28389
  _MODULEAUTHORFORWARD._serialized_start=28392
  _MODULEAUTHORFORWARD._serialized_end=28681
  _MODULEAUTHORFORWARDTITLE._serialized_start=28683
  _MODULEAUTHORFORWARDTITLE._serialized_end=28736
  _MODULEBANNER._serialized_start=28739
  _MODULEBANNER._serialized_end=28936
  _MODULEBANNERUSER._serialized_start=28938
  _MODULEBANNERUSER._serialized_end=29017
  _MODULEBANNERUSERITEM._serialized_start=29020
  _MODULEBANNERUSERITEM._serialized_end=29332
  _MODULEBUTTOM._serialized_start=29334
  _MODULEBUTTOM._serialized_end=29406
  _MODULECOMMENT._serialized_start=29408
  _MODULECOMMENT._serialized_end=29482
  _MODULEDESC._serialized_start=29484
  _MODULEDESC._serialized_end=29580
  _MODULEDESCGOODS._serialized_start=29583
  _MODULEDESCGOODS._serialized_end=29768
  _MODULEDISPUTE._serialized_start=29770
  _MODULEDISPUTE._serialized_end=29827
  _MODULEDYNAMIC._serialized_start=29830
  _MODULEDYNAMIC._serialized_end=30956
  _MODULEEXTEND._serialized_start=30958
  _MODULEEXTEND._serialized_end=31044
  _MODULEEXTENDITEM._serialized_start=31047
  _MODULEEXTENDITEM._serialized_end=31507
  _MODULEFOLD._serialized_start=31510
  _MODULEFOLD._serialized_end=31663
  _MODULEINTERACTION._serialized_start=31665
  _MODULEINTERACTION._serialized_end=31752
  _MODULEITEMNULL._serialized_start=31754
  _MODULEITEMNULL._serialized_end=31798
  _MODULELIKEUSER._serialized_start=31800
  _MODULELIKEUSER._serialized_end=31893
  _MODULERCMD._serialized_start=31896
  _MODULERCMD._serialized_end=32032
  _MODULERECOMMEND._serialized_start=32035
  _MODULERECOMMEND._serialized_end=32169
  _MODULESHAREINFO._serialized_start=32172
  _MODULESHAREINFO._serialized_end=32315
  _MODULESTAT._serialized_start=32318
  _MODULESTAT._serialized_end=32538
  _MODULESTORY._serialized_start=32541
  _MODULESTORY._serialized_end=32721
  _MODULETITLE._serialized_start=32723
  _MODULETITLE._serialized_end=32807
  _MODULETOP._serialized_start=32809
  _MODULETOP._serialized_end=32878
  _MODULETOPTAG._serialized_start=32880
  _MODULETOPTAG._serialized_end=32912
  _MODULETOPIC._serialized_start=32914
  _MODULETOPIC._serialized_end=32966
  _MODULETOPICBRIEF._serialized_start=32968
  _MODULETOPICBRIEF._serialized_end=33037
  _MODULETOPICDETAILSEXT._serialized_start=33039
  _MODULETOPICDETAILSEXT._serialized_end=33085
  _NAMEPLATE._serialized_start=33087
  _NAMEPLATE._serialized_end=33195
  _NEWEP._serialized_start=33197
  _NEWEP._serialized_end=33251
  _NOREPLY._serialized_start=33253
  _NOREPLY._serialized_end=33262
  _NOREQ._serialized_start=33264
  _NOREQ._serialized_end=33271
  _OFFICIALACCOUNTINFO._serialized_start=33274
  _OFFICIALACCOUNTINFO._serialized_end=33465
  _OFFICIALACCOUNTSREPLY._serialized_start=33467
  _OFFICIALACCOUNTSREPLY._serialized_end=33585
  _OFFICIALACCOUNTSREQ._serialized_start=33587
  _OFFICIALACCOUNTSREQ._serialized_end=33664
  _OFFICIALDYNAMICSREPLY._serialized_start=33667
  _OFFICIALDYNAMICSREPLY._serialized_end=33847
  _OFFICIALDYNAMICSREQ._serialized_start=33849
  _OFFICIALDYNAMICSREQ._serialized_end=33926
  _OFFICIALITEM._serialized_start=33929
  _OFFICIALITEM._serialized_end=34110
  _OFFICIALRCMDARCHIVE._serialized_start=34113
  _OFFICIALRCMDARCHIVE._serialized_end=34398
  _OFFICIALRCMDDYNAMIC._serialized_start=34401
  _OFFICIALRCMDDYNAMIC._serialized_end=34656
  _OFFICIALVERIFY._serialized_start=34658
  _OFFICIALVERIFY._serialized_end=34720
  _PGCSEASON._serialized_start=34722
  _PGCSEASON._serialized_end=34781
  _PLAYURLPARAM._serialized_start=34783
  _PLAYURLPARAM._serialized_end=34874
  _POPUP._serialized_start=34876
  _POPUP._serialized_end=34925
  _RCMDARCHIVE._serialized_start=34928
  _RCMDARCHIVE._serialized_end=35258
  _RCMDAUTHOR._serialized_start=35261
  _RCMDAUTHOR._serialized_end=35391
  _RCMDITEM._serialized_start=35394
  _RCMDITEM._serialized_end=35528
  _RCMDOPTION._serialized_start=35530
  _RCMDOPTION._serialized_end=35562
  _RCMDTOPBUTTON._serialized_start=35564
  _RCMDTOPBUTTON._serialized_end=35606
  _RCMDUPSPARAM._serialized_start=35608
  _RCMDUPSPARAM._serialized_end=35642
  _RELATION._serialized_start=35644
  _RELATION._serialized_end=35766
  _REPOSTLISTREQ._serialized_start=35769
  _REPOSTLISTREQ._serialized_end=35923
  _REPOSTLISTRSP._serialized_start=35926
  _REPOSTLISTRSP._serialized_end=36106
  _SCHOOLRECOMMENDREPLY._serialized_start=36108
  _SCHOOLRECOMMENDREPLY._serialized_end=36182
  _SCHOOLRECOMMENDREQ._serialized_start=36184
  _SCHOOLRECOMMENDREQ._serialized_end=36230
  _SCHOOLSEARCHREPLY._serialized_start=36232
  _SCHOOLSEARCHREPLY._serialized_end=36356
  _SCHOOLSEARCHREQ._serialized_start=36358
  _SCHOOLSEARCHREQ._serialized_end=36392
  _SEARCHCHANNEL._serialized_start=36395
  _SEARCHCHANNEL._serialized_end=36546
  _SEARCHINFO._serialized_start=36549
  _SEARCHINFO._serialized_end=36696
  _SEARCHTOAST._serialized_start=36698
  _SEARCHTOAST._serialized_end=36751
  _SEARCHTOPIC._serialized_start=36754
  _SEARCHTOPIC._serialized_end=36904
  _SEARCHTOPICBUTTON._serialized_start=36906
  _SEARCHTOPICBUTTON._serialized_end=36958
  _SEARCHTOPICITEM._serialized_start=36960
  _SEARCHTOPICITEM._serialized_end=37063
  _SETDECISIONREQ._serialized_start=37065
  _SETDECISIONREQ._serialized_end=37097
  _SETRECENTCAMPUSREQ._serialized_start=37099
  _SETRECENTCAMPUSREQ._serialized_end=37159
  _SHARECHANNEL._serialized_start=37161
  _SHARECHANNEL._serialized_end=37277
  _SHARERESERVE._serialized_start=37280
  _SHARERESERVE._serialized_end=37450
  _SORTTYPE._serialized_start=37452
  _SORTTYPE._serialized_end=37505
  _STORYARCHIVE._serialized_start=37507
  _STORYARCHIVE._serialized_end=37617
  _STORYITEM._serialized_start=37620
  _STORYITEM._serialized_end=37803
  _SUBSCRIBECAMPUSREQ._serialized_start=37805
  _SUBSCRIBECAMPUSREQ._serialized_end=37865
  _THREEPOINTATTENTION._serialized_start=37868
  _THREEPOINTATTENTION._serialized_end=38061
  _THREEPOINTAUTOPLAY._serialized_start=38064
  _THREEPOINTAUTOPLAY._serialized_end=38290
  _THREEPOINTCOMMENT._serialized_start=38293
  _THREEPOINTCOMMENT._serialized_end=38461
  _THREEPOINTDEFAULT._serialized_start=38464
  _THREEPOINTDEFAULT._serialized_end=38601
  _THREEPOINTDEFAULTTOAST._serialized_start=38603
  _THREEPOINTDEFAULTTOAST._serialized_end=38656
  _THREEPOINTDISLIKE._serialized_start=38658
  _THREEPOINTDISLIKE._serialized_end=38706
  _THREEPOINTFAVORITE._serialized_start=38708
  _THREEPOINTFAVORITE._serialized_end=38834
  _THREEPOINTHIDE._serialized_start=38837
  _THREEPOINTHIDE._serialized_end=38994
  _THREEPOINTHIDEINTERACTIVE._serialized_start=38996
  _THREEPOINTHIDEINTERACTIVE._serialized_end=39086
  _THREEPOINTITEM._serialized_start=39089
  _THREEPOINTITEM._serialized_end=39865
  _THREEPOINTSHARE._serialized_start=39868
  _THREEPOINTSHARE._serialized_end=40058
  _THREEPOINTSHARECHANNEL._serialized_start=40060
  _THREEPOINTSHARECHANNEL._serialized_end=40113
  _THREEPOINTTOP._serialized_start=40115
  _THREEPOINTTOP._serialized_end=40207
  _THREEPOINTTOPICIRRELEVANT._serialized_start=40210
  _THREEPOINTTOPICIRRELEVANT._serialized_end=40349
  _THREEPOINTWAIT._serialized_start=40351
  _THREEPOINTWAIT._serialized_end=40477
  _TOPADDITIONUP._serialized_start=40479
  _TOPADDITIONUP._serialized_end=40561
  _TOPICBUTTON._serialized_start=40563
  _TOPICBUTTON._serialized_end=40640
  _TOPICITEM._serialized_start=40642
  _TOPICITEM._serialized_end=40752
  _TOPICLIST._serialized_start=40755
  _TOPICLIST._serialized_end=40984
  _TOPICLISTITEM._serialized_start=40987
  _TOPICLISTITEM._serialized_end=41202
  _TOPICLISTREPLY._serialized_start=41204
  _TOPICLISTREPLY._serialized_end=41305
  _TOPICLISTREQ._serialized_start=41307
  _TOPICLISTREQ._serialized_end=41356
  _TOPICRCMDCARD._serialized_start=41359
  _TOPICRCMDCARD._serialized_end=41530
  _TOPICSQUAREINFO._serialized_start=41533
  _TOPICSQUAREINFO._serialized_end=41673
  _TOPICSQUAREREPLY._serialized_start=41675
  _TOPICSQUAREREPLY._serialized_end=41749
  _TOPICSQUAREREQ._serialized_start=41751
  _TOPICSQUAREREQ._serialized_end=41786
  _UNFOLLOW._serialized_start=41788
  _UNFOLLOW._serialized_end=41887
  _UNFOLLOWUSERITEM._serialized_start=41890
  _UNFOLLOWUSERITEM._serialized_end=42245
  _UPLISTITEM._serialized_start=42248
  _UPLISTITEM._serialized_end=42658
  _UPLISTMORELABEL._serialized_start=42660
  _UPLISTMORELABEL._serialized_end=42705
  _USERINFO._serialized_start=42708
  _USERINFO._serialized_end=43106
  _USERITEMSTYLE._serialized_start=43108
  _USERITEMSTYLE._serialized_end=43234
  _USERPENDANT._serialized_start=43236
  _USERPENDANT._serialized_end=43307
  _VIDEOBADGE._serialized_start=43310
  _VIDEOBADGE._serialized_end=43534
  _VIPINFO._serialized_start=43537
  _VIPINFO._serialized_end=43714
  _VIPLABEL._serialized_start=43716
  _VIPLABEL._serialized_end=43775
  _WEIGHT._serialized_start=43777
  _WEIGHT._serialized_end=43866
  _WEIGHTBUTTON._serialized_start=43868
  _WEIGHTBUTTON._serialized_end=43915
  _WEIGHTDISLIKE._serialized_start=43917
  _WEIGHTDISLIKE._serialized_end=43971
  _WEIGHTITEM._serialized_start=43974
  _WEIGHTITEM._serialized_end=44161
  _DYNAMIC._serialized_start=50266
  _DYNAMIC._serialized_end=54507
# @@protoc_insertion_point(module_scope)
